@@ -33,7 +33,7 @@ class FloatType;
 class IntType;
 class StrType;
 class VarLenType;
-class H5_DLLCPP AbstractDs : public H5Object {
+class H5_DLLCPP AbstractDs {
    public:
 	// Gets a copy the datatype of that this abstract dataset uses.
 	// Note that this datatype is a generic one and can only be accessed
@@ -51,6 +51,9 @@ class H5_DLLCPP AbstractDs : public H5Object {
 	StrType getStrType() const;
 	VarLenType getVarLenType() const;
 
+	// Gets the size in memory of this abstract dataset.
+	virtual size_t getInMemDataSize() const = 0;
+
 	// Gets the dataspace of this abstract dataset - pure virtual.
 	virtual DataSpace getSpace() const = 0;
 
@@ -62,6 +65,9 @@ class H5_DLLCPP AbstractDs : public H5Object {
 	// dataset - pure virtual.
 	virtual hsize_t getStorageSize() const = 0;
 
+	// Returns this class name - pure virtual.
+	virtual H5std_string fromClass() const = 0;
+
 	// Copy constructor
 	AbstractDs( const AbstractDs& original );
 
@@ -76,7 +82,7 @@ class H5_DLLCPP AbstractDs : public H5Object {
 	AbstractDs( const hid_t ds_id );
 
    private:
-	// This member function is implemented by DataSet and Attribute.
+	// This member function is implemented by DataSet and Attribute - pure virtual.
 	virtual hid_t p_get_type() const = 0;
 };
 #ifndef H5_NO_NAMESPACE
