@@ -38,10 +38,10 @@ class H5_DLLCPP Attribute : public AbstractDs, public IdComponent {
 	virtual DataSpace getSpace() const;
 
 	// Returns the amount of storage size required for this attribute.
-	hsize_t getStorageSize() const;
+	virtual hsize_t getStorageSize() const;
 
 	// Returns the in memory size of this attribute's data.
-	size_t getInMemDataSize() const;
+	virtual size_t getInMemDataSize() const;
 
 	// Reads data from this attribute.
 	void read( const DataType& mem_type, void *buf ) const;
@@ -51,6 +51,10 @@ class H5_DLLCPP Attribute : public AbstractDs, public IdComponent {
 	void write(const DataType& mem_type, const void *buf ) const;
 	void write(const DataType& mem_type, const H5std_string& strg ) const;
 
+	// Flushes all buffers associated with the file specified by this
+	// attribute to disk.
+	void flush( H5F_scope_t scope ) const;
+
 	///\brief Returns this class name
 	virtual H5std_string fromClass () const { return("Attribute"); }
 
@@ -82,6 +86,10 @@ class H5_DLLCPP Attribute : public AbstractDs, public IdComponent {
 	// sub-types
 	virtual hid_t p_get_type() const;
 
+	// Reads variable or fixed len strings from this attribute.
+	void p_read_variable_len(const DataType& mem_type, H5std_string& strg) const;
+	void p_read_fixed_len(const DataType& mem_type, H5std_string& strg) const;
+
 	// do not inherit H5Object::iterateAttrs
 	int iterateAttrs() { return 0; }
 
