@@ -265,43 +265,6 @@ void DSetMemXferPropList::getVlenMemManager( H5MM_allocate_t& alloc_func, void**
    }
 }
 
-//--------------------------------------------------------------------------
-// Function:	DSetMemXferPropList::setMulti
-///\brief	Sets the data transfer property list for the multi-file driver.
-///\param	memb_dxpl - OUT: Array of data access property lists
-///\exception	H5::PropListIException
-///\par Description
-///		This function can only be used after the member map has
-///		been set with FileAccPropList::setMulti (not done - BMR.)
-// Programmer:	Binh-Minh Ribler - April, 2004
-//--------------------------------------------------------------------------
-void DSetMemXferPropList::setMulti(const hid_t *memb_dxpl)
-{
-   herr_t ret_value = H5Pset_dxpl_multi(id, memb_dxpl);
-   if (ret_value < 0)
-   {
-      throw PropListIException("DSetMemXferPropList::setMulti",
-		"H5Pset_dxpl_multi failed");
-   }
-}
-
-//--------------------------------------------------------------------------
-// Function:	DSetMemXferPropList::getMulti
-///\brief	Returns multi-file data transfer property list information.
-///\param	memb_dxpl - OUT: Array of data access property lists
-///\exception	H5::PropListIException
-// Programmer:	Binh-Minh Ribler - April, 2004
-//--------------------------------------------------------------------------
-void DSetMemXferPropList::getMulti(hid_t *memb_dxpl)
-{
-   herr_t ret_value = H5Pget_dxpl_multi(id, memb_dxpl);
-   if (ret_value < 0)
-   {
-      throw PropListIException("DSetMemXferPropList::getMulti",
-		"H5Pget_dxpl_multi failed");
-   }
-}
-
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::setSmallDataBlockSize
 ///\brief	Sets the size of a contiguous block reserved for small data.
@@ -309,7 +272,7 @@ void DSetMemXferPropList::getMulti(hid_t *memb_dxpl)
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For detail, please refer to the C layer Reference Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetSmallData
+/// http://www.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetSmallData
 // Programmer:	Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void DSetMemXferPropList::setSmallDataBlockSize(hsize_t size)
@@ -349,7 +312,7 @@ hsize_t DSetMemXferPropList::getSmallDataBlockSize()
 ///\par Description
 ///		For information, please refer to the C layer Reference
 ///		Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetHyperVectorSize
+/// http://www.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetHyperVectorSize
 // Programmer:	Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void DSetMemXferPropList::setHyperVectorSize(size_t vector_size)
