@@ -22,7 +22,7 @@
 namespace H5 {
 #endif
 
-const H5std_string Exception::DEFAULT_MSG("No detailed information provided");
+const char Exception::DEFAULT_MSG[] = "No detailed information provided";
 
 //--------------------------------------------------------------------------
 // Function:	Exception default constructor
@@ -252,7 +252,7 @@ void Exception::walkErrorStack( H5E_direction_t direction, H5E_walk2_t func, voi
 // Function:	Exception::getDetailMsg
 ///\brief	Returns the detailed message set at the time the exception
 ///		is thrown.
-///\return	Text message - \c std::string
+///\return	Text message - \c H5std_string
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5std_string Exception::getDetailMsg() const
@@ -275,7 +275,7 @@ const char* Exception::getCDetailMsg() const
 //--------------------------------------------------------------------------
 // Function:	Exception::getFuncName
 ///\brief	Returns the name of the function, where the exception is thrown.
-///\return	Text message - \c std::string
+///\return	Text message - \c H5std_string
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5std_string Exception::getFuncName() const
