@@ -79,18 +79,12 @@ class H5_DLLCPP Exception {
 	virtual ~Exception();
 
    private:
-// Because 'string' is not instantiated at compilation time, this
-// warning is displayed when building DLL; but the class is exported
-// so the warning is harmless
-#if defined(_WIN32)
-#pragma warning(disable: 4251)
-#endif
 	H5std_string detail_message;
 	H5std_string func_name;
 
    protected:
         // Default value for detail_message
-        static const H5std_string DEFAULT_MSG;
+        static const char DEFAULT_MSG[];
 };
 
 class H5_DLLCPP FileIException : public Exception {
