@@ -50,7 +50,7 @@ namespace H5 {
 ///\brief	Default constructor: creates a stub H5File object.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5File::H5File() : IdComponent(0) {}
+H5File::H5File() : IdComponent(), id(0) {}
 
 //--------------------------------------------------------------------------
 // Function:	H5File overloaded constructor
@@ -61,7 +61,7 @@ H5File::H5File() : IdComponent(0) {}
 ///		modifying default file meta-data.  Default to
 ///		FileCreatPropList::DEFAULT
 ///\param	access_plist - IN: File access property list.  Default to
-///		FileCreatPropList::DEFAULT
+///		FileAccPropList::DEFAULT
 ///\par Description
 ///		Valid values of \a flags include:
 ///		\li \c H5F_ACC_TRUNC - Truncate file, if it already exists,
@@ -76,30 +76,44 @@ H5File::H5File() : IdComponent(0) {}
 ///		For info on file creation in the case of an already-open file,
 ///		please refer to the \b Special \b case section in the C layer
 ///		Reference Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5F.html#File-Create
+/// http://www.hdfgroup.org/HDF5/doc/RM/RM_H5F.html#File-Create
+// Notes	With a PGI compiler (~2012-2013), the exception thrown by p_get_file
+//		could not be caught in the applications.  Added try block here
+//		to catch then re-throw it. -BMR 2013/03/21
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5File::H5File( const char* name, unsigned int flags, const FileCreatPropList& create_plist, const FileAccPropList& access_plist ) : IdComponent(0)
 {
-   p_get_file(name, flags, create_plist, access_plist);
+    try {
+	p_get_file(name, flags, create_plist, access_plist);
+    } catch (FileIException open_file) {
+	throw open_file;
+    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	H5File overloaded constructor
 ///\brief	This is another overloaded constructor.  It differs from the
 ///		above constructor only in the type of the \a name argument.
-///\param	name - IN: Name of the file - \c std::string
+///\param	name - IN: Name of the file - \c H5std_string
 ///\param	flags - IN: File access flags
 ///\param	create_plist - IN: File creation property list, used when
 ///		modifying default file meta-data.  Default to
 ///		FileCreatPropList::DEFAULT
 ///\param	access_plist - IN: File access property list.  Default to
-///		FileCreatPropList::DEFAULT
+///		FileAccPropList::DEFAULT
+// Notes	With a PGI compiler (~2012-2013), the exception thrown by p_get_file
+//		could not be caught in the applications.  Added try block here
+//		to catch then re-throw it. -BMR 2013/03/21
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 H5File::H5File( const H5std_string& name, unsigned int flags, const FileCreatPropList& create_plist, const FileAccPropList& access_plist ) : IdComponent(0)
 {
-   p_get_file(name.c_str(), flags, create_plist, access_plist);
+    try {
+	p_get_file(name.c_str(), flags, create_plist, access_plist);
+    } catch (FileIException open_file) {
+	throw open_file;
+    }
 }
 
 //--------------------------------------------------------------------------
@@ -140,7 +154,11 @@ void H5File::p_get_file(const char* name, unsigned int flags, const FileCreatPro
 ///\param	original - IN: H5File instance to copy
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5File::H5File( const H5File& original ) : IdComponent( original ) {}
+H5File::H5File(const H5File& original) : IdComponent(original)
+{
+    id = original.getId();
+    incRefCount(); // increment number of references to this id
+}
 
 //--------------------------------------------------------------------------
 // Function:	H5File::flush
@@ -162,7 +180,7 @@ void H5File::flush(H5F_scope_t scope) const
 }
 
 //--------------------------------------------------------------------------
-// Function:	H5File::isHdf5
+// Function:	H5File::isHdf5 (static)
 ///\brief	Determines whether a file in HDF5 format.
 ///\param	name - IN: Name of the file
 ///\return	true if the file is in HDF5 format, and false, otherwise
@@ -185,10 +203,10 @@ bool H5File::isHdf5(const char* name)
 }
 
 //--------------------------------------------------------------------------
-// Function:	H5File::isHdf5
+// Function:	H5File::isHdf5 (static)
 ///\brief	This is an overloaded member function, provided for convenience.
-///		It takes an \c std::string for \a name.
-///\param	name - IN: Name of the file - \c std::string
+///		It takes an \c H5std_string for \a name.
+///\param	name - IN: Name of the file - \c H5std_string
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 bool H5File::isHdf5(const H5std_string& name )
@@ -227,8 +245,8 @@ void H5File::openFile(const char* name, unsigned int flags, const FileAccPropLis
 //--------------------------------------------------------------------------
 // Function:	H5File::openFile
 ///\brief	This is an overloaded member function, provided for convenience.
-///		It takes an \c std::string for \a name.
-///\param	name         - IN: Name of the file - \c std::string
+///		It takes an \c H5std_string for \a name.
+///\param	name         - IN: Name of the file - \c H5std_string
 ///\param	flags        - IN: File access flags
 ///\param	access_plist - IN: File access property list.  Default to
 ///		FileAccPropList::DEFAULT
@@ -374,9 +392,9 @@ hssize_t H5File::getFreeSpace() const
 /// Multiple object types can be combined with the logical OR operator (|).
 // Programmer   Binh-Minh Ribler - May 2004
 //--------------------------------------------------------------------------
-int H5File::getObjCount(unsigned types) const
+ssize_t H5File::getObjCount(unsigned types) const
 {
-   int num_objs = H5Fget_obj_count(id, types);
+   ssize_t num_objs = H5Fget_obj_count(id, types);
    if( num_objs < 0 )
    {
       throw FileIException("H5File::getObjCount", "H5Fget_obj_count failed");
@@ -393,9 +411,9 @@ int H5File::getObjCount(unsigned types) const
 ///\exception	H5::FileIException
 // Programmer   Binh-Minh Ribler - May 2004
 //--------------------------------------------------------------------------
-int H5File::getObjCount() const
+ssize_t H5File::getObjCount() const
 {
-   int num_objs = H5Fget_obj_count(id, H5F_OBJ_ALL);
+   ssize_t num_objs = H5Fget_obj_count(id, H5F_OBJ_ALL);
    if( num_objs < 0 )
    {
       throw FileIException("H5File::getObjCount", "H5Fget_obj_count failed");
@@ -428,9 +446,9 @@ int H5File::getObjCount() const
 // Notes: will do the overload for this one after hearing from Quincey???
 // Programmer   Binh-Minh Ribler - May 2004
 //--------------------------------------------------------------------------
-void H5File::getObjIDs(unsigned types, int max_objs, hid_t *oid_list) const
+void H5File::getObjIDs(unsigned types, size_t max_objs, hid_t *oid_list) const
 {
-   herr_t ret_value = H5Fget_obj_ids(id, types, max_objs, oid_list);
+   ssize_t ret_value = H5Fget_obj_ids(id, types, max_objs, oid_list);
    if( ret_value < 0 )
    {
       throw FileIException("H5File::getObjIDs", "H5Fget_obj_ids failed");
@@ -502,60 +520,14 @@ H5std_string H5File::getFileName() const
    }
 }
 
-//--------------------------------------------------------------------------
-// Function:	H5File::Reference
-///\brief	Important!!! - This functions does not work correctly, it 
-///		will be removed in the near future.  Please use 
-///		H5File::reference instead!
-// Programmer	Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void* H5File::Reference(const char* name, DataSpace& dataspace, H5R_type_t ref_type) const
-{
-   try {
-      return(p_reference(name, dataspace.getId(), ref_type));
-   }
-   catch (IdComponentException E) {
-      throw FileIException("H5File::Reference", E.getDetailMsg());
-   }
-}
-
-//--------------------------------------------------------------------------
-// Function:	H5File::Reference
-///\brief	Important!!! - This functions does not work correctly, it 
-///		will be removed in the near future.  Please use similar
-///		H5File::reference instead!
-// Programmer	Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void* H5File::Reference(const char* name) const
-{
-   try {
-      return(p_reference(name, -1, H5R_OBJECT));
-   }
-   catch (IdComponentException E) {
-      throw FileIException("H5File::Reference", E.getDetailMsg());
-   }
-}
-
-//--------------------------------------------------------------------------
-// Function:	H5File::Reference
-///\brief	Important!!! - This functions does not work correctly, it 
-///		will be removed in the near future.  Please use similar
-///		H5File::reference instead!
-// Programmer	Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void* H5File::Reference(const H5std_string& name) const
-{
-   return(Reference(name.c_str()));
-}
-
 #ifndef H5_NO_DEPRECATED_SYMBOLS
 //--------------------------------------------------------------------------
 // Function:	H5File::getObjType
 ///\brief	Retrieves the type of object that an object reference points to.
 ///\param	ref      - IN: Reference to query
 ///\param	ref_type - IN: Type of reference, valid values are:
-///		\li \c H5R_OBJECT \tReference is an object reference.
-///		\li \c H5R_DATASET_REGION \tReference is a dataset region reference.
+///		\li \c H5R_OBJECT         - Reference is an object reference
+///		\li \c H5R_DATASET_REGION - Reference is a dataset region reference
 ///\return	Object type, which can be one of the following:
 ///		\li \c H5G_LINK    - Object is a symbolic link.
 ///		\li \c H5G_GROUP   - Object is a group.
@@ -616,6 +588,134 @@ hsize_t H5File::getFileSize() const
    return (file_size);
 }
 
+//--------------------------------------------------------------------------
+// Function:    H5File::p_reference (protected)
+// Purpose      Creates a reference to an HDF5 object or a dataset region.
+// Parameters
+//              name - IN: Name of the object to be referenced
+//              dataspace - IN: Dataspace with selection
+//              ref_type - IN: Type of reference; default to \c H5R_DATASET_REGION
+// Exception    H5::IdComponentException
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void H5File::p_reference(void* ref, const char* name, hid_t space_id, H5R_type_t ref_type) const
+{
+   herr_t ret_value = H5Rcreate(ref, getId(), name, ref_type, space_id);
+   if (ret_value < 0)
+   {
+      throw IdComponentException("", "H5Rcreate failed");
+   }
+}
+
+//--------------------------------------------------------------------------
+// Function:    H5File::reference
+///\brief       Creates a reference to an HDF5 object or a dataset region.
+///\param       ref - IN: Reference pointer
+///\param       name - IN: Name of the object to be referenced
+///\param       dataspace - IN: Dataspace with selection
+///\param       ref_type - IN: Type of reference to query, valid values are:
+///             \li \c H5R_OBJECT         - Reference is an object reference
+///             \li \c H5R_DATASET_REGION - Reference is a dataset region
+///                     reference - this is the default
+///\exception   H5::IdComponentException
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void H5File::reference(void* ref, const char* name, const DataSpace& dataspace, H5R_type_t ref_type) const
+{
+   try {
+      p_reference(ref, name, dataspace.getId(), ref_type);
+   }
+   catch (IdComponentException E) {
+      throw IdComponentException("H5File::reference", E.getDetailMsg());
+   }
+}
+
+//--------------------------------------------------------------------------
+// Function:    H5File::reference
+///\brief       This is an overloaded function, provided for your convenience.
+///             It differs from the above function in that it only creates
+///             a reference to an HDF5 object, not to a dataset region.
+///\param       ref - IN: Reference pointer
+///\param       name - IN: Name of the object to be referenced - \c char pointer
+///\exception   H5::IdComponentException
+///\par Description
+//              This function passes H5R_OBJECT and -1 to the protected
+//              function for it to pass to the C API H5Rcreate
+//              to create a reference to the named object.
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void H5File::reference(void* ref, const char* name) const
+{
+   try {
+      p_reference(ref, name, -1, H5R_OBJECT);
+   }
+   catch (IdComponentException E) {
+      throw IdComponentException("H5File::reference", E.getDetailMsg());
+   }
+}
+//--------------------------------------------------------------------------
+// Function:    H5File::reference
+///\brief       This is an overloaded function, provided for your convenience.
+///             It differs from the above function in that it takes an
+///             \c H5std_string for the object's name.
+///\param       ref - IN: Reference pointer
+///\param       name - IN: Name of the object to be referenced - \c H5std_string
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void H5File::reference(void* ref, const H5std_string& name) const
+{
+   reference(ref, name.c_str());
+}
+
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+//--------------------------------------------------------------------------
+// Function:    H5File::p_get_obj_type (protected)
+// Purpose      Retrieves the type of object that an object reference points to.
+// Parameters
+//              ref      - IN: Reference to query
+//              ref_type - IN: Type of reference to query
+// Return       An object type, which can be one of the following:
+//                      H5G_LINK Object is a symbolic link.
+//                      H5G_GROUP Object is a group.
+//                      H5G_DATASET   Object is a dataset.
+//                      H5G_TYPE Object is a named datatype
+// Exception    H5::IdComponentException
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+H5G_obj_t H5File::p_get_obj_type(void *ref, H5R_type_t ref_type) const
+{
+   H5G_obj_t obj_type = H5Rget_obj_type1(getId(), ref_type, ref);
+
+   if (obj_type == H5G_UNKNOWN)
+   {
+      throw IdComponentException("", "H5Rget_obj_type failed");
+   }
+   return(obj_type);
+}
+#endif /* H5_NO_DEPRECATED_SYMBOLS */
+
+
+//--------------------------------------------------------------------------
+// Function:    H5File::p_get_region (protected)
+// Purpose      Retrieves a dataspace with the region pointed to selected.
+// Parameters
+//              ref_type - IN: Type of reference to get region of - default
+//                              to H5R_DATASET_REGION
+//              ref      - IN: Reference to get region of
+// Return       Dataspace id
+// Exception    H5::IdComponentException
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+hid_t H5File::p_get_region(void *ref, H5R_type_t ref_type) const
+{
+   hid_t space_id = H5Rget_region(getId(), ref_type, ref);
+   if (space_id < 0)
+   {
+      throw IdComponentException("", "H5Rget_region failed");
+   }
+   return(space_id);
+}
+
 //--------------------------------------------------------------------------
 // Function:	H5File::getLocId
 // Purpose:	Get the id of this file
@@ -629,6 +729,47 @@ hid_t H5File::getLocId() const
    return( getId() );
 }
 
+//--------------------------------------------------------------------------
+// Function:    H5File::getId
+// Purpose:     Get the id of this attribute
+// Modification:
+//      May 2008 - BMR
+//              Class hierarchy is revised to address bugzilla 1068.  Class
+//              AbstractDS and Attribute are moved out of H5Object.  In
+//              addition, member IdComponent::id is moved into subclasses, and
+//              IdComponent::getId now becomes pure virtual function.
+// Programmer   Binh-Minh Ribler - May, 2008
+//--------------------------------------------------------------------------
+hid_t H5File::getId() const
+{
+   return(id);
+}
+
+//--------------------------------------------------------------------------
+// Function:    H5File::p_setId
+///\brief       Sets the identifier of this object to a new value.
+///
+///\exception   H5::IdComponentException when the attempt to close the HDF5
+///             object fails
+// Description:
+//              The underlaying reference counting in the C library ensures
+//              that the current valid id of this object is properly closed.
+//              Then the object's id is reset to the new id.
+// Programmer   Binh-Minh Ribler - 2000
+//--------------------------------------------------------------------------
+void H5File::p_setId(const hid_t new_id)
+{
+    // handling references to this old id
+    try {
+        close();
+    }
+    catch (Exception E) {
+        throw FileIException("H5File::p_setId", E.getDetailMsg());
+    }
+   // reset object's id to the given id
+   id = new_id;
+}
+
 //--------------------------------------------------------------------------
 // Function:	H5File::close
 ///\brief	Closes this HDF5 file.
@@ -645,7 +786,7 @@ void H5File::close()
 	{
 	    throw FileIException("H5File::close", "H5Fclose failed");
 	}
-	// reset the id because the file that it represents is now closed
+	// reset the id
 	id = 0;
     }
 }
@@ -685,8 +826,7 @@ H5File::~H5File()
 {
     try {
 	close();
-    }
-    catch (Exception close_error) {
+    } catch (Exception close_error) {
 	cerr << "H5File::~H5File - " << close_error.getDetailMsg() << endl;
     }
 }
