@@ -13,10 +13,11 @@
  * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifdef H5_VMS
+#ifdef OLD_HEADER_FILENAME
+#include <iostream.h>
+#else
 #include <iostream>
-#endif /*H5_VMS*/
-
+#endif
 #include <string>
 
 #include "H5Include.h"
@@ -36,7 +37,7 @@ namespace H5 {
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-IdComponent::IdComponent(const hid_t h5_id) : id(h5_id) {}
+IdComponent::IdComponent(const hid_t h5_id) {}
 
 //--------------------------------------------------------------------------
 // Function:	IdComponent copy constructor
@@ -44,11 +45,7 @@ IdComponent::IdComponent(const hid_t h5_id) : id(h5_id) {}
 ///\param	original - IN: IdComponent instance to copy
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-IdComponent::IdComponent( const IdComponent& original )
-{
-    id = original.id;
-    incRefCount(); // increment number of references to this id
-}
+IdComponent::IdComponent( const IdComponent& original ) {}
 
 //--------------------------------------------------------------------------
 // Function:	IdComponent::incRefCount
@@ -69,7 +66,7 @@ void IdComponent::incRefCount(const hid_t obj_id) const
 //--------------------------------------------------------------------------
 void IdComponent::incRefCount() const
 {
-    incRefCount(id);
+    incRefCount(getId());
 }
 
 //--------------------------------------------------------------------------
@@ -99,7 +96,7 @@ void IdComponent::decRefCount(const hid_t obj_id) const
 //--------------------------------------------------------------------------
 void IdComponent::decRefCount() const
 {
-    decRefCount(id);
+    decRefCount(getId());
 }
 
 //--------------------------------------------------------------------------
@@ -128,13 +125,13 @@ int IdComponent::getCounter(const hid_t obj_id) const
 //--------------------------------------------------------------------------
 int IdComponent::getCounter() const
 {
-    return (getCounter(id));
+    return (getCounter(getId()));
 }
 
 //--------------------------------------------------------------------------
 // Function:	hdfObjectType
 ///\brief	Given an id, returns the type of the object.
-///return	a valid HDF object type, which may be one of the following:
+///\return	a valid HDF object type, which may be one of the following:
 ///		\li \c H5I_FILE
 ///		\li \c H5I_GROUP
 ///		\li \c H5I_DATATYPE
@@ -166,6 +163,10 @@ H5I_type_t IdComponent::getHDFObjType(const hid_t obj_id)
 //		copy the id from rhs to this object, and increment the
 //		reference counter of the id to indicate that another object
 //		is referencing that id.
+// Modification
+//	2010/5/9 - BMR
+//		Removed close() and incRefCount() because setId/p_setId takes
+//		care of close() and setId takes care incRefCount().
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 IdComponent& IdComponent::operator=( const IdComponent& rhs )
@@ -173,18 +174,14 @@ IdComponent& IdComponent::operator=( const IdComponent& rhs )
     if (this != &rhs)
     {
 	// handling references to this id
-	try {
-	    close();
+  	try {
+	    setId(rhs.getId());
+	    // Note: a = b, so there are two objects with the same hdf5 id
+	    // that's why incRefCount is needed, and it is called by setId
 	}
 	catch (Exception close_error) {
 	    throw FileIException(inMemFunc("operator="), close_error.getDetailMsg());
 	}
-
-	// copy the data members from the rhs object
-	id = rhs.id;
-
-	// increment the reference counter
-	incRefCount();
     }
     return *this;
 }
@@ -196,39 +193,29 @@ IdComponent& IdComponent::operator=( const IdComponent& rhs )
 ///\exception	H5::IdComponentException when the attempt to close the HDF5
 ///		object fails
 // Description:
-// 		The underlaying reference counting in the C library ensures
-// 		that the current valid id of this object is properly closed.
-// 		Then the object's id is reset to the new id.
+//		p_setId ensures that the current valid id of this object is
+//		properly closed before resetting the object's id to the new id.
 // Programmer	Binh-Minh Ribler - 2000
+// Modification
+//	2008/7/23 - BMR
+//		Changed all subclasses' setId to p_setId and put back setId
+//		here.  p_setId is used in the library where the id provided
+//		by a C API passed on to user's application in the form of a
+//		C++ API object, which will be destroyed properly, and so
+//		p_setId does not call incRefCount.  On the other hand, the
+//		public version setId is used by other applications, in which
+//		the id passed to setId already has a reference count, so setId
+//		must call incRefCount.
 //--------------------------------------------------------------------------
 void IdComponent::setId(const hid_t new_id)
 {
-    // handling references to this old id
-    try {
-	close();
-    }
-    catch (Exception close_error) {
-	throw IdComponentException(inMemFunc("copy"), close_error.getDetailMsg());
-    }
-
-   // reset object's id to the given id
-   id = new_id;
+   // set to new_id
+   p_setId(new_id);
 
    // increment the reference counter of the new id
    incRefCount();
 }
 
-//--------------------------------------------------------------------------
-// Function:	IdComponent::getId
-///\brief	Returns the id of this object
-///\return	HDF5 id
-// Programmer	Binh-Minh Ribler - 2000
-//--------------------------------------------------------------------------
-hid_t IdComponent::getId () const
-{
-   return(id);
-}
-
 //--------------------------------------------------------------------------
 // Function:	IdComponent destructor
 ///\brief	Noop destructor.
@@ -273,7 +260,7 @@ H5std_string IdComponent::inMemFunc(const char* func_name) const
 ///\brief	Default constructor.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-IdComponent::IdComponent() : id(-1) {}
+IdComponent::IdComponent() {}
 
 //--------------------------------------------------------------------------
 // Function:	IdComponent::p_get_file_name (protected)
@@ -287,8 +274,10 @@ IdComponent::IdComponent() : id(-1) {}
 //--------------------------------------------------------------------------
 H5std_string IdComponent::p_get_file_name() const
 {
+   hid_t temp_id = getId();
+
    // Preliminary call to H5Fget_name to get the length of the file name
-   ssize_t name_size = H5Fget_name(id, NULL, 0);
+   ssize_t name_size = H5Fget_name(temp_id, NULL, 0);
 
    // If H5Aget_name returns a negative value, raise an exception,
    if( name_size < 0 )
@@ -298,7 +287,7 @@ H5std_string IdComponent::p_get_file_name() const
 
    // Call H5Fget_name again to get the actual file name
    char* name_C = new char[name_size+1];  // temporary C-string for C API
-   name_size = H5Fget_name(id, name_C, name_size+1);
+   name_size = H5Fget_name(temp_id, name_C, name_size+1);
 
    // Check for failure again
    if( name_size < 0 )
@@ -312,178 +301,6 @@ H5std_string IdComponent::p_get_file_name() const
    return(file_name);
 }
 
-//--------------------------------------------------------------------------
-// Function:	IdComponent::p_reference (protected)
-// Purpose	Creates a reference to an HDF5 object or a dataset region.
-// Parameters
-//		name - IN: Name of the object to be referenced
-//		dataspace - IN: Dataspace with selection
-//		ref_type - IN: Type of reference; default to \c H5R_DATASET_REGION
-// Exception	H5::IdComponentException
-// Programmer	Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void IdComponent::p_reference(void* ref, const char* name, hid_t space_id, H5R_type_t ref_type) const
-{
-   herr_t ret_value = H5Rcreate(ref, id, name, ref_type, space_id);
-   if (ret_value < 0)
-   {
-      throw IdComponentException("", "H5Rcreate failed");
-   }
-}
-
-//--------------------------------------------------------------------------
-// Function:    IdComponent::reference
-///\brief       Creates a reference to an HDF5 object or a dataset region.
-///\param       ref - IN: Reference pointer
-///\param       name - IN: Name of the object to be referenced
-///\param       dataspace - IN: Dataspace with selection
-///\param       ref_type - IN: Type of reference to query, valid values are:
-///             \li \c H5R_OBJECT \tReference is an object reference.
-///             \li \c H5R_DATASET_REGION \tReference is a dataset region
-///                     reference. - this is the default
-///\exception   H5::IdComponentException
-// Programmer   Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void IdComponent::reference(void* ref, const char* name, const DataSpace& dataspace, H5R_type_t ref_type) const
-{
-   try {
-      p_reference(ref, name, dataspace.getId(), ref_type);
-   }
-   catch (IdComponentException E) {
-      throw IdComponentException("IdComponent::reference", E.getDetailMsg());
-   }
-}
-
-//--------------------------------------------------------------------------
-// Function:    IdComponent::reference
-///\brief       This is an overloaded function, provided for your convenience.
-///             It differs from the above function in that it only creates
-///             a reference to an HDF5 object, not to a dataset region.
-///\param       ref - IN: Reference pointer
-///\param       name - IN: Name of the object to be referenced - \c char pointer
-///\exception   H5::IdComponentException
-///\par Description
-//              This function passes H5R_OBJECT and -1 to the protected
-//              function for it to pass to the C API H5Rcreate
-//              to create a reference to the named object.
-// Programmer   Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void IdComponent::reference(void* ref, const char* name) const
-{
-   try {
-      p_reference(ref, name, -1, H5R_OBJECT);
-   }
-   catch (IdComponentException E) {
-      throw IdComponentException("IdComponent::reference", E.getDetailMsg());
-   }
-}
-
-//--------------------------------------------------------------------------
-// Function:    IdComponent::reference
-///\brief       This is an overloaded function, provided for your convenience.
-///             It differs from the above function in that it takes an
-///             \c std::string for the object's name.
-///\param       ref - IN: Reference pointer
-///\param       name - IN: Name of the object to be referenced - \c std::string
-// Programmer   Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void IdComponent::reference(void* ref, const H5std_string& name) const
-{
-   reference(ref, name.c_str());
-}
-
-//--------------------------------------------------------------------------
-// Function:	IdComponent::p_reference (protected)
-// Purpose	Creates a reference to an HDF5 object or a dataset region.
-// Parameters
-//		name - IN: Name of the object to be referenced
-//		dataspace - IN: Dataspace with selection
-//		ref_type - IN: Type of reference; default to \c H5R_DATASET_REGION
-// Return	A reference
-// Exception	H5::IdComponentException
-// Notes	This function is incorrect, and will be removed in the near
-//		future after notifying users of the new APIs ::reference's.
-//		BMR - Oct 8, 2006
-// Programmer	Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-void* IdComponent::p_reference(const char* name, hid_t space_id, H5R_type_t ref_type) const
-{
-   hobj_ref_t ref;
-   herr_t ret_value = H5Rcreate(&ref, id, name, ref_type, space_id);
-   if (ret_value < 0)
-   {
-      throw IdComponentException("", "H5Rcreate failed");
-   }
-   return (reinterpret_cast<void*>(ref));
-}
-
-//--------------------------------------------------------------------------
-// Function:	IdComponent::dereference
-// Purpose	Opens the HDF5 object referenced.
-// Parameters
-//		obj - IN: Dataset reference object is in or location of
-//                            object that the dataset is located within.
-//		ref - IN: Reference pointer
-// Exception	H5::IdComponentException
-// Programmer	Binh-Minh Ribler - Oct, 2006
-//--------------------------------------------------------------------------
-void IdComponent::dereference(IdComponent& obj, void* ref)
-{
-   id = H5Rdereference(obj.getId(), H5R_OBJECT, ref);
-   if (id < 0)
-   {
-      throw IdComponentException("", "H5Rdereference failed");
-   }
-}
-
-#ifndef H5_NO_DEPRECATED_SYMBOLS
-//--------------------------------------------------------------------------
-// Function:	IdComponent::p_get_obj_type (protected)
-// Purpose	Retrieves the type of object that an object reference points to.
-// Parameters
-//		ref      - IN: Reference to query
-//		ref_type - IN: Type of reference to query
-// Return	An object type, which can be one of the following:
-//			H5G_LINK Object is a symbolic link.
-//			H5G_GROUP Object is a group.
-//			H5G_DATASET   Object is a dataset.
-//			H5G_TYPE Object is a named datatype
-// Exception	H5::IdComponentException
-// Programmer	Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-H5G_obj_t IdComponent::p_get_obj_type(void *ref, H5R_type_t ref_type) const
-{
-   H5G_obj_t obj_type = H5Rget_obj_type1(id, ref_type, ref);
-
-   if (obj_type == H5G_UNKNOWN)
-   {
-      throw IdComponentException("", "H5Rget_obj_type failed");
-   }
-   return(obj_type);
-}
-#endif /* H5_NO_DEPRECATED_SYMBOLS */
-
-//--------------------------------------------------------------------------
-// Function:	IdComponent::p_get_region (protected)
-// Purpose	Retrieves a dataspace with the region pointed to selected.
-// Parameters
-//		ref_type - IN: Type of reference to get region of - default
-//				to H5R_DATASET_REGION
-//		ref      - IN: Reference to get region of
-// Return	Dataspace id
-// Exception	H5::IdComponentException
-// Programmer	Binh-Minh Ribler - May, 2004
-//--------------------------------------------------------------------------
-hid_t IdComponent::p_get_region(void *ref, H5R_type_t ref_type) const
-{
-   hid_t space_id = H5Rget_region(id, ref_type, ref);
-   if (space_id < 0)
-   {
-      throw IdComponentException("", "H5Rget_region failed");
-   }
-   return(space_id);
-}
-
 //
 // Local functions used in this class
 //
@@ -495,7 +312,7 @@ hid_t IdComponent::p_get_region(void *ref, H5R_type_t ref_type) const
 // Return	true if id is valid, false, otherwise
 // Programmer	Binh-Minh Ribler - May, 2005
 //--------------------------------------------------------------------------
-bool IdComponent::p_valid_id(const hid_t obj_id) const
+bool IdComponent::p_valid_id(const hid_t obj_id)
 {
     H5I_type_t id_type = H5Iget_type(obj_id);
     if (id_type <= H5I_BADID || id_type >= H5I_NTYPES)
