@@ -200,9 +200,11 @@ Attribute H5Object::openAttribute( const unsigned int idx ) const
 ///		zero if all attributes were processed
 ///\exception	H5::AttributeIException
 ///\par Description
+///		The signature of user_op is
+///		void (*)(H5::H5Object&, H5std_string, void*).
 ///		For information, please refer to the C layer Reference Manual
 ///		at:
-/// http://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-Create2
+/// http://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-Iterate
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 int H5Object::iterateAttrs( attr_operator_t user_op, unsigned *_idx, void *op_data )
@@ -214,7 +216,7 @@ int H5Object::iterateAttrs( attr_operator_t user_op, unsigned *_idx, void *op_da
    userData->object = this;
 
    // call the C library routine H5Aiterate2 to iterate the attributes
-   hsize_t idx = (hsize_t)*_idx;
+   hsize_t idx = _idx ? (hsize_t)*_idx : 0;
    int ret_value = H5Aiterate2(getId(), H5_INDEX_NAME, H5_ITER_INC, &idx,
 			userAttrOpWrpr, (void *) userData);
 
@@ -223,7 +225,8 @@ int H5Object::iterateAttrs( attr_operator_t user_op, unsigned *_idx, void *op_da
 
    if( ret_value >= 0 ) {
       /* Pass back update index value to calling code */
-      *_idx = (unsigned)idx;
+      if (_idx)
+	 *_idx = (unsigned)idx;
 
       return( ret_value );
    }
@@ -365,9 +368,9 @@ void H5Object::p_reference(void* ref, const char* name, hid_t space_id, H5R_type
 ///\param       name - IN: Name of the object to be referenced
 ///\param       dataspace - IN: Dataspace with selection
 ///\param       ref_type - IN: Type of reference to query, valid values are:
-///             \li \c H5R_OBJECT         - Reference is an object reference.
-///             \li \c H5R_DATASET_REGION - Reference is a dataset region
-///                     reference. - this is the default
+///		\li \c H5R_OBJECT         - Reference is an object reference.
+///		\li \c H5R_DATASET_REGION - Reference is a dataset region
+///			reference. - this is the default
 ///\exception   H5::IdComponentException
 // Programmer   Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
@@ -423,7 +426,7 @@ void H5Object::reference(void* ref, const H5std_string& name) const
 // Function:	H5Object::p_dereference (protected)
 // Purpose	Dereference a ref into an hdf5 object.
 // Parameters
-//		loc_id - IN: An hdf5 identifier specifying the location of the 
+//		loc_id - IN: An hdf5 identifier specifying the location of the
 //			 referenced object
 //		ref - IN: Reference pointer
 //		ref_type - IN: Reference type
