@@ -25,6 +25,8 @@
 #include "H5Exception.h"
 #include "H5IdComponent.h"
 #include "H5PropList.h"
+#include "H5private.h"		// for HDfree
+
 
 #ifndef H5_NO_NAMESPACE
 namespace H5 {
@@ -44,7 +46,7 @@ const PropList PropList::DEFAULT( H5P_DEFAULT );
 ///\brief	Default constructor: creates a stub property list object.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-PropList::PropList() : IdComponent( 0 ) {}
+PropList::PropList() : IdComponent(), id(0) {}
 
 //--------------------------------------------------------------------------
 // Function:	PropList copy constructor
@@ -52,7 +54,11 @@ PropList::PropList() : IdComponent( 0 ) {}
 ///\param	original - IN: The original property list to copy
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-PropList::PropList( const PropList& original ) : IdComponent( original ) {}
+PropList::PropList(const PropList& original) : IdComponent(original)
+{
+    id = original.getId();
+    incRefCount(); // increment number of references to this id
+}
 
 //--------------------------------------------------------------------------
 // Function:	PropList overloaded constructor
@@ -60,29 +66,35 @@ PropList::PropList( const PropList& original ) : IdComponent( original ) {}
 ///\param	plist_id - IN: Id of the existing property list
 ///\exception	H5::PropListIException
 // Description
-//		This function calls H5Pcreate to create a new property list
-//		if the given id, plist_id, is that of a property class.  If
-//		the given id is equal to H5P_ROOT, then set this
-//		property's id to H5P_DEFAULT, otherwise, to the given id.
-//		Note: someone else added this code without comments and this
-//		description was what I came up with from reading the code.
+//		This function creates a new property list if a property
+//		class is provided or makes a copy of a property list if one
+//		is given.  If the given id is anything else, then set this
+//		property's id to H5P_DEFAULT.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-PropList::PropList( const hid_t plist_id ) : IdComponent(0)
+PropList::PropList( const hid_t plist_id ) : IdComponent()
 {
-    if (H5I_GENPROP_CLS == H5Iget_type(plist_id)) {
-	// call C routine to create the new property
-	id = H5Pcreate(plist_id);
-	if( id < 0 )
-	{
-	    throw PropListIException("PropList constructor", "H5Pcreate failed");
-	}
-    }
-    else {
-	if(plist_id==H5P_ROOT)
-	    id=H5P_DEFAULT;
-	else
-	    id=plist_id;
+    H5I_type_t id_type = H5Iget_type(plist_id);
+    switch (id_type) {
+	case H5I_GENPROP_CLS:
+	  // call C routine to create a new property from the given prop class
+	  id = H5Pcreate(plist_id);
+	  if( id < 0 )
+	  {
+	      throw PropListIException("PropList constructor", "H5Pcreate failed");
+	  }
+	  break;
+	case H5I_GENPROP_LST:
+	  // call C routine to make a copy of the given property list
+	  id = H5Pcopy(plist_id);
+	  if( id < 0 )
+	  {
+	      throw PropListIException("PropList constructor", "H5Pcopy failed");
+	  }
+	  break;
+	default:
+	  id = H5P_DEFAULT;
+	  break;
     }
 }
 
@@ -157,7 +169,7 @@ void PropList::copyProp(PropList& dest, const char *name) const
 /// 		It differs from the above function only in what arguments it
 ///		accepts.
 ///\param	dest - IN: Destination property list or class
-///\param	name - IN: Name of the property to copy - \c std::string
+///\param	name - IN: Name of the property to copy - \c H5std_string
 // Programmer	Binh-Minh Ribler - Jul, 2005
 //--------------------------------------------------------------------------
 void PropList::copyProp( PropList& dest, const H5std_string& name ) const
@@ -194,7 +206,7 @@ void PropList::copyProp( PropList& dest, PropList& src, const char *name ) const
 ///		accepts. - Obsolete
 ///\param	dest - IN: Destination property list or class
 ///\param	src  - IN: Source property list or class
-///\param	name - IN: Name of the property to copy - \c std::string
+///\param	name - IN: Name of the property to copy - \c H5std_string
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void PropList::copyProp( PropList& dest, PropList& src, const H5std_string& name ) const
@@ -202,6 +214,46 @@ void PropList::copyProp( PropList& dest, PropList& src, const H5std_string& name
    copyProp( dest, src, name.c_str());
 }
 
+//--------------------------------------------------------------------------
+// Function:    PropList::getId
+// Purpose:     Get the id of this attribute
+// Description:
+//              Class hierarchy is revised to address bugzilla 1068.  Class
+//              AbstractDS and Attribute are moved out of H5Object.  In
+//              addition, member IdComponent::id is moved into subclasses, and
+//              IdComponent::getId now becomes pure virtual function.
+// Programmer   Binh-Minh Ribler - May, 2008
+//--------------------------------------------------------------------------
+hid_t PropList::getId() const
+{
+   return(id);
+}
+
+//--------------------------------------------------------------------------
+// Function:    PropList::p_setId
+///\brief       Sets the identifier of this object to a new value.
+///
+///\exception   H5::IdComponentException when the attempt to close the HDF5
+///             object fails
+// Description:
+//              The underlaying reference counting in the C library ensures
+//              that the current valid id of this object is properly closed.
+//              Then the object's id is reset to the new id.
+// Programmer   Binh-Minh Ribler - 2000
+//--------------------------------------------------------------------------
+void PropList::p_setId(const hid_t new_id)
+{
+    // handling references to this old id
+    try {
+        close();
+    }
+    catch (Exception close_error) {
+        throw PropListIException(inMemFunc("p_setId"), close_error.getDetailMsg());
+    }
+   // reset object's id to the given id
+   id = new_id;
+}
+
 //--------------------------------------------------------------------------
 // Function:	PropList::close
 ///\brief	Closes the property list if it is not a default one.
@@ -218,7 +270,7 @@ void PropList::close()
 	{
 	    throw PropListIException(inMemFunc("close"), "H5Pclose failed");
 	}
-	// reset the id because the property list that it represents is now closed
+	// reset the id
 	id = 0;
     }
 }
@@ -273,7 +325,7 @@ bool PropList::propExist(const char* name ) const
 ///\brief	This is an overloaded member function, provided for convenience.
 /// 		It differs from the above function only in what arguments it
 ///		accepts.
-///\param	name - IN: Name of property to check for - \c std::string
+///\param	name - IN: Name of property to check for - \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 bool PropList::propExist(const H5std_string& name ) const
@@ -326,7 +378,7 @@ void PropList::getProperty(const char* name, void* value) const
 ///   		It differs from the above function only in what arguments it
 ///		accepts.
 ///\param	name -  IN: Name of property to query - \c char pointer
-///\return	The property that is a \c std::string.
+///\return	The property that is a \c H5std_string.
 ///\exception	H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
@@ -343,7 +395,7 @@ H5std_string PropList::getProperty(const char* name) const
    }
 
    // Return propety value as a string after deleting temp C-string
-   H5std_string prop_strg = H5std_string(prop_strg_C);
+   H5std_string prop_strg(prop_strg_C);
    delete []prop_strg_C;
    return (prop_strg);
 }
@@ -352,7 +404,7 @@ H5std_string PropList::getProperty(const char* name) const
 ///\brief	This is an overloaded member function, provided for convenience.
 ///   		It differs from the above function only in what arguments it
 ///		accepts.
-///\param	name -   IN: Name of property to query - \c std::string
+///\param	name -   IN: Name of property to query - \c H5std_string
 ///\param	value - OUT: Pointer to the buffer for the property value
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
@@ -365,8 +417,8 @@ void PropList::getProperty(const H5std_string& name, void* value) const
 ///\brief	This is an overloaded member function, provided for convenience.
 ///   		It differs from the above function only in what arguments it
 ///		accepts.
-///\param	name -  IN: Name of property to query - \c std::string
-///\return	The property that is a \c std::string.
+///\param	name -  IN: Name of property to query - \c H5std_string
+///\return	The property that is a \c H5std_string.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 H5std_string PropList::getProperty(const H5std_string& name) const
@@ -402,7 +454,7 @@ size_t PropList::getPropSize(const char *name) const
 ///\brief	This is an overloaded member function, provided for convenience.
 /// 		It differs from the above function only in what arguments it
 ///		accepts.
-///\param	name - IN: Name of property to query - \c std::string
+///\param	name - IN: Name of property to query - \c H5std_string
 ///
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
@@ -421,12 +473,13 @@ size_t PropList::getPropSize(const H5std_string& name) const
 H5std_string PropList::getClassName() const
 {
    char* temp_str;
-   temp_str = H5Pget_class_name(id);
+   temp_str = H5Pget_class_name(id); // this API specified that temp_str must
+				     // be freed.
 
    if (temp_str != NULL)
    {
-      H5std_string class_name = H5std_string(temp_str);
-      free(temp_str);
+      H5std_string class_name(temp_str);
+      HDfree(temp_str);
       return(class_name);
    }
    else
@@ -489,7 +542,7 @@ void PropList::setProperty(const char* name, const char* charptr) const
 /// 		It differs from the above function only in what arguments it
 ///		accepts.
 ///\param	name - IN: Name of property to set - \c char pointer
-///\param	strg - IN: Value for the property is a \c std::string
+///\param	strg - IN: Value for the property is a \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void PropList::setProperty(const char* name, H5std_string& strg) const
@@ -502,7 +555,7 @@ void PropList::setProperty(const char* name, H5std_string& strg) const
 ///\brief	This is an overloaded member function, provided for convenience.
 /// 		It differs from the above function only in what arguments it
 ///		accepts.
-///\param	name  - IN: Name of property to set - \c std::string
+///\param	name  - IN: Name of property to set - \c H5std_string
 ///\param	value - IN: Void pointer to the value for the property
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
@@ -516,8 +569,8 @@ void PropList::setProperty(const H5std_string& name, void* value) const
 ///\brief	This is an overloaded member function, provided for convenience.
 /// 		It differs from the above function only in what arguments it
 ///		accepts.
-///\param	name - IN: Name of property to set - \c std::string
-///\param	strg - IN: Value for the property is a \c std::string
+///\param	name - IN: Name of property to set - \c H5std_string
+///\param	strg - IN: Value for the property is a \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void PropList::setProperty(const H5std_string& name, H5std_string& strg) const
@@ -569,7 +622,7 @@ void PropList::removeProp(const char *name) const
 ///\brief	This is an overloaded member function, provided for convenience.
 /// 		It differs from the above function only in what arguments it
 ///		accepts.
-///\param	name - IN: Name of property to remove - \c std::string
+///\param	name - IN: Name of property to remove - \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void PropList::removeProp(const H5std_string& name) const
