@@ -34,7 +34,6 @@
 #endif  // H5_NO_STD
 #endif
 
-#include "testhdf5.h"	// C test header file
 #include "H5Cpp.h"	// C++ API header file
 
 #ifndef H5_NO_NAMESPACE
@@ -118,7 +117,7 @@ static void test_attr_basic_write()
     int     i;
 
     // Output message about test being performed
-    SUBTEST("Testing Basic Attribute Writing Functions");
+    SUBTEST("Basic Attribute Writing Functions");
 
     try {
 	// Create file
@@ -237,7 +236,7 @@ static void test_attr_rename()
     int i;
 
 	// Output message about test being performed
-    SUBTEST("Testing Rename Attribute Function");
+    SUBTEST("Rename Attribute Function");
 
     try {
 	// Open file
@@ -308,7 +307,7 @@ static void test_attr_basic_read()
     int i, j;
 
     // Output message about test being performed
-    SUBTEST("Testing Basic Attribute Reading Functions");
+    SUBTEST("Basic Attribute Reading Functions");
 
     try {
 	// Open file
@@ -356,7 +355,7 @@ static void test_attr_basic_read()
 	for(i=0; i<ATTR2_DIM1; i++)
             for(j=0; j<ATTR2_DIM2; j++)
         	if(attr_data2[i][j]!=read_data2[i][j]) {
-		    TestErrPrintf("%d: attribute data different: attr_data2[%d][%d]=%d, read_data2[%d][%d]=%d\n",__LINE__, i,j,attr_data2[i][j],i,j,read_data1[i]);
+		    TestErrPrintf("%d: attribute data different: attr_data2[%d][%d]=%d, read_data2[%d][%d]=%d\n",__LINE__, i,j,attr_data2[i][j],i,j,read_data2[i][j]);
 		}
 	PASSED();
     } // end try block
@@ -375,7 +374,7 @@ static void test_attr_compound_write()
 {
 
 	// Output message about test being performed
-    SUBTEST("Testing Multiple Attribute Functions");
+    SUBTEST("Multiple Attribute Functions");
 
     try {
 	// Create file
@@ -439,7 +438,7 @@ static void test_attr_compound_read()
     int     i,j;
 
     // Output message about test being performed
-    SUBTEST("Testing Basic Attribute Functions");
+    SUBTEST("Basic Attribute Functions");
 
     try {
 	// Open file
@@ -568,7 +567,7 @@ static void test_attr_compound_read()
 static void test_attr_scalar_write()
 {
     // Output message about test being performed
-    SUBTEST("Testing Basic Scalar Attribute Writing Functions");
+    SUBTEST("Basic Scalar Attribute Writing Functions");
 
     try {
 	// Create file
@@ -622,7 +621,7 @@ static void test_attr_scalar_write()
 static void test_attr_scalar_read()
 {
     // Output message about test being performed
-    SUBTEST("Testing Basic Scalar Attribute Reading Functions");
+    SUBTEST("Basic Scalar Attribute Reading Functions");
 
     try {
 	// Open file
@@ -666,7 +665,7 @@ static void test_attr_scalar_read()
 static void test_attr_mult_write()
 {
     // Output message about test being performed
-    SUBTEST("Testing Multiple Attribute Writing Functions");
+    SUBTEST("Multiple Attribute Writing Functions");
 
     try {
 	// Create file
@@ -743,7 +742,7 @@ static void test_attr_mult_read()
     int     i,j,k;
 
 	// Output message about test being performed
-    SUBTEST("Testing Multiple Attribute Reading Functions");
+    SUBTEST("Multiple Attribute Reading Functions");
 
     try {
 	// Open file
@@ -932,7 +931,7 @@ static void test_attr_delete()
     H5std_string  attr_name; // Buffer for attribute names
 
 	// Output message about test being performed
-    SUBTEST("Testing Removing Attribute Function");
+    SUBTEST("Removing Attribute Function");
 
     try {
 	// Open file
@@ -1032,7 +1031,7 @@ static void test_attr_dtype_shared()
     h5_stat_size_t filesize;             /* Size of file after modifications */
 
     // Output message about test being performed
-    SUBTEST("Testing Shared Datatypes with Attributes");
+    SUBTEST("Shared Datatypes with Attributes");
 
     try {
 	// Create a file
@@ -1043,13 +1042,18 @@ static void test_attr_dtype_shared()
 
 	// Get size of file
 	h5_stat_size_t empty_filesize;       // Size of empty file
-	empty_filesize = h5_get_file_size(FILENAME.c_str());
+	empty_filesize = h5_get_file_size(FILENAME.c_str(), H5P_DEFAULT);
 	if (empty_filesize < 0)
-    	TestErrPrintf("Line %d: file size wrong!\n",__LINE__);
+            TestErrPrintf("Line %d: file size wrong!\n", __LINE__);
 
 	// Open the file again
 	fid1.openFile(FILENAME, H5F_ACC_RDWR);
 
+	// Enclosing to work around the issue of unused variables and/or
+	// objects created by copy constructors stay around until end of
+	// scope, causing incorrect number of ref counts.
+	{ // First enclosed block
+
 	// Create a datatype to commit and use
 	IntType dtype(PredType::NATIVE_INT);
 
@@ -1065,13 +1069,6 @@ static void test_attr_dtype_shared()
 	// Create dataspace for dataset
 	DataSpace dspace;
 
-	// Enclose the following so that all temporary objects can be
-	// destroyed before testing reference count - this is to overcome
-	// the different time when the temporary objects are to be destroyed
-	// by different compilers.
-	{
-
-	// Create dataset
 	DataSet dset = fid1.createDataSet(DSET1_NAME, dtype, dspace);
 
 #ifndef H5_NO_DEPRECATED_SYMBOLS
@@ -1089,8 +1086,8 @@ static void test_attr_dtype_shared()
 	verify_val((int)statbuf.nlink, 3, "DataSet::getObjinfo", __LINE__, __FILE__);
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
 
-	// Close attribute
-	attr.close();
+        // Close attribute
+        attr.close();
 
 	// Delete attribute
 	dset.removeAttr(ATTR1_NAME);
@@ -1101,8 +1098,8 @@ static void test_attr_dtype_shared()
 	verify_val((int)statbuf.nlink, 2, "DataSet::getObjinfo after DataSet::removeAttr", __LINE__, __FILE__);
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
 
-	// Create attribute on dataset
-	attr = dset.createAttribute(ATTR1_NAME,dtype,dspace);
+        // Create attribute on dataset
+        attr = dset.createAttribute(ATTR1_NAME,dtype,dspace);
 
 #ifndef H5_NO_DEPRECATED_SYMBOLS
 	// Check reference count on named datatype
@@ -1118,11 +1115,15 @@ static void test_attr_dtype_shared()
 	dset.close();
 	dspace.close();
 	dtype.close();
+	} // end of first enclosing
+
 	fid1.close();
 
 	// Open the file again
 	fid1.openFile(FILENAME, H5F_ACC_RDWR);
 
+	{ // Second enclosed block...
+
 	// Open dataset
 	DataSet *dset2 = new DataSet (fid1.openDataSet(DSET1_NAME));
 
@@ -1142,12 +1143,11 @@ static void test_attr_dtype_shared()
 	fid1.getObjinfo(TYPE1_NAME, statbuf);
 	verify_val((int)statbuf.nlink, 3, "DataSet::openAttribute", __LINE__, __FILE__);
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
+	} // end of second enclosing
 
 	// Unlink the dataset
 	fid1.unlink(DSET1_NAME);
 
-        } // end of enclosing to test reference counts
-
 #ifndef H5_NO_DEPRECATED_SYMBOLS
 	// Check reference count on named datatype
 	fid1.getObjinfo(TYPE1_NAME, statbuf);
@@ -1161,7 +1161,7 @@ static void test_attr_dtype_shared()
 	fid1.close();
 
 	// Check size of file
-	filesize=h5_get_file_size(FILENAME.c_str());
+	filesize = h5_get_file_size(FILENAME.c_str(), H5P_DEFAULT);
 	verify_val((long)filesize, (long)empty_filesize, "Checking file size", __LINE__, __FILE__);
 
 	PASSED();
@@ -1179,20 +1179,26 @@ static void test_attr_dtype_shared()
 **
 ****************************************************************/
 /* Info for a string attribute */
-const H5std_string ATTRSTR_NAME("String_attr");
+const H5std_string ATTR1_FL_STR_NAME("String_attr 1");
+const H5std_string ATTR2_FL_STR_NAME("String_attr 2");
+const H5std_string ATTR_VL_STR_NAME("String_attr");
 const H5std_string ATTRSTR_DATA("String Attribute");
+const int ATTR_LEN = 17;
 
 static void test_string_attr()
 {
     // Output message about test being performed
-    SUBTEST("Testing Basic Attribute Writing Functions");
+    SUBTEST("I/O on FL and VL String Attributes");
 
     try {
 	// Create file
 	H5File fid1(FILENAME, H5F_ACC_RDWR);
 
-	// Create a variable length string datatype to refer to.
-	StrType type(0, H5T_VARIABLE);
+	//
+	// Fixed-lenth string attributes
+	//
+	// Create a fixed-length string datatype to refer to.
+	StrType fls_type(0, ATTR_LEN);
 
 	// Open the root group.
 	Group root = fid1.openGroup("/");
@@ -1200,24 +1206,88 @@ static void test_string_attr()
 	// Create dataspace for the attribute.
 	DataSpace att_space (H5S_SCALAR);
 
+	/* Test Attribute::write(...,const void *buf) with Fixed len string */
+
 	// Create an attribute for the root group.
-	Attribute gr_attr = root.createAttribute(ATTRSTR_NAME, type, att_space);
+	Attribute gr_flattr1 = root.createAttribute(ATTR1_FL_STR_NAME, fls_type, att_space);
 
 	// Write data to the attribute.
-	gr_attr.write(type, ATTRSTR_DATA);
+	gr_flattr1.write(fls_type, ATTRSTR_DATA.c_str());
+
+	/* Test Attribute::write(...,const H5std_string& strg) with FL string */
+
+	// Create an attribute for the root group.
+	Attribute gr_flattr2 = root.createAttribute(ATTR2_FL_STR_NAME, fls_type, att_space);
+
+	// Write data to the attribute.
+	gr_flattr2.write(fls_type, ATTRSTR_DATA);
+
+	/* Test Attribute::read(...,void *buf) with FL string */
 
 	// Read and verify the attribute string as a string of chars.
-	char *string_att_check;
-	gr_attr.read(type, &string_att_check);
-	if(HDstrcmp(string_att_check, ATTRSTR_DATA.c_str())!=0)
-	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,string_att_check=%s\n",__LINE__, ATTRSTR_DATA.c_str(), string_att_check);
+	char flstring_att_check[ATTR_LEN];
+	gr_flattr1.read(fls_type, flstring_att_check);
+	if(HDstrcmp(flstring_att_check, ATTRSTR_DATA.c_str())!=0)
+	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,flstring_att_check=%s\n",__LINE__, ATTRSTR_DATA.c_str(), flstring_att_check);
+
+	// Read and verify the attribute string as a string of chars; buffer
+	// is dynamically allocated.
+	size_t attr_size = gr_flattr1.getInMemDataSize();
+	char *fl_dyn_string_att_check;
+	fl_dyn_string_att_check = new char[attr_size+1];
+	gr_flattr1.read(fls_type, fl_dyn_string_att_check);
+	if(HDstrcmp(fl_dyn_string_att_check, ATTRSTR_DATA.c_str())!=0)
+	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,flstring_att_check=%s\n",__LINE__, ATTRSTR_DATA.c_str(), fl_dyn_string_att_check);
+	delete []fl_dyn_string_att_check;
+
+	/* Test Attribute::read(...,H5std_string& strg) with FL string */
 
+	// Read and verify the attribute string as an std::string.
+	H5std_string read_flstr1;
+	gr_flattr1.read(fls_type, read_flstr1);
+	if (read_flstr1 != ATTRSTR_DATA)
+	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,read_flstr1=%s\n",__LINE__, ATTRSTR_DATA.c_str(), read_flstr1.c_str());
+
+	// Read and verify the attribute string as a string of chars.
+	HDstrcpy(flstring_att_check, "");
+	gr_flattr2.read(fls_type, flstring_att_check);
+	if(HDstrcmp(flstring_att_check, ATTRSTR_DATA.c_str())!=0)
+	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,flstring_att_check=%s\n",__LINE__, ATTRSTR_DATA.c_str(), flstring_att_check);
+
+	/* Test Attribute::read(...,H5std_string& strg) with FL string */
+
+	// Read and verify the attribute string as an std::string.
+	H5std_string read_flstr2;
+	gr_flattr2.read(fls_type, read_flstr2);
+	if (read_flstr2 != ATTRSTR_DATA)
+	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,read_flstr2=%s\n",__LINE__, ATTRSTR_DATA.c_str(), read_flstr2.c_str());
+
+	//
+	// Variable-lenth string attributes
+	//
+	// Create a variable length string datatype to refer to.
+	StrType vls_type(0, H5T_VARIABLE);
+
+	// Create an attribute for the root group.
+	Attribute gr_vlattr = root.createAttribute(ATTR_VL_STR_NAME, vls_type, att_space);
+
+	// Write data to the attribute.
+	gr_vlattr.write(vls_type, ATTRSTR_DATA);
+
+	/* Test Attribute::read(...,void *buf) with Variable len string */
+	// Read and verify the attribute string as a string of chars.
+	char *string_att_check;
+	gr_vlattr.read(vls_type, &string_att_check);
+	if(HDstrcmp(string_att_check, ATTRSTR_DATA.c_str())!=0)
+	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,string_att_check=%s\n",__LINE__, ATTRSTR_DATA.c_str(), string_att_check);
+	HDfree(string_att_check);
+
+	/* Test Attribute::read(...,H5std_string& strg) with VL string */
 	// Read and verify the attribute string as an std::string.
 	H5std_string read_str;
-	gr_attr.read(type, read_str);
+	gr_vlattr.read(vls_type, read_str);
 	if (read_str != ATTRSTR_DATA)
 	    TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,read_str=%s\n",__LINE__, ATTRSTR_DATA.c_str(), read_str.c_str());
-
 	PASSED();
     } // end try block
 
@@ -1237,6 +1307,7 @@ extern "C"
 void test_attr()
 {
     // Output message about test being performed
+    //MESSAGE("Testing Attributes\n");
     MESSAGE(5, ("Testing Attributes\n"));
 
     test_attr_basic_write();	// Test basic H5A writing code
