@@ -33,7 +33,6 @@
 #endif  // H5_NO_STD
 #endif
 
-#include "testhdf5.h"   // C test header file
 #include "H5Cpp.h"      // C++ API header file
 
 #ifndef H5_NO_NAMESPACE
@@ -116,7 +115,8 @@ static void test_compound_2()
     const int	   nelmts = NTESTELEM;
     const hsize_t  four = 4;
     int		   i;
-    unsigned char *buf=NULL, *orig=NULL, *bkg=NULL;
+    unsigned char *buf = NULL, *orig = NULL, *bkg = NULL;
+    ArrayType *array_dt = NULL;
 
     // Output message about test being performed
     SUBTEST("Compound Element Reordering");
@@ -139,7 +139,7 @@ static void test_compound_2()
 	memcpy(buf, orig, nelmts*sizeof(src_typ_t));
 
 	// Build hdf5 datatypes
-	ArrayType* array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
+	array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
 
 	// Create an empty compound datatype
 	CompType st(sizeof(src_typ_t));
@@ -149,6 +149,7 @@ static void test_compound_2()
 	st.insertMember("d", HOFFSET(src_typ_t, d), PredType::NATIVE_INT);
 	st.insertMember("e", HOFFSET(src_typ_t, e), PredType::NATIVE_INT);
 	array_dt->close();
+        delete array_dt;
 
 	array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
 
@@ -178,13 +179,13 @@ static void test_compound_2()
 		s_ptr->e    != d_ptr->e) {
 		H5_FAILED();
 		cerr << "    i=" << i << endl;
-		cerr << "    src={a=" << s_ptr->a << ", b=" << s_ptr->b 
-		     << "c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << "," 
-		     << s_ptr->c[2] << "," << s_ptr->c[3] << ", d=" 
+		cerr << "    src={a=" << s_ptr->a << ", b=" << s_ptr->b
+		     << "c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << ","
+		     << s_ptr->c[2] << "," << s_ptr->c[3] << ", d="
 		     << s_ptr->d << ", e=" << s_ptr->e << "}" << endl;
-		cerr << "    dst={a=" << s_ptr->a << ", b=" << s_ptr->b 
-		     << "c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << "," 
-		     << s_ptr->c[2] << "," << s_ptr->c[3] << ", d=" 
+		cerr << "    dst={a=" << s_ptr->a << ", b=" << s_ptr->b
+		     << "c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << ","
+		     << s_ptr->c[2] << "," << s_ptr->c[3] << ", d="
 		     << s_ptr->d << ", e=" << s_ptr->e << "}" << endl;
 	    }
     	}
@@ -203,6 +204,9 @@ static void test_compound_2()
 cerr << "test_compound_2 in catch" << endl;
         issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
+
+    if(array_dt)
+        delete array_dt;
 }   // test_compound_2()
 
 
@@ -236,7 +240,8 @@ static void test_compound_3()
     int		   i;
     const int	   nelmts = NTESTELEM;
     const hsize_t  four = 4;
-    unsigned char *buf=NULL, *orig=NULL, *bkg=NULL;
+    unsigned char *buf = NULL, *orig = NULL, *bkg = NULL;
+    ArrayType* array_dt = NULL;
 
     // Output message about test being performed
     SUBTEST("Compound Datatype Subset Conversions");
@@ -259,7 +264,7 @@ static void test_compound_3()
 	memcpy(buf, orig, nelmts*sizeof(src_typ_t));
 
 	/* Build hdf5 datatypes */
-	ArrayType* array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
+	array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
 
 	// Create an empty compound datatype
 	CompType st(sizeof(src_typ_t));
@@ -269,6 +274,7 @@ static void test_compound_3()
 	st.insertMember("d", HOFFSET(src_typ_t, d), PredType::NATIVE_INT);
 	st.insertMember("e", HOFFSET(src_typ_t, e), PredType::NATIVE_INT);
 	array_dt->close();
+        delete array_dt;
 
 	array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
 
@@ -294,13 +300,13 @@ static void test_compound_3()
 		s_ptr->e    != d_ptr->e) {
 		H5_FAILED();
 		cerr << "    i=" << i << endl;
-		cerr << "    src={a=" << s_ptr->a << ", b=" << s_ptr->b 
-		     << ", c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << "," 
-		     << s_ptr->c[2] << "," << s_ptr->c[3] << "], d=" 
+		cerr << "    src={a=" << s_ptr->a << ", b=" << s_ptr->b
+		     << ", c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << ","
+		     << s_ptr->c[2] << "," << s_ptr->c[3] << "], d="
 		     << s_ptr->d << ", e=" << s_ptr->e << "}" << endl;
 		cerr << "    dst={a=" << d_ptr->a
-		     << ", c=[" << d_ptr->c[0] << "," << d_ptr->c[1] << "," 
-		     << d_ptr->c[2] << "," << d_ptr->c[3] << "], e=" 
+		     << ", c=[" << d_ptr->c[0] << "," << d_ptr->c[1] << ","
+		     << d_ptr->c[2] << "," << d_ptr->c[3] << "], e="
 		     << d_ptr->e << "}" << endl;
 	    } // if
 	} // for
@@ -320,6 +326,9 @@ static void test_compound_3()
 cerr << "test_compound_3 in catch" << endl;
 	issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
+
+    if(array_dt)
+        delete array_dt;
 }   // test_compound_3()
 
 
@@ -358,7 +367,8 @@ static void test_compound_4()
     int		   i;
     const int	   nelmts = NTESTELEM;
     const hsize_t  four = 4;
-    unsigned char *buf=NULL, *orig=NULL, *bkg=NULL;
+    unsigned char *buf = NULL, *orig = NULL, *bkg = NULL;
+    ArrayType* array_dt = NULL;
 
     // Output message about test being performed
     SUBTEST("Compound Element Shrinking & Reordering");
@@ -381,7 +391,7 @@ static void test_compound_4()
 	memcpy(buf, orig, nelmts*sizeof(src_typ_t));
 
 	/* Build hdf5 datatypes */
-	ArrayType* array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
+	array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
 
 	// Create an empty compound datatype
 	CompType st(sizeof(src_typ_t));
@@ -391,7 +401,8 @@ static void test_compound_4()
 	st.insertMember("d", HOFFSET(src_typ_t, d), PredType::NATIVE_INT);
 	st.insertMember("e", HOFFSET(src_typ_t, e), PredType::NATIVE_INT);
 	array_dt->close();
-    
+        delete array_dt;
+
 	array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
 
 	// Create an empty compound datatype
@@ -402,7 +413,7 @@ static void test_compound_4()
 	dt.insertMember("d", HOFFSET(dst_typ_t, d), PredType::NATIVE_SHORT);
 	dt.insertMember("e", HOFFSET(dst_typ_t, e), PredType::NATIVE_INT);
 	array_dt->close();
-    
+
 	/* Perform the conversion */
 	st.convert(dt, (size_t)nelmts, buf, bkg);
 
@@ -421,17 +432,17 @@ static void test_compound_4()
 	    {
 		H5_FAILED();
 		cerr << "    i=" << i << endl;
-		cerr << "    src={a=" << s_ptr->a << ", b=" << s_ptr->b 
-		     << "c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << "," 
-		     << s_ptr->c[2] << "," << s_ptr->c[3] << ", d=" 
+		cerr << "    src={a=" << s_ptr->a << ", b=" << s_ptr->b
+		     << "c=[" << s_ptr->c[0] << "," << s_ptr->c[1] << ","
+		     << s_ptr->c[2] << "," << s_ptr->c[3] << ", d="
 		     << s_ptr->d << ", e=" << s_ptr->e << "}" << endl;
-		cerr << "    dst={a=" << d_ptr->a << ", b=" << d_ptr->b 
-		     << "c=[" << d_ptr->c[0] << "," << d_ptr->c[1] << "," 
-		     << d_ptr->c[2] << "," << d_ptr->c[3] << ", d=" 
+		cerr << "    dst={a=" << d_ptr->a << ", b=" << d_ptr->b
+		     << "c=[" << d_ptr->c[0] << "," << d_ptr->c[1] << ","
+		     << d_ptr->c[2] << "," << d_ptr->c[3] << ", d="
 		     << d_ptr->d << ", e=" << d_ptr->e << "}" << endl;
 	    } // if
 	} // for
-    
+
 	/* Release resources */
 	free(buf);
 	free(bkg);
@@ -447,6 +458,9 @@ static void test_compound_4()
 cerr << "test_compound_4 in catch" << endl;
         issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
+
+    if(array_dt)
+        delete array_dt;
 }   // test_compound_4()
 
 
@@ -487,19 +501,21 @@ static void test_compound_5()
     dst_typ_t  *dst;
     void        *buf = calloc(2, sizeof(dst_typ_t));
     void        *bkg = calloc(2, sizeof(dst_typ_t));
+    ArrayType* array_dt = NULL;
 
     // Output message about test being performed
     SUBTEST("Optimized Struct Converter");
     try {
 
 	/* Build datatypes */
-	ArrayType* array_dt = new ArrayType(PredType::NATIVE_SHORT, 1, dims);	
+	array_dt = new ArrayType(PredType::NATIVE_SHORT, 1, dims);
 	CompType short_array(4*sizeof(short));
 	short_array.insertMember("_", 0, *array_dt);
 	array_dt->close();
+        delete array_dt;
 
 	CompType int_array(4*sizeof(int));
-	array_dt = new ArrayType(PredType::NATIVE_INT, 1, dims);	
+	array_dt = new ArrayType(PredType::NATIVE_INT, 1, dims);
 	int_array.insertMember("_", 0, *array_dt);
 	array_dt->close();
 
@@ -532,7 +548,7 @@ static void test_compound_5()
 	    src[1].coll_ids[0]!=dst[1].coll_ids[0] ||
 	    src[1].coll_ids[1]!=dst[1].coll_ids[1] ||
 	    src[1].coll_ids[2]!=dst[1].coll_ids[2] ||
-	    src[1].coll_ids[3]!=dst[1].coll_ids[3]) 
+	    src[1].coll_ids[3]!=dst[1].coll_ids[3])
 	{ H5_FAILED(); }
 
 	/* Free memory buffers */
@@ -546,6 +562,9 @@ static void test_compound_5()
 cerr << "test_compound_5 in catch" << endl;
         issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
+
+    if(array_dt)
+        delete array_dt;
 }   // test_compound_5()
 
 
@@ -614,17 +633,17 @@ static void test_compound_6()
 	    s_ptr = ((src_typ_t*)orig) + i;
 	    d_ptr = ((dst_typ_t*)buf)  + i;
 	    if (s_ptr->b    != d_ptr->b    ||
-		s_ptr->d    != d_ptr->d) 
+		s_ptr->d    != d_ptr->d)
 	    {
 		H5_FAILED();
 		cerr << "    i=" << i << endl;
-		cerr << "    src={b=" << s_ptr->b << ", d=" << s_ptr->d 
+		cerr << "    src={b=" << s_ptr->b << ", d=" << s_ptr->d
 		     << "}" << endl;
-		cerr << "    dst={b=" << d_ptr->b << ", d=" << d_ptr->d 
+		cerr << "    dst={b=" << d_ptr->b << ", d=" << d_ptr->d
 		     << "}" << endl;
 	    } // if
 	} // for
-    
+
 	/* Release resources */
 	free(buf);
 	free(bkg);
@@ -730,6 +749,7 @@ extern "C"
 void test_compound()
 {
     // Output message about test being performed
+    //MESSAGE("Testing Compound Data Type operations\n");
     MESSAGE(5, ("Testing Compound Data Type operations\n"));
 
     test_compound_1();	// various things about compound data types
