@@ -26,8 +26,6 @@
    into the list of AddTest() calls in main() below.  Functions which depend
    on other functionality should be placed below the AddTest() call for the
    base functionality testing.
-   Each test module should include testhdf5.h and define a unique set of
-   names for test files they create.
 
    EXTERNAL ROUTINES/VARIABLES:
 	TestInit(...) -- Initialize testing framework
@@ -57,7 +55,7 @@
 #endif  // H5_NO_STD
 #endif
 
-#include "testhdf5.h"	// C test header file
+#include "h5test.h"	// C test header file
 #include "H5Cpp.h"	// C++ API header file
 
 #ifndef H5_NO_NAMESPACE
@@ -73,18 +71,21 @@ main(int argc, char *argv[])
     TestInit(argv[0], NULL, NULL);
 
     // testing file creation and opening in tfile.cpp
-    AddTest("file", test_file, cleanup_file, "File I/O Operations", NULL);
+    AddTest("tfile", test_file, cleanup_file, "File I/O Operations", NULL);
+    // testing dataset functionalities in dset.cpp
+    AddTest("dsets", test_dset, cleanup_dsets, "Dataset I/O Operations", NULL);
     // testing dataspace functionalities in th5s.cpp
-    AddTest("h5s",  test_h5s,  cleanup_h5s,  "Dataspaces", NULL);
+    AddTest("th5s",  test_h5s,  cleanup_h5s,  "Dataspaces", NULL);
     // testing attribute functionalities in tattr.cpp
-    AddTest("attr", test_attr, cleanup_attr,  "Attributes", NULL);
+    AddTest("tattr", test_attr, cleanup_attr,  "Attributes", NULL);
     // testing reference functionalities in trefer.cpp
-    AddTest("reference", test_reference, cleanup_reference,  "References", NULL);
+    AddTest("trefer", test_reference, cleanup_reference,  "References", NULL);
     // testing variable-length strings in tvlstr.cpp
-    AddTest("vlstrings", test_vlstrings, cleanup_vlstrings,  "Variable-Length Strings", NULL);
-    AddTest("types", test_types, cleanup_types,  "Generic Data Types", NULL);
-    AddTest("compound", test_compound, cleanup_compound,  "Compound Data Types", NULL);
-    AddTest("filter", test_filters, cleanup_filters,  "Various Filters", NULL);
+    AddTest("tvlstr", test_vlstrings, cleanup_vlstrings,  "Variable-Length Strings", NULL);
+    AddTest("ttypes", test_types, cleanup_types,  "Generic Data Types", NULL);
+    AddTest("tcompound", test_compound, cleanup_compound,  "Compound Data Types", NULL);
+    AddTest("tfilter", test_filters, cleanup_filters,  "Various Filters", NULL);
+    AddTest("tlinks", test_links, cleanup_links,  "Various Links", NULL);
 /* Comment out tests that are not done yet. - BMR, Feb 2001
     AddTest("select", test_select, cleanup_select,  "Selections", NULL);
     AddTest("time", test_time, cleanup_time,  "Time Datatypes", NULL);
