@@ -33,7 +33,6 @@
 #endif  // H5_NO_STD
 #endif
 
-#include "testhdf5.h"   // C test header file
 #include "H5Cpp.h"      // C++ API header file
 
 #ifndef H5_NO_NAMESPACE
@@ -48,19 +47,21 @@
 #define FILTER_CHUNK_DIM2 25
 
 // will do this function later or use it as guideline - BMR - 2007/01/26
-static herr_t test_filter_internal(hid_t fid, const char *name, hid_t dcpl, 
+#if 0
+static herr_t test_filter_internal(hid_t fid, const char *name, hid_t dcpl,
 		int if_fletcher32, int corrupted, hsize_t *dset_size)
 {
     cerr << "do nothing right now" << endl;
     return(0);
 }
+#endif
 
 /* Temporary filter IDs used for testing */
 #define H5Z_FILTER_BOGUS        305
 static size_t filter_bogus(unsigned int flags, size_t cd_nelmts,
-    const unsigned int *cd_values, size_t nbytes, size_t *buf_size, void **buf); 
+    const unsigned int *cd_values, size_t nbytes, size_t *buf_size, void **buf);
 /* This message derives from H5Z */
-const H5Z_class_t H5Z_BOGUS[1] = {{
+const H5Z_class2_t H5Z_BOGUS[1] = {{
     H5Z_CLASS_T_VERS,       /* H5Z_class_t version */
     H5Z_FILTER_BOGUS,           /* Filter id number             */
     1, 1,               /* Encoding and decoding enabled */
@@ -118,7 +119,7 @@ static void test_null_filter()
     // Output message about test being performed
     SUBTEST("'Null' filter");
     try {
-	hsize_t  null_size;          // Size of dataset with null filter
+	//hsize_t  null_size;          // Size of dataset with null filter
 
 	// Prepare dataset create property list
 	DSetCreatPropList dsplist;
@@ -168,7 +169,6 @@ void test_szip_filter(H5File& file1)
 {
 #ifdef H5_HAVE_FILTER_SZIP
     int      points[DSET_DIM1][DSET_DIM2], check[DSET_DIM1][DSET_DIM2];
-    hsize_t  szip_size;       /* Size of dataset with szip filter */
     unsigned szip_options_mask=H5_SZIP_NN_OPTION_MASK;
     unsigned szip_pixels_per_block=4;
 
@@ -176,59 +176,62 @@ void test_szip_filter(H5File& file1)
     SUBTEST("szip filter (with encoder)");
 
     if ( h5_szip_can_encode() == 1) {
-    char* tconv_buf = new char [1000];
-    try {
-        const hsize_t   size[2] = {DSET_DIM1, DSET_DIM2};
+        char* tconv_buf = new char [1000];
 
-        // Create the data space
-        DataSpace space1(2, size, NULL);
+        try {
+            const hsize_t   size[2] = {DSET_DIM1, DSET_DIM2};
 
-        // Create a small conversion buffer to test strip mining (?)
-        DSetMemXferPropList xfer;
-        xfer.setBuffer (1000, tconv_buf, NULL);
+            // Create the data space
+            DataSpace space1(2, size, NULL);
 
-	// Prepare dataset create property list
-	DSetCreatPropList dsplist;
-	dsplist.setChunk(2, chunk_size);
+            // Create a small conversion buffer to test strip mining (?)
+            DSetMemXferPropList xfer;
+            xfer.setBuffer (1000, tconv_buf, NULL);
 
-	// Set up for szip compression
-	dsplist.setSzip(szip_options_mask, szip_pixels_per_block);
+            // Prepare dataset create property list
+            DSetCreatPropList dsplist;
+            dsplist.setChunk(2, chunk_size);
 
-	// Create a dataset with szip compression
-        DataSpace space2 (2, size, NULL);
-        DataSet dataset(file1.createDataSet (DSET_SZIP_NAME, PredType::NATIVE_INT, space2, dsplist));
+            // Set up for szip compression
+            dsplist.setSzip(szip_options_mask, szip_pixels_per_block);
 
-	hsize_t i, j, n;
-	for (i=n=0; i<size[0]; i++)
-        {
-            for (j=0; j<size[1]; j++)
+            // Create a dataset with szip compression
+            DataSpace space2 (2, size, NULL);
+            DataSet dataset(file1.createDataSet (DSET_SZIP_NAME, PredType::NATIVE_INT, space2, dsplist));
+
+            hsize_t i, j, n;
+            for (i=n=0; i<size[0]; i++)
             {
-                points[i][j] = n++;
+                for (j=0; j<size[1]; j++)
+                {
+                    points[i][j] = (int)n++;
+                }
             }
+
+            // Write to the dataset then read back the values
+            dataset.write ((void*)points, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+            dataset.read ((void*)check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+
+            // Check that the values read are the same as the values written
+            for (i = 0; i < size[0]; i++)
+                for (j = 0; j < size[1]; j++)
+                {
+                    int status = check_values (i, j, points[i][j], check[i][j]);
+                    if (status == -1)
+                        throw Exception("test_szip_filter", "Failed in testing szip method");
+                }
+            dsplist.close();
+            PASSED();
+        } // end of try
+
+        // catch all other exceptions
+        catch (Exception E)
+        {
+            issue_fail_msg("test_szip_filter()", __LINE__, __FILE__, E.getCDetailMsg());
         }
 
-	// Write to the dataset then read back the values
-        dataset.write ((void*)points, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
-        dataset.read ((void*)check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
-
-        // Check that the values read are the same as the values written
-        for (i = 0; i < size[0]; i++)
-            for (j = 0; j < size[1]; j++)
-            {
-                int status = check_values (i, j, points[i][j], check[i][j]);
-                if (status == -1)
-                    throw Exception("test_szip_filter", "Failed in testing szip method");
-            }
-	dsplist.close();
-	PASSED();
-    } // end of try
-
-    // catch all other exceptions
-    catch (Exception E)
-    {
-        issue_fail_msg("test_szip_filter()", __LINE__, __FILE__, E.getCDetailMsg());
-    }
-    } // if szip presents 
+        delete tconv_buf;
+    } // if szip presents
     else {
 	SKIPPED();
     }
@@ -258,7 +261,6 @@ void test_filters()
     hid_t       fapl_id;
     fapl_id = h5_fileaccess(); // in h5test.c, returns a file access template
 
-    int         nerrors=0;      // keep track of number of failures occurr
     try
     {
         // Use the file access template id to create a file access prop. list
