@@ -34,7 +34,6 @@
 #endif  // H5_NO_STD
 #endif
 
-#include "testhdf5.h"   // C test header file
 #include "H5Cpp.h"      // C++ API header file
 
 #ifndef H5_NO_NAMESPACE
@@ -48,6 +47,10 @@ const H5std_string      FILE2("trefer2.h5");
 const H5std_string      FILE3("trefer3.h5");
 const H5std_string      DSET_DEFAULT_NAME("default");
 
+// Dataset 1
+const H5std_string      DSET1_NAME("Dataset1");
+const int DSET1_LEN = 8;
+
 const H5std_string MEMBER1( "a_name" );
 const H5std_string MEMBER2( "b_name" );
 const H5std_string MEMBER3( "c_name" );
@@ -59,17 +62,9 @@ const int SPACE1_DIM1 = 4;
 
 // 2-D dataset with fixed dimensions
 const H5std_string      SPACE2_NAME("Space2");
-const int SPACE2_RANK = 2;
-const int SPACE2_DIM1 = 10;
-const int SPACE2_DIM2 = 10;
 
 // Larger 1-D dataset with fixed dimensions
 const H5std_string      SPACE3_NAME("Space3");
-const int SPACE3_RANK = 1;
-const int SPACE3_DIM1 = 100;
-
-// Element selection information
-const int POINT1_NPOINTS = 10;
 
 // Compound datatype
 typedef struct s1_t {
@@ -84,13 +79,13 @@ typedef struct s1_t {
 **      Tests references to various kinds of objects
 **
 ****************************************************************/
-static void test_reference_obj()
+static void test_reference_obj(void)
 {
     int    i;          // counting variables
     const  H5std_string write_comment="Foo!"; // Comments for group
 
     // Output message about test being performed
-    SUBTEST("Testing Object Reference Functions");
+    SUBTEST("Object Reference Functions");
 
     H5File* file1 = NULL;
     try {
@@ -100,9 +95,9 @@ static void test_reference_obj()
 
 	// Allocate write & read buffers
 	int temp_size = MAX(sizeof(unsigned),sizeof(hobj_ref_t));
-	wbuf=(hobj_ref_t*)malloc(temp_size*SPACE1_DIM1);
-	rbuf=(hobj_ref_t*)malloc(temp_size*SPACE1_DIM1);
-	tbuf=(hobj_ref_t*)malloc(temp_size*SPACE1_DIM1);
+	wbuf=(hobj_ref_t*)HDmalloc(temp_size*SPACE1_DIM1);
+	rbuf=(hobj_ref_t*)HDmalloc(temp_size*SPACE1_DIM1);
+	tbuf=(hobj_ref_t*)HDmalloc(temp_size*SPACE1_DIM1);
 
         // Create file FILE1
         file1 = new H5File (FILE1, H5F_ACC_TRUNC);
@@ -118,7 +113,7 @@ static void test_reference_obj()
 	group.setComment(".", write_comment);
 
 	// Create a dataset (inside /Group1)
-	DataSet dataset = group.createDataSet("Dataset1", PredType::NATIVE_UINT, sid1);
+	DataSet dataset = group.createDataSet(DSET1_NAME, PredType::NATIVE_UINT, sid1);
 
 	unsigned *tu32;      // Temporary pointer to uint32 data
 	for (tu32=(unsigned *)wbuf, i=0; i<SPACE1_DIM1; i++)
@@ -190,7 +185,7 @@ static void test_reference_obj()
 	sid1.close();
 	dataset.close();
 	delete file1;
-	
+
 	// Re-open the file
 	file1 = new H5File(FILE1, H5F_ACC_RDWR);
 
@@ -198,22 +193,22 @@ static void test_reference_obj()
 	dataset = file1->openDataSet("/Dataset3");
 
 	// Read selection from disk
-	dataset.read(rbuf, PredType::STD_REF_OBJ); 
+	dataset.read(rbuf, PredType::STD_REF_OBJ);
 
-	// Dereference dataset object by ctor, from the location where 
+	// Dereference dataset object by ctor, from the location where
 	// 'dataset' is located
 	DataSet dset2(dataset, &rbuf[0]);
 
 	// Check information in the referenced dataset
 	sid1 = dset2.getSpace();
 	hssize_t n_elements = sid1.getSimpleExtentNpoints();
-	verify_val((long)n_elements, (long)4, "DataSpace::getSimpleExtentNpoints", __LINE__, __FILE__);
+	verify_val((long)n_elements, 4, "DataSpace::getSimpleExtentNpoints", __LINE__, __FILE__);
 
 	// Read from disk
 	dset2.read(tbuf, PredType::NATIVE_UINT);
 
 	for(tu32=(unsigned *)tbuf,i=0; i<SPACE1_DIM1; i++,tu32++)
-	   VERIFY(*tu32, (uint32_t)(i*3), "Data");
+	   verify_val(*tu32, (uint32_t)(i*3), "DataSpace::getSimpleExtentNpoints", __LINE__, __FILE__);
 
 	// Close dereferenced dataset
 	dset2.close();
@@ -225,6 +220,57 @@ static void test_reference_obj()
 	H5std_string read_comment1 = group.getComment(".", 10);
 	verify_val(read_comment1, write_comment, "Group::getComment", __LINE__, __FILE__);
 
+	// Test that getComment handles failures gracefully
+	try {
+	    H5std_string read_comment_tmp = group.getComment(NULL);
+	}
+	catch (Exception E) {} // We expect this to fail
+
+	// Test reading the name of an item in the group
+
+	// Test getObjnameByIdx(idx)
+	H5std_string name;
+	name = group.getObjnameByIdx(0);
+	verify_val(name, DSET1_NAME, "Group::getObjnameByIdx", __LINE__, __FILE__);
+	// Test getObjnameByIdx(hsize_t idx, H5std_string& name, size_t size)
+	name.clear();
+	ssize_t name_size = group.getObjnameByIdx(0, name, 5);
+	verify_val(name, "Data", "Group::getObjnameByIdx(index,(std::string)buf,buf_len)", __LINE__, __FILE__);
+	verify_val(name_size, DSET1_LEN, "Group::getObjnameByIdx(index,(std::string)buf,buf_len)", __LINE__, __FILE__);
+
+	name.clear();
+	name_size = group.getObjnameByIdx(0, name, name_size+1);
+	verify_val(name, DSET1_NAME, "Group::getObjnameByIdx(index,(std::string)buf,buf_len)", __LINE__, __FILE__);
+	verify_val(name_size, DSET1_LEN, "Group::getObjnameByIdx(index,(std::string)buf,buf_len)", __LINE__, __FILE__);
+
+	// Test getObjnameByIdx(hsize_t idx, char* name, size_t size)
+	group.getObjnameByIdx(0, name, name_size+1);
+	verify_val(name, DSET1_NAME, "Group::getObjnameByIdx(index,(char*)buf,buf_len)", __LINE__, __FILE__);
+	verify_val(name_size, DSET1_LEN, "Group::getObjnameByIdx(index,(char*)buf,buf_len)", __LINE__, __FILE__);
+
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+	// Test getting the type of objects
+	
+	// Test getObjTypeByIdx(hsize_t idx)
+	obj_type = group.getObjTypeByIdx(0);
+	verify_val(obj_type, H5G_DATASET, "Group::getObjTypeByIdx(index)", __LINE__, __FILE__);
+
+	// Test getObjTypeByIdx(hsize_t idx, char* type_name)
+	obj_type = H5G_UNKNOWN;
+	char type_name_C[256];
+	obj_type = group.getObjTypeByIdx(0, type_name_C);
+	verify_val(obj_type, H5G_DATASET, "Group::getObjTypeByIdx(index, (char*)name)", __LINE__, __FILE__);
+	verify_val((const char*)type_name_C, (const char*)"dataset", "Group::getObjTypeByIdx(index, (char*)name)", __LINE__, __FILE__);
+
+	// Test getObjTypeByIdx(hsize_t idx, H5std_string& type_name)
+	obj_type = H5G_UNKNOWN;
+	H5std_string type_name;
+	obj_type = group.getObjTypeByIdx(0, type_name);
+	verify_val(obj_type, H5G_DATASET, "Group::getObjTypeByIdx(index, (char*)name)", __LINE__, __FILE__);
+	verify_val(type_name, "dataset", "Group::getObjTypeByIdx(index, (char*)name)", __LINE__, __FILE__);
+
+#endif // ifndef H5_NO_DEPRECATED_SYMBOLS
+
 	// Close group
 	group.close();
 
@@ -234,14 +280,14 @@ static void test_reference_obj()
 	verify_val(read_comment2, write_comment, "Group::getComment", __LINE__, __FILE__);
 	group.close();
 
-	// Dereference group object by ctor and using dataset to specify 
+	// Dereference group object by ctor and using dataset to specify
 	// location
 	Group new_group(dataset, &rbuf[2]);
 	H5std_string read_comment3 = new_group.getComment(".", 10);
 	verify_val(read_comment3, write_comment, "Group::getComment", __LINE__, __FILE__);
-	group.close();
+	new_group.close();
 
-	// Dereference datatype object from the location where 'dataset' 
+	// Dereference datatype object from the location where 'dataset'
 	// is located
 	dtype1.dereference(dataset, &rbuf[3]);
 
@@ -270,15 +316,18 @@ static void test_reference_obj()
 	file1->close();
 
 	// Free memory buffers
-	free(wbuf);
-	free(rbuf);
-	free(tbuf);
+	HDfree(wbuf);
+	HDfree(rbuf);
+	HDfree(tbuf);
 
 	PASSED();
     } // end try
     catch (Exception E) {
 	issue_fail_msg("test_reference_obj()", __LINE__, __FILE__, E.getCDetailMsg());
     }
+
+    if(file1)
+        delete file1;
 }   // test_reference_obj()
 
 /****************************************************************
@@ -289,9 +338,10 @@ static void test_reference_obj()
 #ifdef __cplusplus
 extern "C"
 #endif
-void test_reference()
+void test_reference(void)
 {
     // Output message about test being performed
+    //MESSAGE("Testing References\n");
     MESSAGE(5, ("Testing References\n"));
 
     test_reference_obj();       // Test basic object reference functionality
@@ -307,7 +357,7 @@ void test_reference()
 #ifdef __cplusplus
 extern "C"
 #endif
-void cleanup_reference()
+void cleanup_reference(void)
 {
     HDremove(FILE1.c_str());
 }
