@@ -31,12 +31,13 @@
 ! NOTES
 !                         *** IMPORTANT ***
 !  If you add a new H5R function you must add the function name to the
-!  Windows dll file 'hdf5_fortrandll.def' in the fortran/src directory.
+!  Windows dll file 'hdf5_fortrandll.def.in' in the fortran/src directory.
 !  This is needed for Windows based operating systems.
 !
 !*****
 MODULE H5R_PROVISIONAL
   USE H5GLOBAL
+  USE, INTRINSIC :: ISO_C_BINDING
 
   ! If you change the value of these parameters, do not forget to change corresponding
   ! values in the H5f90.h file.
@@ -51,6 +52,19 @@ MODULE H5R_PROVISIONAL
   !             INTEGER ref(REF_REG_BUF_LEN)
   !        END TYPE
   !
+
+  TYPE :: hdset_reg_ref_t_f03 
+     INTEGER(C_SIGNED_CHAR), DIMENSION(1:H5R_DSET_REG_REF_BUF_SIZE_F) :: ref
+  END TYPE hdset_reg_ref_t_f03
+
+  INTERFACE h5rget_region_f
+
+     MODULE PROCEDURE h5rget_region_region_f ! obsolete
+     MODULE PROCEDURE h5rget_region_ptr_f  ! F2003
+
+  END INTERFACE
+
+
   INTERFACE h5rcreate_f
 
      MODULE PROCEDURE h5rcreate_object_f ! obsolete
@@ -123,8 +137,114 @@ MODULE H5R_PROVISIONAL
      END FUNCTION h5rcreate_ptr_c
   END INTERFACE
 
+  INTERFACE
+     INTEGER FUNCTION h5rget_region_ptr_c(dset_id, ref, space_id)
+       USE, INTRINSIC :: ISO_C_BINDING
+       USE H5GLOBAL
+       !DEC$IF DEFINED(HDF5F90_WINDOWS)
+       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RGET_REGION_PTR_C':: h5rget_region_ptr_c
+       !DEC$ENDIF
+       INTEGER(HID_T), INTENT(IN) :: dset_id
+       TYPE(C_PTR), VALUE :: ref
+       INTEGER(HID_T), INTENT(OUT) :: space_id
+     END FUNCTION h5rget_region_ptr_c
+  END INTERFACE
+
 CONTAINS
 
+!****s* H5R/h5rget_region_region_f
+!
+! NAME
+!  h5rget_region_region_f
+!
+! PURPOSE
+!  Retrieves a dataspace with the specified region selected
+!
+! INPUTS
+!  dset_id 	 - identifier of the dataset containing
+!                  reference to the regions
+!  ref 	         - reference to open
+! OUTPUTS
+!  space_id 	 - dataspace identifier
+!  hdferr 	 - Returns 0 if successful and -1 if fails
+! AUTHOR
+!  Elena Pourmal
+!  August 12, 1999
+!
+! HISTORY 	
+!  Explicit Fortran interfaces were added for
+!  called C functions (it is needed for Windows
+!  port).  February 28, 2001
+!
+! NOTES
+!  This is a module procedure for the h5rget_region_f subroutine.
+!
+! SOURCE
+  SUBROUTINE h5rget_region_region_f(dset_id, ref, space_id, hdferr)
+    IMPLICIT NONE
+    INTEGER(HID_T), INTENT(IN) :: dset_id      ! Dataset identifier
+    TYPE(hdset_reg_ref_t_f), INTENT(IN) :: ref ! Dataset region reference
+    INTEGER(HID_T), INTENT(OUT) :: space_id    ! Space identifier
+    INTEGER, INTENT(OUT) :: hdferr             ! Error code
+!*****
+    INTEGER :: ref_f(REF_REG_BUF_LEN)          ! Local buffer to pass reference
+
+    INTERFACE
+       INTEGER FUNCTION h5rget_region_region_c(dset_id, ref_f, space_id)
+         USE H5GLOBAL
+         !DEC$IF DEFINED(HDF5F90_WINDOWS)
+         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RGET_REGION_REGION_C':: h5rget_region_region_c
+         !DEC$ENDIF
+         INTEGER(HID_T), INTENT(IN) :: dset_id
+         !              INTEGER, PARAMETER :: REF_REG_BUF_LEN = 3
+         INTEGER :: ref_f(REF_REG_BUF_LEN)
+         INTEGER(HID_T), INTENT(OUT) :: space_id
+       END FUNCTION h5rget_region_region_c
+    END INTERFACE
+
+    ref_f = ref%ref
+    hdferr = h5rget_region_region_c(dset_id, ref_f, space_id )
+
+  END SUBROUTINE h5rget_region_region_f
+
+!****s* H5R/h5rget_region_ptr_f
+!
+! NAME
+!  h5rget_region_ptr_f
+!
+! PURPOSE
+!  Retrieves a dataspace with the specified region 
+!  selected using pointer
+!
+! INPUTS
+!  dset_id 	 - identifier of the dataset containing
+!                  reference to the regions
+!  ref 	         - reference to open
+! OUTPUTS
+!  space_id 	 - dataspace identifier
+!  hdferr 	 - Returns 0 if successful and -1 if fails
+! AUTHOR
+!  M. Scot Breitenfeld
+!  August 4, 2012
+!
+! NOTES
+!  This is a module procedure for the h5rget_region_f subroutine.
+!
+! SOURCE
+  SUBROUTINE h5rget_region_ptr_f(dset_id, ref, space_id, hdferr)
+    IMPLICIT NONE
+    INTEGER(HID_T), INTENT(IN) :: dset_id      ! Dataset identifier
+    TYPE(C_PTR), INTENT(IN) :: ref ! Dataset region reference
+    INTEGER(HID_T), INTENT(OUT) :: space_id    ! Space identifier
+    INTEGER, INTENT(OUT) :: hdferr             ! Error code
+!*****
+    INTEGER :: ref_f(REF_REG_BUF_LEN)          ! Local buffer to pass reference
+
+    hdferr = h5rget_region_ptr_c(dset_id, ref, space_id )
+
+  END SUBROUTINE h5rget_region_ptr_f
+
+
 !****s* H5R (F03)/h5rcreate_object_f
 !
 ! NAME
@@ -138,9 +258,7 @@ CONTAINS
 !  name      - name of the object at the specified location
 ! Outputs:
 !  ref 	     - reference to the specified object
-!  hdferr:   - error code
-!               Success:  0
-!               Failure: -1
+!  hdferr    - returns 0 if successful and -1 if fails
 ! AUTHOR
 !  Elena Pourmal
 !  August 12, 1999
@@ -175,7 +293,7 @@ CONTAINS
 
   END SUBROUTINE h5rcreate_object_f
 
-!****s* H5R (F03)/h5rcreate_region_f
+!****s* H5R (F90)/h5rcreate_region_f
 !
 ! NAME
 !  h5rcreate_region_f
@@ -183,16 +301,13 @@ CONTAINS
 ! PURPOSE
 !  Creates reference to the dataset region
 !
-! Inputs:
+! INPUTS
 !  loc_id 	 - location identifier
 !  name 	 - name of the dataset at the specified location
 !  space_id 	 - dataspace identifier that describes selected region
-! Outputs:
+! OUTPUTS
 !  ref 	         - reference to the dataset region
-!  hdferr:	 - error code
-!                   Success:  0
-!                   Failure: -1
-!
+!  hdferr        - returns 0 if successful and -1 if fails
 ! AUTHOR
 !  Elena Pourmal
 !  August 12, 1999
@@ -205,46 +320,39 @@ CONTAINS
 ! NOTES
 !  This is a module procedure for the h5rcreate_f subroutine.
 !
-! Signature:
+! SOURCE
   SUBROUTINE h5rcreate_region_f(loc_id, name, space_id, ref, hdferr)
-    USE, INTRINSIC :: ISO_C_BINDING
     IMPLICIT NONE
     INTEGER(HID_T), INTENT(IN) :: loc_id   ! Location identifier
     CHARACTER(LEN=*), INTENT(IN) :: name   ! Name of the dataset at location specified
                                            ! by loc_id identifier
     INTEGER(HID_T), INTENT(IN) :: space_id ! Dataset's dataspace identifier
-    TYPE(hdset_reg_ref_t_f), INTENT(INOUT), TARGET :: ref ! Dataset region reference
+    TYPE(hdset_reg_ref_t_f), INTENT(OUT) :: ref ! Dataset region reference
     INTEGER, INTENT(OUT) :: hdferr         ! Error code
 !*****
     INTEGER :: namelen                     ! Name length
     INTEGER :: ref_f(REF_REG_BUF_LEN)      ! Local buffer to pass reference
 
-    TYPE(C_PTR) :: f_ptr
-
-!  !$    INTERFACE
-!  !$       INTEGER FUNCTION h5rcreate_region_c(ref_f, loc_id, name, namelen, space_id)
-!  !$         USE H5GLOBAL
-!  !$         !DEC$IF DEFINED(HDF5F90_WINDOWS)
-!  !$         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RCREATE_REGION_C':: h5rcreate_region_c
-!  !$         !DEC$ENDIF
-!  !$         !DEC$ATTRIBUTES reference :: name
-!  !$         !              INTEGER, PARAMETER :: REF_REG_BUF_LEN = 3
-!  !$         INTEGER :: ref_f(REF_REG_BUF_LEN)
-!  !$         INTEGER(HID_T), INTENT(IN) :: loc_id
-!  !$         CHARACTER(LEN=*), INTENT(IN) :: name
-!  !$         INTEGER :: namelen
-!  !$         INTEGER(HID_T), INTENT(IN) :: space_id
-!  !$       END FUNCTION h5rcreate_region_c
-!  !$    END INTERFACE
-
-    f_ptr = C_LOC(ref)
+    INTERFACE
+       INTEGER FUNCTION h5rcreate_region_c(ref_f, loc_id, name, namelen, space_id)
+         USE H5GLOBAL
+         !DEC$IF DEFINED(HDF5F90_WINDOWS)
+         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RCREATE_REGION_C':: h5rcreate_region_c
+         !DEC$ENDIF
+         !DEC$ATTRIBUTES reference :: name
+         !              INTEGER, PARAMETER :: REF_REG_BUF_LEN = 3
+         INTEGER :: ref_f(REF_REG_BUF_LEN)
+         INTEGER(HID_T), INTENT(IN) :: loc_id
+         CHARACTER(LEN=*), INTENT(IN) :: name
+         INTEGER :: namelen
+         INTEGER(HID_T), INTENT(IN) :: space_id
+       END FUNCTION h5rcreate_region_c
+    END INTERFACE
 
     namelen = LEN(name)
-    hdferr = h5rcreate_ptr_c(f_ptr, loc_id, name, namelen, 1, space_id)
-
-!  !$            ref_f = 0
-!  !$            hdferr = h5rcreate_region_c(ref_f, loc_id, name, namelen, space_id )
-!  !$            ref%ref = ref_f
+    ref_f = 0
+    hdferr = h5rcreate_region_c(ref_f, loc_id, name, namelen, space_id )
+    ref%ref = ref_f
 
   END SUBROUTINE h5rcreate_region_f
 
@@ -264,9 +372,7 @@ CONTAINS
 !                H5T_STD_REF_DSETREG
 ! Outputs:
 !  ref	      - reference created by the function call.
-!  hdferr     - error code
-!		   Success:  0
-!		   Failure: -1
+!  hdferr     - returns 0 if successful and -1 if fails.
 ! OPTIONAL
 !  space_id   - dataspace identifier that describes selected region
 !
@@ -313,9 +419,7 @@ CONTAINS
 !  ref 	    - reference to open
 ! Outputs:
 !  obj_id   - object_identifier
-!  hdferr:  - error code
-!              Success:  0
-!              Failure: -1
+!  hdferr   - returns 0 if successful and -1 if fails
 ! AUTHOR
 !  Elena Pourmal
 !  August 12, 1999
@@ -353,14 +457,12 @@ CONTAINS
 !  Opens the dataset region
 !
 ! Inputs:
-!  dset_id 	 - identifier of the dataset containing
-!                  reference to teh regions
-!  ref 	         - reference to open
+!  dset_id  - identifier of the dataset containing
+!             reference to teh regions
+!  ref 	    - reference to open
 ! Outputs:
-!  obj_id 	 - dataspace identifier
-!  hdferr:	 - error code
-!                   Success:  0
-!                   Failure: -1
+!  obj_id   - dataspace identifier
+!  hdferr   - returns 0 if successful and -1 if fails
 !
 ! AUTHOR
 !  Elena Pourmal
@@ -405,9 +507,8 @@ CONTAINS
 !  ref        - Reference to open.
 ! Outputs:
 !  ref_obj_id - identifier of referenced object
-!  hdferr     - error code
-!		 Success:  0
-!		 Failure: -1
+!  hdferr     - returns 0 if successful and -1 if fails
+!
 ! AUTHOR
 !  M. Scot Breitenfeld
 !  June 20, 2008
@@ -441,37 +542,32 @@ CONTAINS
 !  Retrieves a name of a referenced object.
 !
 ! Inputs:
-!  loc_id    - Identifier for the dataset containing the reference or for the group that dataset is in.
+!  loc_id    - Identifier for the file containing the reference or for any object in that file.
 !  ref 	     - An object or dataset region reference.
 !
 ! Outputs:
 !  name      - A name associated with the referenced object or dataset region.
-!
-!  hdferr:   - error code
-!               Success:  0
-!               Failure: -1
+!  hdferr    - Returns 0 if successful and -1 if fails.
 !
 ! Optional parameters:
-!  size     - The size of the name buffer.
+!  size     - The size of the name buffer, returning 0 (zero) if no name is associated 
+!             with the identifier.
 !
 ! AUTHOR
 !  M. Scot Breitenfeld
 !  March 28, 2008
 !
-! Signature:S
+! Signature:
   SUBROUTINE h5rget_name_object_f(loc_id,  ref, name, hdferr, size)
     USE, INTRINSIC :: ISO_C_BINDING
     IMPLICIT NONE
-    INTEGER(HID_T), INTENT(IN) :: loc_id   ! Identifier for the dataset containing the reference
-                                           ! or for the group that dataset is in.
-    TYPE(hobj_ref_t_f), INTENT(IN), TARGET :: ref  ! Object reference
-    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size ! The size of the name buffer,
-                                                   ! returning 0 (zero) if no name is associated
-                                                   ! with the identifier
-    CHARACTER(LEN=*), INTENT(OUT) :: name  ! A name associated with the referenced object or dataset region.
-    INTEGER, INTENT(OUT) :: hdferr         ! Error code
+    INTEGER(HID_T), INTENT(IN) :: loc_id
+    TYPE(hobj_ref_t_f), INTENT(IN), TARGET :: ref
+    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size
+    CHARACTER(LEN=*), INTENT(OUT) :: name
+    INTEGER, INTENT(OUT) :: hdferr
 !*****
-    INTEGER(HADDR_T) :: ref_f              ! Local buffer to pass reference
+    INTEGER(HADDR_T) :: ref_f  ! Local buffer to pass reference
 
     INTEGER(SIZE_T) :: size_default
     INTEGER(SIZE_T) :: name_len
@@ -483,7 +579,6 @@ CONTAINS
 
     hdferr = h5rget_name_ptr_c(loc_id, 0, f_ptr, name, name_len, size_default)
 
-
     IF(PRESENT(size)) size = size_default
 
   END SUBROUTINE h5rget_name_object_f
@@ -496,18 +591,15 @@ CONTAINS
 !  Retrieves a name of a dataset region.
 !
 ! Inputs:
-!  loc_id  - Identifier for the dataset containing the reference or
-!            for the group that dataset is in.
+!  loc_id  - Identifier for the file containing the reference or for any object in that file.
 !  ref 	   - An object or dataset region reference.
 !
 ! Outputs:
 !  name    - A name associated with the referenced object or dataset region.
-!  hdferr  - error code
-!              Success:  0
-!              Failure: -1
+!  hdferr  - Returns 0 if successful and -1 if fails.
 !
 ! Optional parameters:
-!  size    - The size of the name buffer.
+!  size    - The size of the name buffer, returning 0 (zero) if no name is associated with the identifier
 !
 ! AUTHOR
 !  M. Scot Breitenfeld
@@ -517,13 +609,11 @@ CONTAINS
   SUBROUTINE h5rget_name_region_f(loc_id, ref, name, hdferr, size)
     USE, INTRINSIC :: ISO_C_BINDING
     IMPLICIT NONE
-    INTEGER(HID_T), INTENT(IN) :: loc_id   ! Identifier for the dataset containing the reference
-                                           ! or for the group that dataset is in.
-    TYPE(hdset_reg_ref_t_f), INTENT(IN), TARGET :: ref ! Object reference
-    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size     ! The size of the name buffer,
-                                                       ! returning 0 (zero) if no name is associated with the identifier
-    CHARACTER(LEN=*), INTENT(OUT) :: name  ! A name associated with the referenced object or dataset region.
-    INTEGER, INTENT(OUT) :: hdferr         ! Error code
+    INTEGER(HID_T), INTENT(IN) :: loc_id
+    TYPE(hdset_reg_ref_t_f), INTENT(IN), TARGET :: ref
+    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size
+    CHARACTER(LEN=*), INTENT(OUT) :: name
+    INTEGER, INTENT(OUT) :: hdferr
 !*****
     INTEGER :: ref_f(REF_REG_BUF_LEN)      ! Local buffer to pass reference
     INTEGER(SIZE_T) :: size_default
@@ -549,20 +639,17 @@ CONTAINS
   !  Retrieves a name of a referenced object.
   !
   ! Inputs:
-  !  loc_id   - Identifier for the dataset containing the reference or
-  !             for the group that dataset is in.
+  !  loc_id   - Identifier for the file containing the reference or for any object in that file.
   !  ref_type - Type of reference.
   !  ref      - An object or dataset region reference.
   !
   ! Outputs:
   !  name     - A name associated with the referenced object or dataset ptr.
-  !
-  !  hdferr   - error code
-  !		  Success:  0
-  !		  Failure: -1
+  !  hdferr   - Returns 0 if successful and -1 if fails.
   !
   ! Optional parameters:
-  !   size   - The size of the name buffer.
+  !   size    - The size of the name buffer, returning 0 (zero) if no name is associated
+  !             with the identifier
   !
   ! AUTHOR
   !  M. Scot Breitenfeld
@@ -572,15 +659,12 @@ CONTAINS
   SUBROUTINE h5rget_name_ptr_f(loc_id, ref_type, ref, name, hdferr, size)
     USE, INTRINSIC :: ISO_C_BINDING
     IMPLICIT NONE
-    INTEGER(HID_T), INTENT(IN) :: loc_id   ! Identifier for the dataset containing the reference
-                                           !  or for the group that dataset is in.
-    INTEGER, INTENT(IN) :: ref_type ! Type of reference.
-    TYPE(C_PTR), INTENT(IN) :: ref  ! An object or dataset region reference.
-    CHARACTER(LEN=*), INTENT(OUT) :: name  ! A name associated with the referenced object or dataset ptr.
-    INTEGER, INTENT(OUT) :: hdferr         ! Error code
-    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size   ! The size of the name buffer,
-                                                     ! returning 0 (zero) if no name is associated
-                                                     ! with the identifier
+    INTEGER(HID_T), INTENT(IN) :: loc_id
+    INTEGER, INTENT(IN) :: ref_type
+    TYPE(C_PTR), INTENT(IN) :: ref
+    CHARACTER(LEN=*), INTENT(OUT) :: name
+    INTEGER, INTENT(OUT) :: hdferr
+    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size
 !*****
     INTEGER(SIZE_T) :: size_default
     INTEGER(SIZE_T) :: name_len
@@ -615,9 +699,7 @@ CONTAINS
   !               H5G_DATASET_F   2
   !               H5G_TYPE_F      3
   !              
-  !  hdferr   - error code
-  !		  Success:  0
-  !		  Failure: -1
+  !  hdferr   - Returns 0 if successful and -1 if fails.
   !
   ! AUTHOR
   !  M. Scot Breitenfeld
