@@ -105,8 +105,13 @@ MODULE H5GLOBAL
        H5T_STD_U8LE,    &
        H5T_STD_U16BE,   &
        H5T_STD_U16LE,   &
-       H5T_STD_U32BE,   &
-       H5T_STD_U32LE,   &
+       H5T_STD_U32BE
+
+! NOTE: Splitting the line since the Fortran 95 standard limits the number of 
+!       continuation lines to 39; the F03/F08 standard limits the number 
+!       to 255 lines.
+
+  INTEGER(HID_T) H5T_STD_U32LE,   &
        H5T_STD_U64BE,   &
        H5T_STD_U64LE,   &
        H5T_STRING,      &
@@ -349,7 +354,7 @@ MODULE H5GLOBAL
   ! H5D flags declaration
   !
 
-  INTEGER, PARAMETER :: H5D_FLAGS_LEN = 22
+  INTEGER, PARAMETER :: H5D_FLAGS_LEN = 27
   INTEGER H5D_flags(H5D_FLAGS_LEN)
   !DEC$if defined(BUILD_HDF5_DLL)
   !DEC$ATTRIBUTES DLLEXPORT :: /H5D_FLAGS/
@@ -381,11 +386,18 @@ MODULE H5GLOBAL
   INTEGER :: H5D_FILL_VALUE_USER_DEFINED_F
 
 ! shortened "_DEFAULT" to "_DFLT" to satisfy the limit of 31
+! characters for variable names in Fortran.
+! shortened "_CONTIGUOUS" to "_CONTIG" to satisfy the limit of 31
 ! characters for variable names in Fortran.
 
   INTEGER :: H5D_CHUNK_CACHE_NSLOTS_DFLT_F
   INTEGER :: H5D_CHUNK_CACHE_NBYTES_DFLT_F
   INTEGER :: H5D_CHUNK_CACHE_W0_DFLT_F
+  INTEGER :: H5D_MPIO_NO_COLLECTIVE_F
+  INTEGER :: H5D_MPIO_CHUNK_INDEPENDENT_F
+  INTEGER :: H5D_MPIO_CHUNK_COLLECTIVE_F
+  INTEGER :: H5D_MPIO_CHUNK_MIXED_F
+  INTEGER :: H5D_MPIO_CONTIG_COLLECTIVE_F
 
   EQUIVALENCE(H5D_flags(1), H5D_COMPACT_F)
   EQUIVALENCE(H5D_flags(2), H5D_CONTIGUOUS_F)
@@ -414,6 +426,11 @@ MODULE H5GLOBAL
   EQUIVALENCE(H5D_flags(20), H5D_CHUNK_CACHE_NSLOTS_DFLT_F)
   EQUIVALENCE(H5D_flags(21), H5D_CHUNK_CACHE_NBYTES_DFLT_F)
   EQUIVALENCE(H5D_flags(22), H5D_CHUNK_CACHE_W0_DFLT_F)
+  EQUIVALENCE(H5D_flags(23), H5D_MPIO_NO_COLLECTIVE_F)
+  EQUIVALENCE(H5D_flags(24), H5D_MPIO_CHUNK_INDEPENDENT_F)
+  EQUIVALENCE(H5D_flags(25), H5D_MPIO_CHUNK_COLLECTIVE_F)
+  EQUIVALENCE(H5D_flags(26), H5D_MPIO_CHUNK_MIXED_F)
+  EQUIVALENCE(H5D_flags(27), H5D_MPIO_CONTIG_COLLECTIVE_F)
 
   !
   ! H5E flags declaration
@@ -685,18 +702,23 @@ MODULE H5GLOBAL
   !
   ! H5S flags declaration
   !
-  INTEGER, PARAMETER :: H5S_FLAGS_LEN = 20
+  INTEGER, PARAMETER :: H5S_FLAGS_LEN = 19
   INTEGER H5S_flags(H5S_FLAGS_LEN)
+  INTEGER, PARAMETER :: H5S_HSIZE_FLAGS_LEN = 1
+  INTEGER(HSIZE_T) H5S_hsize_flags(H5S_HSIZE_FLAGS_LEN)
   !DEC$if defined(BUILD_HDF5_DLL)
   !DEC$ATTRIBUTES DLLEXPORT :: /H5S_FLAGS/
+  !DEC$ATTRIBUTES DLLEXPORT :: /H5S_HSIZE_FLAGS/
   !DEC$endif
   COMMON /H5S_FLAGS/ H5S_flags
+  COMMON /H5S_HSIZE_FLAGS/ H5S_hsize_flags
+
+  INTEGER(HSIZE_T) :: H5S_UNLIMITED_F
 
   INTEGER :: H5S_SCALAR_F
   INTEGER :: H5S_SIMPLE_F
   INTEGER :: H5S_NULL_F
 
-  INTEGER :: H5S_UNLIMITED_F
   INTEGER :: H5S_ALL_F
 
   INTEGER :: H5S_SELECT_NOOP_F
@@ -710,36 +732,36 @@ MODULE H5GLOBAL
   INTEGER :: H5S_SELECT_PREPEND_F
   INTEGER :: H5S_SELECT_INVALID_F
 
-
   INTEGER :: H5S_SEL_ERROR_F
   INTEGER :: H5S_SEL_NONE_F
   INTEGER :: H5S_SEL_POINTS_F
   INTEGER :: H5S_SEL_HYPERSLABS_F
   INTEGER :: H5S_SEL_ALL_F
 
+  EQUIVALENCE(H5S_hsize_flags(1), H5S_UNLIMITED_F)
   EQUIVALENCE(H5S_flags(1), H5S_SCALAR_F)
   EQUIVALENCE(H5S_flags(2), H5S_SIMPLE_F)
   EQUIVALENCE(H5S_flags(3), H5S_NULL_F)
   EQUIVALENCE(H5S_flags(4), H5S_SELECT_SET_F)
   EQUIVALENCE(H5S_flags(5), H5S_SELECT_OR_F)
-  EQUIVALENCE(H5S_flags(6), H5S_UNLIMITED_F)
-  EQUIVALENCE(H5S_flags(7), H5S_ALL_F)
+  EQUIVALENCE(H5S_flags(6), H5S_ALL_F)
 
-  EQUIVALENCE(H5S_flags(8), H5S_SELECT_NOOP_F)
-  EQUIVALENCE(H5S_flags(9), H5S_SELECT_AND_F)
-  EQUIVALENCE(H5S_flags(10), H5S_SELECT_XOR_F)
-  EQUIVALENCE(H5S_flags(11), H5S_SELECT_NOTB_F)
-  EQUIVALENCE(H5S_flags(12), H5S_SELECT_NOTA_F)
-  EQUIVALENCE(H5S_flags(13), H5S_SELECT_APPEND_F)
-  EQUIVALENCE(H5S_flags(14), H5S_SELECT_PREPEND_F)
-  EQUIVALENCE(H5S_flags(15), H5S_SELECT_INVALID_F)
+  EQUIVALENCE(H5S_flags(7), H5S_SELECT_NOOP_F)
+  EQUIVALENCE(H5S_flags(8), H5S_SELECT_AND_F)
+  EQUIVALENCE(H5S_flags(9), H5S_SELECT_XOR_F)
+  EQUIVALENCE(H5S_flags(10), H5S_SELECT_NOTB_F)
+  EQUIVALENCE(H5S_flags(11), H5S_SELECT_NOTA_F)
+  EQUIVALENCE(H5S_flags(12), H5S_SELECT_APPEND_F)
+  EQUIVALENCE(H5S_flags(13), H5S_SELECT_PREPEND_F)
+  EQUIVALENCE(H5S_flags(14), H5S_SELECT_INVALID_F)
 
 
-  EQUIVALENCE(H5S_flags(16), H5S_SEL_ERROR_F)
-  EQUIVALENCE(H5S_flags(17), H5S_SEL_NONE_F)
-  EQUIVALENCE(H5S_flags(18), H5S_SEL_POINTS_F)
-  EQUIVALENCE(H5S_flags(19), H5S_SEL_HYPERSLABS_F)
-  EQUIVALENCE(H5S_flags(20), H5S_SEL_ALL_F)
+  EQUIVALENCE(H5S_flags(15), H5S_SEL_ERROR_F)
+  EQUIVALENCE(H5S_flags(16), H5S_SEL_NONE_F)
+  EQUIVALENCE(H5S_flags(17), H5S_SEL_POINTS_F)
+  EQUIVALENCE(H5S_flags(18), H5S_SEL_HYPERSLABS_F)
+  EQUIVALENCE(H5S_flags(19), H5S_SEL_ALL_F)
+
   !
   ! H5T flags declaration
   !
