@@ -1,4 +1,13 @@
-! * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
+!****h* root/fortran/test/fortranlib_test.f90
+!
+! NAME
+!  fortranlib_test.f90
+!
+! FUNCTION
+!  Basic testing of Fortran API's functionality.
+!
+! COPYRIGHT
+! * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 !   Copyright by The HDF Group.                                               *
 !   Copyright by the Board of Trustees of the University of Illinois.         *
 !   All rights reserved.                                                      *
@@ -11,16 +20,14 @@
 !   is linked from the top-level documents page.  It can also be found at     *
 !   http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
 !   access to either file, you may request a copy from help@hdfgroup.org.     *
-! * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
-!
-!
-! 
-!    Testing Fortran functionality.
+! * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 !
+!*****
+
 PROGRAM fortranlibtest
-  
+
   USE HDF5
-  
+
   IMPLICIT NONE
   INTEGER :: total_error = 0
   INTEGER :: error
@@ -30,6 +37,7 @@ PROGRAM fortranlibtest
   LOGICAL :: cleanup, status
 
   CALL h5open_f(error)
+
   cleanup = .TRUE.
   CALL h5_env_nocleanup_f(status)
   IF(status) cleanup=.FALSE.
@@ -42,7 +50,7 @@ PROGRAM fortranlibtest
 
      WRITE(*, '(" FORTRANLIB_TEST is linked with HDF5 Library version ")', advance="NO")
      WRITE(*, '(I1)', advance="NO") majnum
-     WRITE(*, '(".")', advance="NO") 
+     WRITE(*, '(".")', advance="NO")
      WRITE(*, '(I1)', advance="NO") minnum
      WRITE(*, '(" release ")', advance="NO")
      WRITE(*, '(I3)') relnum
@@ -59,7 +67,7 @@ PROGRAM fortranlibtest
   ret_total_error = 0
   CALL mountingtest(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Mounting test', total_error)
-  
+
   ret_total_error = 0
   CALL reopentest(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Reopen test', total_error)
@@ -74,7 +82,7 @@ PROGRAM fortranlibtest
 8 CONTINUE
 
   ret_total_error = 0
-  CALL file_space(cleanup, ret_total_error)
+  CALL file_space("file_space",cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' File free space test', total_error)
 
 !     write(*,*)
@@ -85,7 +93,7 @@ PROGRAM fortranlibtest
   ret_total_error = 0
   CALL datasettest(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Dataset test', total_error)
-  
+
   ret_total_error = 0
   CALL extenddsettest(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Extendible dataset test', total_error)
@@ -107,7 +115,7 @@ PROGRAM fortranlibtest
   ret_total_error = 0
   CALL refobjtest(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Reference to object test', total_error)
-  
+
   ret_total_error = 0
   CALL refregtest(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Reference to dataset region test', total_error)
@@ -125,7 +133,7 @@ PROGRAM fortranlibtest
   ret_total_error = 0
   CALL test_select_hyperslab( cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Hyperslab selection test', total_error)
-  
+
   ret_total_error = 0
   CALL test_select_element(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Element selection test', total_error)
@@ -164,23 +172,29 @@ PROGRAM fortranlibtest
 
 !     write(*,*)
 !     write(*,*) '========================================='
-!     write(*,*) 'Testing PROPERTY interface               ' 
+!     write(*,*) 'Testing PROPERTY interface               '
 !     write(*,*) '========================================='
 
   ret_total_error = 0
   CALL external_test(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' External dataset test', total_error)
 
+!DEC$ if defined(H5_VMS)
+  GOTO 9
+!DEC$ else
   ret_total_error = 0
   CALL multi_file_test(cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Multi file driver test', total_error)
+!DEC$ endif
+9 CONTINUE
 
+  ret_total_error = 0
   CALL test_chunk_cache (cleanup, ret_total_error)
   CALL write_test_status(ret_total_error, ' Dataset chunk cache configuration', total_error)
 
 !     write(*,*)
 !     write(*,*) '========================================='
-!     write(*,*) 'Testing ATTRIBUTE interface              ' 
+!     write(*,*) 'Testing ATTRIBUTE interface              '
 !     write(*,*) '========================================='
 
   ret_total_error = 0
@@ -202,7 +216,7 @@ PROGRAM fortranlibtest
 
   ret_total_error = 0
   CALL szip_test(szip_flag, cleanup, ret_total_error)
-  
+
   IF (.NOT. szip_flag) THEN ! test not available
      CALL write_test_status(-1, ' SZIP filter test', total_error)
   ELSE
@@ -235,7 +249,7 @@ PROGRAM fortranlibtest
   WRITE(*, fmt = '(i4)', advance='NO') total_error
   WRITE(*, fmt = '(12a)' ) ' error(s) ! '
   WRITE(*,*) '                  ============================================  '
-  
+
   CALL h5close_f(error)
 
   ! if errors detected, exit with non-zero code.
