@@ -93,12 +93,6 @@ PROGRAM fortranlibtest
        ' Testing dataspace encoding and decoding', &
        total_error)
 
-  ret_total_error = 0
-  CALL test_nbit(cleanup, ret_total_error )
-  CALL write_test_status(ret_total_error, &
-       ' Testing nbit filter', &
-       total_error)
-
   ret_total_error = 0
   CALL test_scaleoffset(cleanup, ret_total_error )
   CALL write_test_status(ret_total_error, &
@@ -400,141 +394,6 @@ SUBROUTINE test_h5s_encode(cleanup, total_error)
 
 END SUBROUTINE test_h5s_encode
 
-!-------------------------------------------------------------------------
-! Function:    test_nbit
-!
-! Purpose:     Tests (real) datatype for nbit filter
-!
-! Return:      Success:        0
-!              Failure:        >0
-!
-! Programmer:  M. Scot Breitenfeld
-!              Decemeber 7, 2010
-!
-! Modifications:
-!
-!-------------------------------------------------------------------------
-!
-
-SUBROUTINE test_nbit(cleanup, total_error )
-
-  USE HDF5
-
-  IMPLICIT NONE
-  INTEGER, PARAMETER :: wp = KIND(1.0)
-  LOGICAL, INTENT(IN)  :: cleanup
-  INTEGER, INTENT(INOUT) :: total_error
-  INTEGER(hid_t) :: file
-  
-  INTEGER(hid_t) :: dataset, datatype, space, dc
-  INTEGER(hsize_t), DIMENSION(1:2) :: dims = (/2,5/)
-  INTEGER(hsize_t), DIMENSION(1:2) :: chunk_dim = (/2,5/)
-  ! orig_data[] are initialized to be within the range that can be represented by
-  ! dataset datatype (no precision loss during datatype conversion)
-  !
-  REAL(kind=wp), DIMENSION(1:2,1:5) :: orig_data = RESHAPE( (/188384.00, 19.103516, -1.0831790e9, -84.242188, &
-       5.2045898, -49140.000, 2350.2500, -3.2110596e-1, 6.4998865e-5, -0.0000000/) , (/2,5/) )
-  REAL(kind=wp), DIMENSION(1:2,1:5) :: new_data
-  INTEGER(size_t) :: PRECISION, offset
-  INTEGER :: error
-  LOGICAL :: status
-  INTEGER*8 :: ii
-  INTEGER(size_t) :: i, j
-
-
-  ! check to see if filter is available
-  CALL H5Zfilter_avail_f(H5Z_FILTER_NBIT_F, status, error)
-  IF(.NOT.status)THEN ! We don't have H5Z_FILTER_NBIT_F filter
-     total_error = -1     ! so return
-     RETURN
-  ENDIF
-
-  CALL H5Fcreate_f("nbit.h5", H5F_ACC_TRUNC_F, file, error)
-  CALL check("H5Fcreate_f", error, total_error)
-
-  ! Define dataset datatype (integer), and set precision, offset
-  CALL H5Tcopy_f(H5T_IEEE_F32BE, datatype, error)
-  CALL CHECK(" H5Tcopy_f", error, total_error)
-  CALL H5Tset_fields_f(datatype, 26_size_t, 20_size_t, 6_size_t, 7_size_t, 13_size_t, error)
-  CALL CHECK(" H5Tset_fields_f", error, total_error)
-  offset = 7
-  CALL H5Tset_offset_f(datatype, offset, error)
-  CALL CHECK(" H5Tset_offset_f", error, total_error)
-  PRECISION = 20
-  CALL H5Tset_precision_f(datatype,PRECISION, error)
-  CALL CHECK(" H5Tset_precision_f", error, total_error)
-  
-  CALL H5Tset_size_f(datatype, 4_size_t, error)
-  CALL CHECK(" H5Tset_size_f", error, total_error)
-  
-  CALL H5Tset_ebias_f(datatype, 31_size_t, error)
-  CALL CHECK(" H5Tset_ebias_f", error, total_error)
- 
-  ! Create the data space 
-  CALL H5Screate_simple_f(2, dims, space, error)
-  CALL CHECK(" H5Screate_simple_f", error, total_error)
-
-  ! USE nbit filter
-  CALL H5Pcreate_f(H5P_DATASET_CREATE_F, dc, error)
-  CALL CHECK(" H5Pcreate_f", error, total_error)
-
-  CALL H5Pset_chunk_f(dc, 2, chunk_dim, error)
-  CALL CHECK(" H5Pset_chunk_f", error, total_error)
-  CALL H5Pset_nbit_f(dc, error)
-  CALL CHECK(" H5Pset_nbit_f", error, total_error)
-
-  ! Create the dataset
-  CALL  H5Dcreate_f(file, "nbit_real", datatype, &
-       space, dataset, error, dc)
-  CALL CHECK(" H5Dcreate_f", error, total_error)
-
-  !----------------------------------------------------------------------
-  ! STEP 1: Test nbit by setting up a chunked dataset and writing
-  ! to it.
-  !----------------------------------------------------------------------
-  !
-  CALL H5Dwrite_f(dataset, H5T_NATIVE_REAL, orig_data, dims, error)
-  CALL CHECK(" H5Dwrite_f", error, total_error)
-
-  !----------------------------------------------------------------------
-  ! STEP 2: Try to read the data we just wrote.
-  !----------------------------------------------------------------------
-  !  
-  CALL H5Dread_f(dataset, H5T_NATIVE_REAL, new_data, dims, error)
-  CALL CHECK(" H5Dread_f", error, total_error)
-
-  ! Check that the values read are the same as the values written
-  ! Assume size of long long = size of double
-  !
-  i_loop: DO i = 1, dims(1)
-     j_loop: DO j = 1, dims(2)
-        IF(.NOT.(orig_data(i,j).EQ.orig_data(i,j))) CYCLE  ! skip IF value is NaN
-        IF(new_data(i,j) .NE. orig_data(i,j))THEN
-           total_error = total_error + 1
-           WRITE(*,'("    Read different values than written.")')
-           WRITE(*,'("    At index ", 2(1X,I0))') i, j
-           EXIT i_loop
-        END IF
-     ENDDO j_loop
-  ENDDO i_loop
-
-  !----------------------------------------------------------------------
-  ! Cleanup
-  !----------------------------------------------------------------------
-  !
-  CALL H5Tclose_f(datatype, error)
-  CALL CHECK(" H5Tclose_f", error, total_error)
-  CALL H5Pclose_f(dc, error)
-  CALL CHECK(" H5Pclose_f", error, total_error)
-  CALL H5Sclose_f(space, error)
-  CALL CHECK(" H5Sclose_f", error, total_error)
-  CALL H5Dclose_f(dataset, error)
-  CALL CHECK(" H5Dclose_f", error, total_error)
-  CALL H5Fclose_f(file, error)
-  CALL CHECK(" H5Fclose_f", error, total_error)
-
-END SUBROUTINE test_nbit
-
 !-------------------------------------------------------------------------
 ! Function:    test_scaleoffset
 !
