@@ -1,4 +1,13 @@
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+/****h* root/fortran/test/tc.c
+ *
+ * NAME
+ *   tc.c
+ *
+ * FUNCTION
+ *   This file contains C routines needed for the test programs.
+ *
+ * COPYRIGHT
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
@@ -11,9 +20,13 @@
  * is linked from the top-level documents page.  It can also be found at     *
  * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
  * access to either file, you may request a copy from help@hdfgroup.org.     *
- * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ *
+ ******
+*/
 
 #include "t.h"
+#include "H5Eprivate.h"
 
 /*----------------------------------------------------------------------------
  * Name:        h5_fixname_c
@@ -31,35 +44,31 @@
 int_f
 nh5_fixname_c(_fcd base_name, size_t_f *base_namelen, hid_t_f* fapl, _fcd full_name, size_t_f *full_namelen)
 {
-     int ret_value = -1;
-     char *c_base_name;
-     char *c_full_name;
-     hid_t c_fapl;
+     char *c_base_name = NULL;
+     char *c_full_name = NULL;
+     int_f ret_value = 0;
 
-     /*
-      * Define ifile access property list
-      */
-     c_fapl = (hid_t)*fapl;
      /*
       * Convert FORTRAN name to C name
       */
-     c_base_name = (char *)HD5f2cstring(base_name, (size_t)*base_namelen);
-     if (c_base_name == NULL) goto DONE;
-     c_full_name = (char *) HDmalloc((size_t)*full_namelen + 1);
-     if (c_full_name == NULL) goto DONE;
+     if(NULL == (c_base_name = (char *)HD5f2cstring(base_name, (size_t)*base_namelen)))
+         HGOTO_DONE(FAIL)
+     if(NULL == (c_full_name = (char *)HDmalloc((size_t)*full_namelen + 1)))
+         HGOTO_DONE(FAIL)
 
      /*
       * Call h5_fixname function.
       */
-     if (NULL != h5_fixname(c_base_name, c_fapl, c_full_name, (size_t)*full_namelen + 1)) {
-         HD5packFstring(c_full_name, _fcdtocp(full_name), (size_t)*full_namelen);
-         ret_value = 0;
-         goto DONE;
-     }
+     if(NULL == h5_fixname(c_base_name, (hid_t)*fapl, c_full_name, (size_t)*full_namelen + 1))
+         HGOTO_DONE(FAIL)
+     HD5packFstring(c_full_name, _fcdtocp(full_name), (size_t)*full_namelen);
+
+done:
+     if(c_base_name)
+        HDfree(c_base_name);
+     if(c_full_name)
+        HDfree(c_full_name);
 
-DONE:
-     if (NULL != c_base_name) HDfree(c_base_name);
-     if (NULL != c_full_name) HDfree(c_full_name);
      return ret_value;
 }
 
@@ -129,3 +138,22 @@ nh5_exit_c(int_f *status)
     HDexit((int)*status);
 }   /* h5_exit_c */
 
+/*----------------------------------------------------------------------------
+ * Name:        h5_env_nocleanup_c
+ * Purpose:     Determines the state of the environment variable HDF5_NOCLEANUP
+ * Input:       none
+ * Output:      status:  1 - HDF5_NOCLEANUP is set
+ *                       0 - HDF5_NOCLEANUP is not set
+ * Returns:     none
+ * Programmer:  M.S. Breitenfeld
+ *              September 30, 3008
+ * Modifications:
+ *---------------------------------------------------------------------------*/
+void
+nh5_env_nocleanup_c(int_f *status)
+{
+  *status = (int_f)0;
+  if (HDgetenv("HDF5_NOCLEANUP"))
+    *status = (int_f)1;
+}   /* h5_env_nocleanup_c */
+
