@@ -33,10 +33,10 @@ static H5I_type_t H5PT_ptable_id_type = H5I_UNINIT;
 #define H5PT_HASH_TABLE_SIZE 64
 
 /* Packet Table private functions */
-herr_t H5PT_close( htbl_t* table );
-herr_t H5PT_create_index(htbl_t *table_id);
-herr_t H5PT_set_index(htbl_t *table_id, hsize_t pt_index);
-herr_t H5PT_get_index(htbl_t *table_id, hsize_t *pt_index);
+static herr_t H5PT_close( htbl_t* table );
+static herr_t H5PT_create_index(htbl_t *table_id);
+static herr_t H5PT_set_index(htbl_t *table_id, hsize_t pt_index);
+static herr_t H5PT_get_index(htbl_t *table_id, hsize_t *pt_index);
 
 /*-------------------------------------------------------------------------
  *
@@ -214,6 +214,11 @@ out:
  *
  * Modifications:
  *
+ * 		John Mainzer -- 4/23/08
+ * 		Added error check on malloc of table, initialized fields
+ * 		in table to keep lower level code from choking on bogus
+ * 		data in error cases.
+ *
  *-------------------------------------------------------------------------
  */
 hid_t H5PTopen( hid_t loc_id,
@@ -232,6 +237,12 @@ hid_t H5PTopen( hid_t loc_id,
 
   table = (htbl_t *)malloc(sizeof(htbl_t));
 
+  if ( table == NULL ) {
+    goto out;
+  }
+  table->dset_id = H5I_BADID;
+  table->type_id = H5I_BADID;
+
   /* Open the dataset */
   if((table->dset_id = H5Dopen2(loc_id, dset_name, H5P_DEFAULT)) < 0)
       goto out;
@@ -258,6 +269,8 @@ hid_t H5PTopen( hid_t loc_id,
     goto out;
   if( H5Sget_simple_extent_dims( space_id, dims, NULL) < 0)
     goto out;
+  if(H5Sclose(space_id) < 0)
+    goto out;
   table->size = dims[0];
 
   /* Get an ID for this table */
@@ -273,6 +286,7 @@ hid_t H5PTopen( hid_t loc_id,
 out:
   H5E_BEGIN_TRY
   H5Tclose(type_id);
+  H5Sclose(space_id);
   if(table)
   {
     H5Dclose(table->dset_id);
@@ -303,7 +317,8 @@ out:
  *
  *-------------------------------------------------------------------------
  */
-herr_t H5PT_close( htbl_t* table)
+static herr_t
+H5PT_close( htbl_t* table)
 {
   if(table == NULL)
     goto out;
@@ -556,7 +571,8 @@ out:
  *
  *-------------------------------------------------------------------------
  */
-herr_t H5PT_create_index(htbl_t *table)
+static herr_t
+H5PT_create_index(htbl_t *table)
 {
   if( table != NULL)
   {
@@ -566,7 +582,8 @@ herr_t H5PT_create_index(htbl_t *table)
   return -1;
 }
 
-herr_t H5PT_set_index(htbl_t *table, hsize_t index)
+static herr_t
+H5PT_set_index(htbl_t *table, hsize_t index)
 {
   /* Ensure index is valid */
   if( table != NULL )
@@ -580,7 +597,8 @@ herr_t H5PT_set_index(htbl_t *table, hsize_t index)
   return -1;
 }
 
-herr_t H5PT_get_index(htbl_t *table, hsize_t *index)
+static herr_t
+H5PT_get_index(htbl_t *table, hsize_t *index)
 {
   /* Ensure index is valid */
   if( table != NULL )
