@@ -51,7 +51,6 @@
 static herr_t make_attributes( hid_t loc_id, const char* obj_name );
 
 
-
 /*-------------------------------------------------------------------------
 * test dataset functions
 *-------------------------------------------------------------------------
@@ -1824,7 +1823,6 @@ static int test_valid_path(void)
   herr_t status;
   FILE *fp = NULL;
   htri_t path_valid;
-  char path[10];
   const char *data_string_in = "test";
   
   TESTING("H5LTpath_valid");
@@ -2146,7 +2144,6 @@ static int test_valid_path(void)
   return -1;
 }
 
-
 /*-------------------------------------------------------------------------
 * the main program
 *-------------------------------------------------------------------------
@@ -2161,9 +2158,12 @@ int main( void )
     /* test attribute functions */
     nerrors += test_attr();
 
-    /* test text-dtype functions */
+    /* test valid path functions */
     nerrors += test_valid_path();
 
+    /* test text-dtype functions */
+    nerrors += test_text_dtype();
+
     /* check for errors */
     if (nerrors)
         goto error;
@@ -2172,6 +2172,4 @@ int main( void )
 
 error:
     return 1;
-
-
 }
