@@ -343,6 +343,11 @@ main(int argc, char **argv)
     int exit_value = EXIT_SUCCESS;
     struct options *opts = NULL;
 
+#ifndef STANDALONE
+    /* Initialize h5tools lib */
+    h5tools_init();
+#endif
+    
     output = stdout;
 
     opts = parse_command_line(argc, argv);
