@@ -21,7 +21,7 @@
 
 /** From H5private.h **/
 
-#include "H5public.h"		 /* Include Public Definitions		*/
+#include "H5public.h"     /* Include Public Definitions    */
 
 
 /*
@@ -114,12 +114,7 @@
 #define HDexecve(S,AV,E)        execve(S,AV,E)
 #define HDexecvp(S,AV)          execvp(S,AV)
 #define HDexit(N)               exit(N)
-#if defined __MWERKS__
-#include <abort_exit.h>
-#define HD_exit(N)              __exit(N)
-#else /* __MWERKS __ */
 #define HD_exit(N)              _exit(N)
-#endif /* __MWERKS __ */
 #define HDexp(X)                exp(X)
 #define HDfabs(X)               fabs(X)
 /* use ABS() because fabsf() fabsl() are not common yet. */
@@ -134,11 +129,11 @@
 #define HDfgetc(F)              fgetc(F)
 #define HDfgetpos(F,P)          fgetpos(F,P)
 #define HDfgets(S,N,F)          fgets(S,N,F)
-#ifdef _WIN32
+#ifdef H5_HAVE_WIN32_API
 #define HDfileno(F)             _fileno(F)
-#else /* _WIN32 */
+#else /* H5_HAVE_WIN32_API */
 #define HDfileno(F)             fileno(F)
-#endif /* _WIN32 */
+#endif /* H5_HAVE_WIN32_API */
 #define HDfloor(X)              floor(X)
 #define HDfmod(X,Y)             fmod(X,Y)
 #define HDfopen(S,M)            fopen(S,M)
@@ -174,25 +169,21 @@ H5_DLL int HDfprintf (FILE *stream, const char *fmt, ...);
  * For Unix, if off_t is not 64bit big, try use the pseudo-standard
  * xxx64 versions if available.
  */
-#ifdef _WIN32
-    #ifdef __MWERKS__
-    #define HDfstat(F,B)        fstat(F,B)
-    #define HDstat(S,B)         stat(S,B)
-    typedef struct stat         h5_stat_t;
-    typedef off_t               h5_stat_size_t;
-    #else /*MSVC*/
+#ifdef H5_HAVE_WIN32_API
     #define HDfstat(F,B)        _fstati64(F,B)
+    #define HDlstat(S,B)        _lstati64(S,B)
     #define HDstat(S,B)         _stati64(S,B)
     typedef struct _stati64     h5_stat_t;
     typedef __int64             h5_stat_size_t;
-    #endif
 #elif H5_SIZEOF_OFF_T!=8 && H5_SIZEOF_OFF64_T==8 && defined(H5_HAVE_STAT64)
     #define HDfstat(F,B)        fstat64(F,B)
+    #define HDlstat(S,B)        lstat64(S,B)
     #define HDstat(S,B)         stat64(S,B)
     typedef struct stat64       h5_stat_t;
     typedef off64_t             h5_stat_size_t;
 #else
     #define HDfstat(F,B)        fstat(F,B)
+    #define HDlstat(S,B)        lstat(S,B)
     #define HDstat(S,B)         stat(S,B)
     typedef struct stat         h5_stat_t;
     typedef off_t               h5_stat_size_t;
@@ -211,7 +202,11 @@ H5_DLL int HDfprintf (FILE *stream, const char *fmt, ...);
 #define HDgetgrgid(G)           getgrgid(G)
 #define HDgetgrnam(S)           getgrnam(S)
 #define HDgetgroups(Z,G)        getgroups(Z,G)
+#ifdef H5_HAVE_VISUAL_STUDIO
+#define HDgetlogin()            Wgetlogin()
+#else /* H5_HAVE_VISUAL_STUDIO */
 #define HDgetlogin()            getlogin()
+#endif /* H5_HAVE_VISUAL_STUDIO */
 #define HDgetpgrp()             getpgrp()
 #define HDgetpid()              getpid()
 #define HDgetppid()             getppid()
@@ -244,18 +239,14 @@ H5_DLL int HDfprintf (FILE *stream, const char *fmt, ...);
 #define HDlog(X)                log(X)
 #define HDlog10(X)              log10(X)
 #define HDlongjmp(J,N)          longjmp(J,N)
-#ifdef _WIN32
-     #ifdef __MWERKS__
-        #define HDlseek(F,O,W)  lseek(F,O,W)
-     #else /*MSVS */
-        #define HDlseek(F,O,W)  _lseeki64(F,O,W)
-     #endif
+#ifdef H5_HAVE_WIN32_API
+    #define HDlseek(F,O,W)  _lseeki64(F,O,W)
 #else
-     #ifdef H5_HAVE_FSEEK64
+    #ifdef H5_HAVE_LSEEK64
         #define HDlseek(F,O,W)  lseek64(F,O,W)
-     #else
+    #else
         #define HDlseek(F,O,W)  lseek(F,O,W)
-     #endif
+    #endif
 #endif
 #define HDmalloc(Z)             malloc(Z)
 #define HDposix_memalign(P,A,Z) posix_memalign(P,A,Z)
@@ -271,18 +262,18 @@ H5_DLL int HDfprintf (FILE *stream, const char *fmt, ...);
 #define HDmemcpy(X,Y,Z)         memcpy((char*)(X),(const char*)(Y),Z)
 #define HDmemmove(X,Y,Z)        memmove((char*)(X),(const char*)(Y),Z)
 /*
- * The (void*) cast just avoids a compiler warning in _WIN32
+ * The (void*) cast just avoids a compiler warning in H5_HAVE_VISUAL_STUDIO
  */
-#ifdef _WIN32
+#ifdef H5_HAVE_VISUAL_STUDIO
 #define HDmemset(X,C,Z)         memset((void*)(X),C,Z)
-#else /* _WIN32 */
+#else /* H5_HAVE_VISUAL_STUDIO */
 #define HDmemset(X,C,Z)         memset(X,C,Z)
-#endif /* _WIN32 */
-#ifdef _WIN32
+#endif /* H5_HAVE_VISUAL_STUDIO */
+#ifdef H5_HAVE_WIN32_API
 #define HDmkdir(S,M)            _mkdir(S)
-#else /* _WIN32 */
+#else /* H5_HAVE_WIN32_API */
 #define HDmkdir(S,M)            mkdir(S,M)
-#endif /* _WIN32 */
+#endif /* H5_HAVE_WIN32_API */
 #define HDmkfifo(S,M)           mkfifo(S,M)
 #define HDmktime(T)             mktime(T)
 #define HDmodf(X,Y)             modf(X,Y)
@@ -344,12 +335,11 @@ int HDremove_all(const char * fname);
 #define HDsetuid(U)             setuid(U)
 /* Windows does not permit setting the buffer size to values
    less than 2.  */
-#ifndef _WIN32
+#ifndef H5_HAVE_WIN32_API
 #define HDsetvbuf(F,S,M,Z)      setvbuf(F,S,M,Z)
 #else
 #define HDsetvbuf(F,S,M,Z)  setvbuf(F,S,M,(Z>1?Z:2))
 #endif
-#define HDsigaction(N,A)        sigaction(N,A)
 #define HDsigaddset(S,N)        sigaddset(S,N)
 #define HDsigdelset(S,N)        sigdelset(S,N)
 #define HDsigemptyset(S)        sigemptyset(S)
@@ -364,7 +354,7 @@ int HDremove_all(const char * fname);
 #define HDsin(X)                sin(X)
 #define HDsinh(X)               sinh(X)
 #define HDsleep(N)              sleep(N)
-#ifdef _WIN32
+#ifdef H5_HAVE_WIN32_API
 #define HDsnprintf              _snprintf /*varargs*/
 #else
 #define HDsnprintf              snprintf /*varargs*/
@@ -383,6 +373,7 @@ H5_DLL void HDsrand(unsigned int seed);
 #endif
 /* sscanf() variable arguments */
 
+#define HDstrcasecmp(X,Y)      strcasecmp(X,Y)
 #define HDstrcat(X,Y)           strcat(X,Y)
 #define HDstrchr(S,C)           strchr(S,C)
 #define HDstrcmp(X,Y)           strcmp(X,Y)
@@ -428,7 +419,7 @@ H5_DLL int64_t HDstrtoll (const char *s, const char **rest, int base);
 #define HDumask(N)              umask(N)
 #define HDuname(S)              uname(S)
 #define HDungetc(C,F)           ungetc(C,F)
-#ifdef _WIN32
+#ifdef H5_HAVE_WIN32_API
 #define HDunlink(S)             _unlink(S)
 #else
 #define HDunlink(S)             unlink(S)
@@ -441,7 +432,7 @@ H5_DLL int64_t HDstrtoll (const char *s, const char **rest, int base);
 #define HDvfprintf(F,FMT,A)     vfprintf(F,FMT,A)
 #define HDvprintf(FMT,A)        vprintf(FMT,A)
 #define HDvsprintf(S,FMT,A)     vsprintf(S,FMT,A)
-#ifdef _WIN32
+#ifdef H5_HAVE_WIN32_API
 #   define HDvsnprintf(S,N,FMT,A) _vsnprintf(S,N,FMT,A)
 #else
 #   define HDvsnprintf(S,N,FMT,A) vsnprintf(S,N,FMT,A)
@@ -450,23 +441,15 @@ H5_DLL int64_t HDstrtoll (const char *s, const char **rest, int base);
 #define HDwaitpid(P,W,O)        waitpid(P,W,O)
 #define HDwcstombs(S,P,Z)       wcstombs(S,P,Z)
 #define HDwctomb(S,C)           wctomb(S,C)
-
-#if defined (__MWERKS__)
-/* workaround for a bug in the Metrowerks version 6.0 header file for write
- which is not defined as const void*
- */
-#define HDwrite(F,M,Z)          write(F,(void*)M,Z)
-#else
 #define HDwrite(F,M,Z)          write(F,M,Z)
-#endif
 
 /*
  * And now for a couple non-Posix functions...  Watch out for systems that
  * define these in terms of macros.
  */
-#ifdef _WIN32
+#ifdef H5_HAVE_WIN32_API
 #define HDstrdup(S)    _strdup(S)
-#else /* _WIN32 */
+#else /* H5_HAVE_WIN32_API */
 
 #if !defined strdup && !defined H5_HAVE_STRDUP
 extern char *strdup(const char *s);
@@ -474,7 +457,7 @@ extern char *strdup(const char *s);
 
 #define HDstrdup(S)     strdup(S)
 
-#endif /* _WIN32 */
+#endif /* H5_HAVE_WIN32_API */
 
 /*
  * HDF Boolean type.
@@ -508,7 +491,7 @@ extern const char *opt_arg;     /* flag argument (or value)                 */
 
 enum {
     no_arg = 0,         /* doesn't take an argument     */
-    require_arg,        /* requires an argument	        */
+    require_arg,        /* requires an argument          */
     optional_arg        /* argument is optional         */
 };
 
