@@ -23,6 +23,7 @@
 
 /* our header files */
 #include "h5test.h"
+#include "h5tools.h"
 #include "h5tools_utils.h"
 
 #ifdef H5_HAVE_FILTER_DEFLATE
@@ -574,6 +575,9 @@ main(int argc, char **argv)
 
     prog = argv[0];
 
+    /* Initialize h5tools lib */
+    h5tools_init();
+
     while ((opt = get_option(argc, (const char **)argv, s_opts, l_opts)) > 0) {
         switch ((char)opt) {
         case '0': case '1': case '2':
