@@ -158,29 +158,6 @@ typedef struct {
     H5A_t       **attrs;        /* Pointer to array of attribute pointers */
 } H5A_attr_table_t;
 
-/* Attribute iteration operator for internal library callbacks */
-typedef herr_t (*H5A_lib_iterate_t)(const H5A_t *attr, void *op_data);
-
-/* Describe kind of callback to make for each attribute */
-typedef enum H5A_attr_iter_op_type_t {
-#ifndef H5_NO_DEPRECATED_SYMBOLS
-    H5A_ATTR_OP_APP,                /* Application callback */
-#endif /* H5_NO_DEPRECATED_SYMBOLS */
-    H5A_ATTR_OP_APP2,               /* Revised application callback */
-    H5A_ATTR_OP_LIB                 /* Library internal callback */
-} H5A_attr_iter_op_type_t;
-
-typedef struct H5A_attr_iter_op_t {
-    H5A_attr_iter_op_type_t op_type;
-    union {
-#ifndef H5_NO_DEPRECATED_SYMBOLS
-        H5A_operator1_t app_op;         /* Application callback for each attribute */
-#endif /* H5_NO_DEPRECATED_SYMBOLS */
-        H5A_operator2_t app_op2;        /* Revised application callback for each attribute */
-        H5A_lib_iterate_t lib_op;       /* Library internal callback for each attribute */
-    } u;
-} H5A_attr_iter_op_t;
-
 
 /*****************************/
 /* Package Private Variables */
@@ -268,9 +245,6 @@ H5_DLL herr_t H5O_attr_write(const H5O_loc_t *loc, hid_t dxpl_id,
     H5A_t *attr);
 H5_DLL herr_t H5O_attr_rename(const H5O_loc_t *loc, hid_t dxpl_id,
     const char *old_name, const char *new_name);
-H5_DLL herr_t H5O_attr_iterate(hid_t loc_id, hid_t dxpl_id, H5_index_t idx_type,
-    H5_iter_order_t order, hsize_t skip, hsize_t *last_attr,
-    const H5A_attr_iter_op_t *op, void *op_data);
 H5_DLL herr_t H5O_attr_remove(const H5O_loc_t *loc, const char *name,
     hid_t dxpl_id);
 H5_DLL herr_t H5O_attr_remove_by_idx(const H5O_loc_t *loc, H5_index_t idx_type,
