@@ -27,6 +27,7 @@
 #include "H5Dpkg.h"		/* Dataset functions			*/
 #include "H5Eprivate.h"		/* Error handling		  	*/
 #include "H5FLprivate.h"	/* Free Lists                           */
+#include "H5Iprivate.h"		/* IDs                                  */
 
 
 /****************/
@@ -42,19 +43,19 @@
 /********************/
 /* Local Prototypes */
 /********************/
-static size_t H5D_gather_file(const H5D_io_info_t *io_info,
-    const H5S_t *file_space, H5S_sel_iter_t *file_iter, size_t nelmts,
-    void *buf);
-static herr_t H5D_scatter_file(const H5D_io_info_t *io_info,
+static herr_t H5D__scatter_file(const H5D_io_info_t *io_info,
     const H5S_t *file_space, H5S_sel_iter_t *file_iter, size_t nelmts,
     const void *buf);
-static size_t H5D_gather_mem(const void *_buf,
+static size_t H5D__gather_file(const H5D_io_info_t *io_info,
+    const H5S_t *file_space, H5S_sel_iter_t *file_iter, size_t nelmts,
+    void *buf);
+static size_t H5D__gather_mem(const void *_buf,
     const H5S_t *space, H5S_sel_iter_t *iter, size_t nelmts,
     const H5D_dxpl_cache_t *dxpl_cache, void *_tgath_buf/*out*/);
-static herr_t H5D_compound_opt_read(size_t nelmts, const H5S_t *mem_space,
+static herr_t H5D__compound_opt_read(size_t nelmts, const H5S_t *mem_space,
     H5S_sel_iter_t *iter, const H5D_dxpl_cache_t *dxpl_cache,
     const H5D_type_info_t *type_info, void *user_buf/*out*/);
-static herr_t H5D_compound_opt_write(size_t nelmts, const H5D_type_info_t *type_info);
+static herr_t H5D__compound_opt_write(size_t nelmts, const H5D_type_info_t *type_info);
 
 
 /*********************/
@@ -75,7 +76,7 @@ H5FL_SEQ_EXTERN(hsize_t);
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_scatter_file
+ * Function:	H5D__scatter_file
  *
  * Purpose:	Scatters dataset elements from the type conversion buffer BUF
  *		to the file F where the data points are arranged according to
@@ -91,7 +92,7 @@ H5FL_SEQ_EXTERN(hsize_t);
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5D_scatter_file(const H5D_io_info_t *_io_info,
+H5D__scatter_file(const H5D_io_info_t *_io_info,
     const H5S_t *space, H5S_sel_iter_t *iter, size_t nelmts,
     const void *_buf)
 {
@@ -108,7 +109,7 @@ H5D_scatter_file(const H5D_io_info_t *_io_info,
     size_t  nelem;                 /* Number of elements used in sequences */
     herr_t  ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Check args */
     HDassert(_io_info);
@@ -165,11 +166,11 @@ done:
         off = H5FL_SEQ_FREE(hsize_t, off);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5D_scatter_file() */
+} /* H5D__scatter_file() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_gather_file
+ * Function:	H5D__gather_file
  *
  * Purpose:	Gathers data points from file F and accumulates them in the
  *		type conversion buffer BUF.  The LAYOUT argument describes
@@ -190,7 +191,7 @@ done:
  *-------------------------------------------------------------------------
  */
 static size_t
-H5D_gather_file(const H5D_io_info_t *_io_info,
+H5D__gather_file(const H5D_io_info_t *_io_info,
     const H5S_t *space, H5S_sel_iter_t *iter, size_t nelmts,
     void *_buf/*out*/)
 {
@@ -207,7 +208,7 @@ H5D_gather_file(const H5D_io_info_t *_io_info,
     size_t nelem;               /* Number of elements used in sequences */
     size_t ret_value = nelmts;  /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Check args */
     HDassert(_io_info);
@@ -266,11 +267,11 @@ done:
         off = H5FL_SEQ_FREE(hsize_t, off);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5D_gather_file() */
+} /* H5D__gather_file() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_scatter_mem
+ * Function:	H5D__scatter_mem
  *
  * Purpose:	Scatters NELMTS data points from the scatter buffer
  *		TSCAT_BUF to the application buffer BUF.  Each element is
@@ -285,7 +286,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5D_scatter_mem (const void *_tscat_buf, const H5S_t *space,
+H5D__scatter_mem (const void *_tscat_buf, const H5S_t *space,
     H5S_sel_iter_t *iter, size_t nelmts, const H5D_dxpl_cache_t *dxpl_cache,
     void *_buf/*out*/)
 {
@@ -301,7 +302,7 @@ H5D_scatter_mem (const void *_tscat_buf, const H5S_t *space,
     size_t nelem;               /* Number of elements used in sequences */
     herr_t ret_value = SUCCEED;   /* Number of elements scattered */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* Check args */
     HDassert(tscat_buf);
@@ -351,17 +352,17 @@ done:
         off = H5FL_SEQ_FREE(hsize_t, off);
 
     FUNC_LEAVE_NOAPI(ret_value)
-}   /* H5D_scatter_mem() */
+}   /* H5D__scatter_mem() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_gather_mem
+ * Function:	H5D__gather_mem
  *
  * Purpose:	Gathers dataset elements from application memory BUF and
  *		copies them into the gather buffer TGATH_BUF.
  *		Each element is ELMT_SIZE bytes and arranged in application
  *		memory according to SPACE.
- *		The caller is requesting that at most NELMTS be gathered.
+ *		The caller is requesting that exactly NELMTS be gathered.
  *
  * Return:	Success:	Number of elements copied.
  *		Failure:	0
@@ -372,7 +373,7 @@ done:
  *-------------------------------------------------------------------------
  */
 static size_t
-H5D_gather_mem(const void *_buf, const H5S_t *space,
+H5D__gather_mem(const void *_buf, const H5S_t *space,
     H5S_sel_iter_t *iter, size_t nelmts, const H5D_dxpl_cache_t *dxpl_cache,
     void *_tgath_buf/*out*/)
 {
@@ -388,7 +389,7 @@ H5D_gather_mem(const void *_buf, const H5S_t *space,
     size_t nelem;               /* Number of elements used in sequences */
     size_t ret_value = nelmts;    /* Number of elements gathered */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Check args */
     HDassert(buf);
@@ -438,11 +439,11 @@ done:
         off = H5FL_SEQ_FREE(hsize_t, off);
 
     FUNC_LEAVE_NOAPI(ret_value)
-}   /* H5D_gather_mem() */
+}   /* H5D__gather_mem() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_scatgath_read
+ * Function:	H5D__scatgath_read
  *
  * Purpose:	Perform scatter/gather ead from a contiguous [piece of a] dataset.
  *
@@ -454,7 +455,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5D_scatgath_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
+H5D__scatgath_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
     hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space)
 {
     const H5D_dxpl_cache_t *dxpl_cache = io_info->dxpl_cache;     /* Local pointer to dataset transfer info */
@@ -469,7 +470,7 @@ H5D_scatgath_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info
     size_t	smine_nelmts;		/*elements per strip	*/
     herr_t	ret_value = SUCCEED;	/*return value		*/
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(io_info);
@@ -510,7 +511,7 @@ H5D_scatgath_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info
 	/*
          * Gather data
          */
-        n = H5D_gather_file(io_info, file_space, &file_iter, smine_nelmts,
+        n = H5D__gather_file(io_info, file_space, &file_iter, smine_nelmts,
                 type_info->tconv_buf/*out*/);
 	if(n != smine_nelmts)
             HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "file gather failed")
@@ -520,13 +521,13 @@ H5D_scatgath_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info
          * bypass the rest of steps.
          */
         if(type_info->cmpd_subset && H5T_SUBSET_FALSE != type_info->cmpd_subset->subset) {
-            if(H5D_compound_opt_read(smine_nelmts, mem_space, &mem_iter, dxpl_cache,
+            if(H5D__compound_opt_read(smine_nelmts, mem_space, &mem_iter, dxpl_cache,
                     type_info, buf /*out*/) < 0)
                 HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "datatype conversion failed")
         } /* end if */
         else {
             if(H5T_BKG_YES == type_info->need_bkg) {
-                n = H5D_gather_mem(buf, mem_space, &bkg_iter, smine_nelmts,
+                n = H5D__gather_mem(buf, mem_space, &bkg_iter, smine_nelmts,
                         dxpl_cache, type_info->bkg_buf/*out*/);
                 if(n != smine_nelmts)
                     HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "mem gather failed")
@@ -548,7 +549,7 @@ H5D_scatgath_read(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info
             /*
              * Scatter the data into memory.
              */
-            if(H5D_scatter_mem(type_info->tconv_buf, mem_space, &mem_iter,
+            if(H5D__scatter_mem(type_info->tconv_buf, mem_space, &mem_iter,
                     smine_nelmts, dxpl_cache, buf/*out*/) < 0)
                 HGOTO_ERROR(H5E_DATASET, H5E_READERROR, FAIL, "scatter failed")
         } /* end else */
@@ -570,11 +571,11 @@ done:
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5D_scatgath_read() */
+} /* end H5D__scatgath_read() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_scatgath_write
+ * Function:	H5D__scatgath_write
  *
  * Purpose:	Perform scatter/gather write to a contiguous [piece of a] dataset.
  *
@@ -586,7 +587,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5D_scatgath_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
+H5D__scatgath_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_info,
     hsize_t nelmts, const H5S_t *file_space, const H5S_t *mem_space)
 {
     const H5D_dxpl_cache_t *dxpl_cache = io_info->dxpl_cache;     /* Local pointer to dataset transfer info */
@@ -601,7 +602,7 @@ H5D_scatgath_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_inf
     size_t	smine_nelmts;		/*elements per strip	*/
     herr_t	ret_value = SUCCEED;	/*return value		*/
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(io_info);
@@ -638,7 +639,7 @@ H5D_scatgath_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_inf
          * buffer. Also gather data from the file into the background buffer
          * if necessary.
          */
-        n = H5D_gather_mem(buf, mem_space, &mem_iter, smine_nelmts,
+        n = H5D__gather_mem(buf, mem_space, &mem_iter, smine_nelmts,
                 dxpl_cache, type_info->tconv_buf/*out*/);
         if(n != smine_nelmts)
             HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "mem gather failed")
@@ -650,13 +651,13 @@ H5D_scatgath_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_inf
          * function H5T_conv_struct_opt to protect the background data.
          */
         if(type_info->cmpd_subset && H5T_SUBSET_DST == type_info->cmpd_subset->subset
-            && type_info->dst_type_size == type_info->cmpd_subset->copy_size) {
-            if(H5D_compound_opt_write(smine_nelmts, type_info) < 0)
+                && type_info->dst_type_size == type_info->cmpd_subset->copy_size) {
+            if(H5D__compound_opt_write(smine_nelmts, type_info) < 0)
                 HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "datatype conversion failed")
         } /* end if */
         else {
             if(H5T_BKG_YES == type_info->need_bkg) {
-                n = H5D_gather_file(io_info, file_space, &bkg_iter, smine_nelmts,
+                n = H5D__gather_file(io_info, file_space, &bkg_iter, smine_nelmts,
                         type_info->bkg_buf/*out*/);
                 if(n != smine_nelmts)
                     HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "file gather failed")
@@ -680,7 +681,7 @@ H5D_scatgath_write(const H5D_io_info_t *io_info, const H5D_type_info_t *type_inf
         /*
          * Scatter the data out to the file.
          */
-        if(H5D_scatter_file(io_info, file_space, &file_iter, smine_nelmts,
+        if(H5D__scatter_file(io_info, file_space, &file_iter, smine_nelmts,
                 type_info->tconv_buf) < 0)
             HGOTO_ERROR(H5E_DATASET, H5E_WRITEERROR, FAIL, "scatter failed")
     } /* end for */
@@ -701,11 +702,11 @@ done:
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5D_scatgath_write() */
+} /* end H5D__scatgath_write() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_compound_opt_read
+ * Function:	H5D__compound_opt_read
  *
  * Purpose:	A special optimization case when the source and
  *              destination members are a subset of each other, and
@@ -737,7 +738,7 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5D_compound_opt_read(size_t nelmts, const H5S_t *space,
+H5D__compound_opt_read(size_t nelmts, const H5S_t *space,
     H5S_sel_iter_t *iter, const H5D_dxpl_cache_t *dxpl_cache,
     const H5D_type_info_t *type_info, void *user_buf/*out*/)
 {
@@ -750,7 +751,7 @@ H5D_compound_opt_read(size_t nelmts, const H5S_t *space,
     size_t     src_stride, dst_stride, copy_size;
     herr_t     ret_value = SUCCEED;	       /*return value		*/
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* Check args */
     HDassert(nelmts > 0);
@@ -832,11 +833,11 @@ done:
         off = H5FL_SEQ_FREE(hsize_t, off);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5D_compound_opt_read() */
+} /* end H5D__compound_opt_read() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5D_compound_opt_write
+ * Function:	H5D__compound_opt_write
  *
  * Purpose:	A special optimization case when the source and
  *              destination members are a subset of each other, and
@@ -869,13 +870,13 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5D_compound_opt_write(size_t nelmts, const H5D_type_info_t *type_info)
+H5D__compound_opt_write(size_t nelmts, const H5D_type_info_t *type_info)
 {
     uint8_t    *xsbuf, *xdbuf;                  /* Source & destination pointers into dataset buffer */
     size_t     src_stride, dst_stride;          /* Strides through source & destination datatypes */
     size_t     i;                               /* Local index variable */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Check args */
     HDassert(nelmts > 0);
@@ -897,5 +898,206 @@ H5D_compound_opt_write(size_t nelmts, const H5D_type_info_t *type_info)
     } /* end for */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5D_compound_opt_write() */
+} /* end H5D__compound_opt_write() */
+
+
+/*-------------------------------------------------------------------------
+ * Function:    H5Dscatter
+ *
+ * Purpose:     Scatters data provided by the callback op to the
+ *              destination buffer dst_buf, where the dimensions of
+ *              dst_buf and the selection to be scattered to are specified
+ *              by the dataspace dst_space_id.  The type of the data to be
+ *              scattered is specified by type_id.
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ * Programmer:  Neil Fortner
+ *              14 Jan 2013
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5Dscatter(H5D_scatter_func_t op, void *op_data, hid_t type_id,
+    hid_t dst_space_id, void *dst_buf)
+{
+    H5T_t *type;                /* Datatype */
+    H5S_t *dst_space;           /* Dataspace */
+    H5S_sel_iter_t iter;        /* Selection iteration info*/
+    hbool_t iter_init = FALSE;  /* Selection iteration info has been initialized */
+    void *src_buf = NULL;       /* Source (contiguous) data buffer */
+    size_t src_buf_nbytes = 0;  /* Size of src_buf */
+    size_t type_size;           /* Datatype element size */
+    hssize_t nelmts;            /* Number of remaining elements in selection */
+    size_t nelmts_scatter = 0;  /* Number of elements to scatter to dst_buf */
+    H5D_dxpl_cache_t _dxpl_cache; /* Data transfer property cache buffer */
+    H5D_dxpl_cache_t *dxpl_cache = &_dxpl_cache; /* Data transfer property cache */
+    herr_t ret_value = SUCCEED; /* Return value */
+
+    FUNC_ENTER_API(FAIL)
+    H5TRACE5("e", "x*xii*x", op, op_data, type_id, dst_space_id, dst_buf);
+
+    /* Check args */
+    if(op == NULL)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid callback function pointer")
+    if(NULL == (type = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype")
+    if(NULL == (dst_space= (H5S_t *)H5I_object_verify(dst_space_id, H5I_DATASPACE)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
+    if(dst_buf == NULL)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no destination buffer provided")
+
+    /* Fill the DXPL cache values for later use */
+    if(H5D__get_dxpl_cache(H5P_DATASET_XFER_DEFAULT, &dxpl_cache) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't fill dxpl cache")
+
+    /* Get datatype element size */
+    if(0 == (type_size = H5T_GET_SIZE(type)))
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get datatype size")
+
+    /* Get number of elements in dataspace */
+    if((nelmts = (hssize_t)H5S_GET_SELECT_NPOINTS(dst_space)) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTCOUNT, FAIL, "unable to get number of elements in selection")
+
+    /* Initialize selection iterator */
+    if(H5S_select_iter_init(&iter, dst_space, type_size) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize selection iterator information")
+    iter_init = TRUE;
+
+    /* Loop until all data has been scattered */
+    while(nelmts > 0) {
+        /* Make callback to retrieve data */
+        if(op(&src_buf, &src_buf_nbytes, op_data) < 0)
+            HGOTO_ERROR(H5E_DATASET, H5E_CALLBACK, FAIL, "callback operator returned failure")
+
+        /* Calculate number of elements */
+        nelmts_scatter = src_buf_nbytes / type_size;
+
+        /* Check callback results */
+        if(!src_buf)
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "callback did not return a buffer")
+        if(src_buf_nbytes == 0)
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "callback returned a buffer size of 0")
+        if(src_buf_nbytes % type_size)
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "buffer size is not a multiple of datatype size")
+        if(nelmts_scatter > (size_t)nelmts)
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "callback returned more elements than in selection")
+
+        /* Scatter data */
+        if(H5D__scatter_mem(src_buf, dst_space, &iter, nelmts_scatter, dxpl_cache, dst_buf) < 0)
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTCOPY, FAIL, "scatter failed")
+
+        nelmts -= (hssize_t)nelmts_scatter;
+    } /* end while */
+
+done:
+    /* Release selection iterator */
+    if(iter_init) {
+        if(H5S_SELECT_ITER_RELEASE(&iter) < 0)
+            HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't release selection iterator")
+    } /* end if */
+
+    FUNC_LEAVE_API(ret_value)
+}   /* H5Dscatter() */
+
+
+/*-------------------------------------------------------------------------
+ * Function:    H5Dgather
+ *
+ * Purpose:     Gathers data provided from the source buffer src_buf to
+ *              contiguous buffer dst_buf, then calls the callback op.
+ *              The dimensions of src_buf and the selection to be gathered
+ *              are specified by the dataspace src_space_id.  The type of
+ *              the data to be gathered is specified by type_id.
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ * Programmer:  Neil Fortner
+ *              16 Jan 2013
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5Dgather(hid_t src_space_id, void *src_buf, hid_t type_id, size_t dst_buf_size,
+    void *dst_buf, H5D_gather_func_t op, void *op_data)
+{
+    H5T_t *type;                /* Datatype */
+    H5S_t *src_space;           /* Dataspace */
+    H5S_sel_iter_t iter;        /* Selection iteration info*/
+    hbool_t iter_init = FALSE;  /* Selection iteration info has been initialized */
+    size_t type_size;           /* Datatype element size */
+    hssize_t nelmts;            /* Number of remaining elements in selection */
+    size_t dst_buf_nelmts;      /* Number of elements that can fit in dst_buf */
+    size_t nelmts_gathered;     /* Number of elements gathered from src_buf */
+    H5D_dxpl_cache_t _dxpl_cache; /* Data transfer property cache buffer */
+    H5D_dxpl_cache_t *dxpl_cache = &_dxpl_cache; /* Data transfer property cache */
+    herr_t ret_value = SUCCEED; /* Return value */
+
+    FUNC_ENTER_API(FAIL)
+    H5TRACE7("e", "i*xiz*xx*x", src_space_id, src_buf, type_id, dst_buf_size,
+             dst_buf, op, op_data);
+
+    /* Check args */
+    if(NULL == (src_space= (H5S_t *)H5I_object_verify(src_space_id, H5I_DATASPACE)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
+    if(src_buf == NULL)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no source buffer provided")
+    if(NULL == (type = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype")
+    if(dst_buf_size == 0)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "destination buffer size is 0")
+    if(dst_buf == NULL)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no destination buffer provided")
+
+    /* Fill the DXPL cache values for later use */
+    if(H5D__get_dxpl_cache(H5P_DATASET_XFER_DEFAULT, &dxpl_cache) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't fill dxpl cache")
+
+    /* Get datatype element size */
+    if(0 == (type_size = H5T_GET_SIZE(type)))
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get datatype size")
+
+    /* Get number of elements in dst_buf_size */
+    dst_buf_nelmts = dst_buf_size / type_size;
+    if(dst_buf_nelmts == 0)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "destination buffer is not large enough to hold one element")
+
+    /* Get number of elements in dataspace */
+    if((nelmts = (hssize_t)H5S_GET_SELECT_NPOINTS(src_space)) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTCOUNT, FAIL, "unable to get number of elements in selection")
+
+    /* If dst_buf is not large enough to hold all the elements, make sure there
+     * is a callback */
+    if(((size_t)nelmts > dst_buf_nelmts) && (op == NULL))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no callback supplied and destination buffer too small")
+
+    /* Initialize selection iterator */
+    if(H5S_select_iter_init(&iter, src_space, type_size) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize selection iterator information")
+    iter_init = TRUE;
+
+    /* Loop until all data has been scattered */
+    while(nelmts > 0) {
+        /* Gather data */
+        if(0 == (nelmts_gathered = H5D__gather_mem(src_buf, src_space, &iter, MIN(dst_buf_nelmts, (size_t)nelmts), dxpl_cache, dst_buf)))
+            HGOTO_ERROR(H5E_IO, H5E_CANTCOPY, FAIL, "gather failed")
+        HDassert(nelmts_gathered == MIN(dst_buf_nelmts, (size_t)nelmts));
+
+        /* Make callback to process dst_buf */
+        if(op && op(dst_buf, nelmts_gathered * type_size, op_data) < 0)
+            HGOTO_ERROR(H5E_DATASET, H5E_CALLBACK, FAIL, "callback operator returned failure")
+
+        nelmts -= (hssize_t)nelmts_gathered;
+        HDassert(op || (nelmts == 0));
+    } /* end while */
+
+done:
+    /* Release selection iterator */
+    if(iter_init) {
+        if(H5S_SELECT_ITER_RELEASE(&iter) < 0)
+            HDONE_ERROR(H5E_DATASET, H5E_CANTFREE, FAIL, "Can't release selection iterator")
+    } /* end if */
+
+    FUNC_LEAVE_API(ret_value)
+}   /* H5Dgather() */
 
