@@ -32,15 +32,15 @@ typedef struct H5E_t H5E_t;
  * and a FUNC_LEAVE() within a function body.  The arguments are the major
  * error number, the minor error number, and a description of the error.
  */
-#define HERROR(maj_id, min_id, str) H5E_push_stack(NULL, __FILE__, FUNC, __LINE__, H5E_ERR_CLS_g, maj_id, min_id, str)
+#define HERROR(maj_id, min_id, ...) H5E_printf_stack(NULL, __FILE__, FUNC, __LINE__, H5E_ERR_CLS_g, maj_id, min_id, __VA_ARGS__)
 
 /*
  * HCOMMON_ERROR macro, used by HDONE_ERROR and HGOTO_ERROR
  * (Shouldn't need to be used outside this header file)
  */
-#define HCOMMON_ERROR(maj, min, str)  				              \
-   HERROR(maj, min, str);						      \
-   (void)H5E_dump_api_stack((int)H5_IS_API(FUNC));
+#define HCOMMON_ERROR(maj, min, ...)  				              \
+   HERROR(maj, min, __VA_ARGS__);						      \
+   err_occurred = TRUE;
 
 /*
  * HDONE_ERROR macro, used to facilitate error reporting between a
@@ -51,8 +51,8 @@ typedef struct H5E_t H5E_t;
  * (This macro can also be used to push an error and set the return value
  *      without jumping to any labels)
  */
-#define HDONE_ERROR(maj, min, ret_val, str) {				      \
-   HCOMMON_ERROR(maj, min, str);					      \
+#define HDONE_ERROR(maj, min, ret_val, ...) {				      \
+   HCOMMON_ERROR(maj, min, __VA_ARGS__);					      \
    ret_value = ret_val;                                                       \
 }
 
@@ -63,8 +63,8 @@ typedef struct H5E_t H5E_t;
  * error string.  The return value is assigned to a variable `ret_value' and
  * control branches to the `done' label.
  */
-#define HGOTO_ERROR(maj, min, ret_val, str) {				      \
-   HCOMMON_ERROR(maj, min, str);					      \
+#define HGOTO_ERROR(maj, min, ret_val, ...) {				      \
+   HCOMMON_ERROR(maj, min, __VA_ARGS__);					      \
    HGOTO_DONE(ret_val)						              \
 }
 
@@ -78,8 +78,10 @@ typedef struct H5E_t H5E_t;
 
 /* Library-private functions defined in H5E package */
 H5_DLL herr_t H5E_init(void);
-H5_DLL herr_t H5E_push_stack(H5E_t *estack, const char *file, const char *func, unsigned line,
-                            hid_t cls_id, hid_t maj_id, hid_t min_id, const char *desc);
+H5_DLL herr_t H5E_push_stack(H5E_t *estack, const char *file, const char *func,
+    unsigned line, hid_t cls_id, hid_t maj_id, hid_t min_id, const char *desc);
+H5_DLL herr_t H5E_printf_stack(H5E_t *estack, const char *file, const char *func,
+    unsigned line, hid_t cls_id, hid_t maj_id, hid_t min_id, const char *fmt, ...);
 H5_DLL herr_t H5E_clear_stack(H5E_t *estack);
 H5_DLL herr_t H5E_dump_api_stack(int is_api);
 
@@ -91,16 +93,13 @@ H5_DLL herr_t H5E_dump_api_stack(int is_api);
 /* Retrieve the error code description string and push it onto the error
  * stack.
  */
-#define	HSYS_ERROR(errnum) {						      \
-    HERROR(H5E_INTERNAL, H5E_SYSERRSTR, HDstrerror(errnum));                  \
-}
 #define	HSYS_DONE_ERROR(majorcode, minorcode, retcode, str) {		      \
-    HSYS_ERROR(errno);							      \
-    HDONE_ERROR(majorcode, minorcode, retcode, str);			      \
+    int myerrno = errno;							      \
+    HDONE_ERROR(majorcode, minorcode, retcode, "%s, errno = %d, error message = '%s'", str, myerrno, HDstrerror(myerrno));			      \
 }
 #define	HSYS_GOTO_ERROR(majorcode, minorcode, retcode, str) {		      \
-    HSYS_ERROR(errno);							      \
-    HGOTO_ERROR(majorcode, minorcode, retcode, str);			      \
+    int myerrno = errno;							      \
+    HGOTO_ERROR(majorcode, minorcode, retcode, "%s, errno = %d, error message = '%s'", str, myerrno, HDstrerror(myerrno));			      \
 }
 
 #ifdef H5_HAVE_PARALLEL
