@@ -74,6 +74,11 @@
 #define END_MEMBERS	}}
 
 
+#define H5FD_MULTI_DXPL_PROP_NAME       "H5FD_MULTI_DXPL"
+#define H5FD_MULTI_DXPL_PROP_SIZE       sizeof(H5FD_multi_dxpl_t)
+
+#define H5FD_MULT_MAX_FILE_NAME_LEN     1024
+
 /* The driver identification number, initialized at runtime */
 static hid_t H5FD_MULTI_g = 0;
 
@@ -125,8 +130,6 @@ static herr_t H5FD_multi_sb_decode(H5FD_t *file, const char *name,
 static void *H5FD_multi_fapl_get(H5FD_t *file);
 static void *H5FD_multi_fapl_copy(const void *_old_fa);
 static herr_t H5FD_multi_fapl_free(void *_fa);
-static void *H5FD_multi_dxpl_copy(const void *_old_dx);
-static herr_t H5FD_multi_dxpl_free(void *_dx);
 static H5FD_t *H5FD_multi_open(const char *name, unsigned flags,
 			       hid_t fapl_id, haddr_t maxaddr);
 static herr_t H5FD_multi_close(H5FD_t *_file);
@@ -159,9 +162,9 @@ static const H5FD_class_t H5FD_multi_g = {
     H5FD_multi_fapl_get,			/*fapl_get		*/
     H5FD_multi_fapl_copy,			/*fapl_copy		*/
     H5FD_multi_fapl_free,			/*fapl_free		*/
-    sizeof(H5FD_multi_dxpl_t),			/*dxpl_size		*/
-    H5FD_multi_dxpl_copy,			/*dxpl_copy		*/
-    H5FD_multi_dxpl_free,			/*dxpl_free		*/
+    0,						/*dxpl_size		*/
+    NULL,					/*dxpl_copy		*/
+    NULL,					/*dxpl_free		*/
     H5FD_multi_open,				/*open			*/
     H5FD_multi_close,				/*close			*/
     H5FD_multi_cmp,				/*cmp			*/
@@ -203,12 +206,14 @@ static char *
 my_strdup(const char *s)
 {
     char *x;
+    size_t str_len;
 
     if(!s)
         return NULL;
-    if(NULL == (x = (char *)malloc(strlen(s) + 1)))
+    str_len = strlen(s) + 1;
+    if(NULL == (x = (char *)malloc(str_len)))
         return NULL;
-    strcpy(x, s);
+    memcpy(x, s, str_len);
 
     return x;
 }
@@ -298,7 +303,7 @@ H5Pset_fapl_split(hid_t fapl, const char *meta_ext, hid_t meta_plist_id,
     H5FD_mem_t		memb_map[H5FD_MEM_NTYPES];
     hid_t		memb_fapl[H5FD_MEM_NTYPES];
     const char		*memb_name[H5FD_MEM_NTYPES];
-    char		meta_name[1024], raw_name[1024];
+    char		meta_name[H5FD_MULT_MAX_FILE_NAME_LEN], raw_name[H5FD_MULT_MAX_FILE_NAME_LEN];
     haddr_t		memb_addr[H5FD_MEM_NTYPES];
 
     /*NO TRACE*/
@@ -308,7 +313,8 @@ H5Pset_fapl_split(hid_t fapl, const char *meta_ext, hid_t meta_plist_id,
 
     /* Initialize */
     ALL_MEMBERS(mt) {
-	memb_map[mt] = (H5FD_MEM_DRAW==mt?mt:H5FD_MEM_SUPER);
+	/* Treat global heap as raw data, not metadata */
+	memb_map[mt] = ((mt == H5FD_MEM_DRAW || mt == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : H5FD_MEM_SUPER);
 	memb_fapl[mt] = -1;
 	memb_name[mt] = NULL;
 	memb_addr[mt] = HADDR_UNDEF;
@@ -320,25 +326,39 @@ H5Pset_fapl_split(hid_t fapl, const char *meta_ext, hid_t meta_plist_id,
 
     /* The names */
     /* process meta filename */
-    if (meta_ext){
-	if (strstr(meta_ext, "%s"))
-	    strcpy(meta_name, meta_ext);
+    if(meta_ext) {
+	if(strstr(meta_ext, "%s")) {
+            /* Note: this doesn't accommodate for when the '%s' in the user's
+             *  string is at a position >sizeof(meta_name) - QK & JK - 2013/01/17
+             */
+	    strncpy(meta_name, meta_ext, sizeof(meta_name));
+            meta_name[sizeof(meta_name) - 1] = '\0';
+        }
 	else
 	    sprintf(meta_name, "%%s%s", meta_ext);
     }
-    else
-	strcpy(meta_name, "%s.meta");
+    else {
+	strncpy(meta_name, "%s.meta", sizeof(meta_name));
+        meta_name[sizeof(meta_name) - 1] = '\0';
+    }
     memb_name[H5FD_MEM_SUPER] = meta_name;
 
     /* process raw filename */
-    if (raw_ext){
-	if (strstr(raw_ext, "%s"))
-	    strcpy(raw_name, raw_ext);
+    if(raw_ext) {
+	if(strstr(raw_ext, "%s")) {
+            /* Note: this doesn't accommodate for when the '%s' in the user's
+             *  string is at a position >sizeof(raw_name) - QK & JK - 2013/01/17
+             */
+	    strncpy(raw_name, raw_ext, sizeof(raw_name));
+            raw_name[sizeof(raw_name) - 1] = '\0';
+        }
 	else
 	    sprintf(raw_name, "%%s%s", raw_ext);
     }
-    else
-	strcpy(raw_name, "%s.raw");
+    else {
+	strncpy(raw_name, "%s.raw", sizeof(raw_name));
+        raw_name[sizeof(raw_name) - 1] = '\0';
+    }
     memb_name[H5FD_MEM_DRAW] = raw_name;
 
     /* The sizes */
@@ -569,12 +589,11 @@ H5Pget_fapl_multi(hid_t fapl_id, H5FD_mem_t *memb_map/*out*/,
 		memb_fapl[mt] = fa->memb_fapl[mt]; /*default or bad ID*/
 	}
     }
-    if (memb_name) {
-	for (mt=H5FD_MEM_DEFAULT; mt<H5FD_MEM_NTYPES; mt=(H5FD_mem_t)(mt+1)) {
-	    if (fa->memb_name[mt]) {
-		memb_name[mt] = (char *)malloc(strlen(fa->memb_name[mt])+1);
-		strcpy(memb_name[mt], fa->memb_name[mt]);
-	    } else
+    if(memb_name) {
+	for(mt = H5FD_MEM_DEFAULT; mt < H5FD_MEM_NTYPES; mt = (H5FD_mem_t)(mt + 1)) {
+	    if(fa->memb_name[mt])
+		memb_name[mt] = my_strdup(fa->memb_name[mt]);
+	    else
 		memb_name[mt] = NULL;
 	}
     }
@@ -588,106 +607,123 @@ H5Pget_fapl_multi(hid_t fapl_id, H5FD_mem_t *memb_map/*out*/,
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Pset_dxpl_multi
+ * Function:	H5FD_multi_dxpl_copy_cb
  *
- * Purpose:	Set the data transfer property list DXPL_ID to use the multi
- *		driver with the specified data transfer properties for each
- *		memory usage type MEMB_DXPL[] (after the usage map is
- *		applied).
+ * Purpose:	Multi VFD DXPL property 'copy' callback
  *
  * Return:	Success:	0
- *
  *		Failure:	-1
  *
- * Programmer:	Robb Matzke
- *              Tuesday, August 10, 1999
- *
- * Modifications:
+ * Programmer:	Quincey Koziol
+ *              Wednesday, August 15, 2012
  *
  *-------------------------------------------------------------------------
  */
-herr_t
-H5Pset_dxpl_multi(hid_t dxpl_id, const hid_t *memb_dxpl)
+static herr_t
+H5FD_multi_dxpl_copy_cb(const char *name, size_t size, void *_dx)
 {
-    H5FD_multi_dxpl_t	dx;
-    H5FD_mem_t		mt;
-    static const char *func="H5FDset_dxpl_multi";  /* Function Name for error reporting */
+    H5FD_multi_dxpl_t *dx = (H5FD_multi_dxpl_t *)_dx;
+    static const char *func = "H5FD_multi_dxpl_copy_cb";  /* Function Name for error reporting */
 
-    /*NO TRACE*/
+    /* Shut compiler up */
+    name = name;
 
-    /* Clear the error stack */
-    H5Eclear2(H5E_DEFAULT);
+    /* Sanity check */
+    assert(size == sizeof(H5FD_multi_dxpl_t));
 
-    /* Check arguments */
-    if (TRUE!=H5Pisa_class(dxpl_id,  H5P_DATASET_XFER))
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_BADTYPE, "not a data transfer property list", -1)
-    if (!memb_dxpl)
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_INTERNAL, H5E_BADVALUE, "invalid pointer", -1)
-    for (mt=H5FD_MEM_DEFAULT; mt<H5FD_MEM_NTYPES; mt=(H5FD_mem_t)(mt+1)) {
-        if (memb_dxpl[mt]!=H5P_DEFAULT && TRUE!=H5Pisa_class(memb_dxpl[mt], H5P_DATASET_XFER))
-            H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_BADTYPE, "not a data transfer property list", -1)
-    }
+    ALL_MEMBERS(mt) {
+        if(dx->memb_dxpl[mt] >= 0)
+            if(H5Iinc_ref(dx->memb_dxpl[mt]) < 0)
+                H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_CANTINC, "can't increment ref. count for multi VFD property", -1)
+    } END_MEMBERS;
 
-    /* Initialize the data transfer property list */
-    memcpy(dx.memb_dxpl, memb_dxpl, H5FD_MEM_NTYPES*sizeof(hid_t));
-
-    /* Convert "generic" default property lists into default dataset transfer property lists */
-    for (mt=H5FD_MEM_DEFAULT; mt<H5FD_MEM_NTYPES; mt=(H5FD_mem_t)(mt+1)) {
-        if (dx.memb_dxpl[mt]==H5P_DEFAULT)
-            dx.memb_dxpl[mt]=H5P_DATASET_XFER_DEFAULT;
-    }
-
-    return H5Pset_driver(dxpl_id, H5FD_MULTI, &dx);
-}
+    return 0;
+} /* end H5FD_multi_dxpl_copy_cb() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5Pget_dxpl_multi
+ * Function:	H5FD_multi_dxpl_cmp_cb
  *
- * Purpose:	Returns information which was set with H5Pset_dxpl_multi()
- *		above.
+ * Purpose:	Multi VFD DXPL property 'compare' callback
  *
- * Return:	Success:	0
+ * Return:	Success:	same as memcmp()
+ *		Failure:	<can't fail>
  *
- *		Failure:	-1
- *
- * Programmer:	Robb Matzke
- *              Tuesday, August 10, 1999
- *
- * Modifications:
+ * Programmer:	Quincey Koziol
+ *              Wednesday, August 15, 2012
  *
  *-------------------------------------------------------------------------
  */
-herr_t
-H5Pget_dxpl_multi(hid_t dxpl_id, hid_t *memb_dxpl/*out*/)
+static int
+H5FD_multi_dxpl_cmp_cb(const void *_dx1, const void *_dx2, size_t size)
 {
-    H5FD_multi_dxpl_t	*dx;
-    H5FD_mem_t		mt;
-    static const char *func="H5FDget_dxpl_multi";  /* Function Name for error reporting */
+    const H5FD_multi_dxpl_t *dx1 = (const H5FD_multi_dxpl_t *)_dx1;
+    const H5FD_multi_dxpl_t *dx2 = (const H5FD_multi_dxpl_t *)_dx2;
+    int cmp_status;
 
-    /*NO TRACE*/
+    /* Sanity check */
+    assert(size == sizeof(H5FD_multi_dxpl_t));
 
-    /* Clear the error stack */
-    H5Eclear2(H5E_DEFAULT);
-
-    if (TRUE!=H5Pisa_class(dxpl_id, H5P_DATASET_XFER))
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_BADTYPE, "not a file access property list", -1)
-    if (H5FD_MULTI!=H5Pget_driver(dxpl_id))
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_BADVALUE, "incorrect VFL driver", -1)
-    if(NULL == (dx = (H5FD_multi_dxpl_t *)H5Pget_driver_info(dxpl_id)))
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_BADVALUE, "bad VFL driver info", -1)
-
-    if (memb_dxpl) {
-	for (mt=H5FD_MEM_DEFAULT; mt<H5FD_MEM_NTYPES; mt=(H5FD_mem_t)(mt+1)) {
-	    if (dx->memb_dxpl[mt]>=0)
-		memb_dxpl[mt] = H5Pcopy(dx->memb_dxpl[mt]);
-	    else
-		memb_dxpl[mt] = dx->memb_dxpl[mt]; /*default or bad ID */
-	}
-    }
+    ALL_MEMBERS(mt) {
+        if(dx1->memb_dxpl[mt] >= 0) {
+            if(dx2->memb_dxpl[mt] >= 0) {
+                cmp_status = H5Pequal(dx1->memb_dxpl[mt], dx2->memb_dxpl[mt]);
+                if(cmp_status != 0)
+                    return(cmp_status);
+            } /* end if */
+            else
+                return(-1);
+        } /* end if */
+        else {
+            if(dx2->memb_dxpl[mt] >= 0)
+                return(1);
+            else
+                if(dx1->memb_dxpl[mt] > dx2->memb_dxpl[mt])
+                    return(-1);
+                else if(dx1->memb_dxpl[mt] < dx2->memb_dxpl[mt])
+                    return(1);
+                else
+                    continue;
+        } /* end else */
+    } END_MEMBERS;
 
     return 0;
-}
+} /* end H5FD_multi_dxpl_cmp_cb() */
+
+
+/*-------------------------------------------------------------------------
+ * Function:	H5FD_multi_dxpl_cls_cb
+ *
+ * Purpose:	Multi VFD DXPL property 'close' callback
+ *
+ * Return:	Success:	0
+ *		Failure:	-1
+ *
+ * Programmer:	Quincey Koziol
+ *              Wednesday, August 15, 2012
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5FD_multi_dxpl_cls_cb(const char *name, size_t size, void *_dx)
+{
+    H5FD_multi_dxpl_t *dx = (H5FD_multi_dxpl_t *)_dx;
+    static const char *func = "H5FD_multi_dxpl_cls_cb";  /* Function Name for error reporting */
+
+    /* Shut compiler up */
+    name = name;
+
+    /* Sanity check */
+    assert(size == sizeof(H5FD_multi_dxpl_t));
+
+    ALL_MEMBERS(mt) {
+        if(dx->memb_dxpl[mt] >= 0)
+            if(H5Idec_ref(dx->memb_dxpl[mt]) < 0)
+                H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_CANTDEC, "can't increment ref. count for multi VFD property", -1)
+    } END_MEMBERS;
+
+    return 0;
+} /* end H5FD_multi_dxpl_cls_cb() */
 
 
 /*-------------------------------------------------------------------------
@@ -804,17 +840,17 @@ H5FD_multi_sb_encode(H5FD_t *_file, char *name/*out*/,
         p += sizeof(haddr_t);
         nseen++;
     } END_MEMBERS;
-    if (H5Tconvert(H5T_NATIVE_HADDR, H5T_STD_U64LE, nseen*2, buf+8, NULL,
-		   H5P_DEFAULT)<0)
+    if (H5Tconvert(H5T_NATIVE_HADDR, H5T_STD_U64LE, nseen*2, buf+8, NULL, H5P_DEFAULT)<0)
         H5Epush_ret(func, H5E_ERR_CLS, H5E_DATATYPE, H5E_CANTCONVERT, "can't convert superblock info", -1)
 
     /* Encode all name templates */
     p = buf + 8 + nseen*2*8;
     UNIQUE_MEMBERS(file->fa.memb_map, mt) {
         size_t n = strlen(file->fa.memb_name[mt]) + 1;
-        strcpy((char *)p, file->fa.memb_name[mt]);
+        strncpy((char *)p, file->fa.memb_name[mt], n);
         p += n;
-        for (i=n; i%8; i++) *p++ = '\0';
+        for (i=n; i%8; i++)
+            *p++ = '\0';
     } END_MEMBERS;
 
     return 0;
@@ -1044,19 +1080,21 @@ H5FD_multi_fapl_copy(const void *_old_fa)
     ALL_MEMBERS(mt) {
 	if (old_fa->memb_fapl[mt]>=0) {
 	    new_fa->memb_fapl[mt] = H5Pcopy(old_fa->memb_fapl[mt]);
-	    if (new_fa->memb_fapl[mt]<0) nerrors++;
+	    if(new_fa->memb_fapl[mt]<0)
+                nerrors++;
 	}
 	if (old_fa->memb_name[mt]) {
-	    new_fa->memb_name[mt] = (char *)malloc(strlen(old_fa->memb_name[mt])+1);
+	    new_fa->memb_name[mt] = my_strdup(old_fa->memb_name[mt]);
 	    assert(new_fa->memb_name[mt]);
-	    strcpy(new_fa->memb_name[mt], old_fa->memb_name[mt]);
 	}
     } END_MEMBERS;
 
     if (nerrors) {
         ALL_MEMBERS(mt) {
-            if (new_fa->memb_fapl[mt]>=0) (void)H5Pclose(new_fa->memb_fapl[mt]);
-            if (new_fa->memb_name[mt]) free(new_fa->memb_name[mt]);
+            if (new_fa->memb_fapl[mt]>=0)
+                (void)H5Pclose(new_fa->memb_fapl[mt]);
+            if (new_fa->memb_name[mt])
+                free(new_fa->memb_name[mt]);
         } END_MEMBERS;
         free(new_fa);
         H5Epush_ret(func, H5E_ERR_CLS, H5E_INTERNAL, H5E_BADVALUE, "invalid freespace objects", NULL)
@@ -1102,90 +1140,6 @@ H5FD_multi_fapl_free(void *_fa)
     return 0;
 }
 
-
-/*-------------------------------------------------------------------------
- * Function:	H5FD_multi_dxpl_copy
- *
- * Purpose:	Copes the multi-specific data transfer properties.
- *
- * Return:	Success:	Ptr to new property list
- *
- *		Failure:	NULL
- *
- * Programmer:	Robb Matzke
- *              Wednesday, August  4, 1999
- *
- * Modifications:
- *
- *-------------------------------------------------------------------------
- */
-static void *
-H5FD_multi_dxpl_copy(const void *_old_dx)
-{
-    const H5FD_multi_dxpl_t *old_dx = (const H5FD_multi_dxpl_t*)_old_dx;
-    H5FD_multi_dxpl_t *new_dx = (H5FD_multi_dxpl_t *)malloc(sizeof(H5FD_multi_dxpl_t));
-    int nerrors = 0;
-    static const char *func="H5FD_multi_dxpl_copy";  /* Function Name for error reporting */
-
-    assert(new_dx);
-
-    /* Clear the error stack */
-    H5Eclear2(H5E_DEFAULT);
-
-    memcpy(new_dx, old_dx, sizeof(H5FD_multi_dxpl_t));
-    ALL_MEMBERS(mt) {
-	if (old_dx->memb_dxpl[mt]>=0) {
-	    new_dx->memb_dxpl[mt] = H5Pcopy(old_dx->memb_dxpl[mt]);
-	    if (new_dx->memb_dxpl[mt]<0) nerrors++;
-	}
-    } END_MEMBERS;
-
-    if (nerrors) {
-        ALL_MEMBERS(mt) {
-            (void)H5Pclose(new_dx->memb_dxpl[mt]);
-        } END_MEMBERS;
-        free(new_dx);
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_INTERNAL, H5E_BADVALUE, "invalid freespace objects", NULL)
-    }
-    return new_dx;
-}
-
-
-/*-------------------------------------------------------------------------
- * Function:	H5FD_multi_dxpl_free
- *
- * Purpose:	Frees the multi-specific data transfer properties.
- *
- * Return:	Success:	0
- *
- *		Failure:	-1
- *
- * Programmer:	Robb Matzke
- *              Wednesday, August  4, 1999
- *
- * Modifications:
- *
- *-------------------------------------------------------------------------
- */
-static herr_t
-H5FD_multi_dxpl_free(void *_dx)
-{
-    H5FD_multi_dxpl_t	*dx = (H5FD_multi_dxpl_t*)_dx;
-    static const char *func="H5FD_multi_dxpl_free";  /* Function Name for error reporting */
-
-    /* Clear the error stack */
-    H5Eclear2(H5E_DEFAULT);
-
-    ALL_MEMBERS(mt) {
-        if (dx->memb_dxpl[mt]>=0)
-            if(H5Pclose(dx->memb_dxpl[mt])<0)
-                H5Epush_ret(func, H5E_ERR_CLS, H5E_FILE, H5E_CANTCLOSEOBJ, "can't close property list", -1)
-    } END_MEMBERS;
-
-    free(dx);
-    return 0;
-}
-
 
 /*-------------------------------------------------------------------------
  * Function:	H5FD_multi_open
@@ -1821,25 +1775,33 @@ H5FD_multi_free(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, hsi
  * Programmer:	Robb Matzke
  *              Wednesday, August  4, 1999
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_multi_read(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, size_t size,
-		 void *_buf/*out*/)
+H5FD_multi_read(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr,
+    size_t size, void *_buf/*out*/)
 {
     H5FD_multi_t	*file = (H5FD_multi_t*)_file;
-    H5FD_multi_dxpl_t	*dx=NULL;
-    H5FD_mem_t		mt, mmt, hi=H5FD_MEM_DEFAULT;
-    haddr_t		start_addr=0;
+    H5FD_multi_dxpl_t	dx;
+    htri_t              prop_exists = FALSE;    /* Whether the multi VFD DXPL property already exists */
+    H5FD_mem_t		mt, mmt, hi = H5FD_MEM_DEFAULT;
+    haddr_t		start_addr = 0;
+    static const char  *func = "H5FD_multi_read";  /* Function Name for error reporting */
 
     /* Clear the error stack */
     H5Eclear2(H5E_DEFAULT);
 
     /* Get the data transfer properties */
-    if(H5P_FILE_ACCESS_DEFAULT != dxpl_id && H5FD_MULTI == H5Pget_driver(dxpl_id))
-	dx = (H5FD_multi_dxpl_t *)H5Pget_driver_info(dxpl_id);
+    if(H5P_FILE_ACCESS_DEFAULT != dxpl_id) {
+        /* Check for existence of multi VFD DXPL property in DXPL */
+        if((prop_exists = H5Pexist(dxpl_id, H5FD_MULTI_DXPL_PROP_NAME)) < 0)
+            H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_CANTGET, "can't check for multi VFD property", -1)
+
+        /* Get the DXPL value, if it exists */
+        if(prop_exists)
+            if(H5Pget(dxpl_id, H5FD_MULTI_DXPL_PROP_NAME, &dx) < 0)
+                H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_CANTGET, "can't get property value", -1)
+    } /* end if */
 
     /* Find the file to which this address belongs */
     for(mt = H5FD_MEM_SUPER; mt < H5FD_MEM_NTYPES; mt = (H5FD_mem_t)(mt + 1)) {
@@ -1848,18 +1810,19 @@ H5FD_multi_read(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, siz
             mmt = mt;
 	assert(mmt > 0 && mmt < H5FD_MEM_NTYPES);
 
-	if (file->fa.memb_addr[mmt]>addr) continue;
-	if (file->fa.memb_addr[mmt]>=start_addr) {
+	if(file->fa.memb_addr[mmt] > addr)
+            continue;
+	if(file->fa.memb_addr[mmt] >= start_addr) {
 	    start_addr = file->fa.memb_addr[mmt];
 	    hi = mmt;
-	}
-    }
-    assert(hi>0);
+	} /* end if */
+    } /* end for */
+    assert(hi > 0);
 
     /* Read from that member */
-    return H5FDread(file->memb[hi], type, dx?dx->memb_dxpl[hi]:H5P_DEFAULT,
-		    addr-start_addr, size, _buf);
-}
+    return H5FDread(file->memb[hi], type, (prop_exists ? dx.memb_dxpl[hi] : H5P_DEFAULT),
+            addr - start_addr, size, _buf);
+} /* end H5FD_multi_read() */
 
 
 /*-------------------------------------------------------------------------
@@ -1876,45 +1839,54 @@ H5FD_multi_read(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, siz
  * Programmer:	Robb Matzke
  *              Wednesday, August  4, 1999
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_multi_write(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, size_t size,
-		  const void *_buf)
+H5FD_multi_write(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr,
+    size_t size, const void *_buf)
 {
     H5FD_multi_t	*file = (H5FD_multi_t*)_file;
-    H5FD_multi_dxpl_t	*dx=NULL;
-    H5FD_mem_t		mt, mmt, hi=H5FD_MEM_DEFAULT;
-    haddr_t		start_addr=0;
+    H5FD_multi_dxpl_t	dx;
+    htri_t              prop_exists = FALSE;    /* Whether the multi VFD DXPL property already exists */
+    H5FD_mem_t		mt, mmt, hi = H5FD_MEM_DEFAULT;
+    haddr_t		start_addr = 0;
+    static const char  *func = "H5FD_multi_read";  /* Function Name for error reporting */
 
     /* Clear the error stack */
     H5Eclear2(H5E_DEFAULT);
 
     /* Get the data transfer properties */
-    if(H5P_FILE_ACCESS_DEFAULT != dxpl_id && H5FD_MULTI == H5Pget_driver(dxpl_id))
-	dx = (H5FD_multi_dxpl_t *)H5Pget_driver_info(dxpl_id);
+    if(H5P_FILE_ACCESS_DEFAULT != dxpl_id) {
+        /* Check for existence of multi VFD DXPL property in DXPL */
+        if((prop_exists = H5Pexist(dxpl_id, H5FD_MULTI_DXPL_PROP_NAME)) < 0)
+            H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_CANTGET, "can't check for multi VFD property", -1)
+
+        /* Get the DXPL value, if it exists */
+        if(prop_exists)
+            if(H5Pget(dxpl_id, H5FD_MULTI_DXPL_PROP_NAME, &dx) < 0)
+                H5Epush_ret(func, H5E_ERR_CLS, H5E_PLIST, H5E_CANTGET, "can't get property value", -1)
+    } /* end if */
 
     /* Find the file to which this address belongs */
     for(mt = H5FD_MEM_SUPER; mt < H5FD_MEM_NTYPES; mt = (H5FD_mem_t)(mt + 1)) {
 	mmt = file->fa.memb_map[mt];
 	if(H5FD_MEM_DEFAULT == mmt)
             mmt = mt;
-	assert(mmt>0 && mmt<H5FD_MEM_NTYPES);
+	assert(mmt > 0 && mmt<H5FD_MEM_NTYPES);
 
-	if (file->fa.memb_addr[mmt]>addr) continue;
-	if (file->fa.memb_addr[mmt]>=start_addr) {
+	if(file->fa.memb_addr[mmt] > addr)
+            continue;
+	if(file->fa.memb_addr[mmt] >= start_addr) {
 	    start_addr = file->fa.memb_addr[mmt];
 	    hi = mmt;
-	}
-    }
-    assert(hi>0);
+	} /* end if */
+    } /* end for */
+    assert(hi > 0);
 
     /* Write to that member */
-    return H5FDwrite(file->memb[hi], type, dx?dx->memb_dxpl[hi]:H5P_DEFAULT,
-		     addr-start_addr, size, _buf);
-}
+    return H5FDwrite(file->memb[hi], type, (prop_exists ? dx.memb_dxpl[hi] : H5P_DEFAULT),
+            addr - start_addr, size, _buf);
+} /* end H5FD_multi_write() */
 
 
 /*-------------------------------------------------------------------------
@@ -1929,8 +1901,6 @@ H5FD_multi_write(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, si
  * Programmer:	Robb Matzke
  *              Wednesday, August  4, 1999
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -2094,7 +2064,7 @@ compute_next(H5FD_multi_t *file)
 static int
 open_members(H5FD_multi_t *file)
 {
-    char	tmp[1024];
+    char	tmp[H5FD_MULT_MAX_FILE_NAME_LEN];
     int		nerrors=0;
     static const char *func="(H5FD_multi)open_members";  /* Function Name for error reporting */
 
@@ -2102,30 +2072,28 @@ open_members(H5FD_multi_t *file)
     H5Eclear2(H5E_DEFAULT);
 
     UNIQUE_MEMBERS(file->fa.memb_map, mt) {
-	if (file->memb[mt]) continue; /*already open*/
+	if(file->memb[mt])
+            continue; /*already open*/
 	assert(file->fa.memb_name[mt]);
+        /* Note: This truncates the user's filename down to only sizeof(tmp)
+         *      characters. -QK & JK, 2013/01/17
+         */
 	sprintf(tmp, file->fa.memb_name[mt], file->name);
 
 #ifdef H5FD_MULTI_DEBUG
-	if (file->flags & H5F_ACC_DEBUG) {
-	    fprintf(stderr, "H5FD_MULTI: open member %d \"%s\"\n",
-		    (int)mt, tmp);
-	}
+	if(file->flags & H5F_ACC_DEBUG)
+	    fprintf(stderr, "H5FD_MULTI: open member %d \"%s\"\n", (int)mt, tmp);
 #endif
 	H5E_BEGIN_TRY {
-	    file->memb[mt] = H5FDopen(tmp, file->flags, file->fa.memb_fapl[mt],
-				      HADDR_UNDEF);
+	    file->memb[mt] = H5FDopen(tmp, file->flags, file->fa.memb_fapl[mt], HADDR_UNDEF);
 	} H5E_END_TRY;
-	if (!file->memb[mt]) {
+	if(!file->memb[mt]) {
 #ifdef H5FD_MULTI_DEBUG
-	    if (file->flags & H5F_ACC_DEBUG) {
-		fprintf(stderr, "H5FD_MULTI: open failed for member %d\n",
-			(int)mt);
-	    }
+	    if(file->flags & H5F_ACC_DEBUG)
+		fprintf(stderr, "H5FD_MULTI: open failed for member %d\n", (int)mt);
 #endif
-	    if (!file->fa.relax || (file->flags & H5F_ACC_RDWR)) {
+	    if(!file->fa.relax || (file->flags & H5F_ACC_RDWR))
 		nerrors++;
-	    }
 	}
     } END_MEMBERS;
     if (nerrors)
