@@ -145,7 +145,7 @@ typedef struct H5FL_reg_head_t {
 #define H5FL_DEFINE_STATIC(t)  static H5FL_DEFINE_COMMON(t)
 #define H5FL_MALLOC(t) (t *)H5MM_malloc(sizeof(t))
 #define H5FL_CALLOC(t) (t *)H5MM_calloc(sizeof(t))
-#define H5FL_FREE(t,obj) H5MM_xfree(obj)
+#define H5FL_FREE(t,obj) (t *)H5MM_xfree(obj)
 #endif /* H5_NO_REG_FREE_LISTS */
 
 /* Data structure to store information about each block allocated */
@@ -215,7 +215,7 @@ typedef struct H5FL_blk_head_t {
 #define H5FL_BLK_DEFINE_STATIC(t)  static H5FL_BLK_DEFINE_COMMON(t)
 #define H5FL_BLK_MALLOC(t,size) (uint8_t *)H5MM_malloc(size)
 #define H5FL_BLK_CALLOC(t,size) (uint8_t *)H5MM_calloc(size)
-#define H5FL_BLK_FREE(t,blk) H5MM_xfree(blk)
+#define H5FL_BLK_FREE(t,blk) (uint8_t *)H5MM_xfree(blk)
 #define H5FL_BLK_REALLOC(t,blk,new_size) (uint8_t *)H5MM_realloc(blk,new_size)
 #define H5FL_BLK_AVAIL(t,size)  (FALSE)
 #endif /* H5_NO_BLK_FREE_LISTS */
@@ -277,7 +277,7 @@ typedef struct H5FL_arr_head_t {
 #define H5FL_ARR_CALLOC(t,elem) H5FL_arr_calloc(&(H5FL_ARR_NAME(t)),elem)
 
 /* Free an array of type 't' */
-#define H5FL_ARR_FREE(t,obj) H5FL_arr_free(&(H5FL_ARR_NAME(t)),obj)
+#define H5FL_ARR_FREE(t,obj) (t *)H5FL_arr_free(&(H5FL_ARR_NAME(t)),obj)
 
 /* Re-allocate an array of type 't' */
 #define H5FL_ARR_REALLOC(t,obj,new_elem) H5FL_arr_realloc(&(H5FL_ARR_NAME(t)),obj,new_elem)
@@ -293,7 +293,7 @@ typedef struct H5FL_arr_head_t {
 #define H5FL_BARR_DEFINE_STATIC(b,t,m)  static H5FL_ARR_DEFINE_COMMON(t,m) = sizeof(b)
 #define H5FL_ARR_MALLOC(t,elem) H5MM_malloc(H5FL_ARR_NAME(t) + ((elem)*sizeof(t)))
 #define H5FL_ARR_CALLOC(t,elem) H5MM_calloc(H5FL_ARR_NAME(t) + ((elem)*sizeof(t)))
-#define H5FL_ARR_FREE(t,obj) H5MM_xfree(obj)
+#define H5FL_ARR_FREE(t,obj) (t *)H5MM_xfree(obj)
 #define H5FL_ARR_REALLOC(t,obj,new_elem) H5MM_realloc(obj,H5FL_ARR_NAME(t) + ((new_elem)*sizeof(t)))
 #endif /* H5_NO_ARR_FREE_LISTS */
 
@@ -344,12 +344,24 @@ typedef struct H5FL_seq_head_t {
 #define H5FL_SEQ_DEFINE_STATIC(t)  static H5FL_SEQ_DEFINE_COMMON(t)
 #define H5FL_SEQ_MALLOC(t,elem) (t *)H5MM_malloc((elem)*sizeof(t))
 #define H5FL_SEQ_CALLOC(t,elem) (t *)H5MM_calloc((elem)*sizeof(t))
-#define H5FL_SEQ_FREE(t,obj) H5MM_xfree(obj)
+#define H5FL_SEQ_FREE(t,obj) (t *)H5MM_xfree(obj)
 #define H5FL_SEQ_REALLOC(t,obj,new_elem) (t *)H5MM_realloc(obj,(new_elem)*sizeof(t))
 #endif /* H5_NO_SEQ_FREE_LISTS */
 
-/* Forward declaration of the data structure for free list block factory */
-typedef struct H5FL_fac_head_t H5FL_fac_head_t;
+/* Forward declarations of the data structures for free list block factory */
+typedef struct H5FL_fac_gc_node_t H5FL_fac_gc_node_t;
+typedef struct H5FL_fac_node_t H5FL_fac_node_t;
+
+/* Data structure for free list block factory */
+typedef struct H5FL_fac_head_t {
+    unsigned init;      /* Whether the free list has been initialized */
+    unsigned allocated; /* Number of blocks allocated */
+    unsigned onlist;    /* Number of blocks on free list */
+    size_t size;        /* Size of the blocks in the list */
+    H5FL_fac_node_t *list;  /* List of free blocks */
+    H5FL_fac_gc_node_t *prev_gc; /* Previous garbage collection node in list */
+} H5FL_fac_head_t;
+
 
 /*
  * Macros for defining & using free list factories
@@ -360,18 +372,18 @@ typedef struct H5FL_fac_head_t H5FL_fac_head_t;
  */
 #ifndef H5_NO_FAC_FREE_LISTS
 /* Allocate a block from a factory */
-#define H5FL_FAC_MALLOC(t) H5FL_fac_malloc(t H5FL_TRACK_INFO)
+#define H5FL_FAC_MALLOC(f) H5FL_fac_malloc(f H5FL_TRACK_INFO)
 
 /* Allocate a block from a factory and clear it to all zeros */
-#define H5FL_FAC_CALLOC(t) H5FL_fac_calloc(t H5FL_TRACK_INFO)
+#define H5FL_FAC_CALLOC(f) H5FL_fac_calloc(f H5FL_TRACK_INFO)
 
 /* Return a block to a factory */
-#define H5FL_FAC_FREE(t,obj) H5FL_fac_free(t,obj)
+#define H5FL_FAC_FREE(f, obj) H5FL_fac_free(f, obj)
 
 #else /* H5_NO_FAC_FREE_LISTS */
-#define H5FL_FAC_MALLOC(t) H5MM_malloc(t->size)
-#define H5FL_FAC_CALLOC(t) H5MM_calloc(t->size)
-#define H5FL_FAC_FREE(t,obj) H5MM_xfree(obj)
+#define H5FL_FAC_MALLOC(f) H5MM_malloc(f->size)
+#define H5FL_FAC_CALLOC(f) H5MM_calloc(f->size)
+#define H5FL_FAC_FREE(f, obj) H5MM_xfree(obj)
 #endif /* H5_NO_FAC_FREE_LISTS */
 
 /*
