@@ -75,14 +75,14 @@ H5FO_create(const H5F_t *f)
 {
     herr_t ret_value=SUCCEED;          /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_create,FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     assert(f);
     assert(f->shared);
 
     /* Create container used to store open object info */
-    if((f->shared->open_objs = H5SL_create(H5SL_TYPE_HADDR)) == NULL)
+    if((f->shared->open_objs = H5SL_create(H5SL_TYPE_HADDR, NULL)) == NULL)
         HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to create open object container")
 
 done:
@@ -116,7 +116,7 @@ H5FO_opened(const H5F_t *f, haddr_t addr)
     H5FO_open_obj_t *open_obj;  /* Information about open object */
     void *ret_value;            /* Return value */
 
-    FUNC_ENTER_NOAPI_NOFUNC(H5FO_opened)
+    FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -163,7 +163,7 @@ H5FO_insert(const H5F_t *f, haddr_t addr, void *obj, hbool_t delete_flag)
     H5FO_open_obj_t *open_obj;  /* Information about open object */
     herr_t ret_value=SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_insert,FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     assert(f);
@@ -215,7 +215,7 @@ H5FO_delete(H5F_t *f, hid_t dxpl_id, haddr_t addr)
     H5FO_open_obj_t *open_obj;  /* Information about open object */
     herr_t ret_value=SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_delete,FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     HDassert(f);
@@ -234,7 +234,7 @@ H5FO_delete(H5F_t *f, hid_t dxpl_id, haddr_t addr)
     } /* end if */
 
     /* Release the object information */
-    (void)H5FL_FREE(H5FO_open_obj_t, open_obj);
+    open_obj = H5FL_FREE(H5FO_open_obj_t, open_obj);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -266,7 +266,7 @@ H5FO_mark(const H5F_t *f, haddr_t addr, hbool_t deleted)
     H5FO_open_obj_t *open_obj;  /* Information about open object */
     herr_t ret_value=SUCCEED;            /* Return value */
 
-    FUNC_ENTER_NOAPI_NOFUNC(H5FO_mark)
+    FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity check */
     assert(f);
@@ -290,12 +290,12 @@ H5FO_mark(const H5F_t *f, haddr_t addr, hbool_t deleted)
  PURPOSE
     Check if an object is marked to be deleted when it is closed
  USAGE
-    htri_t H5FO_marked(f,addr)
+    hbool_t H5FO_marked(f,addr)
         const H5F_t *f;         IN: File opened object is in
         haddr_t addr;           IN: Address of object to delete
 
  RETURNS
-    Returns a TRUE/FALSE on success, negative on failure
+    Returns a TRUE/FALSE on success
  DESCRIPTION
     Checks if the object is currently in the "opened objects" tree and
     whether its marks for deletion from the file when it is closed.
@@ -304,13 +304,13 @@ H5FO_mark(const H5F_t *f, haddr_t addr, hbool_t deleted)
  EXAMPLES
  REVISION LOG
 --------------------------------------------------------------------------*/
-htri_t
+hbool_t
 H5FO_marked(const H5F_t *f, haddr_t addr)
 {
     H5FO_open_obj_t *open_obj;  /* Information about open object */
-    htri_t ret_value = FAIL;      /* Return value */
+    hbool_t ret_value = FALSE;  /* Return value */
 
-    FUNC_ENTER_NOAPI_NOFUNC(H5FO_marked)
+    FUNC_ENTER_NOAPI_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -349,7 +349,7 @@ H5FO_dest(const H5F_t *f)
 {
     herr_t ret_value=SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_dest,FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     assert(f);
@@ -394,13 +394,13 @@ H5FO_top_create(H5F_t *f)
 {
     herr_t ret_value = SUCCEED;          /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_top_create, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     HDassert(f);
 
     /* Create container used to store open object info */
-    if((f->obj_count = H5SL_create(H5SL_TYPE_HADDR)) == NULL)
+    if((f->obj_count = H5SL_create(H5SL_TYPE_HADDR, NULL)) == NULL)
         HGOTO_ERROR(H5E_FILE, H5E_CANTINIT, FAIL, "unable to create open object container")
 
 done:
@@ -433,7 +433,7 @@ H5FO_top_incr(const H5F_t *f, haddr_t addr)
     H5FO_obj_count_t *obj_count;  /* Ref. count for object */
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_top_incr, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     HDassert(f);
@@ -488,7 +488,7 @@ H5FO_top_decr(const H5F_t *f, haddr_t addr)
     H5FO_obj_count_t *obj_count;  /* Ref. count for object */
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_top_decr, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     HDassert(f);
@@ -506,7 +506,7 @@ H5FO_top_decr(const H5F_t *f, haddr_t addr)
                 HGOTO_ERROR(H5E_CACHE, H5E_CANTRELEASE, FAIL, "can't remove object from container")
 
             /* Release the object information */
-            (void)H5FL_FREE(H5FO_obj_count_t, obj_count);
+            obj_count = H5FL_FREE(H5FO_obj_count_t, obj_count);
         } /* end if */
     } /* end if */
     else
@@ -542,7 +542,7 @@ H5FO_top_count(const H5F_t *f, haddr_t addr)
     H5FO_obj_count_t *obj_count;        /* Ref. count for object */
     hsize_t ret_value;                  /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5FO_top_count)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -582,7 +582,7 @@ H5FO_top_dest(H5F_t *f)
 {
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5FO_top_dest, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
     HDassert(f);
