@@ -76,7 +76,7 @@ H5FL_BLK_EXTERN(str_buf);
 
 
 /*-------------------------------------------------------------------------
- * Function:    H5G_ent_decode_vec
+ * Function:    H5G__ent_decode_vec
  *
  * Purpose:     Same as H5G_ent_decode() except it does it for an array of
  *              symbol table entries.
@@ -93,12 +93,12 @@ H5FL_BLK_EXTERN(str_buf);
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G_ent_decode_vec(const H5F_t *f, const uint8_t **pp, H5G_entry_t *ent, unsigned n)
+H5G__ent_decode_vec(const H5F_t *f, const uint8_t **pp, H5G_entry_t *ent, unsigned n)
 {
     unsigned    u;                      /* Local index variable */
     herr_t      ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5G_ent_decode_vec, FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* check arguments */
     HDassert(f);
@@ -112,7 +112,7 @@ H5G_ent_decode_vec(const H5F_t *f, const uint8_t **pp, H5G_entry_t *ent, unsigne
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5G_ent_decode_vec() */
+} /* end H5G__ent_decode_vec() */
 
 
 /*-------------------------------------------------------------------------
@@ -138,7 +138,7 @@ H5G_ent_decode(const H5F_t *f, const uint8_t **pp, H5G_entry_t *ent)
     uint32_t		tmp;
     herr_t      ret_value = SUCCEED;       /* Return value */
 
-    FUNC_ENTER_NOAPI(H5G_ent_decode, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(f);
@@ -181,7 +181,7 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:    H5G_ent_encode_vec
+ * Function:    H5G__ent_encode_vec
  *
  * Purpose:     Same as H5G_ent_encode() except it does it for an array of
  *              symbol table entries.
@@ -198,12 +198,12 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G_ent_encode_vec(const H5F_t *f, uint8_t **pp, const H5G_entry_t *ent, unsigned n)
+H5G__ent_encode_vec(const H5F_t *f, uint8_t **pp, const H5G_entry_t *ent, unsigned n)
 {
     unsigned    u;                      /* Local index variable */
     herr_t      ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5G_ent_encode_vec, FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* check arguments */
     HDassert(f);
@@ -217,7 +217,7 @@ H5G_ent_encode_vec(const H5F_t *f, uint8_t **pp, const H5G_entry_t *ent, unsigne
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5G_ent_encode_vec() */
+} /* H5G__ent_encode_vec() */
 
 
 /*-------------------------------------------------------------------------
@@ -243,7 +243,7 @@ H5G_ent_encode(const H5F_t *f, uint8_t **pp, const H5G_entry_t *ent)
     uint8_t	*p_ret = *pp + H5G_SIZEOF_ENTRY(f);
     herr_t      ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5G_ent_encode, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(f);
@@ -296,7 +296,7 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function:    H5G_ent_copy
+ * Function:    H5G__ent_copy
  *
  * Purpose:     Do a deep copy of symbol table entries
  *
@@ -319,10 +319,10 @@ done:
  *
  *-------------------------------------------------------------------------
  */
-herr_t
-H5G_ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5_copy_depth_t depth)
+void
+H5G__ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5_copy_depth_t depth)
 {
-    FUNC_ENTER_NOAPI_NOFUNC(H5G_ent_copy)
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
     HDassert(src);
@@ -338,15 +338,15 @@ H5G_ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5_copy_depth_t depth)
         ;
     } else if(depth == H5_COPY_SHALLOW) {
         /* Discarding 'const' qualifier OK - QAK */
-        H5G_ent_reset((H5G_entry_t *)src);
+        H5G__ent_reset((H5G_entry_t *)src);
     } /* end if */
 
-    FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5G_ent_copy() */
+    FUNC_LEAVE_NOAPI_VOID
+} /* end H5G__ent_copy() */
 
 
 /*-------------------------------------------------------------------------
- * Function:	H5G_ent_reset
+ * Function:	H5G__ent_reset
  *
  * Purpose:	Reset a symbol table entry to an empty state
  *
@@ -358,10 +358,10 @@ H5G_ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5_copy_depth_t depth)
  *
  *-------------------------------------------------------------------------
  */
-herr_t
-H5G_ent_reset(H5G_entry_t *ent)
+void
+H5G__ent_reset(H5G_entry_t *ent)
 {
-    FUNC_ENTER_NOAPI_NOFUNC(H5G_ent_reset)
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(ent);
@@ -370,12 +370,12 @@ H5G_ent_reset(H5G_entry_t *ent)
     HDmemset(ent, 0, sizeof(H5G_entry_t));
     ent->header = HADDR_UNDEF;
 
-    FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5G_ent_reset() */
+    FUNC_LEAVE_NOAPI_VOID
+} /* end H5G__ent_reset() */
 
 
 /*-------------------------------------------------------------------------
- * Function:    H5G_ent_convert
+ * Function:    H5G__ent_convert
  *
  * Purpose:     Convert a link to a symbol table entry
  *
@@ -389,14 +389,14 @@ H5G_ent_reset(H5G_entry_t *ent)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G_ent_convert(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, const char *name,
+H5G__ent_convert(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, const char *name,
     const H5O_link_t *lnk, H5O_type_t obj_type, const void *crt_info,
     H5G_entry_t *ent)
 {
     size_t	name_offset;            /* Offset of name in heap */
     herr_t      ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5G_ent_convert, FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* check arguments */
     HDassert(f);
@@ -405,7 +405,7 @@ H5G_ent_convert(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, const char *name,
     HDassert(lnk);
 
     /* Reset the new entry */
-    H5G_ent_reset(ent);
+    H5G__ent_reset(ent);
 
     /*
      * Add the new name to the heap.
@@ -523,11 +523,11 @@ H5G_ent_convert(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, const char *name,
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5G_ent_convert() */
+} /* end H5G__ent_convert() */
 
 
 /*-------------------------------------------------------------------------
- * Function:    H5G_ent_debug
+ * Function:    H5G__ent_debug
  *
  * Purpose:     Prints debugging information about a symbol table entry.
  *
@@ -540,13 +540,13 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G_ent_debug(const H5G_entry_t *ent, FILE *stream, int indent, int fwidth,
+H5G__ent_debug(const H5G_entry_t *ent, FILE *stream, int indent, int fwidth,
     const H5HL_t *heap)
 {
     const char		*lval = NULL;
     int nested_indent, nested_fwidth;
 
-    FUNC_ENTER_NOAPI_NOFUNC(H5G_ent_debug)
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Calculate the indent & field width values for nested information */
     nested_indent = indent + 3;
@@ -603,5 +603,5 @@ H5G_ent_debug(const H5G_entry_t *ent, FILE *stream, int indent, int fwidth,
     } /* end switch */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5G_ent_debug() */
+} /* end H5G__ent_debug() */
 
