@@ -95,7 +95,7 @@ H5FL_DEFINE(H5HF_block_loc_t);
 herr_t
 H5HF_man_iter_init(H5HF_block_iter_t *biter)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HF_man_iter_init)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /*
      * Check arguments.
@@ -138,10 +138,7 @@ H5HF_man_iter_start_offset(H5HF_hdr_t *hdr, hid_t dxpl_id,
     hbool_t root_block = TRUE;  /* Flag to indicate the current block is the root indirect block */
     herr_t ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5HF_man_iter_start_offset)
-#ifdef QAK
-HDfprintf(stderr, "%s: offset = %Hu\n", FUNC, offset);
-#endif /* QAK */
+    FUNC_ENTER_NOAPI_NOINIT
 
     /*
      * Check arguments.
@@ -183,20 +180,13 @@ HDfprintf(stderr, "%s: offset = %Hu\n", FUNC, offset);
         curr_offset = offset - hdr->man_dtable.row_block_off[row];
 
         /* Compute column */
-        col = curr_offset / hdr->man_dtable.row_block_size[row];
-#ifdef QAK
-HDfprintf(stderr, "%s: row = %u, col = %u\n", FUNC, row, col);
-HDfprintf(stderr, "%s: offset = %Hu\n", FUNC, offset);
-HDfprintf(stderr, "%s: curr_offset = %Hu\n", FUNC, curr_offset);
-#endif /* QAK */
+        H5_CHECK_OVERFLOW((curr_offset / hdr->man_dtable.row_block_size[row]), hsize_t, unsigned);
+        col = (unsigned)(curr_offset / hdr->man_dtable.row_block_size[row]);
 
         /* Set the current level's context */
         biter->curr->row = row;
         biter->curr->col = col;
         biter->curr->entry = (row * hdr->man_dtable.cparam.width) + col;
-#ifdef QAK
-HDfprintf(stderr, "%s: biter->curr->entry = %u\n", FUNC, biter->curr->entry);
-#endif /* QAK */
 
         /* Get the context indirect block's information */
         if(root_block) {
@@ -291,7 +281,7 @@ done:
 herr_t
 H5HF_man_iter_set_entry(const H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigned entry)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HF_man_iter_set_entry)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /*
      * Check arguments.
@@ -325,10 +315,10 @@ herr_t
 H5HF_man_iter_start_entry(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter,
     H5HF_indirect_t *iblock, unsigned start_entry)
 {
-    H5HF_block_loc_t *new_loc;          /* Pointer to new block location */
+    H5HF_block_loc_t *new_loc = NULL;   /* Pointer to new block location */
     herr_t ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5HF_man_iter_start_entry)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /*
      * Check arguments.
@@ -360,6 +350,9 @@ H5HF_man_iter_start_entry(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter,
     biter->ready = TRUE;
 
 done:
+    if(ret_value < 0 && new_loc)
+        new_loc = H5FL_FREE(H5HF_block_loc_t, new_loc);
+
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_man_iter_start_entry() */
 
@@ -383,7 +376,7 @@ H5HF_man_iter_reset(H5HF_block_iter_t *biter)
 {
     herr_t ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5HF_man_iter_reset)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /*
      * Check arguments.
@@ -407,7 +400,7 @@ H5HF_man_iter_reset(H5HF_block_iter_t *biter)
                     HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL, "can't decrement reference count on shared indirect block")
 
             /* Free the current location context */
-            H5FL_FREE(H5HF_block_loc_t, curr_loc);
+            curr_loc = H5FL_FREE(H5HF_block_loc_t, curr_loc);
 
             /* Advance to next location */
             curr_loc = next_loc;
@@ -441,7 +434,7 @@ done:
 herr_t
 H5HF_man_iter_next(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigned nentries)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HF_man_iter_next)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /*
      * Check arguments.
@@ -456,11 +449,6 @@ H5HF_man_iter_next(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, unsigned nentries)
     biter->curr->row = biter->curr->entry / hdr->man_dtable.cparam.width;
     biter->curr->col = biter->curr->entry % hdr->man_dtable.cparam.width;
 /*    HDassert(biter->curr->row <= biter->curr->context->nrows); */
-#ifdef QAK
-HDfprintf(stderr, "%s: biter->curr->entry = %u\n", "H5HF_man_iter_next", biter->curr->entry);
-HDfprintf(stderr, "%s: biter->curr->row = %u\n", "H5HF_man_iter_next", biter->curr->row);
-HDfprintf(stderr, "%s: biter->curr->col = %u\n", "H5HF_man_iter_next", biter->curr->col);
-#endif /* QAK */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5HF_man_iter_next() */
@@ -485,7 +473,7 @@ H5HF_man_iter_up(H5HF_block_iter_t *biter)
     H5HF_block_loc_t *up_loc;           /* Pointer to 'up' block location */
     herr_t ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5HF_man_iter_up)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /*
      * Check arguments.
@@ -504,7 +492,7 @@ H5HF_man_iter_up(H5HF_block_iter_t *biter)
     up_loc = biter->curr->up;
 
     /* Release this location */
-    H5FL_FREE(H5HF_block_loc_t, biter->curr);
+    biter->curr = H5FL_FREE(H5HF_block_loc_t, biter->curr);
 
     /* Point location to next location up */
     biter->curr = up_loc;
@@ -530,10 +518,10 @@ done:
 herr_t
 H5HF_man_iter_down(H5HF_block_iter_t *biter, H5HF_indirect_t *iblock)
 {
-    H5HF_block_loc_t *down_loc;         /* Pointer to new 'down' block location */
+    H5HF_block_loc_t *down_loc = NULL;  /* Pointer to new 'down' block location */
     herr_t ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5HF_man_iter_down)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /*
      * Check arguments.
@@ -562,6 +550,9 @@ H5HF_man_iter_down(H5HF_block_iter_t *biter, H5HF_indirect_t *iblock)
     biter->curr = down_loc;
 
 done:
+    if(ret_value < 0 && down_loc)
+        down_loc = H5FL_FREE(H5HF_block_loc_t, down_loc);
+
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_man_iter_down() */
 
@@ -583,7 +574,7 @@ herr_t
 H5HF_man_iter_curr(H5HF_block_iter_t *biter, unsigned *row, unsigned *col,
     unsigned *entry, H5HF_indirect_t **block)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HF_man_iter_curr)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /*
      * Check arguments.
@@ -623,7 +614,7 @@ H5HF_man_iter_offset(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, hsize_t *offset)
 {
     hsize_t curr_offset;        /* For computing offset in heap */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HF_man_iter_offset)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /*
      * Check arguments.
@@ -661,7 +652,7 @@ H5HF_man_iter_offset(H5HF_hdr_t *hdr, H5HF_block_iter_t *biter, hsize_t *offset)
 hbool_t
 H5HF_man_iter_ready(H5HF_block_iter_t *biter)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HF_man_iter_ready)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /*
      * Check arguments.
