@@ -118,7 +118,7 @@ H5HL_create(H5F_t *f, hid_t dxpl_id, size_t size_hint, haddr_t *addr_p/*out*/)
     hsize_t	total_size;		/* Total heap size on disk	*/
     herr_t	ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_create, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(f);
@@ -215,7 +215,7 @@ H5HL_dblk_realloc(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, size_t new_heap_size)
     size_t old_heap_size;               /* Old size of heap data block */
     herr_t ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5HL_dblk_realloc)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* check arguments */
     HDassert(heap);
@@ -325,7 +325,7 @@ H5HL_minimize_heap_space(H5F_t *f, hid_t dxpl_id, H5HL_t *heap)
     size_t new_heap_size = heap->dblk_size;     /* New size of heap */
     herr_t ret_value = SUCCEED;                 /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_minimize_heap_space, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check args */
     HDassert(f);
@@ -451,7 +451,7 @@ H5HL_protect(H5F_t *f, hid_t dxpl_id, haddr_t addr, H5AC_protect_t rw)
     unsigned dblk_cache_flags = H5AC__NO_FLAGS_SET;         /* Cache flags for unprotecting data block entry */
     H5HL_t *ret_value;          /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_protect, NULL)
+    FUNC_ENTER_NOAPI(NULL)
 
     /* check arguments */
     HDassert(f);
@@ -539,7 +539,7 @@ H5HL_offset_into(const H5HL_t *heap, size_t offset)
      * We need to have called some other function before this to get a
      * valid heap pointer. So, this can remain "FUNC_ENTER_NOAPI_NOINIT"
      */
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HL_offset_into)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Sanity check */
     HDassert(heap);
@@ -568,7 +568,7 @@ H5HL_unprotect(H5HL_t *heap)
 {
     herr_t  ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI(H5HL_unprotect, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(heap);
@@ -617,7 +617,7 @@ done:
 static H5HL_free_t *
 H5HL_remove_free(H5HL_t *heap, H5HL_free_t *fl)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HL_remove_free)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if(fl->prev)
         fl->prev->next = fl->next;
@@ -650,7 +650,7 @@ H5HL_dirty(H5HL_t *heap)
 {
     herr_t ret_value = SUCCEED;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5HL_dirty)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* check arguments */
     HDassert(heap);
@@ -697,7 +697,7 @@ H5HL_insert(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, size_t buf_size, const void *
     hbool_t	found;
     size_t	ret_value;      /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_insert, UFAIL)
+    FUNC_ENTER_NOAPI(UFAIL)
 
     /* check arguments */
     HDassert(f);
@@ -913,7 +913,7 @@ H5HL_remove(H5F_t *f, hid_t dxpl_id, H5HL_t *heap, size_t offset, size_t size)
     H5HL_free_t		*fl = NULL;
     herr_t      	ret_value = SUCCEED;       /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_remove, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(f);
@@ -1064,7 +1064,7 @@ H5HL_delete(H5F_t *f, hid_t dxpl_id, haddr_t addr)
     unsigned    cache_flags = H5AC__NO_FLAGS_SET;       /* Flags for unprotecting heap */
     herr_t      ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_delete, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(f);
@@ -1139,7 +1139,7 @@ H5HL_get_size(H5F_t *f, hid_t dxpl_id, haddr_t addr, size_t *size)
     H5HL_t *heap;               /* Heap data structure */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_get_size, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(f);
@@ -1191,7 +1191,7 @@ H5HL_heapsize(H5F_t *f, hid_t dxpl_id, haddr_t addr, hsize_t *heap_size)
     H5HL_t *heap;               /* Heap data structure */
     herr_t ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5HL_heapsize, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* check arguments */
     HDassert(f);
