@@ -84,7 +84,7 @@ static herr_t H5O_dtype_debug(H5F_t *f, hid_t dxpl_id, const void *_mesg,
 #define H5O_DTYPE_CHECK_VERSION(DT, VERS, MIN_VERS, IOF, CLASS, ERR)           \
     if(((VERS) < (MIN_VERS)) && !(*(IOF) & H5O_DECODEIO_NOCHANGE)) {           \
         (VERS) = (MIN_VERS);                                                   \
-        if(H5T_upgrade_version((DT), (VERS)) < 0)                              \
+        if(H5T__upgrade_version((DT), (VERS)) < 0)                              \
             HGOTO_ERROR(H5E_DATATYPE, H5E_CANTSET, FAIL, "can't upgrade " CLASS " encoding version") \
         *(IOF) |= H5O_DECODEIO_DIRTY;                                          \
     } /* end if */
@@ -325,7 +325,7 @@ H5O_dtype_decode_helper(H5F_t *f, unsigned *ioflags/*in,out*/, const uint8_t **p
                     } /* end if */
 
                     /* Allocate space for the field's datatype */
-                    if(NULL == (temp_type = H5T_alloc()))
+                    if(NULL == (temp_type = H5T__alloc()))
                         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
 
                     /* Decode the field's datatype information */
@@ -349,7 +349,7 @@ H5O_dtype_decode_helper(H5F_t *f, unsigned *ioflags/*in,out*/, const uint8_t **p
                         /* Check if this member is an array field */
                         if(ndims > 0) {
                             /* Create the array datatype for the field */
-                            if((array_dt = H5T_array_create(temp_type, ndims, dim)) == NULL) {
+                            if((array_dt = H5T__array_create(temp_type, ndims, dim)) == NULL) {
                                 for(j = 0; j <= i; j++)
                                     H5MM_xfree(dt->shared->u.compnd.memb[j].name);
                                 H5MM_xfree(dt->shared->u.compnd.memb);
@@ -409,12 +409,12 @@ H5O_dtype_decode_helper(H5F_t *f, unsigned *ioflags/*in,out*/, const uint8_t **p
                 } /* end for */
 
                 /* Check if the compound type is packed */
-                H5T_update_packed(dt);
+                H5T__update_packed(dt);
 
                 /* Upgrade the compound if requested */
                 if(version < upgrade_to) {
                     version = upgrade_to;
-                    if(H5T_upgrade_version(dt, upgrade_to) < 0)
+                    if(H5T__upgrade_version(dt, upgrade_to) < 0)
                         HGOTO_ERROR(H5E_DATATYPE, H5E_CANTSET, FAIL, "can't upgrade compound encoding version")
                     /* We won't mark the message dirty since there were no
                      * errors in the file, simply type versions that we will no
@@ -453,7 +453,7 @@ H5O_dtype_decode_helper(H5F_t *f, unsigned *ioflags/*in,out*/, const uint8_t **p
              * Enumeration datatypes...
              */
             dt->shared->u.enumer.nmembs = dt->shared->u.enumer.nalloc = flags & 0xffff;
-            if(NULL == (dt->shared->parent = H5T_alloc()))
+            if(NULL == (dt->shared->parent = H5T__alloc()))
                 HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
             if(H5O_dtype_decode_helper(f, ioflags, pp, dt->shared->parent) < 0)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "unable to decode parent datatype")
@@ -495,7 +495,7 @@ H5O_dtype_decode_helper(H5F_t *f, unsigned *ioflags/*in,out*/, const uint8_t **p
             } /* end if */
 
             /* Decode base type of VL information */
-            if(NULL == (dt->shared->parent = H5T_alloc()))
+            if(NULL == (dt->shared->parent = H5T__alloc()))
                 HGOTO_ERROR(H5E_DATATYPE, H5E_NOSPACE, FAIL, "memory allocation failed")
             if(H5O_dtype_decode_helper(f, ioflags, pp, dt->shared->parent) < 0)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "unable to decode VL parent type")
@@ -535,7 +535,7 @@ H5O_dtype_decode_helper(H5F_t *f, unsigned *ioflags/*in,out*/, const uint8_t **p
                 *pp += dt->shared->u.array.ndims * 4;
 
             /* Decode base type of array */
-            if(NULL == (dt->shared->parent = H5T_alloc()))
+            if(NULL == (dt->shared->parent = H5T__alloc()))
                 HGOTO_ERROR(H5E_DATATYPE, H5E_NOSPACE, FAIL, "memory allocation failed")
             if(H5O_dtype_decode_helper(f, ioflags, pp, dt->shared->parent) < 0)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "unable to decode array parent type")
@@ -626,6 +626,7 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
 
                 case H5T_ORDER_ERROR:
                 case H5T_ORDER_VAX:
+                case H5T_ORDER_MIXED:
                 case H5T_ORDER_NONE:
                 default:
                     HGOTO_ERROR(H5E_DATATYPE, H5E_UNSUPPORTED, FAIL, "byte order is not supported in file format yet")
@@ -696,6 +697,7 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
                     HDassert(dt->shared->version >= H5O_DTYPE_VERSION_3);
                     break;
 
+                case H5T_ORDER_MIXED:
                 case H5T_ORDER_ERROR:
                 case H5T_ORDER_NONE:
                 default:
@@ -764,7 +766,7 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
                     HGOTO_ERROR(H5E_DATATYPE, H5E_UNSUPPORTED, FAIL, "normalization scheme is not supported in file format yet")
             } /* end switch */
 
-            flags |= (dt->shared->u.atomic.u.f.sign << 8) & 0xff00;
+            flags = (unsigned)(flags | ((dt->shared->u.atomic.u.f.sign << 8) & 0xff00));
             UINT16ENCODE(*pp, dt->shared->u.atomic.offset);
             UINT16ENCODE(*pp, dt->shared->u.atomic.prec);
             HDassert(dt->shared->u.atomic.u.f.epos <= 255);
@@ -787,8 +789,9 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
                     flags |= 0x01;
                     break;
 
-                case H5T_ORDER_ERROR:
                 case H5T_ORDER_VAX:
+                case H5T_ORDER_MIXED:
+                case H5T_ORDER_ERROR:
                 case H5T_ORDER_NONE:
                 default:
                     HGOTO_ERROR(H5E_DATATYPE, H5E_UNSUPPORTED, FAIL, "byte order is not supported in file format yet")
@@ -806,8 +809,8 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
             HDassert(dt->shared->u.atomic.lsb_pad == H5T_PAD_ZERO);
             HDassert(dt->shared->u.atomic.msb_pad == H5T_PAD_ZERO);
 
-            flags |= (dt->shared->u.atomic.u.s.pad & 0x0f);
-            flags |= (dt->shared->u.atomic.u.s.cset & 0x0f) << 4;
+            flags = (unsigned)(flags | (dt->shared->u.atomic.u.s.pad & 0x0f));
+            flags = (unsigned)(flags | ((((unsigned)dt->shared->u.atomic.u.s.cset) & 0x0f) << 4));
             break;
 
         case H5T_BITFIELD:
@@ -822,8 +825,9 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
                     flags |= 0x01;
                     break;
 
-                case H5T_ORDER_ERROR:
                 case H5T_ORDER_VAX:
+                case H5T_ORDER_MIXED:
+                case H5T_ORDER_ERROR:
                 case H5T_ORDER_NONE:
                 default:
                     HGOTO_ERROR(H5E_DATATYPE, H5E_UNSUPPORTED, FAIL, "byte order is not supported in file format yet")
@@ -874,7 +878,7 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
 
                 z = HDstrlen(dt->shared->u.opaque.tag);
                 aligned = (z + 7) & (H5T_OPAQUE_TAG_MAX - 8);
-                flags |= aligned;
+                flags = (unsigned)(flags | aligned);
                 HDmemcpy(*pp, dt->shared->u.opaque.tag, MIN(z,aligned));
                 for(n = MIN(z, aligned); n < aligned; n++)
                     (*pp)[n] = 0;
@@ -918,7 +922,7 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
                     /* Member offset */
                     /* (starting with version 3 of the datatype message, use the minimum # of bytes required) */
                     if(dt->shared->version >= H5O_DTYPE_VERSION_3)
-                        UINT32ENCODE_VAR(*pp, dt->shared->u.compnd.memb[i].offset, offset_nbytes)
+                        UINT32ENCODE_VAR(*pp, (uint32_t)dt->shared->u.compnd.memb[i].offset, offset_nbytes)
                     else
                         UINT32ENCODE(*pp, dt->shared->u.compnd.memb[i].offset)
 
@@ -1000,8 +1004,8 @@ H5O_dtype_encode_helper(const H5F_t *f, uint8_t **pp, const H5T_t *dt)
 
             flags |= (dt->shared->u.vlen.type & 0x0f);
             if(dt->shared->u.vlen.type == H5T_VLEN_STRING) {
-                flags |= (dt->shared->u.vlen.pad   & 0x0f) << 4;
-                flags |= ((unsigned)dt->shared->u.vlen.cset  & 0x0f) << 8;
+                flags = (unsigned)(flags | (((unsigned)dt->shared->u.vlen.pad   & 0x0f) << 4));
+                flags = (unsigned)(flags | (((unsigned)dt->shared->u.vlen.cset  & 0x0f) << 8));
             } /* end if */
 
             /* Encode base type of VL information */
@@ -1097,7 +1101,7 @@ H5O_dtype_decode(H5F_t *f, hid_t UNUSED dxpl_id, H5O_t UNUSED *open_oh, unsigned
     HDassert(p);
 
     /* Allocate datatype message */
-    if(NULL == (dt = H5T_alloc()))
+    if(NULL == (dt = H5T__alloc()))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
     /* Perform actual decode of message */
@@ -1358,7 +1362,7 @@ H5O_dtype_reset(void *_mesg)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if(dt)
-        H5T_free(dt);
+        H5T__free(dt);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O_dtype_reset() */
@@ -1599,7 +1603,7 @@ H5O_dtype_shared_post_copy_upd(const H5O_loc_t UNUSED *src_oloc,
 {
     H5T_t       *dt_dst = (H5T_t *)mesg_dst;    /* Destination datatype */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if(dt_dst->sh_loc.type == H5O_SHARE_TYPE_COMMITTED) {
         HDassert(H5T_committed(dt_dst));
@@ -1977,6 +1981,10 @@ H5O_dtype_debug(H5F_t *f, hid_t dxpl_id, const void *mesg, FILE *stream,
                 s = "none";
                 break;
 
+            case H5T_ORDER_MIXED:
+                s = "mixed";
+                break;
+
             case H5T_ORDER_ERROR:
             default:
                 sprintf(buf, "H5T_ORDER_%d", dt->shared->u.atomic.order);
