@@ -230,7 +230,7 @@ H5O_efl_encode(H5F_t *f, hbool_t UNUSED disable_shared, uint8_t *p, const void *
 	 */
 	HDassert(mesg->slot[u].name_offset);
 	H5F_ENCODE_LENGTH(f, p, mesg->slot[u].name_offset);
-	H5F_ENCODE_LENGTH(f, p, mesg->slot[u].offset);
+	H5F_ENCODE_LENGTH(f, p, (hsize_t)mesg->slot[u].offset);
 	H5F_ENCODE_LENGTH(f, p, mesg->slot[u].size);
     } /* end for */
 
@@ -351,13 +351,13 @@ H5O_efl_size(const H5F_t *f, hbool_t UNUSED disable_shared, const void *_mesg)
     HDassert(f);
     HDassert(mesg);
 
-    ret_value = H5F_SIZEOF_ADDR(f) +			/*heap address	*/
+    ret_value = (size_t)H5F_SIZEOF_ADDR(f) +			/*heap address	*/
 		2 +					/*slots allocated*/
 		2 +					/*num slots used*/
 		4 +					/*reserved	*/
-		mesg->nused * (H5F_SIZEOF_SIZE(f) +	/*name offset	*/
-			       H5F_SIZEOF_SIZE(f) +	/*file offset	*/
-			       H5F_SIZEOF_SIZE(f));	/*file size	*/
+		mesg->nused * ((size_t)H5F_SIZEOF_SIZE(f) +	/*name offset	*/
+			       (size_t)H5F_SIZEOF_SIZE(f) +	/*file offset	*/
+			       (size_t)H5F_SIZEOF_SIZE(f));	/*file size	*/
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_efl_size() */
