@@ -45,6 +45,13 @@
 /* Local Typedefs */
 /******************/
 
+/* Typedef for property iterator callback */
+typedef struct {
+    H5P_iterate_t iter_func;    /* Iterator callback */
+    hid_t id;                   /* Property list or class ID */
+    void *iter_data;            /* Iterator callback pointer */
+} H5P_iter_ud_t;
+
 
 /********************/
 /* Local Prototypes */
@@ -111,7 +118,7 @@ H5P_init_pub_interface(void)
 hid_t
 H5Pcopy(hid_t id)
 {
-    void *obj;                 /* Property object to copy */
+    void *obj;                  /* Property object to copy */
     hid_t ret_value=FALSE;      /* return value */
 
     FUNC_ENTER_API(FAIL)
@@ -217,7 +224,7 @@ H5Pcreate_class(hid_t parent, const char *name,
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "can't retrieve parent class")
 
     /* Create the new property list class */
-    if(NULL == (pclass = H5P_create_class(par_class, name, FALSE, cls_create, create_data, cls_copy, copy_data, cls_close, close_data)))
+    if(NULL == (pclass = H5P_create_class(par_class, name, H5P_TYPE_USER, cls_create, create_data, cls_copy, copy_data, cls_close, close_data)))
         HGOTO_ERROR(H5E_PLIST, H5E_CANTCREATE, FAIL, "unable to create property list class")
 
     /* Get an atom for the class */
@@ -983,8 +990,13 @@ H5Pequal(hid_t id1, hid_t id2)
 
     /* Compare property lists */
     if(H5I_GENPROP_LST == H5I_get_type(id1)) {
-        if(H5P_cmp_plist((const H5P_genplist_t *)obj1, (const H5P_genplist_t *)obj2) == 0)
-            ret_value = TRUE;
+        int cmp_ret = 0;
+
+        if(H5P_cmp_plist((const H5P_genplist_t *)obj1, (const H5P_genplist_t *)obj2, &cmp_ret) < 0)
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTCOMPARE, FAIL, "can't compare property lists")
+
+        /* Set return value */
+        ret_value = cmp_ret == 0 ? TRUE : FALSE;
     } /* end if */
     /* Must be property classes */
     else {
@@ -1042,6 +1054,46 @@ done:
     FUNC_LEAVE_API(ret_value)
 }   /* H5Pisa_class() */
 
+
+/*--------------------------------------------------------------------------
+ NAME
+    H5P__iterate_cb
+ PURPOSE
+    Internal callback routine when iterating over properties in property list
+    or class
+ USAGE
+    int H5P__iterate_cb(prop, udata)
+        H5P_genprop_t *prop;        IN: Pointer to the property
+        void *udata;                IN/OUT: Pointer to iteration data from user
+ RETURNS
+    Success: Returns the return value of the last call to ITER_FUNC
+    Failure: negative value
+ DESCRIPTION
+    This routine calls the actual callback routine for the property in the
+property list or class.
+ GLOBAL VARIABLES
+ COMMENTS, BUGS, ASSUMPTIONS
+ EXAMPLES
+ REVISION LOG
+--------------------------------------------------------------------------*/
+static int
+H5P__iterate_cb(H5P_genprop_t *prop, void *_udata)
+{
+    H5P_iter_ud_t *udata = (H5P_iter_ud_t *)_udata;     /* Pointer to user data */
+    int ret_value = 0;                                  /* Return value */
+
+    FUNC_ENTER_STATIC_NOERR
+
+    /* Sanity check */
+    HDassert(prop);
+    HDassert(udata);
+
+    /* Call the user's callback routine */
+    ret_value = (*udata->iter_func)(udata->id, prop->name, udata->iter_data);
+
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5P__iterate_cb() */
+
 
 /*--------------------------------------------------------------------------
  NAME
@@ -1099,7 +1151,9 @@ iteration, the function's behavior is undefined.
 int
 H5Piterate(hid_t id, int *idx, H5P_iterate_t iter_func, void *iter_data)
 {
+    H5P_iter_ud_t udata;    /* User data for internal iterator callback */
     int fake_idx = 0;       /* Index when user doesn't provide one */
+    void *obj;              /* Property object to copy */
     int ret_value;          /* return value */
 
     FUNC_ENTER_API(FAIL)
@@ -1108,18 +1162,25 @@ H5Piterate(hid_t id, int *idx, H5P_iterate_t iter_func, void *iter_data)
     /* Check arguments. */
     if(H5I_GENPROP_LST != H5I_get_type(id) && H5I_GENPROP_CLS != H5I_get_type(id))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a property object");
+    if(NULL == (obj = H5I_object(id)))
+        HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "property object doesn't exist");
     if(iter_func == NULL)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid iteration callback");
 
+    /* Set up user data */
+    udata.iter_func = iter_func;
+    udata.id = id;
+    udata.iter_data = iter_data;
+
     if(H5I_GENPROP_LST == H5I_get_type(id)) {
         /* Iterate over a property list */
-        if((ret_value = H5P_iterate_plist(id, (idx ? idx : &fake_idx), iter_func, iter_data)) < 0)
+        if((ret_value = H5P_iterate_plist((H5P_genplist_t *)obj, TRUE, (idx ? idx : &fake_idx), H5P__iterate_cb, &udata)) < 0)
             HGOTO_ERROR(H5E_PLIST, H5E_CANTREGISTER, FAIL, "unable to iterate over list");
     } /* end if */
     else
         if(H5I_GENPROP_CLS == H5I_get_type(id)) {
             /* Iterate over a property class */
-            if((ret_value = H5P_iterate_pclass(id, (idx ? idx : &fake_idx), iter_func, iter_data)) < 0)
+            if((ret_value = H5P_iterate_pclass((H5P_genclass_t *)obj, (idx ? idx : &fake_idx), H5P__iterate_cb, &udata)) < 0)
                 HGOTO_ERROR(H5E_PLIST, H5E_CANTREGISTER, FAIL, "unable to iterate over class");
         } /* end if */
         else
