@@ -31,19 +31,9 @@ typedef enum {
     H5R_BADTYPE     =   (-1),   /*invalid Reference Type                     */
     H5R_OBJECT,                 /*Object reference                           */
     H5R_DATASET_REGION,         /*Dataset Region Reference                   */
-    H5R_INTERNAL,               /*Internal Reference                         */
     H5R_MAXTYPE                 /*highest type (Invalid as true type)	     */
 } H5R_type_t;
 
-#ifdef LATER
-/* Generic reference structure for user's code */
-typedef struct {
-    unsigned long oid[2];       /* OID of object referenced */
-    unsigned long region[2];    /* heap ID of region in object */
-    unsigned long file[2];      /* heap ID of external filename */
-} href_t;
-#endif /* LATER */
-
 /* Note! Be careful with the sizes of the references because they should really
  * depend on the run-time values in the file.  Unfortunately, the arrays need
  * to be defined at compile-time, so we have to go with the worst case sizes for
@@ -61,7 +51,7 @@ typedef haddr_t hobj_ref_t; /* Needs to be large enough to store largest haddr_t
 typedef unsigned char hdset_reg_ref_t[H5R_DSET_REG_REF_BUF_SIZE];/* Buffer to store heap ID and index */
 /* Needs to be large enough to store largest haddr_t in a worst case machine (ie. 8 bytes currently) plus an int */
 
-/* Publicly visible datastructures */
+/* Publicly visible data structures */
 
 #ifdef __cplusplus
 extern "C" {
@@ -70,17 +60,33 @@ extern "C" {
 /* Functions in H5R.c */
 H5_DLL herr_t H5Rcreate(void *ref, hid_t loc_id, const char *name,
 			 H5R_type_t ref_type, hid_t space_id);
-H5_DLL hid_t H5Rdereference(hid_t dataset, H5R_type_t ref_type, void *ref);
-H5_DLL hid_t H5Rget_region(hid_t dataset, H5R_type_t ref_type, void *ref);
-#ifdef H5_WANT_H5_V1_4_COMPAT
-H5_DLL int H5Rget_object_type(hid_t dataset, void *_ref);
-H5_DLL int H5Rget_obj_type(hid_t id, H5R_type_t ref_type, void *_ref);
-#else /* H5_WANT_H5_V1_4_COMPAT */
-H5_DLL H5G_obj_t H5Rget_obj_type(hid_t id, H5R_type_t ref_type, void *_ref);
-#endif /* H5_WANT_H5_V1_4_COMPAT */
+H5_DLL hid_t H5Rdereference(hid_t dataset, H5R_type_t ref_type, const void *ref);
+H5_DLL hid_t H5Rget_region(hid_t dataset, H5R_type_t ref_type, const void *ref);
+H5_DLL herr_t H5Rget_obj_type2(hid_t id, H5R_type_t ref_type, const void *_ref,
+    H5O_type_t *obj_type);
+H5_DLL ssize_t H5Rget_name(hid_t loc_id, H5R_type_t ref_type, const void *ref,
+    char *name/*out*/, size_t size);
+
+/* Symbols defined for compatibility with previous versions of the HDF5 API.
+ *
+ * Use of these symbols is deprecated.
+ */
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+
+/* Macros */
+
+
+/* Typedefs */
+
+
+/* Function prototypes */
+H5_DLL H5G_obj_t H5Rget_obj_type1(hid_t id, H5R_type_t ref_type, const void *_ref);
+
+#endif /* H5_NO_DEPRECATED_SYMBOLS */
 
 #ifdef __cplusplus
 }
 #endif
 
 #endif  /* _H5Rpublic_H */
+
