@@ -47,13 +47,16 @@ typedef enum {
     H5SL_TYPE_HSIZE,    /* Skip list keys are 'hsize_t's */
     H5SL_TYPE_UNSIGNED, /* Skip list keys are 'unsigned's */
     H5SL_TYPE_SIZE,     /* Skip list keys are 'size_t's */
-    H5SL_TYPE_OBJ       /* Skip list keys are 'H5_obj_t's */
+    H5SL_TYPE_OBJ,      /* Skip list keys are 'H5_obj_t's */
+    H5SL_TYPE_GENERIC   /* Skip list keys are unknown, comparison callback supplied */
 } H5SL_type_t;
 
 /**********/
 /* Macros */
 /**********/
-#define H5SL_LEVEL_MAX          32      /* (for now) */
+
+/* Typedef for comparison operations */
+typedef int (*H5SL_cmp_t)(const void *key1, const void *key2);
 
 /* Typedef for iteration operations */
 typedef herr_t (*H5SL_operator_t)(void *item, void *key,
@@ -62,7 +65,7 @@ typedef herr_t (*H5SL_operator_t)(void *item, void *key,
 /********************/
 /* Private routines */
 /********************/
-H5_DLL H5SL_t *H5SL_create(H5SL_type_t type, double p, size_t max_level);
+H5_DLL H5SL_t *H5SL_create(H5SL_type_t type, H5SL_cmp_t cmp);
 H5_DLL size_t H5SL_count(H5SL_t *slist);
 H5_DLL herr_t H5SL_insert(H5SL_t *slist, void *item, const void *key);
 H5_DLL H5SL_node_t *H5SL_add(H5SL_t *slist, void *item, const void *key);
@@ -72,6 +75,8 @@ H5_DLL void *H5SL_search(H5SL_t *slist, const void *key);
 H5_DLL void *H5SL_less(H5SL_t *slist, const void *key);
 H5_DLL void *H5SL_greater(H5SL_t *slist, const void *key);
 H5_DLL H5SL_node_t *H5SL_find(H5SL_t *slist, const void *key);
+H5_DLL H5SL_node_t *H5SL_below(H5SL_t *slist, const void *key);
+H5_DLL H5SL_node_t *H5SL_above(H5SL_t *slist, const void *key);
 H5_DLL H5SL_node_t *H5SL_first(H5SL_t *slist);
 H5_DLL H5SL_node_t *H5SL_next(H5SL_node_t *slist_node);
 H5_DLL H5SL_node_t *H5SL_prev(H5SL_node_t *slist_node);
@@ -82,6 +87,7 @@ H5_DLL herr_t H5SL_release(H5SL_t *slist);
 H5_DLL herr_t H5SL_free(H5SL_t *slist, H5SL_operator_t op, void *op_data);
 H5_DLL herr_t H5SL_close(H5SL_t *slist);
 H5_DLL herr_t H5SL_destroy(H5SL_t *slist, H5SL_operator_t op, void *op_data);
+H5_DLL int H5SL_term_interface(void);
 
 #endif /* _H5SLprivate_H */
 
