@@ -49,7 +49,7 @@ DESCRIPTION
 static herr_t
 H5T_init_precis_interface(void)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5T_init_precis_interface)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     FUNC_LEAVE_NOAPI(H5T_init())
 } /* H5T_init_precis_interface() */
@@ -80,26 +80,61 @@ H5T_init_precis_interface(void)
 size_t
 H5Tget_precision(hid_t type_id)
 {
-    H5T_t	*dt = NULL;
+    H5T_t	*dt;
     size_t	ret_value;
 
-    FUNC_ENTER_API(H5Tget_precision, 0)
-    H5TRACE1("z","i",type_id);
+    FUNC_ENTER_API(0)
+    H5TRACE1("z", "i", type_id);
 
     /* Check args */
     if (NULL == (dt = H5I_object_verify(type_id,H5I_DATATYPE)))
 	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, 0, "not a datatype")
-    while (dt->shared->parent)
-        dt = dt->shared->parent;	/*defer to parent*/
-    if (!H5T_IS_ATOMIC(dt->shared))
+
+    /* Get precision */
+    if((ret_value = H5T_get_precision(dt)) == 0)
+	HGOTO_ERROR(H5E_DATATYPE, H5E_UNSUPPORTED, 0, "cant't get precision for specified datatype")
+
+done:
+    FUNC_LEAVE_API(ret_value)
+} /* end H5Tget_precision() */
+
+
+/*-------------------------------------------------------------------------
+ * Function:	H5T_get_precision
+ *
+ * Purpose:	Gets the precision of a datatype.  The precision is
+ *		the number of significant bits which, unless padding is
+ *		present, is 8 times larger than the value returned by
+ *		H5Tget_size().
+ *
+ * Return:	Success:	Number of significant bits
+ *		Failure:	0 (all atomic types have at least one
+ *				significant bit)
+ *
+ * Programmer:	Quincey Koziol
+ *		Wednesday, October 17, 2007
+ *
+ *-------------------------------------------------------------------------
+ */
+size_t
+H5T_get_precision(const H5T_t *dt)
+{
+    size_t	ret_value;
+
+    FUNC_ENTER_NOAPI(0)
+
+    /* Defer to parent*/
+    while(dt->shared->parent)
+        dt = dt->shared->parent;
+    if(!H5T_IS_ATOMIC(dt->shared))
 	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, 0, "operation not defined for specified datatype")
 
     /* Precision */
     ret_value = dt->shared->u.atomic.prec;
 
 done:
-    FUNC_LEAVE_API(ret_value)
-}
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5T_get_precision() */
 
 
 /*-------------------------------------------------------------------------
@@ -137,8 +172,8 @@ H5Tset_precision(hid_t type_id, size_t prec)
     H5T_t	*dt = NULL;
     herr_t      ret_value=SUCCEED;       /* Return value */
 
-    FUNC_ENTER_API(H5Tset_precision, FAIL)
-    H5TRACE2("e","iz",type_id,prec);
+    FUNC_ENTER_API(FAIL)
+    H5TRACE2("e", "iz", type_id, prec);
 
     /* Check args */
     if (NULL == (dt = H5I_object_verify(type_id,H5I_DATATYPE)))
@@ -198,7 +233,7 @@ H5T_set_precision(const H5T_t *dt, size_t prec)
     size_t	offset, size;
     herr_t      ret_value=SUCCEED;       /* Return value */
 
-    FUNC_ENTER_NOAPI(H5T_set_precision, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Check args */
     assert(dt);
@@ -248,7 +283,6 @@ H5T_set_precision(const H5T_t *dt, size_t prec)
                             dt->shared->u.atomic.u.f.mpos + dt->shared->u.atomic.u.f.msize > prec+offset)
                         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "adjust sign, mantissa, and exponent fields first")
                     break;
-
                 default:
                     HGOTO_ERROR(H5E_ARGS, H5E_UNSUPPORTED, FAIL, "operation not defined for datatype class")
 	    } /* end switch */ /*lint !e788 All appropriate cases are covered */
