@@ -26,6 +26,7 @@
 #include "H5MMprivate.h"	/* Memory management			*/
 #include "H5Oprivate.h"		/* Object headers		  	*/
 #include "H5Pprivate.h"         /* Property lists                       */
+#include "H5PLprivate.h"        /* Plugins                              */
 #include "H5Sprivate.h"		/* Dataspace functions			*/
 #include "H5Zpkg.h"		/* Data filters				*/
 
@@ -81,7 +82,7 @@ H5Z_init_interface (void)
 {
     herr_t	ret_value=SUCCEED;      /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5Z_init_interface)
+    FUNC_ENTER_NOAPI_NOINIT
 
 #ifdef H5_HAVE_FILTER_DEFLATE
     if (H5Z_register (H5Z_DEFLATE)<0)
@@ -224,7 +225,7 @@ H5Zregister(const void *cls)
     H5Z_class2_t        cls_new;                /* Translated class struct */
     herr_t              ret_value=SUCCEED;      /* Return value */
 
-    FUNC_ENTER_API(H5Zregister, FAIL)
+    FUNC_ENTER_API(FAIL)
     H5TRACE1("e", "*x", cls);
 
     /* Check args */
@@ -302,7 +303,7 @@ H5Z_register (const H5Z_class2_t *cls)
     size_t	i;
     herr_t      ret_value = SUCCEED;       /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_register, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     HDassert(cls);
     HDassert(cls->id >= 0 && cls->id <= H5Z_FILTER_MAX);
@@ -368,7 +369,7 @@ H5Zunregister(H5Z_filter_t id)
 {
     herr_t      ret_value=SUCCEED;       /* Return value */
 
-    FUNC_ENTER_API(H5Zunregister, FAIL)
+    FUNC_ENTER_API(FAIL)
     H5TRACE1("e", "Zf", id);
 
     /* Check args */
@@ -407,7 +408,7 @@ H5Z_unregister (H5Z_filter_t id)
     size_t i;                   /* Local index variable */
     herr_t ret_value=SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_unregister,FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     assert (id>=0 && id<=H5Z_FILTER_MAX);
 
@@ -450,27 +451,52 @@ done:
 htri_t
 H5Zfilter_avail(H5Z_filter_t id)
 {
-    size_t i;                   /* Local index variable */
     htri_t ret_value=FALSE;     /* Return value */
 
-    FUNC_ENTER_API(H5Zfilter_avail, FAIL)
+    FUNC_ENTER_API(FAIL)
     H5TRACE1("t", "Zf", id);
 
     /* Check args */
     if(id<0 || id>H5Z_FILTER_MAX)
         HGOTO_ERROR (H5E_ARGS, H5E_BADVALUE, FAIL, "invalid filter identification number")
-
-    /* Is the filter already registered? */
-    for(i=0; i<H5Z_table_used_g; i++)
-	if(H5Z_table_g[i].id==id) {
-            ret_value=TRUE;
-            break;
-        } /* end if */
+ 
+    if((ret_value = H5Z_filter_avail(id)) < 0)
+	HGOTO_ERROR(H5E_PLINE, H5E_NOTFOUND, FAIL, "unable to check the availability of the filter")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Zfilter_avail() */
 
+
+/*-------------------------------------------------------------------------
+ * Function:	H5Z_filter_avail
+ *
+ * Purpose:	Private function to check if a filter is available
+ *
+ * Return:	Non-negative (TRUE/FALSE) on success/Negative on failure
+ *
+ * Programmer:	Raymond Lu
+ *              13 February 2013
+ *
+ *-------------------------------------------------------------------------
+ */
+htri_t
+H5Z_filter_avail(H5Z_filter_t id)
+{
+    size_t i;                   /* Local index variable */
+    htri_t ret_value = FALSE;   /* Return value */
+
+    FUNC_ENTER_NOAPI(FAIL)
+
+    /* Is the filter already registered? */
+    for(i = 0; i < H5Z_table_used_g; i++)
+	if(H5Z_table_g[i].id == id)
+	    HGOTO_DONE(TRUE)
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5Z_filter_avail() */
+
 
 /*-------------------------------------------------------------------------
  * Function:	H5Z_prelude_callback
@@ -498,7 +524,7 @@ H5Z_prelude_callback(const H5O_pline_t *pline, hid_t dcpl_id, hid_t type_id,
     size_t          u;                      /* Local index variable */
     htri_t          ret_value = TRUE;    /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5Z_prelude_callback)
+    FUNC_ENTER_NOAPI_NOINIT
 
     HDassert(pline->nused > 0);
 
@@ -583,7 +609,7 @@ H5Z_prepare_prelude_callback_dcpl(hid_t dcpl_id, hid_t type_id, H5Z_prelude_type
     hid_t space_id = -1;            /* ID for dataspace describing chunk */
     herr_t ret_value = SUCCEED;     /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5Z_prepare_prelude_callback_dcpl)
+    FUNC_ENTER_NOAPI_NOINIT
 
     HDassert(H5I_GENPROP_LST == H5I_get_type(dcpl_id));
     HDassert(H5I_DATATYPE == H5I_get_type(type_id));
@@ -666,7 +692,7 @@ H5Z_can_apply(hid_t dcpl_id, hid_t type_id)
 {
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_can_apply, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Make "can apply" callbacks for filters in pipeline */
     if(H5Z_prepare_prelude_callback_dcpl(dcpl_id, type_id, H5Z_PRELUDE_CAN_APPLY) < 0)
@@ -701,7 +727,7 @@ H5Z_set_local(hid_t dcpl_id, hid_t type_id)
 {
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_set_local, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Make "set local" callbacks for filters in pipeline */
     if(H5Z_prepare_prelude_callback_dcpl(dcpl_id, type_id, H5Z_PRELUDE_SET_LOCAL) < 0)
@@ -731,7 +757,7 @@ H5Z_can_apply_direct(const H5O_pline_t *pline)
 {
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_can_apply_direct, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     HDassert(pline->nused > 0);
 
@@ -768,7 +794,7 @@ H5Z_set_local_direct(const H5O_pline_t *pline)
 {
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_set_local_direct, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     HDassert(pline->nused > 0);
 
@@ -802,7 +828,7 @@ H5Z_modify(const H5O_pline_t *pline, H5Z_filter_t filter, unsigned flags,
     size_t	idx;                    /* Index of filter in pipeline */
     herr_t      ret_value = SUCCEED;      /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_modify, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     HDassert(pline);
     HDassert(filter >= 0 && filter <= H5Z_FILTER_MAX);
@@ -872,7 +898,7 @@ H5Z_append(H5O_pline_t *pline, H5Z_filter_t filter, unsigned flags,
     size_t	idx;
     herr_t      ret_value = SUCCEED;       /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_append, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     HDassert(pline);
     HDassert(filter >= 0 && filter <= H5Z_FILTER_MAX);
@@ -977,7 +1003,7 @@ H5Z_find_idx(H5Z_filter_t id)
     size_t i;                   /* Local index variable */
     int ret_value=FAIL;         /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5Z_find_idx)
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     for (i=0; i<H5Z_table_used_g; i++)
 	if (H5Z_table_g[i].id == id)
@@ -1012,7 +1038,7 @@ H5Z_find(H5Z_filter_t id)
     int	idx;                            /* Filter index in global table */
     H5Z_class2_t *ret_value=NULL;        /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_find, NULL)
+    FUNC_ENTER_NOAPI(NULL)
 
     /* Get the index in the global table */
     if((idx=H5Z_find_idx(id))<0)
@@ -1071,7 +1097,7 @@ H5Z_pipeline(const H5O_pline_t *pline, unsigned flags,
     unsigned	tmp_flags;
     herr_t      ret_value=SUCCEED;       /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_pipeline, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     assert(0==(flags & ~((unsigned)H5Z_FLAG_INVMASK)));
     assert(filter_mask);
@@ -1088,16 +1114,45 @@ H5Z_pipeline(const H5O_pline_t *pline, unsigned flags,
 		failed |= (unsigned)1 << idx;
 		continue;/*filter excluded*/
 	    }
-	    if ((fclass_idx=H5Z_find_idx(pline->filter[idx].id))<0) {
-                /* Print out the filter name to give more info.  But the name is optional for 
-                 * the filter */
-                if(pline->filter[idx].name)
-		    HGOTO_ERROR(H5E_PLINE, H5E_READERROR, FAIL, "required filter '%s' is not registered", 
-                            pline->filter[idx].name)
-                else
-		    HGOTO_ERROR(H5E_PLINE, H5E_READERROR, FAIL, "required filter (name unavailable) is not registered")
 
-	    }
+            /* If the filter isn't registered and the application doesn't 
+             * indicate no plugin through HDF5_PRELOAD_PLUG (using the symbol "::"), 
+             * try to load it dynamically and register it.  Otherwise, return failure
+             */
+	    if((fclass_idx = H5Z_find_idx(pline->filter[idx].id)) < 0) {
+                hbool_t issue_error = FALSE;
+
+                /* Check for "no plugins" indicated" */
+	        if(H5PL_no_plugin())
+                    issue_error = TRUE;
+                else {
+                    const H5Z_class2_t    *filter_info;
+
+                    /* Try loading the filter */
+                    if(NULL != (filter_info = (const H5Z_class2_t *)H5PL_load(H5PL_TYPE_FILTER, (int)(pline->filter[idx].id)))) {
+                        /* Register the filter we loaded */
+                        if(H5Z_register(filter_info) < 0)
+                            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, FAIL, "unable to register filter")
+
+                        /* Search in the table of registered filters again to find the dynamic filter just loaded and registered */ 
+                        if((fclass_idx = H5Z_find_idx(pline->filter[idx].id)) < 0)
+                            issue_error = TRUE;
+                    } /* end if */
+                    else
+                        issue_error = TRUE;
+                } /* end else */
+
+                /* Check for error */
+                if(issue_error) {
+                    /* Print out the filter name to give more info.  But the name is optional for 
+                     * the filter */
+                    if(pline->filter[idx].name)
+                        HGOTO_ERROR(H5E_PLINE, H5E_READERROR, FAIL, "required filter '%s' is not registered", pline->filter[idx].name)
+                    else
+                        HGOTO_ERROR(H5E_PLINE, H5E_READERROR, FAIL, "required filter (name unavailable) is not registered")
+                } /* end if */
+            } /* end if */
+
             fclass=&H5Z_table_g[fclass_idx];
 #ifdef H5Z_DEBUG
             fstats=&H5Z_stat_table_g[fclass_idx];
@@ -1197,7 +1252,7 @@ H5Z_filter_info(const H5O_pline_t *pline, H5Z_filter_t filter)
     size_t	idx;                    /* Index of filter in pipeline */
     H5Z_filter_info_t *ret_value;       /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_filter_info, NULL)
+    FUNC_ENTER_NOAPI(NULL)
 
     assert(pline);
     assert(filter>=0 && filter<=H5Z_FILTER_MAX);
@@ -1240,7 +1295,7 @@ H5Z_all_filters_avail(const H5O_pline_t *pline)
     size_t i,j;                 /* Local index variable */
     htri_t ret_value=TRUE;      /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_all_filters_avail, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Check args */
     assert(pline);
@@ -1284,7 +1339,7 @@ H5Z_delete(H5O_pline_t *pline, H5Z_filter_t filter)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_delete, FAIL)
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Check args */
     HDassert(pline);
@@ -1368,7 +1423,7 @@ H5Zget_filter_info(H5Z_filter_t filter, unsigned int *filter_config_flags)
     H5Z_class2_t *fclass;
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_API(H5Zget_filter_info, FAIL)
+    FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "Zf*Iu", filter, filter_config_flags);
 
     /* Look up the filter class info */
