@@ -34,7 +34,7 @@ static size_t H5Z_filter_fletcher32 (unsigned flags, size_t cd_nelmts,
     const unsigned cd_values[], size_t nbytes, size_t *buf_size, void **buf);
 
 /* This message derives from H5Z */
-const H5Z_class_t H5Z_FLETCHER32[1] = {{
+const H5Z_class2_t H5Z_FLETCHER32[1] = {{
     H5Z_CLASS_T_VERS,       /* H5Z_class_t version */
     H5Z_FILTER_FLETCHER32,	/* Filter id number		*/
     1,              /* encoder_present flag (set to true) */
@@ -85,7 +85,7 @@ H5Z_filter_fletcher32 (unsigned flags, size_t UNUSED cd_nelmts, const unsigned U
     uint8_t  tmp;
     size_t   ret_value;         /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_filter_fletcher32, 0)
+    FUNC_ENTER_NOAPI(0)
 
     assert(sizeof(uint32_t)>=4);
 
