@@ -38,7 +38,7 @@ typedef struct {
 } parms_atomic;
 
 /* Local function prototypes */
-static herr_t H5Z_can_apply_nbit(hid_t dcpl_id, hid_t type_id, hid_t space_id);
+static htri_t H5Z_can_apply_nbit(hid_t dcpl_id, hid_t type_id, hid_t space_id);
 static herr_t H5Z_set_local_nbit(hid_t dcpl_id, hid_t type_id, hid_t space_id);
 static size_t H5Z_filter_nbit(unsigned flags, size_t cd_nelmts, const unsigned cd_values[],
                               size_t nbytes, size_t *buf_size, void **buf);
@@ -80,7 +80,7 @@ static void H5Z_nbit_compress(unsigned char *data, unsigned d_nelmts, unsigned c
                               size_t *buffer_size, const unsigned parms[]);
 
 /* This message derives from H5Z */
-H5Z_class_t H5Z_NBIT[1] = {{
+H5Z_class2_t H5Z_NBIT[1] = {{
     H5Z_CLASS_T_VERS,       /* H5Z_class_t version */
     H5Z_FILTER_NBIT,		/* Filter id number		*/
     1,              /* Assume encoder present: check before registering */
@@ -129,16 +129,16 @@ static unsigned parms_index = 0;
  *
  *-------------------------------------------------------------------------
  */
-static herr_t
+static htri_t
 H5Z_can_apply_nbit(hid_t UNUSED dcpl_id, hid_t type_id, hid_t UNUSED space_id)
 {
     const H5T_t	*type;                  /* Datatype */
-    herr_t ret_value = TRUE;            /* Return value */
+    htri_t ret_value = TRUE;            /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_can_apply_nbit, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Get datatype */
-    if(NULL == (type = H5I_object_verify(type_id, H5I_DATATYPE)))
+    if(NULL == (type = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
 	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype")
 
     /* Get datatype's class, for checking the "datatype class" */
@@ -235,7 +235,7 @@ H5Z_calc_parms_array(const H5T_t *type)
     H5T_class_t dtype_base_class;  /* Array datatype's base datatype's class */
     herr_t ret_value = SUCCEED;    /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_calc_parms_array, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Store datatype class code */
     ++cd_values_actual_nparms;
@@ -308,7 +308,7 @@ H5Z_calc_parms_compound(const H5T_t *type)
     unsigned    u;                  /* Local index variable */
     herr_t ret_value = SUCCEED;     /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_calc_parms_compound, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Store compound datatype class code */
     ++cd_values_actual_nparms;
@@ -326,7 +326,7 @@ H5Z_calc_parms_compound(const H5T_t *type)
     /* For each member, calculate parameters */
     for(u = 0; u < (unsigned)nmembers; u++) {
         /* Get member datatype */
-        if(NULL == (dtype_member = H5T_get_member_type(type, u)))
+        if(NULL == (dtype_member = H5T_get_member_type(type, u, H5T_COPY_TRANSIENT)))
             HGOTO_ERROR(H5E_PLINE, H5E_BADTYPE, FAIL, "bad member datatype")
 
         /* Get member datatype's class */
@@ -397,7 +397,7 @@ H5Z_set_parms_nooptype(const H5T_t *type, unsigned cd_values[])
     size_t dtype_size;          /* No-op datatype's size (in bytes) */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_set_parms_nooptype, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Set datatype class code */
     cd_values[cd_values_index++] = H5Z_NBIT_NOOPTYPE;
@@ -439,7 +439,7 @@ H5Z_set_parms_atomic(const H5T_t *type, unsigned cd_values[])
     int dtype_offset;           /* Atomic datatype's offset (in bits) */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_set_parms_atomic, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Set datatype class code */
     cd_values[cd_values_index++] = H5Z_NBIT_ATOMIC;
@@ -525,7 +525,7 @@ H5Z_set_parms_array(const H5T_t *type, unsigned cd_values[])
     htri_t is_vlstring;            /* flag indicating if datatype is varible-length string */
     herr_t ret_value=SUCCEED;      /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_set_parms_array, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Set datatype class code */
     cd_values[cd_values_index++] = H5Z_NBIT_ARRAY;
@@ -615,7 +615,7 @@ H5Z_set_parms_compound(const H5T_t *type, unsigned cd_values[])
     unsigned u;                     /* Local index variable */
     herr_t ret_value = SUCCEED;     /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_set_parms_compound, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Set "local" parameter for compound datatype class code */
     cd_values[cd_values_index++] = H5Z_NBIT_COMPOUND;
@@ -637,7 +637,7 @@ H5Z_set_parms_compound(const H5T_t *type, unsigned cd_values[])
     /* For each member, set parameters */
     for(u = 0; u < (unsigned)nmembers; u++) {
         /* Get member datatype */
-        if(NULL == (dtype_member = H5T_get_member_type(type, u)))
+        if(NULL == (dtype_member = H5T_get_member_type(type, u, H5T_COPY_TRANSIENT)))
             HGOTO_ERROR(H5E_PLINE, H5E_BADTYPE, FAIL, "bad member datatype")
 
         /* Get member datatype's class */
@@ -739,10 +739,10 @@ H5Z_set_local_nbit(hid_t dcpl_id, hid_t type_id, hid_t space_id)
     H5T_class_t dtype_class;        /* Datatype's class */
     herr_t ret_value = SUCCEED;     /* Return value */
 
-    FUNC_ENTER_NOAPI(H5Z_set_local_nbit, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* Get datatype */
-    if(NULL == (type = H5I_object_verify(type_id, H5I_DATATYPE)))
+    if(NULL == (type = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)))
 	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype")
 
     /* Get datatype's class */
@@ -781,7 +781,7 @@ H5Z_set_local_nbit(hid_t dcpl_id, hid_t type_id, hid_t space_id)
         HGOTO_ERROR(H5E_PLINE, H5E_BADTYPE, FAIL, "datatype needs too many nbit parameters")
 
     /* Allocate memory space for cd_values[] */
-    if(NULL == (cd_values = H5MM_malloc(cd_values_actual_nparms * sizeof(unsigned))))
+    if(NULL == (cd_values = (unsigned *)H5MM_malloc(cd_values_actual_nparms * sizeof(unsigned))))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for cd_values[]")
 
     /* Get the plist structure */
@@ -799,6 +799,7 @@ H5Z_set_local_nbit(hid_t dcpl_id, hid_t type_id, hid_t space_id)
     /* Get total number of elements in the chunk */
     if((npoints = H5S_GET_EXTENT_NPOINTS(ds)) < 0)
         HGOTO_ERROR(H5E_PLINE, H5E_CANTGET, FAIL, "unable to get number of points in the dataspace")
+    HDassert(npoints);
 
     /* Initialize index for cd_values array starting from the third entry */
     cd_values_index = 2;
@@ -861,77 +862,70 @@ done:
  * Programmer:	Xiaowen Wu
  *              Friday, January 21, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static size_t
 H5Z_filter_nbit(unsigned flags, size_t cd_nelmts, const unsigned cd_values[],
                 size_t nbytes, size_t *buf_size, void **buf)
 {
-    size_t ret_value = 0;          /* return value */
-    size_t size_out  = 0;          /* size of output buffer */
-    unsigned d_nelmts = 0;         /* number of elements in the chunk */
-    unsigned char *outbuf = NULL;  /* pointer to new output buffer */
+    unsigned char *outbuf;      /* pointer to new output buffer */
+    size_t size_out  = 0;       /* size of output buffer */
+    unsigned d_nelmts = 0;      /* number of elements in the chunk */
+    size_t ret_value = 0;       /* return value */
 
-    FUNC_ENTER_NOAPI(H5Z_filter_nbit, 0)
+    FUNC_ENTER_NOAPI_NOINIT
 
     /* check arguments
      * cd_values[0] stores actual number of parameters in cd_values[]
      */
-    if (cd_nelmts!=cd_values[0])
+    if(cd_nelmts != cd_values[0])
 	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid nbit aggression level")
 
     /* check if need to do nbit compress or decompress
      * cd_values[1] stores the flag if true indicating no need to compress
      */
-    if (cd_values[1]) {
-        ret_value = *buf_size;
-        goto done;
-    }
+    if(cd_values[1])
+        HGOTO_DONE(*buf_size)
 
     /* copy a filter parameter to d_nelmts */
     d_nelmts = cd_values[2];
 
     /* input; decompress */
-    if (flags & H5Z_FLAG_REVERSE) {
+    if(flags & H5Z_FLAG_REVERSE) {
         size_out = d_nelmts * cd_values[4]; /* cd_values[4] stores datatype size */
 
         /* allocate memory space for decompressed buffer */
-        if(NULL==(outbuf = H5MM_malloc(size_out)))
+        if(NULL == (outbuf = (unsigned char *)H5MM_malloc(size_out)))
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, 0, "memory allocation failed for nbit decompression")
 
         /* decompress the buffer */
-        H5Z_nbit_decompress(outbuf, d_nelmts, *buf, cd_values);
-    }
+        H5Z_nbit_decompress(outbuf, d_nelmts, (unsigned char *)*buf, cd_values);
+    } /* end if */
     /* output; compress */
     else {
-        assert(nbytes == d_nelmts * cd_values[4]);
+        HDassert(nbytes == d_nelmts * cd_values[4]);
 
         size_out = nbytes;
 
         /* allocate memory space for compressed buffer */
-        if(NULL==(outbuf = H5MM_malloc(size_out)))
+        if(NULL == (outbuf = (unsigned char *)H5MM_malloc(size_out)))
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, 0, "memory allocation failed for nbit compression")
 
         /* compress the buffer, size_out will be changed */
-        H5Z_nbit_compress(*buf, d_nelmts, outbuf, &size_out, cd_values);
-    }
+        H5Z_nbit_compress((unsigned char *)*buf, d_nelmts, outbuf, &size_out, cd_values);
+    } /* end else */
 
     /* free the input buffer */
     H5MM_xfree(*buf);
 
     /* set return values */
     *buf = outbuf;
-    outbuf = NULL;
     *buf_size = size_out;
     ret_value = size_out;
 
 done:
-    if(outbuf)
-        H5MM_xfree(outbuf);
     FUNC_LEAVE_NOAPI(ret_value)
-}
+} /* end H5Z_filter_nbit() */
 
 /* ======== Nbit Algorithm ===============================================
  * assume one byte has 8 bit
@@ -941,14 +935,17 @@ done:
  * atomic datatype is treated on byte basis
  */
 
-static void H5Z_nbit_next_byte(size_t *j, int *buf_len)
+static void
+H5Z_nbit_next_byte(size_t *j, int *buf_len)
 {
    ++(*j);
    *buf_len = 8 * sizeof(unsigned char);
 }
 
-static void H5Z_nbit_decompress_one_byte(unsigned char *data, size_t data_offset, int k, int begin_i,
-int end_i, unsigned char *buffer, size_t *j, int *buf_len, parms_atomic p, int datatype_len)
+static void
+H5Z_nbit_decompress_one_byte(unsigned char *data, size_t data_offset, int k,
+    int begin_i, int end_i, unsigned char *buffer, size_t *j, int *buf_len,
+    parms_atomic p, int datatype_len)
 {
    int dat_len; /* dat_len is the number of bits to be copied in each data byte */
    int uchar_offset;
@@ -990,7 +987,8 @@ int end_i, unsigned char *buffer, size_t *j, int *buf_len, parms_atomic p, int d
    }
 }
 
-static void H5Z_nbit_decompress_one_nooptype(unsigned char *data, size_t data_offset,
+static void
+H5Z_nbit_decompress_one_nooptype(unsigned char *data, size_t data_offset,
                        unsigned char *buffer, size_t *j, int *buf_len, unsigned size)
 {
    unsigned i;        /* index */
@@ -1013,7 +1011,8 @@ static void H5Z_nbit_decompress_one_nooptype(unsigned char *data, size_t data_of
    }
 }
 
-static void H5Z_nbit_decompress_one_atomic(unsigned char *data, size_t data_offset,
+static void
+H5Z_nbit_decompress_one_atomic(unsigned char *data, size_t data_offset,
                     unsigned char *buffer, size_t *j, int *buf_len, parms_atomic p)
 {
    /* begin_i: the index of byte having first significant bit
@@ -1049,7 +1048,8 @@ static void H5Z_nbit_decompress_one_atomic(unsigned char *data, size_t data_offs
    }
 }
 
-static void H5Z_nbit_decompress_one_array(unsigned char *data, size_t data_offset,
+static void
+H5Z_nbit_decompress_one_array(unsigned char *data, size_t data_offset,
            unsigned char *buffer, size_t *j, int *buf_len, const unsigned parms[])
 {
    unsigned i, total_size, base_class, base_size, n, begin_index;
@@ -1096,7 +1096,8 @@ static void H5Z_nbit_decompress_one_array(unsigned char *data, size_t data_offse
    } /* end switch */
 }
 
-static void H5Z_nbit_decompress_one_compound(unsigned char *data, size_t data_offset,
+static void
+H5Z_nbit_decompress_one_compound(unsigned char *data, size_t data_offset,
               unsigned char *buffer, size_t *j, int *buf_len, const unsigned parms[])
 {
    unsigned i, nmembers, member_offset, member_class, size;
@@ -1134,7 +1135,8 @@ static void H5Z_nbit_decompress_one_compound(unsigned char *data, size_t data_of
    }
 }
 
-static void H5Z_nbit_decompress(unsigned char *data, unsigned d_nelmts, unsigned char *buffer,
+static void
+H5Z_nbit_decompress(unsigned char *data, unsigned d_nelmts, unsigned char *buffer,
                                 const unsigned parms[])
 {
    /* i: index of data, j: index of buffer,
@@ -1363,17 +1365,17 @@ static void H5Z_nbit_compress_one_compound(unsigned char *data, size_t data_offs
 static void H5Z_nbit_compress(unsigned char *data, unsigned d_nelmts, unsigned char *buffer,
                               size_t *buffer_size, const unsigned parms[])
 {
-   /* i: index of data, j: index of buffer,
+   /* i: index of data, new_size: index of buffer,
       buf_len: number of bits to be filled in current byte */
-   size_t i, j, size;
+   size_t i, size;
+   size_t new_size = 0;
    int buf_len;
    parms_atomic p;
 
    /* must initialize buffer to be zeros */
-   for(j = 0; j < *buffer_size; j++) buffer[j] = 0;
+   HDmemset(buffer, 0, *buffer_size);
 
    /* initialization before the loop */
-   j = 0;
    buf_len = sizeof(unsigned char) * 8;
 
    switch(parms[3]) {
@@ -1385,14 +1387,14 @@ static void H5Z_nbit_compress(unsigned char *data, unsigned d_nelmts, unsigned c
            p.offset = parms[7];
 
            for(i = 0; i < d_nelmts; i++) {
-              H5Z_nbit_compress_one_atomic(data, i*p.size, buffer, &j, &buf_len, p);
+              H5Z_nbit_compress_one_atomic(data, i*p.size, buffer, &new_size, &buf_len, p);
            }
            break;
       case H5Z_NBIT_ARRAY:
            size = parms[4];
            parms_index = 4;
            for(i = 0; i < d_nelmts; i++) {
-              H5Z_nbit_compress_one_array(data, i*size, buffer, &j, &buf_len, parms);
+              H5Z_nbit_compress_one_array(data, i*size, buffer, &new_size, &buf_len, parms);
               parms_index = 4;
            }
            break;
@@ -1400,12 +1402,14 @@ static void H5Z_nbit_compress(unsigned char *data, unsigned d_nelmts, unsigned c
            size = parms[4];
            parms_index = 4;
            for(i = 0; i < d_nelmts; i++) {
-              H5Z_nbit_compress_one_compound(data, i*size, buffer, &j, &buf_len, parms);
+              H5Z_nbit_compress_one_compound(data, i*size, buffer, &new_size, &buf_len, parms);
               parms_index = 4;
            }
            break;
    } /* end switch */
 
-   *buffer_size = j + 1; /* sometimes is catually j, but to be safe */
+   /* Update the size to the new value after compression.  If there are any bits hanging over in
+    * the last byte, increment the value by 1. */
+   *buffer_size = new_size + 1;
 }
 #endif /* H5_HAVE_FILTER_NBIT */
