@@ -94,13 +94,13 @@
 
 /*
  * If a program may include both `time.h' and `sys/time.h' then
- * TIME_WITH_SYS_TIME is defined (see AC_HEADER_TIME in configure.in).
+ * TIME_WITH_SYS_TIME is defined (see AC_HEADER_TIME in configure.ac).
  * On some older systems, `sys/time.h' includes `time.h' but `time.h' is not
  * protected against multiple inclusion, so programs should not explicitly
  * include both files. This macro is useful in programs that use, for example,
  * `struct timeval' or `struct timezone' as well as `struct tm'.  It is best
  * used in conjunction with `HAVE_SYS_TIME_H', whose existence is checked
- * by `AC_CHECK_HEADERS(sys/time.h)' in configure.in.
+ * by `AC_CHECK_HEADERS(sys/time.h)' in configure.ac.
  */
 #if defined(H5_TIME_WITH_SYS_TIME)
 #   include <sys/time.h>
@@ -149,13 +149,24 @@
 #   include <io.h>
 #endif
 
+/*
+ * Dynamic library handling.  These are needed for dynamically loading I/O
+ * filters and VFDs.
+ */
+#ifdef H5_HAVE_DLFCN_H
+#include <dlfcn.h>
+#endif
+#ifdef H5_HAVE_DIRENT_H
+#include <dirent.h>
+#endif
+
 
 #ifdef H5_HAVE_WIN32_API
 /* The following two defines must be before any windows headers are included */
 #define WIN32_LEAN_AND_MEAN    /* Exclude rarely-used stuff from Windows headers */
 #define NOGDI                  /* Exclude Graphic Display Interface macros */
 
-#ifdef H5_HAVE_WINSOCK_H
+#ifdef H5_HAVE_WINSOCK2_H
 #include <winsock2.h>
 #endif
 
@@ -426,6 +437,24 @@
 #define  HSSIZET_MAX  ((hssize_t)LLONG_MAX)
 #define HSSIZET_MIN  (~(HSSIZET_MAX))
 
+/*
+ * Types and max sizes for POSIX I/O.
+ * OS X (Darwin) is odd since the max I/O size does not match the types.
+ */
+#if defined(H5_HAVE_WIN32_API)
+#   define h5_posix_io_t                unsigned int
+#   define h5_posix_io_ret_t            int
+#   define H5_POSIX_MAX_IO_BYTES        INT_MAX
+#elif defined(H5_HAVE_DARWIN)
+#   define h5_posix_io_t                size_t
+#   define h5_posix_io_ret_t            ssize_t
+#   define H5_POSIX_MAX_IO_BYTES        INT_MAX
+#else
+#   define h5_posix_io_t                size_t
+#   define h5_posix_io_ret_t            ssize_t
+#   define H5_POSIX_MAX_IO_BYTES        SSIZET_MAX
+#endif
+
 /*
  * A macro to portably increment enumerated types.
  */
@@ -1449,19 +1478,20 @@ extern char *strdup(const char *s);
 #if defined(H5_HAVE_WINDOW_PATH)
 
 /* directory delimiter for Windows: slash and backslash are acceptable on Windows */
-#define  DIR_SLASH_SEPC     '/'
-#define  DIR_SEPC     '\\'
-#define  DIR_SEPS     "\\"
-#define CHECK_DELIMITER(SS)     ((SS == DIR_SEPC)||(SS == DIR_SLASH_SEPC))
-#define CHECK_ABSOLUTE(NAME)    ((isalpha(NAME[0])) && (NAME[1] == ':') && (CHECK_DELIMITER(NAME[2])))
-#define CHECK_ABS_DRIVE(NAME)   ((isalpha(NAME[0])) && (NAME[1] == ':'))
-#define CHECK_ABS_PATH(NAME)    (CHECK_DELIMITER(NAME[0]))
+#define H5_DIR_SLASH_SEPC       '/'
+#define H5_DIR_SEPC             '\\'
+#define H5_DIR_SEPS             "\\"
+#define H5_CHECK_DELIMITER(SS)     ((SS == H5_DIR_SEPC) || (SS == H5_DIR_SLASH_SEPC))
+#define H5_CHECK_ABSOLUTE(NAME)    ((HDisalpha(NAME[0])) && (NAME[1] == ':') && (H5_CHECK_DELIMITER(NAME[2])))
+#define H5_CHECK_ABS_DRIVE(NAME)   ((HDisalpha(NAME[0])) && (NAME[1] == ':'))
+#define H5_CHECK_ABS_PATH(NAME)    (H5_CHECK_DELIMITER(NAME[0]))
 
-#define GET_LAST_DELIMITER(NAME, ptr) {                 \
+#define H5_GET_LAST_DELIMITER(NAME, ptr) {                 \
     char        *slash, *backslash;                     \
-    slash = strrchr(NAME, DIR_SLASH_SEPC);              \
-    backslash = strrchr(NAME, DIR_SEPC);                \
-    if (backslash > slash)                              \
+                                                        \
+    slash = HDstrrchr(NAME, H5_DIR_SLASH_SEPC);         \
+    backslash = HDstrrchr(NAME, H5_DIR_SEPC);           \
+    if(backslash > slash)                               \
         (ptr = backslash);                              \
     else                                                \
         (ptr = slash);                                  \
@@ -1471,27 +1501,27 @@ extern char *strdup(const char *s);
 
 /* OpenVMS pathname: <disk name>$<partition>:[path]<file name>
  *     i.g. SYS$SYSUSERS:[LU.HDF5.SRC]H5system.c */
-#define    DIR_SEPC  ']'
-#define    DIR_SEPS  "]"
-#define         CHECK_DELIMITER(SS)             (SS == DIR_SEPC)
-#define         CHECK_ABSOLUTE(NAME)            (strrchr(NAME, ':') && strrchr(NAME, '['))
-#define   CHECK_ABS_DRIVE(NAME)           (0)
-#define   CHECK_ABS_PATH(NAME)      (0)
-#define         GET_LAST_DELIMITER(NAME, ptr)   ptr = strrchr(NAME, DIR_SEPC);
+#define H5_DIR_SEPC                     ']'
+#define H5_DIR_SEPS                     "]"
+#define H5_CHECK_DELIMITER(SS)             (SS == H5_DIR_SEPC)
+#define H5_CHECK_ABSOLUTE(NAME)            (HDstrrchr(NAME, ':') && HDstrrchr(NAME, '['))
+#define H5_CHECK_ABS_DRIVE(NAME)           (0)
+#define H5_CHECK_ABS_PATH(NAME)            (0)
+#define H5_GET_LAST_DELIMITER(NAME, ptr)   ptr = HDstrrchr(NAME, H5_DIR_SEPC);
 
 #else
 
-#define    DIR_SEPC  '/'
-#define    DIR_SEPS  "/"
-#define         CHECK_DELIMITER(SS)             (SS == DIR_SEPC)
-#define         CHECK_ABSOLUTE(NAME)            (CHECK_DELIMITER(*NAME))
-#define   CHECK_ABS_DRIVE(NAME)     (0)
-#define   CHECK_ABS_PATH(NAME)      (0)
-#define         GET_LAST_DELIMITER(NAME, ptr)   ptr = strrchr(NAME, DIR_SEPC);
+#define H5_DIR_SEPC             '/'
+#define H5_DIR_SEPS             "/"
+#define H5_CHECK_DELIMITER(SS)     (SS == H5_DIR_SEPC)
+#define H5_CHECK_ABSOLUTE(NAME)    (H5_CHECK_DELIMITER(*NAME))
+#define H5_CHECK_ABS_DRIVE(NAME)   (0)
+#define H5_CHECK_ABS_PATH(NAME)    (0)
+#define H5_GET_LAST_DELIMITER(NAME, ptr)   ptr = HDstrrchr(NAME, H5_DIR_SEPC);
 
 #endif
 
-#define   COLON_SEPC  ':'
+#define   H5_COLON_SEPC  ':'
 
 
 /* Use FUNC to safely handle variations of C99 __func__ keyword handling */
@@ -1899,15 +1929,15 @@ static herr_t    H5_INTERFACE_INIT_FUNC(void);
     H5_PUSH_FUNC                                                              \
     {
 
-/* Use the following macro as replacement for the FUNC_ENTER_PACKAGE
- * macro when the function needs to set up a metadata tag. */
-#define FUNC_ENTER_PACKAGE_TAG(dxpl_id, tag, err) {                           \
-    haddr_t prev_tag = HADDR_UNDEF;                                           \
-    hid_t tag_dxpl_id = dxpl_id;                                              \
-                                                                              \
+/* Use this macro for all "normal" staticly-scoped functions */
+#define FUNC_ENTER_STATIC {                                                   \
     FUNC_ENTER_COMMON(H5_IS_PKG(FUNC));                                       \
-    if(H5AC_tag(tag_dxpl_id, tag, &prev_tag) < 0)                             \
-        HGOTO_ERROR(H5E_CACHE, H5E_CANTTAG, err, "unable to apply metadata tag") \
+    H5_PUSH_FUNC                                                              \
+    {
+
+/* Use this macro for staticly-scoped functions which propgate errors, but don't issue them */
+#define FUNC_ENTER_STATIC_NOERR {                                             \
+    FUNC_ENTER_COMMON_NOERR(H5_IS_PKG(FUNC));                                 \
     H5_PUSH_FUNC                                                              \
     {
 
@@ -2036,6 +2066,7 @@ H5_DLL int H5G_term_interface(void);
 H5_DLL int H5I_term_interface(void);
 H5_DLL int H5L_term_interface(void);
 H5_DLL int H5P_term_interface(void);
+H5_DLL int H5PL_term_interface(void);
 H5_DLL int H5R_term_interface(void);
 H5_DLL int H5S_term_interface(void);
 H5_DLL int H5T_term_interface(void);
