@@ -19,19 +19,22 @@
  *		This file contains common #defines, type definitions, and
  *		externs for tests of the cache implemented in H5C.c
  */
-#include "h5test.h"
-#include "H5Iprivate.h"
-#include "H5ACprivate.h"
+#ifndef _CACHE_COMMON_H
+#define _CACHE_COMMON_H
 
 #define H5C_PACKAGE             /*suppress error about including H5Cpkg   */
-
-#include "H5Cpkg.h"
-
 #define H5F_PACKAGE             /*suppress error about including H5Fpkg   */
 
+/* Include library header files */
+#include "H5ACprivate.h"
+#include "H5Cpkg.h"
 #include "H5Fpkg.h"
+#include "H5Iprivate.h"
 
-#define NO_CHANGE       -1
+/* Include test header files */
+#include "h5test.h"
+
+#define NO_CHANGE       	-1
 
 /* with apologies for the abuse of terminology... */
 
@@ -46,7 +49,7 @@
 #define MONSTER_ENTRY_TYPE	8
 #define VARIABLE_ENTRY_TYPE	9
 
-#define NUMBER_OF_ENTRY_TYPES   10	
+#define NUMBER_OF_ENTRY_TYPES   10
 
 #define PICO_ENTRY_SIZE		(size_t)1
 #define NANO_ENTRY_SIZE		(size_t)4
@@ -72,7 +75,12 @@
 
 #define MAX_ENTRIES		(10 * 1024)
 
-#define PICO_BASE_ADDR		(haddr_t)0
+
+/* The choice of the BASE_ADDR below is arbitrary -- it just has to be
+ * larger than the superblock.
+ */
+#define BASE_ADDR		(haddr_t)1024
+#define PICO_BASE_ADDR		BASE_ADDR
 #define NANO_BASE_ADDR		(haddr_t)(PICO_BASE_ADDR + \
                                       (PICO_ENTRY_SIZE * NUM_PICO_ENTRIES))
 #define MICRO_BASE_ADDR		(haddr_t)(NANO_BASE_ADDR + \
@@ -112,6 +120,9 @@
                                       (HUGE_ENTRY_SIZE * NUM_HUGE_ENTRIES))
 #define VARIABLE_ALT_BASE_ADDR	(haddr_t)(MONSTER_ALT_BASE_ADDR + \
                                      (MONSTER_ENTRY_SIZE * NUM_MONSTER_ENTRIES))
+#define MAX_ADDR		(haddr_t)(VARIABLE_ALT_BASE_ADDR + \
+				   (VARIABLE_ENTRY_SIZE * NUM_VARIABLE_ENTRIES))
+#define ADDR_SPACE_SIZE		(haddr_t)(MAX_ADDR - BASE_ADDR)
 
 #define MAX_PINS	8	/* Maximum number of entries that can be
 				 * directly pinned by a single entry.
@@ -120,11 +131,11 @@
 #define FLUSH_OP__NO_OP		0
 #define FLUSH_OP__DIRTY		1
 #define FLUSH_OP__RESIZE	2
-#define FLUSH_OP__RENAME	3
+#define FLUSH_OP__MOVE		3
 #define FLUSH_OP__MAX_OP	3
 
 #define MAX_FLUSH_OPS		10	/* Maximum number of flush operations
-					 * that can be associated with a 
+					 * that can be associated with a
 					 * cache entry.
 					 */
 
@@ -137,7 +148,7 @@ typedef struct flush_op
 					 *   FLUSH_OP__NO_OP
 					 *   FLUSH_OP__DIRTY
 					 *   FLUSH_OP__RESIZE
-					 *   FLUSH_OP__RENAME
+					 *   FLUSH_OP__MOVE
 					 */
     int			type;		/* type code of the cache entry that
 					 * is the target of the operation.
@@ -151,30 +162,30 @@ typedef struct flush_op
                                          * function implementing the flush
                                          * operation.
 					 */
-    hbool_t		flag;		/* boolean flag passed into the 
+    hbool_t		flag;		/* boolean flag passed into the
 					 * function implementing the flush
 					 * operation.  The meaning of the
 					 * flag is dependant upon the flush
 					 * operation:
 					 *
-					 * FLUSH_OP__DIRTY: TRUE iff the 
-					 *   target is pinned, and is to 
-					 *   be dirtied via the 
-					 *   H5C_mark_pinned_entry_dirty()
+					 * FLUSH_OP__DIRTY: TRUE iff the
+					 *   target is pinned, and is to
+					 *   be dirtied via the
+					 *   H5C_mark_entry_dirty()
 					 *   call.
 					 *
 					 * FLUSH_OP__RESIZE: TRUE iff the
-					 *   target is pinned, and is to 
-					 *   be resized via the 
-					 *   H5C_mark_pinned_entry_dirty()
+					 *   target is pinned, and is to
+					 *   be resized via the
+					 *   H5C_resize_entry()
 					 *   call.
 					 *
-					 * FLUSH_OP__RENAME: TRUE iff the
-					 *    target is to be renamed to 
+					 * FLUSH_OP__MOVE: TRUE iff the
+					 *    target is to be moved to
 					 *    its main address.
 					 */
-    size_t		size;		/* New target size in the 
-					 * FLUSH_OP__RENAME operation.
+    size_t		size;		/* New target size in the
+					 * FLUSH_OP__MOVE operation.
 					 * Unused elsewhere.
 					 */
 } flush_op;
@@ -202,7 +213,7 @@ typedef struct test_entry_t
     haddr_t		  main_addr;    /* initial location of the entry
                                          */
     haddr_t		  alt_addr;	/* location to which the entry
-					 * can be relocated or "renamed"
+					 * can be relocated or "moved"
                                          */
     size_t		  size;         /* how big the cache thinks this
                                          * entry is
@@ -224,7 +235,7 @@ typedef struct test_entry_t
     hbool_t		  is_protected;	/* entry should currently be on
 					 * the cache's protected list.
                                          */
-    hbool_t		  is_read_only; /* TRUE iff the entry should be 
+    hbool_t		  is_read_only; /* TRUE iff the entry should be
 					 * protected read only.
 					 */
     int			  ro_ref_count; /* Number of outstanding read only
@@ -250,14 +261,14 @@ typedef struct test_entry_t
 					 * entries pinned by this entry.
 					 */
     int			  num_flush_ops; /* integer field containing the
-					 * number of flush operations to 
-					 * be executed when the entry is 
+					 * number of flush operations to
+					 * be executed when the entry is
 					 * flushed.  This value must lie in
-					 * the closed interval 
+					 * the closed interval
 					 * [0, MAX_FLUSH_OPS].
 					 */
     struct flush_op	  flush_ops[MAX_FLUSH_OPS]; /* Array of instances
-					 * of struct flush_op detailing the 
+					 * of struct flush_op detailing the
 					 * flush operations (if any) that
 					 * are to be executed when the entry
 					 * is flushed from the cache.
@@ -265,14 +276,14 @@ typedef struct test_entry_t
 					 * num_flush_ops contains the number
 					 * of valid entries in this array.
 					 */
-    hbool_t		  flush_op_self_resize_in_progress; /* Boolean flag 
-					 * that is set to TRUE iff this 
+    hbool_t		  flush_op_self_resize_in_progress; /* Boolean flag
+					 * that is set to TRUE iff this
 					 * entry is being flushed, it has
 					 * been resized by a resize flush
 					 * op, and the flush function has
 					 * not yet returned,  This field is
-					 * used to turn off overactive santity 
-					 * checking code that would otherwise 
+					 * used to turn off overactive santity
+					 * checking code that would otherwise
 					 * cause a false test failure.
 					 */
     hbool_t		  loaded;       /* entry has been loaded since the
@@ -289,8 +300,8 @@ typedef struct test_entry_t
                                          */
 } test_entry_t;
 
-/* The following is a cut down copy of the hash table manipulation
- * macros from H5C.c, which have been further modified to avoid references
+/* The following are cut down test versions of the hash table manipulation
+ * macros from H5Cpkg.h, which have been further modified to avoid references
  * to the error reporting macros.  Needless to say, these macros must be
  * updated as necessary.
  */
@@ -298,21 +309,25 @@ typedef struct test_entry_t
 #define H5C__HASH_MASK          ((size_t)(H5C__HASH_TABLE_LEN - 1) << 3)
 #define H5C__HASH_FCN(x)        (int)(((x) & H5C__HASH_MASK) >> 3)
 
-#define H5C__PRE_HT_SEARCH_SC(cache_ptr, Addr)          \
-if ( ( (cache_ptr) == NULL ) ||                         \
-     ( (cache_ptr)->magic != H5C__H5C_T_MAGIC ) ||      \
-     ( ! H5F_addr_defined(Addr) ) ||                    \
-     ( H5C__HASH_FCN(Addr) < 0 ) ||                     \
-     ( H5C__HASH_FCN(Addr) >= H5C__HASH_TABLE_LEN ) ) { \
-    HDfprintf(stdout, "Pre HT search SC failed.\n");    \
+#define H5C_TEST__PRE_HT_SEARCH_SC(cache_ptr, Addr)          \
+if ( ( (cache_ptr) == NULL ) ||                              \
+     ( (cache_ptr)->magic != H5C__H5C_T_MAGIC ) ||           \
+     ( (cache_ptr)->index_size !=                            \
+       ((cache_ptr)->clean_index_size + (cache_ptr)->dirty_index_size) ) || \
+     ( ! H5F_addr_defined(Addr) ) ||                         \
+     ( H5C__HASH_FCN(Addr) < 0 ) ||                          \
+     ( H5C__HASH_FCN(Addr) >= H5C__HASH_TABLE_LEN ) ) {      \
+    HDfprintf(stdout, "Pre HT search SC failed.\n");         \
 }
 
-#define H5C__POST_SUC_HT_SEARCH_SC(cache_ptr, entry_ptr, Addr, k) \
+#define H5C_TEST__POST_SUC_HT_SEARCH_SC(cache_ptr, entry_ptr, Addr, k) \
 if ( ( (cache_ptr) == NULL ) ||                                   \
      ( (cache_ptr)->magic != H5C__H5C_T_MAGIC ) ||                \
      ( (cache_ptr)->index_len < 1 ) ||                            \
      ( (entry_ptr) == NULL ) ||                                   \
      ( (cache_ptr)->index_size < (entry_ptr)->size ) ||           \
+     ( (cache_ptr)->index_size !=                                 \
+       ((cache_ptr)->clean_index_size + (cache_ptr)->dirty_index_size) ) || \
      ( H5F_addr_ne((entry_ptr)->addr, (Addr)) ) ||                \
      ( (entry_ptr)->size <= 0 ) ||                                \
      ( ((cache_ptr)->index)[k] == NULL ) ||                       \
@@ -327,12 +342,18 @@ if ( ( (cache_ptr) == NULL ) ||                                   \
     HDfprintf(stdout, "Post successful HT search SC failed.\n");  \
 }
 
+#define H5C_TEST__POST_HT_SHIFT_TO_FRONT(cache_ptr, entry_ptr, k)      \
+if ( ( (cache_ptr) == NULL ) ||                                        \
+     ( ((cache_ptr)->index)[k] != (entry_ptr) ) ||                     \
+     ( (entry_ptr)->ht_prev != NULL ) ) {                              \
+    HDfprintf(stdout, "Post HT shift to front failed.\n");             \
+}
 
-#define H5C__SEARCH_INDEX(cache_ptr, Addr, entry_ptr)                   \
+#define H5C_TEST__SEARCH_INDEX(cache_ptr, Addr, entry_ptr)              \
 {                                                                       \
     int k;                                                              \
     int depth = 0;                                                      \
-    H5C__PRE_HT_SEARCH_SC(cache_ptr, Addr)                              \
+    H5C_TEST__PRE_HT_SEARCH_SC(cache_ptr, Addr)                         \
     k = H5C__HASH_FCN(Addr);                                            \
     entry_ptr = ((cache_ptr)->index)[k];                                \
     while ( ( entry_ptr ) && ( H5F_addr_ne(Addr, (entry_ptr)->addr) ) ) \
@@ -342,7 +363,7 @@ if ( ( (cache_ptr) == NULL ) ||                                   \
     }                                                                   \
     if ( entry_ptr )                                                    \
     {                                                                   \
-        H5C__POST_SUC_HT_SEARCH_SC(cache_ptr, entry_ptr, Addr, k)       \
+        H5C_TEST__POST_SUC_HT_SEARCH_SC(cache_ptr, entry_ptr, Addr, k)  \
         if ( entry_ptr != ((cache_ptr)->index)[k] )                     \
         {                                                               \
             if ( (entry_ptr)->ht_next )                                 \
@@ -355,102 +376,102 @@ if ( ( (cache_ptr) == NULL ) ||                                   \
             (entry_ptr)->ht_next = ((cache_ptr)->index)[k];             \
             (entry_ptr)->ht_prev = NULL;                                \
             ((cache_ptr)->index)[k] = (entry_ptr);                      \
+            H5C_TEST__POST_HT_SHIFT_TO_FRONT(cache_ptr, entry_ptr, k)   \
         }                                                               \
     }                                                                   \
 }
 
+/* Macros used in H5AC level tests */
+
+#define CACHE_CONFIGS_EQUAL(a, b, cmp_set_init, cmp_init_size)        \
+  ( ( (a).version                 == (b).version ) &&                 \
+    ( (a).rpt_fcn_enabled         == (b).rpt_fcn_enabled ) &&         \
+    ( (a).open_trace_file         == (b).open_trace_file ) &&         \
+    ( (a).close_trace_file        == (b).close_trace_file ) &&        \
+    ( ( (a).open_trace_file == FALSE ) ||                             \
+      ( strcmp((a).trace_file_name, (b).trace_file_name) == 0 ) ) &&  \
+    ( (a).evictions_enabled       == (b).evictions_enabled ) &&       \
+    ( ( ! cmp_set_init ) ||                                           \
+      ( (a).set_initial_size      == (b).set_initial_size ) ) &&      \
+    ( ( ! cmp_init_size ) ||                                          \
+      ( (a).initial_size          == (b).initial_size ) ) &&          \
+    ( (a).min_clean_fraction      == (b).min_clean_fraction ) &&      \
+    ( (a).max_size                == (b).max_size ) &&                \
+    ( (a).min_size                == (b).min_size ) &&                \
+    ( (a).epoch_length            == (b).epoch_length ) &&            \
+    ( (a).incr_mode               == (b).incr_mode ) &&               \
+    ( (a).lower_hr_threshold      == (b).lower_hr_threshold ) &&      \
+    ( (a).increment               == (b).increment ) &&               \
+    ( (a).apply_max_increment     == (b).apply_max_increment ) &&     \
+    ( (a).max_increment           == (b).max_increment ) &&           \
+    ( (a).flash_incr_mode         == (b).flash_incr_mode ) &&         \
+    ( (a).flash_multiple          == (b).flash_multiple ) &&          \
+    ( (a).flash_threshold         == (b).flash_threshold ) &&         \
+    ( (a).decr_mode               == (b).decr_mode ) &&               \
+    ( (a).upper_hr_threshold      == (b).upper_hr_threshold ) &&      \
+    ( (a).decrement               == (b).decrement ) &&               \
+    ( (a).apply_max_decrement     == (b).apply_max_decrement ) &&     \
+    ( (a).max_decrement           == (b).max_decrement ) &&           \
+    ( (a).epochs_before_eviction  == (b).epochs_before_eviction ) &&  \
+    ( (a).apply_empty_reserve     == (b).apply_empty_reserve ) &&     \
+    ( (a).empty_reserve           == (b).empty_reserve ) &&           \
+    ( (a).dirty_bytes_threshold   == (b).dirty_bytes_threshold ) &&   \
+    ( (a).metadata_write_strategy == (b).metadata_write_strategy ) )
+
+#define XLATE_EXT_TO_INT_MDC_CONFIG(i, e)                           \
+{                                                                   \
+    (i).version                = H5C__CURR_AUTO_SIZE_CTL_VER;       \
+    if ( (e).rpt_fcn_enabled )                                      \
+        (i).rpt_fcn            = H5C_def_auto_resize_rpt_fcn;       \
+    else                                                            \
+        (i).rpt_fcn            = NULL;                              \
+    (i).set_initial_size       = (e).set_initial_size;              \
+    (i).initial_size           = (e).initial_size;                  \
+    (i).min_clean_fraction     = (e).min_clean_fraction;            \
+    (i).max_size               = (e).max_size;                      \
+    (i).min_size               = (e).min_size;                      \
+    (i).epoch_length           = (long int)((e).epoch_length);      \
+    (i).incr_mode              = (e).incr_mode;                     \
+    (i).lower_hr_threshold     = (e).lower_hr_threshold;            \
+    (i).increment              = (e).increment;                     \
+    (i).apply_max_increment    = (e).apply_max_increment;           \
+    (i).max_increment          = (e).max_increment;                 \
+    (i).flash_incr_mode        = (e).flash_incr_mode;               \
+    (i).flash_multiple         = (e).flash_multiple;                \
+    (i).flash_threshold        = (e).flash_threshold;               \
+    (i).decr_mode              = (e).decr_mode;                     \
+    (i).upper_hr_threshold     = (e).upper_hr_threshold;            \
+    (i).flash_incr_mode        = (e).flash_incr_mode;               \
+    (i).flash_multiple         = (e).flash_multiple;                \
+    (i).flash_threshold        = (e).flash_threshold;               \
+    (i).decrement              = (e).decrement;                     \
+    (i).apply_max_decrement    = (e).apply_max_decrement;           \
+    (i).max_decrement          = (e).max_decrement;                 \
+    (i).epochs_before_eviction = (int)((e).epochs_before_eviction); \
+    (i).apply_empty_reserve    = (e).apply_empty_reserve;           \
+    (i).empty_reserve          = (e).empty_reserve;                 \
+}
+
+/* Epsilon for floating-point comparisons */
+#define FP_EPSILON 0.000001
+
 
 /* misc type definitions */
 
-struct flush_cache_test_spec
-{
-    int			entry_num;
-    int			entry_type;
-    int			entry_index;
-    hbool_t		insert_flag;
-    hbool_t		dirty_flag;
-    unsigned int	flags;
-    hbool_t		expected_loaded;
-    hbool_t		expected_cleared;
-    hbool_t		expected_flushed;
-    hbool_t		expected_destroyed;
-};
-
-struct pe_flush_cache_test_spec
-{
-    int			entry_num;
-    int			entry_type;
-    int			entry_index;
-    hbool_t		insert_flag;
-    hbool_t		dirty_flag;
-    unsigned int	flags;
-    int			num_pins;
-    int			pin_type[MAX_PINS];
-    int			pin_idx[MAX_PINS];
-    hbool_t		expected_loaded;
-    hbool_t		expected_cleared;
-    hbool_t		expected_flushed;
-    hbool_t		expected_destroyed;
-};
-
-struct fo_flush_entry_check
-{
-    int			entry_num;
-    int			entry_type;
-    int			entry_index;
-    size_t		expected_size;
-    hbool_t		in_cache;
-    hbool_t		at_main_addr;
-    hbool_t		is_dirty;
-    hbool_t		is_protected;
-    hbool_t		is_pinned;
-    hbool_t		expected_loaded;
-    hbool_t		expected_cleared;
-    hbool_t		expected_flushed;
-    hbool_t		expected_destroyed;
-};
-
-struct fo_flush_cache_test_spec
-{
-    int				entry_num;
-    int				entry_type;
-    int				entry_index;
-    hbool_t			insert_flag;
-    unsigned int		flags;
-    size_t			new_size;
-    int				num_pins;
-    int				pin_type[MAX_PINS];
-    int				pin_idx[MAX_PINS];
-    int				num_flush_ops;
-    struct flush_op		flush_ops[MAX_FLUSH_OPS];
-    hbool_t			expected_loaded;
-    hbool_t			expected_cleared;
-    hbool_t			expected_flushed;
-    hbool_t			expected_destroyed;
-};
-
-struct rename_entry_test_spec
-{
-    int			entry_type;
-    int			entry_index;
-    hbool_t		is_dirty;
-    hbool_t		is_pinned;
-};
-
 struct expected_entry_status
 {
     int			entry_type;
     int                 entry_index;
     size_t              size;
-    hbool_t		in_cache;
-    hbool_t             at_main_addr;
-    hbool_t		is_dirty;
-    hbool_t		is_protected;
-    hbool_t		is_pinned;
-    hbool_t		loaded;
-    hbool_t		cleared;
-    hbool_t		flushed;
-    hbool_t		destroyed;
+    unsigned char	in_cache;
+    unsigned char       at_main_addr;
+    unsigned char	is_dirty;
+    unsigned char	is_protected;
+    unsigned char	is_pinned;
+    unsigned char	loaded;
+    unsigned char	cleared;
+    unsigned char	flushed;
+    unsigned char	destroyed;
 };
 
 
@@ -458,7 +479,7 @@ struct expected_entry_status
 
 /* global variable externs: */
 
-extern const char *FILENAME[];
+extern const char *FILENAME[3];
 
 extern hbool_t write_permitted;
 extern hbool_t pass; /* set to false on error */
@@ -466,16 +487,6 @@ extern hbool_t skip_long_tests;
 extern hbool_t run_full_test;
 extern const char *failure_mssg;
 
-extern test_entry_t pico_entries[NUM_PICO_ENTRIES];
-extern test_entry_t nano_entries[NUM_NANO_ENTRIES];
-extern test_entry_t micro_entries[NUM_MICRO_ENTRIES];
-extern test_entry_t tiny_entries[NUM_TINY_ENTRIES];
-extern test_entry_t small_entries[NUM_SMALL_ENTRIES];
-extern test_entry_t medium_entries[NUM_MEDIUM_ENTRIES];
-extern test_entry_t large_entries[NUM_LARGE_ENTRIES];
-extern test_entry_t huge_entries[NUM_HUGE_ENTRIES];
-extern test_entry_t monster_entries[NUM_MONSTER_ENTRIES];
-
 extern test_entry_t * entries[NUMBER_OF_ENTRY_TYPES];
 extern const int32_t max_indices[NUMBER_OF_ENTRY_TYPES];
 extern const size_t entry_sizes[NUMBER_OF_ENTRY_TYPES];
@@ -490,85 +501,6 @@ herr_t check_write_permitted(const H5F_t * f,
                              hid_t dxpl_id,
                              hbool_t * write_permitted_ptr);
 
-herr_t pico_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t nano_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t micro_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t tiny_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t small_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t medium_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t large_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t huge_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t monster_clear(H5F_t * f, void *  thing, hbool_t dest);
-herr_t variable_clear(H5F_t * f, void *  thing, hbool_t dest);
-
-
-herr_t pico_dest(H5F_t * f, void * thing);
-herr_t nano_dest(H5F_t * f, void * thing);
-herr_t micro_dest(H5F_t * f, void * thing);
-herr_t tiny_dest(H5F_t * f, void * thing);
-herr_t small_dest(H5F_t * f, void * thing);
-herr_t medium_dest(H5F_t * f, void * thing);
-herr_t large_dest(H5F_t * f, void * thing);
-herr_t huge_dest(H5F_t * f, void *  thing);
-herr_t monster_dest(H5F_t * f, void *  thing);
-herr_t variable_dest(H5F_t * f, void *  thing);
-
-
-herr_t pico_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                  haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t nano_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                  haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t micro_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                   haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t tiny_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                  haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t small_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                   haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t medium_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                    haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t large_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                   haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t huge_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                  haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t monster_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                     haddr_t addr, void *thing, unsigned * flags_ptr);
-herr_t variable_flush(H5F_t *f, hid_t dxpl_id, hbool_t dest,
-                      haddr_t addr, void *thing, unsigned * flags_ptr);
-
-
-void * pico_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                 const void *udata1, void *udata2);
-void * nano_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                 const void *udata1, void *udata2);
-void * micro_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                  const void *udata1, void *udata2);
-void * tiny_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                 const void *udata1, void *udata2);
-void * small_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                  const void *udata1, void *udata2);
-void * medium_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                   const void *udata1, void *udata2);
-void * large_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                  const void *udata1, void *udata2);
-void * huge_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                 const void *udata1, void *udata2);
-void * monster_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                    const void *udata1, void *udata2);
-void * variable_load(H5F_t *f, hid_t dxpl_id, haddr_t addr,
-                     const void *udata1, void *udata2);
-
-
-herr_t pico_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t nano_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t micro_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t tiny_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t small_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t medium_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t large_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t huge_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t monster_size(H5F_t * f, void * thing, size_t * size_ptr);
-herr_t variable_size(H5F_t * f, void * thing, size_t * size_ptr);
-
 /* callback table extern */
 
 extern const H5C_class_t types[NUMBER_OF_ENTRY_TYPES];
@@ -594,41 +526,33 @@ haddr_t type_and_index_to_addr(int32_t type,
                                int32_t idx);
 #endif
 
-void dirty_entry(H5C_t * cache_ptr,
+void dirty_entry(H5F_t * file_ptr,
                  int32_t type,
                  int32_t idx,
                  hbool_t dirty_pin);
 
-void expunge_entry(H5C_t * cache_ptr,
+void expunge_entry(H5F_t * file_ptr,
                    int32_t type,
                    int32_t idx);
 
-void insert_entry(H5C_t * cache_ptr,
+void insert_entry(H5F_t * file_ptr,
                   int32_t type,
                   int32_t idx,
-                  hbool_t dirty,
                   unsigned int flags);
 
-void mark_pinned_entry_dirty(H5C_t * cache_ptr,
-	                     int32_t type,
-		             int32_t idx,
-		             hbool_t size_changed,
-		             size_t  new_size);
+void mark_entry_dirty(int32_t type,
+		      int32_t idx);
 
-void mark_pinned_or_protected_entry_dirty(H5C_t * cache_ptr,
-                                          int32_t type,
-                                          int32_t idx);
+void move_entry(H5C_t * cache_ptr,
+                int32_t type,
+                int32_t idx,
+                hbool_t main_addr);
 
-void rename_entry(H5C_t * cache_ptr,
-                  int32_t type,
-                  int32_t idx,
-                  hbool_t main_addr);
-
-void protect_entry(H5C_t * cache_ptr,
+void protect_entry(H5F_t * file_ptr,
                    int32_t type,
                    int32_t idx);
 
-void protect_entry_ro(H5C_t * cache_ptr,
+void protect_entry_ro(H5F_t * file_ptr,
                       int32_t type,
                       int32_t idx);
 
@@ -636,145 +560,119 @@ hbool_t entry_in_cache(H5C_t * cache_ptr,
                        int32_t type,
                        int32_t idx);
 
-void create_pinned_entry_dependency(H5C_t * cache_ptr,
+void create_pinned_entry_dependency(H5F_t * file_ptr,
 		                    int pinning_type,
 		                    int pinning_idx,
 		                    int pinned_type,
 		                    int pinned_idx);
 
-void execute_flush_op(H5C_t * cache_ptr,
-		      struct test_entry_t * entry_ptr,
-                      struct flush_op * op_ptr,
-		      unsigned * flags_ptr);
-
 void reset_entries(void);
 
-void resize_entry(H5C_t * cache_ptr,
-                   int32_t type,
-                   int32_t idx,
-                   size_t new_size,
-                   hbool_t resize_pin);
+void resize_entry(H5F_t * file_ptr,
+                  int32_t type,
+                  int32_t idx,
+                  size_t new_size,
+                  hbool_t in_cache);
 
-void resize_pinned_entry(H5C_t * cache_ptr,
-                         int32_t type,
-                         int32_t idx,
-                         size_t new_size);
+H5F_t *setup_cache(size_t max_cache_size, size_t min_clean_size);
 
-H5C_t * setup_cache(size_t max_cache_size, size_t min_clean_size);
-
-void row_major_scan_forward(H5C_t * cache_ptr,
+void row_major_scan_forward(H5F_t * file_ptr,
                             int32_t lag,
                             hbool_t verbose,
                             hbool_t reset_stats,
                             hbool_t display_stats,
                             hbool_t display_detailed_stats,
                             hbool_t do_inserts,
-                            hbool_t dirty_inserts,
-                            hbool_t do_renames,
-                            hbool_t rename_to_main_addr,
+                            hbool_t do_moves,
+                            hbool_t move_to_main_addr,
                             hbool_t do_destroys,
                             hbool_t do_mult_ro_protects,
                             int dirty_destroys,
                             int dirty_unprotects);
 
-void hl_row_major_scan_forward(H5C_t * cache_ptr,
+void hl_row_major_scan_forward(H5F_t * file_ptr,
                                int32_t max_index,
                                hbool_t verbose,
                                hbool_t reset_stats,
                                hbool_t display_stats,
                                hbool_t display_detailed_stats,
-                               hbool_t do_inserts,
-                               hbool_t dirty_inserts);
+                               hbool_t do_inserts);
 
-void row_major_scan_backward(H5C_t * cache_ptr,
+void row_major_scan_backward(H5F_t * file_ptr,
                              int32_t lag,
                              hbool_t verbose,
                              hbool_t reset_stats,
                              hbool_t display_stats,
                              hbool_t display_detailed_stats,
                              hbool_t do_inserts,
-                             hbool_t dirty_inserts,
-                             hbool_t do_renames,
-                             hbool_t rename_to_main_addr,
+                             hbool_t do_moves,
+                             hbool_t move_to_main_addr,
                              hbool_t do_destroys,
                              hbool_t do_mult_ro_protects,
                              int dirty_destroys,
                              int dirty_unprotects);
 
-void hl_row_major_scan_backward(H5C_t * cache_ptr,
+void hl_row_major_scan_backward(H5F_t * file_ptr,
                                 int32_t max_index,
                                 hbool_t verbose,
                                 hbool_t reset_stats,
                                 hbool_t display_stats,
                                 hbool_t display_detailed_stats,
-                                hbool_t do_inserts,
-                                hbool_t dirty_inserts);
+                                hbool_t do_inserts);
 
-void col_major_scan_forward(H5C_t * cache_ptr,
+void col_major_scan_forward(H5F_t * file_ptr,
                             int32_t lag,
                             hbool_t verbose,
                             hbool_t reset_stats,
                             hbool_t display_stats,
                             hbool_t display_detailed_stats,
                             hbool_t do_inserts,
-                            hbool_t dirty_inserts,
                             int dirty_unprotects);
 
-void hl_col_major_scan_forward(H5C_t * cache_ptr,
+void hl_col_major_scan_forward(H5F_t * file_ptr,
                                int32_t max_index,
                                hbool_t verbose,
                                hbool_t reset_stats,
                                hbool_t display_stats,
                                hbool_t display_detailed_stats,
                                hbool_t do_inserts,
-                               hbool_t dirty_inserts,
                                int dirty_unprotects);
 
-void col_major_scan_backward(H5C_t * cache_ptr,
+void col_major_scan_backward(H5F_t * file_ptr,
                              int32_t lag,
                              hbool_t verbose,
                              hbool_t reset_stats,
                              hbool_t display_stats,
                              hbool_t display_detailed_stats,
                              hbool_t do_inserts,
-                             hbool_t dirty_inserts,
                              int dirty_unprotects);
 
-void hl_col_major_scan_backward(H5C_t * cache_ptr,
+void hl_col_major_scan_backward(H5F_t * file_ptr,
                                 int32_t max_index,
                                 hbool_t verbose,
                                 hbool_t reset_stats,
                                 hbool_t display_stats,
                                 hbool_t display_detailed_stats,
                                 hbool_t do_inserts,
-                                hbool_t dirty_inserts,
                                 int dirty_unprotects);
 
-void takedown_cache(H5C_t * cache_ptr,
+void takedown_cache(H5F_t * file_ptr,
                     hbool_t dump_stats,
                     hbool_t dump_detailed_stats);
 
-void flush_cache(H5C_t * cache_ptr,
+void flush_cache(H5F_t * file_ptr,
                  hbool_t destroy_entries,
                  hbool_t dump_stats,
                  hbool_t dump_detailed_stats);
 
-void unpin_entry(H5C_t * cache_ptr,
-                 int32_t type,
+void unpin_entry(int32_t type,
                  int32_t idx);
 
-void unprotect_entry(H5C_t * cache_ptr,
+void unprotect_entry(H5F_t * file_ptr,
                      int32_t type,
                      int32_t idx,
-                     int dirty,
                      unsigned int flags);
 
-void unprotect_entry_with_size_change(H5C_t * cache_ptr,
-                                      int32_t type,
-                                      int32_t idx,
-                                      unsigned int flags,
-                                      size_t new_size);
-
 void verify_clean(void);
 
 void verify_entry_status(H5C_t * cache_ptr,
@@ -784,3 +682,25 @@ void verify_entry_status(H5C_t * cache_ptr,
 
 void verify_unprotected(void);
 
+/*** H5AC level utility functions ***/
+
+void check_and_validate_cache_hit_rate(hid_t file_id,
+                                       double * hit_rate_ptr,
+                                       hbool_t dump_data,
+                                       int64_t min_accesses,
+                                       double min_hit_rate);
+
+void check_and_validate_cache_size(hid_t file_id,
+                                   size_t * max_size_ptr,
+                                   size_t * min_clean_size_ptr,
+                                   size_t * cur_size_ptr,
+                                   int32_t * cur_num_entries_ptr,
+                                   hbool_t dump_data);
+
+void validate_mdc_config(hid_t file_id,
+                         H5AC_cache_config_t * ext_config_ptr,
+                         hbool_t compare_init,
+                         int test_num);
+
+#endif /* _CACHE_COMMON_H */
+
