@@ -111,15 +111,15 @@ test_dangle_dataset(H5F_close_degree_t degree)
         if(H5Fclose(fid) < 0)
             TEST_ERROR;
 
+    if(h5_get_file_size(filename, fapl) < 0)
+        TEST_ERROR;
+
     if(H5Pclose(fapl) < 0)
         TEST_ERROR;
 
     if(H5close() < 0)
         TEST_ERROR;
 
-    if(h5_get_file_size(filename) < 0)
-        TEST_ERROR;
-
     /* Clean up temporary file */
     HDremove(filename);
 
@@ -202,15 +202,15 @@ test_dangle_group(H5F_close_degree_t degree)
         if(H5Fclose(fid) < 0)
             TEST_ERROR;
 
+    if(h5_get_file_size(filename, fapl) < 0)
+        TEST_ERROR;
+
     if(H5Pclose(fapl) < 0)
         TEST_ERROR;
 
     if(H5close() < 0)
         TEST_ERROR;
 
-    if(h5_get_file_size(filename) < 0)
-        TEST_ERROR;
-
     /* Clean up temporary file */
     HDremove(filename);
 
@@ -298,15 +298,15 @@ test_dangle_datatype1(H5F_close_degree_t degree)
         if(H5Fclose(fid) < 0)
             TEST_ERROR;
 
+    if(h5_get_file_size(filename, fapl) < 0)
+        TEST_ERROR;
+
     if(H5Pclose(fapl) < 0)
         TEST_ERROR;
 
     if(H5close() < 0)
         TEST_ERROR;
 
-    if(h5_get_file_size(filename) < 0)
-        TEST_ERROR;
-
     /* Clean up temporary file */
     HDremove(filename);
 
@@ -385,15 +385,15 @@ test_dangle_datatype2(H5F_close_degree_t degree)
         if(H5Fclose(fid) < 0)
             TEST_ERROR;
 
+    if(h5_get_file_size(filename, fapl) < 0)
+        TEST_ERROR;
+
     if(H5Pclose(fapl) < 0)
         TEST_ERROR;
 
     if(H5close() < 0)
         TEST_ERROR;
 
-    if(h5_get_file_size(filename) < 0)
-        TEST_ERROR;
-
     /* Clean up temporary file */
     HDremove(filename);
 
@@ -492,15 +492,15 @@ test_dangle_attribute(H5F_close_degree_t degree)
         if(H5Fclose(fid) < 0)
             TEST_ERROR;
 
+    if(h5_get_file_size(filename, fapl) < 0)
+        TEST_ERROR;
+
     if(H5Pclose(fapl) < 0)
         TEST_ERROR;
 
     if(H5close() < 0)
         TEST_ERROR;
 
-    if(h5_get_file_size(filename) < 0)
-        TEST_ERROR;
-
     /* Clean up temporary file */
     HDremove(filename);
 
