@@ -175,7 +175,7 @@ H5TEST_DLL void ParseTestVerbosity(char *argv);
 H5TEST_DLL int  GetTestNumErrs(void);
 H5TEST_DLL void  IncTestNumErrs(void);
 H5TEST_DLL const void *GetTestParameters(void);
-H5TEST_DLL int  TestErrPrintf(const char *format, ...);
+H5TEST_DLL int  TestErrPrintf(const char *format, ...) __attribute__ ((format (printf, 1, 2)));
 H5TEST_DLL void SetTest(const char *testname, int action);
 H5TEST_DLL void TestAlarmOn(void);
 H5TEST_DLL void TestAlarmOff(void);
