@@ -46,14 +46,11 @@
  * Purpose:	Test trivial creating & closing memory pool
  *
  * Return:	Success:	0
- *
  *		Failure:	1
  *
  * Programmer:	Quincey Koziol
  *              Tuesday, May 3, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -74,66 +71,16 @@ test_create(void)
 
     /* Check free space */
     if(H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+        TEST_ERROR
     if(free_size != 0)
         TEST_ERROR
 
     /* Check first page */
-    if (H5MP_get_pool_first_page(mp, &page) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_first_page(mp, &page) < 0)
+        TEST_ERROR
     if(page != NULL)
         TEST_ERROR
 
-    /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
-        TEST_ERROR
-
-    PASSED();
-
-    return 0;
-
-error:
-    H5E_BEGIN_TRY {
-    } H5E_END_TRY;
-    return 1;
-} /* test_create() */
-
-
-/*-------------------------------------------------------------------------
- * Function:	test_close_one
- *
- * Purpose:	Tests closing pool with one block allocated
- *
- * Return:	Success:	0
- *
- *		Failure:	1
- *
- * Programmer:	Quincey Koziol
- *              Friday, May 6, 2005
- *
- * Modifications:
- *
- *-------------------------------------------------------------------------
- */
-static int
-test_close_one(void)
-{
-    H5MP_pool_t *mp;            /* Memory pool */
-    void *spc1;                 /* Pointer to space allocated */
-
-    /*
-     * Test memory pool closing
-     */
-    TESTING("closing pool with blocks still allocated in one page");
-
-    /* Create a memory pool */
-    if(NULL == (mp = H5MP_create((size_t)MPOOL_PAGE_SIZE, MPOOL_FLAGS)))
-        TEST_ERROR
-
-    /* Allocate space in pool */
-    if(NULL == (spc1 = H5MP_malloc(mp, (size_t)MPOOL_NORMAL_BLOCK)))
-        TEST_ERROR
-
     /* Close the memory pool */
     if(H5MP_close(mp) < 0)
         TEST_ERROR
@@ -144,7 +91,59 @@ test_close_one(void)
 
 error:
     H5E_BEGIN_TRY {
+        if(mp)
+            H5MP_close(mp);
     } H5E_END_TRY;
+
+    return 1;
+} /* test_create() */
+
+
+/*-------------------------------------------------------------------------
+ * Function:	test_close_one
+ *
+ * Purpose:	Tests closing pool with one block allocated
+ *
+ * Return:	Success:	0
+ *		Failure:	1
+ *
+ * Programmer:	Quincey Koziol
+ *              Friday, May 6, 2005
+ *
+ *-------------------------------------------------------------------------
+ */
+static int
+test_close_one(void)
+{
+    H5MP_pool_t *mp;            /* Memory pool */
+
+    /*
+     * Test memory pool closing
+     */
+    TESTING("closing pool with blocks still allocated in one page");
+
+    /* Create a memory pool */
+    if(NULL == (mp = H5MP_create((size_t)MPOOL_PAGE_SIZE, MPOOL_FLAGS)))
+        TEST_ERROR
+
+    /* Allocate space in pool */
+    if(NULL == H5MP_malloc(mp, (size_t)MPOOL_NORMAL_BLOCK))
+        TEST_ERROR
+
+    /* Close the memory pool */
+    if(H5MP_close(mp) < 0)
+        TEST_ERROR
+
+    PASSED();
+
+    return 0;
+
+error:
+    H5E_BEGIN_TRY {
+        if(mp)
+            H5MP_close(mp);
+    } H5E_END_TRY;
+
     return 1;
 } /* test_close_one() */
 
@@ -155,14 +154,11 @@ error:
  * Purpose:	Tests allocating first block in pool
  *
  * Return:	Success:	0
- *
  *		Failure:	1
  *
  * Programmer:	Quincey Koziol
  *              Tuesday, May 3, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -188,29 +184,29 @@ test_allocate_first(void)
 
     /* Check pool's free space */
     if(H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - (H5MP_BLOCK_ALIGN(MPOOL_NORMAL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t)) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))))
         TEST_ERROR
 
     /* Get first page */
-    if (H5MP_get_pool_first_page(mp, &page) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_first_page(mp, &page) < 0)
+        TEST_ERROR
     if(page == NULL)
         TEST_ERROR
 
     /* Check page's free space */
-    if (H5MP_get_page_free_size(page, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_page_free_size(page, &free_size) < 0)
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - (H5MP_BLOCK_ALIGN(MPOOL_NORMAL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t)) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Check next page */
-    if (H5MP_get_page_next_page(page, &page) < 0)
-        TEST_ERROR;
+    if(H5MP_get_page_next_page(page, &page) < 0)
+        TEST_ERROR
     if(page != NULL)
         TEST_ERROR
 
@@ -218,17 +214,17 @@ test_allocate_first(void)
     H5MP_free(mp, spc);
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t)))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
+    if(H5MP_close(mp) < 0)
         TEST_ERROR
 
     PASSED();
@@ -245,29 +241,29 @@ test_allocate_first(void)
 
     /* Check pool's free space */
     if(H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+        TEST_ERROR
     if(free_size != 0)
         TEST_ERROR
 
     /* Get first page */
-    if (H5MP_get_pool_first_page(mp, &page) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_first_page(mp, &page) < 0)
+        TEST_ERROR
     if(page == NULL)
         TEST_ERROR
 
     /* Check page's free space */
-    if (H5MP_get_page_free_size(page, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_page_free_size(page, &free_size) < 0)
+        TEST_ERROR
     if(free_size != 0)
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Check next page */
-    if (H5MP_get_page_next_page(page, &page) < 0)
-        TEST_ERROR;
+    if(H5MP_get_page_next_page(page, &page) < 0)
+        TEST_ERROR
     if(page != NULL)
         TEST_ERROR
 
@@ -275,17 +271,17 @@ test_allocate_first(void)
     H5MP_free(mp, spc);
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != MPOOL_LARGE_BLOCK + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t)))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
+    if(H5MP_close(mp) < 0)
         TEST_ERROR
 
     PASSED();
@@ -294,7 +290,10 @@ test_allocate_first(void)
 
 error:
     H5E_BEGIN_TRY {
+        if(mp)
+            H5MP_close(mp);
     } H5E_END_TRY;
+
     return 1;
 } /* test_allocate_first() */
 
@@ -306,14 +305,11 @@ error:
  *              existing block
  *
  * Return:	Success:	0
- *
  *		Failure:	1
  *
  * Programmer:	Quincey Koziol
  *              Tuesday, May 3, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -339,13 +335,13 @@ test_allocate_split(void)
 
     /* Check pool's free space */
     if(H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - (H5MP_BLOCK_ALIGN(MPOOL_NORMAL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t)) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Allocate more space in pool */
     if(NULL == (spc2 = H5MP_malloc(mp, (size_t)MPOOL_NORMAL_BLOCK)))
@@ -353,42 +349,42 @@ test_allocate_split(void)
 
     /* Check pool's free space */
     if(H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - (((H5MP_BLOCK_ALIGN(MPOOL_NORMAL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t))) * 2) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Free first block in pool */
     H5MP_free(mp, spc1);
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - (H5MP_BLOCK_ALIGN(MPOOL_NORMAL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t)) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Free second block in pool (should merge with first block) */
     H5MP_free(mp, spc2);
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t)))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
+    if(H5MP_close(mp) < 0)
         TEST_ERROR
 
     PASSED();
@@ -397,7 +393,10 @@ test_allocate_split(void)
 
 error:
     H5E_BEGIN_TRY {
+        if(mp)
+            H5MP_close(mp);
     } H5E_END_TRY;
+
     return 1;
 } /* test_allocate_split() */
 
@@ -408,14 +407,11 @@ error:
  * Purpose:	Tests allocating many small blocks in a pool
  *
  * Return:	Success:	0
- *
  *		Failure:	1
  *
  * Programmer:	Quincey Koziol
  *              Tuesday, May 6, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -442,13 +438,13 @@ test_allocate_many_small(void)
 
     /* Check pool's free space */
     if(H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - (((H5MP_BLOCK_ALIGN(MPOOL_SMALL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t))) * MPOOL_NUM_SMALL_BLOCKS) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Free blocks in pool */
     /* (Tests free block merging with block after it */
@@ -456,17 +452,17 @@ test_allocate_many_small(void)
         H5MP_free(mp, spc[i]);
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t)))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
+    if(H5MP_close(mp) < 0)
         TEST_ERROR
 
     PASSED();
@@ -475,7 +471,10 @@ test_allocate_many_small(void)
 
 error:
     H5E_BEGIN_TRY {
+        if(mp)
+            H5MP_close(mp);
     } H5E_END_TRY;
+
     return 1;
 } /* test_allocate_many_small() */
 
@@ -487,14 +486,11 @@ error:
  *              new page
  *
  * Return:	Success:	0
- *
  *		Failure:	1
  *
  * Programmer:	Quincey Koziol
  *              Friday, May 6, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -523,13 +519,13 @@ test_allocate_new_page(void)
 
     /* Check pool's free space */
     if(H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+        TEST_ERROR
     if(free_size != (MPOOL_PAGE_SIZE * 3) - (((H5MP_BLOCK_ALIGN(MPOOL_NORMAL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t))) * MPOOL_NUM_NORMAL_BLOCKS) + (H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t)) * 3)))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Free blocks in pool */
     /* (Free alternating blocks, in two passes, which tests block merging w/both neighbors) */
@@ -539,17 +535,17 @@ test_allocate_new_page(void)
         H5MP_free(mp, spc[u]);
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != ((MPOOL_PAGE_SIZE - H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))) * 3))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
+    if(H5MP_close(mp) < 0)
         TEST_ERROR
 
     PASSED();
@@ -569,32 +565,32 @@ test_allocate_new_page(void)
         TEST_ERROR
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != MPOOL_PAGE_SIZE - (H5MP_BLOCK_ALIGN(MPOOL_NORMAL_BLOCK) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t)) + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Free blocks in pool */
     H5MP_free(mp, spc1);
     H5MP_free(mp, spc2);
 
     /* Check pool's free space */
-    if (H5MP_get_pool_free_size(mp, &free_size) < 0)
-        TEST_ERROR;
+    if(H5MP_get_pool_free_size(mp, &free_size) < 0)
+        TEST_ERROR
     if(free_size != ((MPOOL_PAGE_SIZE - H5MP_BLOCK_ALIGN(sizeof(H5MP_page_t))) +
             MPOOL_LARGE_BLOCK + H5MP_BLOCK_ALIGN(sizeof(H5MP_page_blk_t))))
         TEST_ERROR
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
+    if(H5MP_close(mp) < 0)
         TEST_ERROR
 
     PASSED();
@@ -603,7 +599,10 @@ test_allocate_new_page(void)
 
 error:
     H5E_BEGIN_TRY {
+        if(mp)
+            H5MP_close(mp);
     } H5E_END_TRY;
+
     return 1;
 } /* test_allocate_new_page() */
 
@@ -614,14 +613,11 @@ error:
  * Purpose:	Tests allocating random sized blocks in pool
  *
  * Return:	Success:	0
- *
  *		Failure:	1
  *
  * Programmer:	Quincey Koziol
  *              Friday, May 6, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -641,23 +637,23 @@ test_allocate_random(void)
     TESTING("allocate many random sized blocks");
 
     /* Initialize random number seed */
-    curr_time=HDtime(NULL);
+    curr_time = HDtime(NULL);
 #ifdef QAK
 curr_time=1115412944;
 HDfprintf(stderr,"curr_time=%lu\n",(unsigned long)curr_time);
 #endif /* QAK */
-    HDsrandom((unsigned long)curr_time);
+    HDsrandom((unsigned)curr_time);
 
     /* Create a memory pool */
     if(NULL == (mp = H5MP_create((size_t)MPOOL_PAGE_SIZE, MPOOL_FLAGS)))
         TEST_ERROR
 
     /* Allocate space for the block sizes */
-    if(NULL == (blk_size = HDmalloc(sizeof(size_t) * MPOOL_NUM_RANDOM)))
+    if(NULL == (blk_size = (size_t *)HDmalloc(sizeof(size_t) * MPOOL_NUM_RANDOM)))
         TEST_ERROR
 
     /* Allocate space for the block pointers */
-    if(NULL == (spc = HDmalloc(sizeof(void *) * MPOOL_NUM_RANDOM)))
+    if(NULL == (spc = (void **)HDmalloc(sizeof(void *) * MPOOL_NUM_RANDOM)))
         TEST_ERROR
 
     /* Initialize the block sizes with random values */
@@ -671,7 +667,7 @@ HDfprintf(stderr,"curr_time=%lu\n",(unsigned long)curr_time);
 
     /* Check that free space totals match */
     if(H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+        TEST_ERROR
 
     /* Shuffle pointers to free */
     for(u = 0; u < MPOOL_NUM_RANDOM; u++) {
@@ -686,8 +682,8 @@ HDfprintf(stderr,"curr_time=%lu\n",(unsigned long)curr_time);
         H5MP_free(mp, spc[u]);
 
     /* Check that free space totals match */
-    if (H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+    if(H5MP_pool_is_free_size_correct(mp) <= 0)
+        TEST_ERROR
 
     /* Initialize the block sizes with random values */
     for(u = 0; u < MPOOL_NUM_RANDOM; u++)
@@ -701,10 +697,10 @@ HDfprintf(stderr,"curr_time=%lu\n",(unsigned long)curr_time);
 
     /* Check that free space totals match */
     if(H5MP_pool_is_free_size_correct(mp) <= 0)
-        TEST_ERROR;
+        TEST_ERROR
 
     /* Close the memory pool */
-    if (H5MP_close(mp) < 0)
+    if(H5MP_close(mp) < 0)
         TEST_ERROR
 
     /* Free memory for block sizes & pointers */
@@ -721,7 +717,10 @@ error:
     if(spc)
         HDfree(spc);
     H5E_BEGIN_TRY {
+        if(mp)
+            H5MP_close(mp);
     } H5E_END_TRY;
+
     return 1;
 } /* test_allocate_random() */
 
@@ -732,20 +731,17 @@ error:
  * Purpose:	Test the memory pool code
  *
  * Return:	Success:
- *
  *		Failure:
  *
  * Programmer:	Quincey Koziol
  *              Tuesday, May 3, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 int
 main(void)
 {
-    int		nerrors=0;
+    int nerrors = 0;
 
     /* Reset library */
     h5_reset();
@@ -763,14 +759,14 @@ main(void)
     nerrors += test_allocate_new_page();
     nerrors += test_allocate_random();
 
-    if (nerrors) goto error;
+    if(nerrors)
+        goto error;
     puts("All memory pool tests passed.");
+
     return 0;
 
 error:
     puts("*** TESTS FAILED ***");
-    H5E_BEGIN_TRY {
-    } H5E_END_TRY;
     return 1;
 }
 
