@@ -26,7 +26,7 @@
  *   ttsafe_dcreate.h5
  *
  * HDF5 APIs exercised in thread:
- * H5Screate_simple, H5Tcopy, H5Tset_order, H5Dcreate, H5Dwrite, H5Dclose,
+ * H5Screate_simple, H5Tcopy, H5Tset_order, H5Dcreate2, H5Dwrite, H5Dclose,
  * H5Tclose, H5Sclose.
  *
  * Created: Apr 28 2000
@@ -88,21 +88,21 @@ thread_info thread_out[NUM_THREAD];
  */
 void tts_dcreate(void)
 {
-    /* Pthread definitions */
-    pthread_t threads[NUM_THREAD];
+    /* thread definitions */
+    H5TS_thread_t threads[NUM_THREAD];
 
     /* HDF5 data definitions */
     hid_t file, dataset;
     int datavalue, i;
-    pthread_attr_t attribute;
+    H5TS_attr_t attribute;
     int ret;
 
     /* set pthread attribute to perform global scheduling */
-    ret=pthread_attr_init(&attribute);
-    assert(ret==0);
+    H5TS_attr_init(&attribute);
+
+    /* set thread scope to system */
 #ifdef H5_HAVE_SYSTEM_SCOPE_THREADS
-    ret=pthread_attr_setscope(&attribute, PTHREAD_SCOPE_SYSTEM);
-    assert(ret==0);
+    H5TS_attr_setscope(&attribute, H5TS_SCOPE_SYSTEM);
 #endif /* H5_HAVE_SYSTEM_SCOPE_THREADS */
 
     /*
@@ -110,90 +110,90 @@ void tts_dcreate(void)
      * creation plist and default file access plist
      */
     file = H5Fcreate(FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
-    assert(file>=0);
+    assert(file >= 0);
 
     /* simultaneously create a large number of datasets within the file */
-    for (i = 0; i < NUM_THREAD; i++) {
+    for(i = 0; i < NUM_THREAD; i++) {
         thread_out[i].id = i;
         thread_out[i].file = file;
         thread_out[i].dsetname = dsetname[i];
-        ret=pthread_create(&threads[i], NULL, tts_dcreate_creator, &thread_out[i]);
-        assert(ret==0);
-    }
+        threads[i] = H5TS_create_thread(tts_dcreate_creator, NULL, &thread_out[i]);
+    } /* end for */
 
-    for (i = 0;i < NUM_THREAD; i++) {
-        ret=pthread_join(threads[i], NULL);
-        assert(ret==0);
+    for(i = 0;i < NUM_THREAD; i++) {
+        H5TS_wait_for_thread(threads[i]);
     } /* end for */
 
     /* compare data to see if it is written correctly */
 
-    for (i = 0; i < NUM_THREAD; i++) {
-        if ((dataset = H5Dopen(file,dsetname[i])) < 0) {
+    for(i = 0; i < NUM_THREAD; i++) {
+        if((dataset = H5Dopen2(file, dsetname[i], H5P_DEFAULT)) < 0) {
             TestErrPrintf("Dataset name not found - test failed\n");
             H5Fclose(file);
             return;
         } else {
-            ret=H5Dread(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, &datavalue);
-            assert(ret>=0);
+            ret = H5Dread(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, &datavalue);
+            assert(ret >= 0);
 
-            if (datavalue != i) {
+            if(datavalue != i) {
                 TestErrPrintf("Wrong value read %d for dataset name %s - test failed\n",
                             datavalue, dsetname[i]);
-                H5Dclose(dataset);
-                H5Fclose(file);
+                ret = H5Dclose(dataset);
+                assert(ret >= 0);
+                ret = H5Fclose(file);
+                assert(ret >= 0);
                 return;
             }
 
-            ret=H5Dclose(dataset);
-            assert(ret>=0);
+            ret = H5Dclose(dataset);
+            assert(ret >= 0);
         }
     }
 
     /* close remaining resources */
-    ret=H5Fclose(file);
-    assert(ret>=0);
+    ret = H5Fclose(file);
+    assert(ret >= 0);
 
     /* Destroy the thread attribute */
-    ret=pthread_attr_destroy(&attribute);
-    assert(ret==0);
+    H5TS_attr_destroy(&attribute);
 }
 
 void *tts_dcreate_creator(void *_thread_data)
 {
-	hid_t   dataspace, dataset;
-        herr_t  ret;
-	hsize_t dimsf[1]; /* dataset dimensions */
-	struct thread_info thread_data;
+    hid_t   dataspace, dataset;
+    herr_t  ret;
+    hsize_t dimsf[1]; /* dataset dimensions */
+    struct thread_info thread_data;
 
-	memcpy(&thread_data,_thread_data,sizeof(struct thread_info));
+    memcpy(&thread_data, _thread_data, sizeof(struct thread_info));
 
-	/* define dataspace for dataset */
-	dimsf[0] = 1;
-	dataspace = H5Screate_simple(1,dimsf,NULL);
-        assert(dataspace>=0);
+    /* define dataspace for dataset */
+    dimsf[0] = 1;
+    dataspace = H5Screate_simple(1, dimsf, NULL);
+    assert(dataspace >= 0);
 
-	/* create a new dataset within the file */
-	dataset = H5Dcreate(thread_data.file, thread_data.dsetname,
-			    H5T_NATIVE_INT, dataspace, H5P_DEFAULT);
-        assert(dataset>=0);
+    /* create a new dataset within the file */
+    dataset = H5Dcreate2(thread_data.file, thread_data.dsetname,
+                        H5T_NATIVE_INT, dataspace, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    assert(dataset >= 0);
 
-	/* initialize data for dataset and write value to dataset */
-	ret=H5Dwrite(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL,
-		 H5P_DEFAULT, &thread_data.id);
-        assert(ret>=0);
+    /* initialize data for dataset and write value to dataset */
+    ret = H5Dwrite(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL,
+             H5P_DEFAULT, &thread_data.id);
+    assert(ret >= 0);
 
-	/* close dataset and dataspace resources */
-	ret=H5Dclose(dataset);
-        assert(ret>=0);
-	ret=H5Sclose(dataspace);
-        assert(ret>=0);
+    /* close dataset and dataspace resources */
+    ret = H5Dclose(dataset);
+    assert(ret >= 0);
+    ret = H5Sclose(dataspace);
+    assert(ret >= 0);
 
-	return NULL;
+    return NULL;
 }
 
 void cleanup_dcreate(void)
 {
-	HDunlink(FILENAME);
+    HDunlink(FILENAME);
 }
 #endif /*H5_HAVE_THREADSAFE*/
+
