@@ -22,27 +22,27 @@
  */
 
 #include "testphdf5.h"
-static int	mpi_size, mpi_rank;
+static int  mpi_size, mpi_rank;
 
-#define DATASETNAME "ExtendibleArray"
-#define CHUNKSIZE	1000		/* #elements per chunk */
-#define DSETCHUNKS		20000
+#define DSET_NAME "ExtendibleArray"
+#define CHUNK_SIZE  1000    /* #elements per chunk */
+#define CHUNK_FACTOR  200     /* default dataset size in terms of chunks */
 #define CLOSE           1
 #define NO_CLOSE        0
 
 static MPI_Offset
 get_filesize(const char *filename)
 {
-    int		mpierr;
-    MPI_File	fd;
-    MPI_Offset	filesize;
+    int    mpierr;
+    MPI_File  fd;
+    MPI_Offset  filesize;
 #ifndef H5_HAVE_MPI_GET_SIZE
-    struct stat stat_buf;
+    h5_stat_t stat_buf;
 #endif
 
 #ifdef H5_HAVE_MPI_GET_SIZE
     mpierr = MPI_File_open(MPI_COMM_SELF, (char*)filename, MPI_MODE_RDONLY,
-	MPI_INFO_NULL, &fd);
+  MPI_INFO_NULL, &fd);
     VRFY((mpierr == MPI_SUCCESS), "");
 
     mpierr = MPI_File_get_size(fd, &filesize);
@@ -54,7 +54,7 @@ get_filesize(const char *filename)
     /* Some systems (only SGI Altix Propack 4 so far) doesn't return correct
      * file size for MPI_File_get_size.  Use stat instead.
      */
-    if((mpierr=stat(filename, &stat_buf))<0)
+    if((mpierr=HDstat(filename, &stat_buf))<0)
     VRFY((mpierr == MPI_SUCCESS), "");
 
     /* Hopefully this casting is safe */
@@ -78,12 +78,12 @@ typedef enum access_ {
 
 
 /*
- * This creates a dataset serially with 'nchunks' chunks, each of CHUNKSIZE
+ * This creates a dataset serially with chunks, each of CHUNK_SIZE
  * elements. The allocation time is set to H5D_ALLOC_TIME_EARLY. Another
  * routine will open this in parallel for extension test.
  */
-void
-create_chunked_dataset(const char *filename, int nchunks, write_type write_pattern)
+static void
+create_chunked_dataset(const char *filename, int chunk_factor, write_type write_pattern)
 {
     hid_t       file_id, dataset;                          /* handles */
     hid_t       dataspace,memspace;
@@ -91,19 +91,18 @@ create_chunked_dataset(const char *filename, int nchunks, write_type write_patte
     hsize_t      dims[1];
     hsize_t      maxdims[1] = {H5S_UNLIMITED};
 
-    hsize_t      chunk_dims[1] ={CHUNKSIZE};
+    hsize_t      chunk_dims[1] ={CHUNK_SIZE};
     hsize_t     count[1];
     hsize_t     stride[1];
     hsize_t     block[1];
     hsize_t     offset[1];            /* Selection offset within dataspace */
     /* Variables used in reading data back */
-    char         buffer[CHUNKSIZE];
-    int           i;
-
+    char         buffer[CHUNK_SIZE];
+    long         nchunks;
     herr_t       hrc;
 
-    MPI_Offset  filesize,	    /* actual file size */
-		est_filesize;	    /* estimated file size */
+    MPI_Offset  filesize,      /* actual file size */
+    est_filesize;      /* estimated file size */
 
     /* set up MPI parameters */
     MPI_Comm_size(MPI_COMM_WORLD,&mpi_size);
@@ -111,36 +110,36 @@ create_chunked_dataset(const char *filename, int nchunks, write_type write_patte
 
     /* Only MAINPROCESS should create the file.  Others just wait. */
     if (MAINPROCESS){
+        nchunks=chunk_factor*mpi_size;
+  dims[0]=nchunks*CHUNK_SIZE;
+  /* Create the data space with unlimited dimensions. */
+  dataspace = H5Screate_simple (1, dims, maxdims);
+  VRFY((dataspace >= 0), "");
 
-	dims[0]=nchunks*CHUNKSIZE;
-	/* Create the data space with unlimited dimensions. */
-	dataspace = H5Screate_simple (1, dims, maxdims);
-	VRFY((dataspace >= 0), "");
+  memspace = H5Screate_simple(1, chunk_dims, NULL);
+  VRFY((memspace >= 0), "");
 
-	memspace = H5Screate_simple(1, chunk_dims, NULL);
-	VRFY((memspace >= 0), "");
+  /* Create a new file. If file exists its contents will be overwritten. */
+  file_id = H5Fcreate(h5_rmprefix(filename), H5F_ACC_TRUNC, H5P_DEFAULT,
+        H5P_DEFAULT);
+  VRFY((file_id >= 0), "H5Fcreate");
 
-	/* Create a new file. If file exists its contents will be overwritten. */
-	file_id = H5Fcreate(h5_rmprefix(filename), H5F_ACC_TRUNC, H5P_DEFAULT,
-		    H5P_DEFAULT);
-	VRFY((file_id >= 0), "H5Fcreate");
+  /* Modify dataset creation properties, i.e. enable chunking  */
+  cparms = H5Pcreate(H5P_DATASET_CREATE);
+  VRFY((cparms >= 0), "");
 
-	/* Modify dataset creation properties, i.e. enable chunking  */
-	cparms = H5Pcreate(H5P_DATASET_CREATE);
-	VRFY((cparms >= 0), "");
+  hrc = H5Pset_alloc_time(cparms, H5D_ALLOC_TIME_EARLY);
+  VRFY((hrc >= 0), "");
 
-	hrc = H5Pset_alloc_time(cparms, H5D_ALLOC_TIME_EARLY);
-	VRFY((hrc >= 0), "");
+  hrc = H5Pset_chunk(cparms, 1, chunk_dims);
+  VRFY((hrc >= 0), "");
 
-	hrc = H5Pset_chunk(cparms, 1, chunk_dims);
-	VRFY((hrc >= 0), "");
+  /* Create a new dataset within the file using cparms creation properties. */
+  dataset = H5Dcreate2(file_id, DSET_NAME, H5T_NATIVE_UCHAR, dataspace, H5P_DEFAULT, cparms, H5P_DEFAULT);
+  VRFY((dataset >= 0), "");
 
-	/* Create a new dataset within the file using cparms creation properties. */
-	dataset = H5Dcreate2(file_id, DATASETNAME, H5T_NATIVE_UCHAR, dataspace, H5P_DEFAULT, cparms, H5P_DEFAULT);
-	VRFY((dataset >= 0), "");
-
-	if(write_pattern == sec_last) {
-            HDmemset(buffer, 100, CHUNKSIZE);
+  if(write_pattern == sec_last) {
+            HDmemset(buffer, 100, CHUNK_SIZE);
 
             count[0] = 1;
             stride[0] = 1;
@@ -155,28 +154,28 @@ create_chunked_dataset(const char *filename, int nchunks, write_type write_patte
             VRFY((hrc >= 0), "H5Dwrite");
         } /* end if */
 
-	/* Close resources */
-	hrc = H5Dclose (dataset);
-	VRFY((hrc >= 0), "");
-	dataset = -1;
+  /* Close resources */
+  hrc = H5Dclose (dataset);
+  VRFY((hrc >= 0), "");
+  dataset = -1;
 
-	hrc = H5Sclose (dataspace);
-	VRFY((hrc >= 0), "");
+  hrc = H5Sclose (dataspace);
+  VRFY((hrc >= 0), "");
 
-	hrc = H5Sclose (memspace);
-	VRFY((hrc >= 0), "");
+  hrc = H5Sclose (memspace);
+  VRFY((hrc >= 0), "");
 
-	hrc = H5Pclose (cparms);
-	VRFY((hrc >= 0), "");
+  hrc = H5Pclose (cparms);
+  VRFY((hrc >= 0), "");
 
-	hrc = H5Fclose (file_id);
-	VRFY((hrc >= 0), "");
-	file_id = -1;
+  hrc = H5Fclose (file_id);
+  VRFY((hrc >= 0), "");
+  file_id = -1;
 
-	/* verify file size */
-	filesize = get_filesize(filename);
-	est_filesize = nchunks * CHUNKSIZE * sizeof(unsigned char);
-	VRFY((filesize >= est_filesize), "file size check");
+  /* verify file size */
+  filesize = get_filesize(filename);
+  est_filesize = nchunks * CHUNK_SIZE * sizeof(unsigned char);
+  VRFY((filesize >= est_filesize), "file size check");
 
     }
 
@@ -191,38 +190,41 @@ create_chunked_dataset(const char *filename, int nchunks, write_type write_patte
 
 /*
  * This program performs three different types of parallel access. It writes on
- * the entire dataset, it extends the dataset to nchunks*CHUNKSIZE, and it only
+ * the entire dataset, it extends the dataset to nchunks*CHUNK_SIZE, and it only
  * opens the dataset. At the end, it verifies the size of the dataset to be
- * consistent with argument 'nchunks'.
+ * consistent with argument 'chunk_factor'.
  */
-void
-parallel_access_dataset(const char *filename, int nchunks, access_type action, hid_t *file_id, hid_t *dataset)
+static void
+parallel_access_dataset(const char *filename, int chunk_factor, access_type action, hid_t *file_id, hid_t *dataset)
 {
     /* HDF5 gubbins */
     hid_t    memspace, dataspace;     /* HDF5 file identifier */
     hid_t    access_plist;         /* HDF5 ID for file access property list */
     herr_t   hrc;                  /* HDF5 return code */
     hsize_t  size[1];
-    hsize_t  dim_size;
 
-    hsize_t     chunk_dims[1] ={CHUNKSIZE};
+    hsize_t     chunk_dims[1] ={CHUNK_SIZE};
     hsize_t     count[1];
     hsize_t     stride[1];
     hsize_t     block[1];
     hsize_t     offset[1];            /* Selection offset within dataspace */
-    /* Variables used in reading data back */
-    char         buffer[CHUNKSIZE];
-    int         i;
+    hsize_t     dims[1];
+    hsize_t     maxdims[1];
 
+    /* Variables used in reading data back */
+    char         buffer[CHUNK_SIZE];
+    int         i;
+    long        nchunks;
     /* MPI Gubbins */
-    MPI_Offset  filesize,	    /* actual file size */
-		est_filesize;	    /* estimated file size */
-    int         mpierr;
+    MPI_Offset  filesize,      /* actual file size */
+    est_filesize;      /* estimated file size */
 
     /* Initialize MPI */
     MPI_Comm_size(MPI_COMM_WORLD,&mpi_size);
     MPI_Comm_rank(MPI_COMM_WORLD,&mpi_rank);
 
+    nchunks=chunk_factor*mpi_size;
+
     /* Set up MPIO file access property lists */
     access_plist  = H5Pcreate(H5P_FILE_ACCESS);
     VRFY((access_plist >= 0), "");
@@ -238,7 +240,7 @@ parallel_access_dataset(const char *filename, int nchunks, access_type action, h
 
     /* Open dataset*/
     if (*dataset<0){
-        *dataset = H5Dopen2(*file_id, DATASETNAME, H5P_DEFAULT);
+        *dataset = H5Dopen2(*file_id, DSET_NAME, H5P_DEFAULT);
         VRFY((*dataset >= 0), "");
     }
 
@@ -248,42 +250,44 @@ parallel_access_dataset(const char *filename, int nchunks, access_type action, h
     dataspace = H5Dget_space(*dataset);
     VRFY((dataspace >= 0), "");
 
-    size[0] = nchunks*CHUNKSIZE;
+    size[0] = nchunks*CHUNK_SIZE;
 
     switch (action) {
 
         /* all chunks are written by all the processes in an interleaved way*/
         case write_all:
 
-	    memset(buffer, mpi_rank+1, CHUNKSIZE);
-	    count[0] = 1;
-	    stride[0] = 1;
-	    block[0] = chunk_dims[0];
-            for (i=0; i<(nchunks+mpi_size-1)/mpi_size; i++){
-		if (i*mpi_size+mpi_rank < nchunks){
-		    offset[0] = (i*mpi_size+mpi_rank)*chunk_dims[0];
+      memset(buffer, mpi_rank+1, CHUNK_SIZE);
+      count[0] = 1;
+      stride[0] = 1;
+      block[0] = chunk_dims[0];
+            for (i=0; i<nchunks/mpi_size; i++){
+        offset[0] = (i*mpi_size+mpi_rank)*chunk_dims[0];
 
-		    hrc = H5Sselect_hyperslab(dataspace, H5S_SELECT_SET, offset, stride, count, block);
-		    VRFY((hrc >= 0), "");
-
-		    /* Write the buffer out */
-		    hrc = H5Dwrite(*dataset, H5T_NATIVE_UCHAR, memspace, dataspace, H5P_DEFAULT, buffer);
-		    VRFY((hrc >= 0), "H5Dwrite");
-		}
+        hrc = H5Sselect_hyperslab(dataspace, H5S_SELECT_SET, offset, stride, count, block);
+        VRFY((hrc >= 0), "");
 
+        /* Write the buffer out */
+        hrc = H5Dwrite(*dataset, H5T_NATIVE_UCHAR, memspace, dataspace, H5P_DEFAULT, buffer);
+        VRFY((hrc >= 0), "H5Dwrite");
             }
 
             break;
 
         /* only extends the dataset */
         case extend_only:
-            /* Extend dataset*/
-            hrc = H5Dset_extent(*dataset, size);
+            /* check if new size is larger than old size */
+            hrc = H5Sget_simple_extent_dims(dataspace, dims, maxdims);
             VRFY((hrc >= 0), "");
 
+            /* Extend dataset*/
+            if (size[0] > dims[0]) {
+                hrc = H5Dset_extent(*dataset, size);
+                VRFY((hrc >= 0), "");
+            }
             break;
 
-        /* only opens the dataset */
+        /* only opens the *dataset */
         case open_only:
 
             break;
@@ -295,10 +299,10 @@ parallel_access_dataset(const char *filename, int nchunks, access_type action, h
     *dataset = -1;
 
     hrc = H5Sclose (dataspace);
-	VRFY((hrc >= 0), "");
+    VRFY((hrc >= 0), "");
 
-	hrc = H5Sclose (memspace);
-	VRFY((hrc >= 0), "");
+    hrc = H5Sclose (memspace);
+    VRFY((hrc >= 0), "");
 
     hrc = H5Fclose(*file_id);
     VRFY((hrc >= 0), "");
@@ -306,7 +310,7 @@ parallel_access_dataset(const char *filename, int nchunks, access_type action, h
 
     /* verify file size */
     filesize = get_filesize(filename);
-    est_filesize = nchunks*CHUNKSIZE*sizeof(unsigned char);
+    est_filesize = nchunks*CHUNK_SIZE*sizeof(unsigned char);
     VRFY((filesize >= est_filesize), "file size check");
 
     /* Can close some plists */
@@ -328,32 +332,30 @@ parallel_access_dataset(const char *filename, int nchunks, access_type action, h
  * 3. it returns correct values when the whole dataset has been written in an
  *    interleaved pattern.
  */
-void verify_data(const char *filename, int nchunks, write_type write_pattern, int close, hid_t *file_id, hid_t *dataset)
+static void
+verify_data(const char *filename, int chunk_factor, write_type write_pattern, int close, hid_t *file_id, hid_t *dataset)
 {
     /* HDF5 gubbins */
     hid_t    dataspace, memspace;     /* HDF5 file identifier */
     hid_t    access_plist;         /* HDF5 ID for file access property list */
     herr_t   hrc;                  /* HDF5 return code */
 
-    hsize_t     chunk_dims[1] ={CHUNKSIZE};
+    hsize_t     chunk_dims[1] ={CHUNK_SIZE};
     hsize_t     count[1];
     hsize_t     stride[1];
     hsize_t     block[1];
     hsize_t     offset[1];            /* Selection offset within dataspace */
     /* Variables used in reading data back */
-    char         buffer[CHUNKSIZE];
+    char         buffer[CHUNK_SIZE];
     int         value, i;
-    int         index, current;
-
-    /* MPI Gubbins */
-    MPI_Offset  filesize,	    /* actual file size */
-		est_filesize;	    /* estimated file size */
-    int         mpierr;
-
+    int         index;
+    long        nchunks;
     /* Initialize MPI */
     MPI_Comm_size(MPI_COMM_WORLD,&mpi_size);
     MPI_Comm_rank(MPI_COMM_WORLD,&mpi_rank);
 
+    nchunks=chunk_factor*mpi_size;
+
     /* Set up MPIO file access property lists */
     access_plist  = H5Pcreate(H5P_FILE_ACCESS);
     VRFY((access_plist >= 0), "");
@@ -369,7 +371,7 @@ void verify_data(const char *filename, int nchunks, write_type write_pattern, in
 
     /* Open dataset*/
     if (*dataset<0){
-        *dataset = H5Dopen2(*file_id, DATASETNAME, H5P_DEFAULT);
+        *dataset = H5Dopen2(*file_id, DSET_NAME, H5P_DEFAULT);
         VRFY((*dataset >= 0), "");
     }
 
@@ -384,8 +386,8 @@ void verify_data(const char *filename, int nchunks, write_type write_pattern, in
     stride[0] = 1;
     block[0] = chunk_dims[0];
     for (i=0; i<nchunks; i++){
-	/* reset buffer values */
-	memset(buffer, -1, CHUNKSIZE);
+  /* reset buffer values */
+  memset(buffer, -1, CHUNK_SIZE);
 
         offset[0] = i*chunk_dims[0];
 
@@ -397,31 +399,30 @@ void verify_data(const char *filename, int nchunks, write_type write_pattern, in
         VRFY((hrc >= 0), "H5Dread");
 
         /* set expected value according the write pattern */
-	switch (write_pattern) {
-	    case all:
-		value = i%mpi_size + 1;
-		break;
-	    case none:
-		value = 0;
-		break;
+  switch (write_pattern) {
+      case all:
+    value = i%mpi_size + 1;
+    break;
+      case none:
+    value = 0;
+    break;
             case sec_last:
-		if (i==(nchunks-2))
-		    value = 100;
-		else
-		    value = 0;
-	}
+    if (i==nchunks-2)
+        value = 100;
+    else
+        value = 0;
+  }
 
         /* verify content of the chunk */
-        for (index = 0; index < CHUNKSIZE; index++)
+        for (index = 0; index < CHUNK_SIZE; index++)
             VRFY((buffer[index] == value), "data verification");
-
     }
 
     hrc = H5Sclose (dataspace);
-	VRFY((hrc >= 0), "");
+  VRFY((hrc >= 0), "");
 
-	hrc = H5Sclose (memspace);
-	VRFY((hrc >= 0), "");
+  hrc = H5Sclose (memspace);
+  VRFY((hrc >= 0), "");
 
     /* Can close some plists */
     hrc = H5Pclose(access_plist);
@@ -473,34 +474,38 @@ test_chunk_alloc(void)
 
     file_id = dataset = -1;
 
+    /* Initialize MPI */
+    MPI_Comm_size(MPI_COMM_WORLD,&mpi_size);
+    MPI_Comm_rank(MPI_COMM_WORLD,&mpi_rank);
+
     filename = GetTestParameters();
     if (VERBOSE_MED)
-	printf("Extend Chunked allocation test on file %s\n", filename);
+  printf("Extend Chunked allocation test on file %s\n", filename);
 
     /* Case 1 */
     /* Create chunked dataset without writing anything.*/
-    create_chunked_dataset(filename, DSETCHUNKS, none);
+    create_chunked_dataset(filename, CHUNK_FACTOR, none);
     /* reopen dataset in parallel and check for file size */
-    parallel_access_dataset(filename, DSETCHUNKS, open_only, &file_id, &dataset);
+    parallel_access_dataset(filename, CHUNK_FACTOR, open_only, &file_id, &dataset);
     /* reopen dataset in parallel, read and verify the data */
-    verify_data(filename, DSETCHUNKS, none, CLOSE, &file_id, &dataset);
+    verify_data(filename, CHUNK_FACTOR, none, CLOSE, &file_id, &dataset);
 
     /* Case 2 */
     /* Create chunked dataset without writing anything */
     create_chunked_dataset(filename, 20, none);
     /* reopen dataset in parallel and only extend it */
-    parallel_access_dataset(filename, DSETCHUNKS, extend_only, &file_id, &dataset);
+    parallel_access_dataset(filename, CHUNK_FACTOR, extend_only, &file_id, &dataset);
     /* reopen dataset in parallel, read and verify the data */
-    verify_data(filename, DSETCHUNKS, none, CLOSE, &file_id, &dataset);
+    verify_data(filename, CHUNK_FACTOR, none, CLOSE, &file_id, &dataset);
 
     /* Case 3 */
     /* Create chunked dataset and write in the second to last chunk */
-    create_chunked_dataset(filename, DSETCHUNKS, sec_last);
+    create_chunked_dataset(filename, CHUNK_FACTOR, sec_last);
     /* Reopen dataset in parallel, read and verify the data. The file and dataset are not closed*/
-    verify_data(filename, DSETCHUNKS, sec_last, NO_CLOSE, &file_id, &dataset);
+    verify_data(filename, CHUNK_FACTOR, sec_last, NO_CLOSE, &file_id, &dataset);
     /* All processes write in all the chunks in a interleaved way */
-    parallel_access_dataset(filename, DSETCHUNKS, write_all, &file_id, &dataset);
+    parallel_access_dataset(filename, CHUNK_FACTOR, write_all, &file_id, &dataset);
     /* reopen dataset in parallel, read and verify the data */
-    verify_data(filename, DSETCHUNKS, all, CLOSE, &file_id, &dataset);
+    verify_data(filename, CHUNK_FACTOR, all, CLOSE, &file_id, &dataset);
 
 }
