@@ -411,9 +411,13 @@ int main(int argc, char **argv)
     AddTest("cngrpw", collective_group_write, NULL,
       "collective group and dataset write", &collngroups_params);
     AddTest("ingrpr", independent_group_read, NULL,
-      "independent group and dataset read", &collngroups_params);
+	    "independent group and dataset read", &collngroups_params);
+#ifndef H5_HAVE_WIN32_API
     AddTest("bigdset", big_dataset, NULL,
             "big dataset test", PARATESTFILE);
+#else
+    printf("big dataset test will be skipped on Windows (JIRA HDDFV-8064)\n");
+#endif
     AddTest("fill", dataset_fillvalue, NULL,
       "dataset fill value", PARATESTFILE);
 
@@ -436,7 +440,7 @@ int main(int argc, char **argv)
   "linked chunk collective IO without optimization",PARATESTFILE);
     AddTest((mpi_size < 3)? "-cchunk6" : "cchunk6",
   coll_chunk6,NULL,
-  "multi-chunk collective IO without optimization",PARATESTFILE);
+  "multi-chunk collective IO with direct request",PARATESTFILE);
     AddTest((mpi_size < 3)? "-cchunk7" : "cchunk7",
   coll_chunk7,NULL,
   "linked chunk collective IO with optimization",PARATESTFILE);
@@ -502,6 +506,10 @@ int main(int argc, char **argv)
             "test actual io mode proprerty",
             PARATESTFILE);
 
+    AddTest("nocolcause", no_collective_cause_tests, NULL,
+            "test cause for broken collective io",
+            PARATESTFILE);
+
     if((mpi_size < 2) && MAINPROCESS) {
         printf("File Image Ops daisy chain test needs at least 2 processes.\n");
         printf("File Image Ops daisy chain test will be skipped \n");
@@ -509,16 +517,6 @@ int main(int argc, char **argv)
     AddTest((mpi_size < 2)? "-fiodc" : "fiodc", file_image_daisy_chain_test, NULL,
             "file image ops daisy chain", NULL);
 
-    /* Display testing information */
-    TestInfo(argv[0]);
-
-    /* setup file access property list */
-    fapl = H5Pcreate (H5P_FILE_ACCESS);
-    H5Pset_fapl_mpio(fapl, MPI_COMM_WORLD, MPI_INFO_NULL);
-
-    /* Parse command line arguments */
-    TestParseCmdLine(argc, argv);
-
     if((mpi_size < 2)&& MAINPROCESS ) {
 	printf("Atomicity tests need at least 2 processes to participate\n");
 	printf("8 is more recommended.. Atomicity tests will be skipped \n");
@@ -531,6 +529,20 @@ int main(int argc, char **argv)
                 "dataset atomic updates", PARATESTFILE);
     }
 
+    AddTest("denseattr", test_dense_attr, NULL,
+	    "Store Dense Attributes", NULL);
+
+
+    /* Display testing information */
+    TestInfo(argv[0]);
+
+    /* setup file access property list */
+    fapl = H5Pcreate (H5P_FILE_ACCESS);
+    H5Pset_fapl_mpio(fapl, MPI_COMM_WORLD, MPI_INFO_NULL);
+
+    /* Parse command line arguments */
+    TestParseCmdLine(argc, argv);
+
     if (facc_type == FACC_MPIPOSIX && MAINPROCESS){
   printf("===================================\n"
          "   Using MPIPOSIX driver\n"
