@@ -169,11 +169,25 @@ enum H5TEST_COLL_CHUNK_API {API_NONE=0,API_LINK_HARD,
 #define TEST_ACTUAL_IO_MULTI_CHUNK_COL                  3
 #define TEST_ACTUAL_IO_MULTI_CHUNK_MIX                  4
 #define TEST_ACTUAL_IO_MULTI_CHUNK_MIX_DISAGREE         5
-#define TEST_ACTUAL_IO_MULTI_CHUNK_NO_OPT_IND           6
-#define TEST_ACTUAL_IO_MULTI_CHUNK_NO_OPT_COL           7
-#define TEST_ACTUAL_IO_MULTI_CHUNK_NO_OPT_MIX_DISAGREE  8 
-#define TEST_ACTUAL_IO_LINK_CHUNK                       9
-#define TEST_ACTUAL_IO_CONTIGUOUS                       10
+#define TEST_ACTUAL_IO_DIRECT_MULTI_CHUNK_IND           6
+#define TEST_ACTUAL_IO_DIRECT_MULTI_CHUNK_COL           7
+#define TEST_ACTUAL_IO_LINK_CHUNK                       8
+#define TEST_ACTUAL_IO_CONTIGUOUS                       9
+
+/* Definitions of the selection mode for the no_collective_cause_tests function. */
+#define TEST_COLLECTIVE                                 0x001
+#define TEST_SET_INDEPENDENT                            0x002 
+#define TEST_DATATYPE_CONVERSION                        0x004
+#define TEST_DATA_TRANSFORMS                            0x008
+#define TEST_SET_MPIPOSIX                               0x010
+#define TEST_NOT_SIMPLE_OR_SCALAR_DATASPACES            0x020
+#define TEST_POINT_SELECTIONS                           0x040
+#define TEST_NOT_CONTIGUOUS_OR_CHUNKED_DATASET_COMPACT  0x080
+#define TEST_NOT_CONTIGUOUS_OR_CHUNKED_DATASET_EXTERNAL 0x100
+#define TEST_FILTERS                                    0x200
+/* TEST_FILTERS will take place of this after supporting mpio + filter for 
+ * H5Dcreate and H5Dwrite */
+#define TEST_FILTERS_READ                               0x400
 
 /* Don't erase these lines, they are put here for debugging purposes */
 /*
@@ -239,6 +253,7 @@ void extend_readInd(void);
 void extend_readAll(void);
 void none_selection_chunk(void);
 void actual_io_mode_tests(void);
+void no_collective_cause_tests(void);
 void test_chunk_alloc(void);
 void test_filter_read(void);
 void compact_dataset(void);
@@ -273,6 +288,7 @@ void file_image_daisy_chain_test(void);
 #ifdef H5_HAVE_FILTER_DEFLATE
 void compress_readAll(void);
 #endif /* H5_HAVE_FILTER_DEFLATE */
+void test_dense_attr(void);
 
 /* commonly used prototypes */
 hid_t create_faccess_plist(MPI_Comm comm, MPI_Info info, int l_facc_type, hbool_t use_gpfs);
