@@ -18,6 +18,7 @@
 #include <memory.h>
 #include "h5diff.h"
 #include "h5diff_common.h"
+#include "h5tools.h"
 #include "h5tools_utils.h"
 
 
@@ -81,11 +82,14 @@ int main(int argc, const char *argv[])
 
     h5tools_setprogname(PROGRAMNAME);
     h5tools_setstatus(EXIT_SUCCESS);
+
+    /* Initialize h5tools lib */
+    h5tools_init();
+
     /*-------------------------------------------------------------------------
     * process the command-line
     *-------------------------------------------------------------------------
     */
-
     parse_command_line(argc, argv, &fname1, &fname2, &objname1, &objname2, &options);
 
     /*-------------------------------------------------------------------------
