@@ -542,6 +542,56 @@ done:
     return ret;
 }
 
+/*-------------------------------------------------------------------------
+ * Function:    attr_iteration
+ *
+ * Purpose:     Iterate and display attributes within the specified group
+ *
+ * Return:      void
+ *
+ *-------------------------------------------------------------------------
+ */
+void
+attr_iteration(hid_t gid, unsigned attr_crt_order_flags)
+{
+    /* attribute iteration: if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
+       in the group for attributes, then, sort by creation order, otherwise by name */
+
+    if((sort_by == H5_INDEX_CRT_ORDER) && (attr_crt_order_flags & H5P_CRT_ORDER_TRACKED)) {
+        if(H5Aiterate2(gid, sort_by, sort_order, NULL, dump_attr_cb, NULL) < 0) {
+            error_msg("error getting attribute information\n");
+            h5tools_setstatus(EXIT_FAILURE);
+        } /* end if */
+    } /* end if */
+    else {
+        if(H5Aiterate2(gid, H5_INDEX_NAME, sort_order, NULL, dump_attr_cb, NULL) < 0) {
+            error_msg("error getting attribute information\n");
+            h5tools_setstatus(EXIT_FAILURE);
+        } /* end if */
+    } /* end else */
+}
+
+/*-------------------------------------------------------------------------
+ * Function:    link_iteration
+ *
+ * Purpose:     Iterate and display links within the specified group
+ *
+ * Return:      void
+ *
+ *-------------------------------------------------------------------------
+ */
+void
+link_iteration(hid_t gid, unsigned crt_order_flags)
+{
+
+    /* if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
+       in the group, then, sort by creation order, otherwise by name */
+    if((sort_by == H5_INDEX_CRT_ORDER) && (crt_order_flags & H5P_CRT_ORDER_TRACKED))
+        H5Literate(gid, sort_by, sort_order, NULL, dump_all_cb, NULL);
+    else
+        H5Literate(gid, H5_INDEX_NAME, sort_order, NULL, dump_all_cb, NULL);
+}
+
 /*-------------------------------------------------------------------------
  * Function:    dump_named_datatype
  *
@@ -659,21 +709,7 @@ dump_named_datatype(hid_t tid, const char *name)
     /* print attributes */
     dump_indent += COL;
 
-    /* attribute iteration: if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
-      in the datatype's create property list for attributes, then, sort by creation order, otherwise by name */
-
-    if((sort_by == H5_INDEX_CRT_ORDER) && (attr_crt_order_flags & H5P_CRT_ORDER_TRACKED)) {
-        if(H5Aiterate2(tid, sort_by, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-            error_msg("error getting attribute information\n");
-            h5tools_setstatus(EXIT_FAILURE);
-        } /* end if */
-    } /* end if */
-    else {
-        if(H5Aiterate2(tid, H5_INDEX_NAME, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-            error_msg("error getting attribute information\n");
-            h5tools_setstatus(EXIT_FAILURE);
-        } /* end if */
-    } /* end else */
+    attr_iteration(tid, attr_crt_order_flags);
 
     dump_indent -= COL;
 
@@ -829,53 +865,13 @@ dump_group(hid_t gid, const char *name)
         }
         else {
             found_obj->displayed = TRUE;
-            /* attribute iteration: if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
-               in the group for attributes, then, sort by creation order, otherwise by name */
-
-            if((sort_by == H5_INDEX_CRT_ORDER) && (attr_crt_order_flags & H5P_CRT_ORDER_TRACKED)) {
-                if(H5Aiterate2(gid, sort_by, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-                    error_msg("error getting attribute information\n");
-                    h5tools_setstatus(EXIT_FAILURE);
-                } /* end if */
-            } /* end if */
-            else {
-                if(H5Aiterate2(gid, H5_INDEX_NAME, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-                    error_msg("error getting attribute information\n");
-                    h5tools_setstatus(EXIT_FAILURE);
-                } /* end if */
-            } /* end else */
-
-            /* if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
-               in the group, then, sort by creation order, otherwise by name */
-            if((sort_by == H5_INDEX_CRT_ORDER) && (crt_order_flags & H5P_CRT_ORDER_TRACKED))
-                H5Literate(gid, sort_by, sort_order, NULL, dump_all_cb, NULL);
-            else
-                H5Literate(gid, H5_INDEX_NAME, sort_order, NULL, dump_all_cb, NULL);
+            attr_iteration(gid, attr_crt_order_flags);
+            link_iteration(gid, crt_order_flags);
         }
     }
     else {
-        /* attribute iteration: if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
-           in the group for attributes, then, sort by creation order, otherwise by name */
-
-        if((sort_by == H5_INDEX_CRT_ORDER) && (attr_crt_order_flags & H5P_CRT_ORDER_TRACKED)) {
-            if(H5Aiterate2(gid, sort_by, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-                error_msg("error getting attribute information\n");
-                h5tools_setstatus(EXIT_FAILURE);
-            } /* end if */
-        } /* end if */
-        else {
-            if(H5Aiterate2(gid, H5_INDEX_NAME, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-                error_msg("error getting attribute information\n");
-                h5tools_setstatus(EXIT_FAILURE);
-            } /* end if */
-        } /* end else */
-
-         /* if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
-            in the group, then, sort by creation order, otherwise by name */
-        if((sort_by == H5_INDEX_CRT_ORDER) && (crt_order_flags & H5P_CRT_ORDER_TRACKED))
-            H5Literate(gid, sort_by, sort_order, NULL, dump_all_cb, NULL);
-        else
-            H5Literate(gid, H5_INDEX_NAME, sort_order, NULL, dump_all_cb, NULL);
+        attr_iteration(gid, attr_crt_order_flags);
+        link_iteration(gid, crt_order_flags);
     }
 
     dump_indent -= COL;
@@ -1050,20 +1046,7 @@ dump_dataset(hid_t did, const char *name, struct subset_t *sset)
     H5Tclose(type);
 
     if (!bin_output) {
-       /* attribute iteration: if there is a request to do H5_INDEX_CRT_ORDER and tracking order is set
-        in the group for attributes, then, sort by creation order, otherwise by name */
-        if((sort_by == H5_INDEX_CRT_ORDER) && (attr_crt_order_flags & H5P_CRT_ORDER_TRACKED)) {
-            if(H5Aiterate2(did, sort_by, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-                error_msg("error getting attribute information\n");
-                h5tools_setstatus(EXIT_FAILURE);
-            } /* end if */
-        } /* end if */
-        else {
-            if(H5Aiterate2(did, H5_INDEX_NAME, sort_order, NULL, dump_attr_cb, NULL) < 0) {
-                error_msg("error getting attribute information\n");
-                h5tools_setstatus(EXIT_FAILURE);
-            } /* end if */
-        } /* end else */
+        attr_iteration(did, attr_crt_order_flags);
     }
     ctx.indent_level--;
     dump_indent -= COL;
@@ -1185,23 +1168,23 @@ dump_fcpl(hid_t fid)
     * SUPER_BLOCK
     *-------------------------------------------------------------------------
     */
-    HDfprintf(rawoutstream, "\n%s %s\n",SUPER_BLOCK, BEGIN);
+    PRINTSTREAM(rawoutstream, "\n%s %s\n",SUPER_BLOCK, BEGIN);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %u\n","SUPERBLOCK_VERSION", super);
+    PRINTSTREAM(rawoutstream, "%s %u\n","SUPERBLOCK_VERSION", super);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %u\n","FREELIST_VERSION", freelist);
+    PRINTSTREAM(rawoutstream, "%s %u\n","FREELIST_VERSION", freelist);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %u\n","SYMBOLTABLE_VERSION", stab);
+    PRINTSTREAM(rawoutstream, "%s %u\n","SYMBOLTABLE_VERSION", stab);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %u\n","OBJECTHEADER_VERSION", shhdr);
+    PRINTSTREAM(rawoutstream, "%s %u\n","OBJECTHEADER_VERSION", shhdr);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream,"%s %Hd\n","OFFSET_SIZE", (long long)off_size);
+    PRINTSTREAM(rawoutstream,"%s %Hd\n","OFFSET_SIZE", (long long)off_size);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream,"%s %Hd\n","LENGTH_SIZE", (long long)len_size);
+    PRINTSTREAM(rawoutstream,"%s %Hd\n","LENGTH_SIZE", (long long)len_size);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %u\n","BTREE_RANK", sym_ik);
+    PRINTSTREAM(rawoutstream, "%s %u\n","BTREE_RANK", sym_ik);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %d\n","BTREE_LEAF", sym_lk);
+    PRINTSTREAM(rawoutstream, "%s %d\n","BTREE_LEAF", sym_lk);
 
 #ifdef SHOW_FILE_DRIVER
     if (H5FD_CORE==fdriver)
@@ -1232,23 +1215,23 @@ dump_fcpl(hid_t fid)
     /* Take out this because the driver used can be different from the
      * standard output. */
     /*indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %s\n","FILE_DRIVER", dname);*/
+    PRINTSTREAM(rawoutstream, "%s %s\n","FILE_DRIVER", dname);*/
 #endif
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s %u\n","ISTORE_K", istore_ik);
+    PRINTSTREAM(rawoutstream, "%s %u\n","ISTORE_K", istore_ik);
 
     /*-------------------------------------------------------------------------
     * USER_BLOCK
     *-------------------------------------------------------------------------
     */
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "USER_BLOCK %s\n",BEGIN);
+    PRINTSTREAM(rawoutstream, "USER_BLOCK %s\n",BEGIN);
     indentation(dump_indent + COL + COL);
-    HDfprintf(rawoutstream,"%s %Hu\n","USERBLOCK_SIZE", userblock);
+    PRINTSTREAM(rawoutstream,"%s %Hu\n","USERBLOCK_SIZE", userblock);
     indentation(dump_indent + COL);
-    HDfprintf(rawoutstream, "%s\n",END);
+    PRINTSTREAM(rawoutstream, "%s\n",END);
 
-    HDfprintf(rawoutstream, "%s",END);
+    PRINTSTREAM(rawoutstream, "%s",END);
 }
 
 /*-------------------------------------------------------------------------
@@ -1267,7 +1250,7 @@ dump_fcpl(hid_t fid)
 void
 dump_fcontents(hid_t fid)
 {
-    HDfprintf(rawoutstream, "%s %s\n",FILE_CONTENTS, BEGIN);
+    PRINTSTREAM(rawoutstream, "%s %s\n",FILE_CONTENTS, BEGIN);
 
     /* special case of unamed types in root group */
     if (unamedtype) {
@@ -1275,14 +1258,14 @@ dump_fcontents(hid_t fid)
 
         for (u = 0; u < type_table->nobjs; u++) {
             if (!type_table->objs[u].recorded)
-                HDfprintf(rawoutstream, " %-10s /#"H5_PRINTF_HADDR_FMT"\n", "datatype", type_table->objs[u].objno);
+                PRINTSTREAM(rawoutstream, " %-10s /#"H5_PRINTF_HADDR_FMT"\n", "datatype", type_table->objs[u].objno);
         }
     }
 
     /* print objects in the files */
     h5trav_print(fid);
 
-    HDfprintf(rawoutstream, " %s\n",END);
+    PRINTSTREAM(rawoutstream, " %s\n",END);
 }
 
 /*-------------------------------------------------------------------------
@@ -1308,7 +1291,7 @@ handle_attributes(hid_t fid, const char *attr, void UNUSED * data, int UNUSED pe
     hid_t  oid = -1;
     hid_t  attr_id = -1;
     char *obj_name;
-    const char *attr_name;
+    char *attr_name;
     int j;
     h5tools_str_t buffer;          /* string into which to render   */
     h5tools_context_t ctx;            /* print context  */
@@ -1323,7 +1306,7 @@ handle_attributes(hid_t fid, const char *attr, void UNUSED * data, int UNUSED pe
 
     /* find the last / */
     while(j >= 0) {
-        if (attr[j] == '/')
+        if (attr[j] == '/' && (j==0 || (j>0 && attr[j-1]!='\\'))) 
             break;
         j--;
     }
@@ -1358,9 +1341,12 @@ handle_attributes(hid_t fid, const char *attr, void UNUSED * data, int UNUSED pe
     string_dataformat.do_escape = display_escape;
     outputformat = &string_dataformat;
 
-    attr_name = attr + j + 1;
+    //attr_name = attr + j + 1;
+	// need to replace escape characters
+	attr_name = h5tools_str_replace(attr + j + 1, "\\/", "/");
 
-    /* Open the object with the attribute */
+
+    /* handle error case: cannot open the object with the attribute */
     if((oid = H5Oopen(fid, obj_name, H5P_DEFAULT)) < 0) {
         /* setup */
         HDmemset(&buffer, 0, sizeof(h5tools_str_t));
@@ -1401,7 +1387,7 @@ handle_attributes(hid_t fid, const char *attr, void UNUSED * data, int UNUSED pe
     attr_data_output = display_attr_data;
 
     h5dump_type_table = type_table;
-    h5tools_dump_attribute(rawoutstream, outputformat, &ctx, oid, attr, attr_id, display_ai, display_char);
+    h5tools_dump_attribute(rawoutstream, outputformat, &ctx, oid, attr_name, attr_id, display_ai, display_char);
     h5dump_type_table = NULL;
 
     if(attr_id < 0) {
@@ -1414,6 +1400,7 @@ handle_attributes(hid_t fid, const char *attr, void UNUSED * data, int UNUSED pe
     } /* end if */
 
     HDfree(obj_name);
+	HDfree(attr_name);
     dump_indent -= COL;
     return;
 
@@ -1421,6 +1408,9 @@ error:
     h5tools_setstatus(EXIT_FAILURE);
     if(obj_name)
         HDfree(obj_name);
+		
+	if (attr_name)
+		HDfree(attr_name);
 
     H5E_BEGIN_TRY {
         H5Oclose(oid);
@@ -1467,15 +1457,18 @@ handle_datasets(hid_t fid, const char *dset, void *data, int pe, const char *dis
 
     if(sset) {
         unsigned int i;
+        unsigned int ndims;
         hid_t sid = H5Dget_space(dsetid);
-        int ndims = H5Sget_simple_extent_ndims(sid);
+        int ndims_res = H5Sget_simple_extent_ndims(sid);
 
         H5Sclose(sid);
-        if(ndims < 0) {
+        if(ndims_res < 0) {
             error_msg("H5Sget_simple_extent_ndims failed\n");
             h5tools_setstatus(EXIT_FAILURE);
             return;
         }
+        else
+            ndims = ndims_res;
 
         if(!sset->start.data || !sset->stride.data || !sset->count.data || !sset->block.data) {
             /* they didn't specify a ``stride'' or ``block''. default to 1 in all
@@ -1557,12 +1550,12 @@ handle_datasets(hid_t fid, const char *dset, void *data, int pe, const char *dis
 
         if(found_obj) {
             if (found_obj->displayed) {
-                HDfprintf(rawoutstream, "\n");
+                PRINTVALSTREAM(rawoutstream, "\n");
                 indentation(dump_indent);
                 begin_obj(h5tools_dump_header_format->datasetbegin, real_name, h5tools_dump_header_format->datasetblockbegin);
-                HDfprintf(rawoutstream, "\n");
+                PRINTVALSTREAM(rawoutstream, "\n");
                 indentation(dump_indent + COL);
-                HDfprintf(rawoutstream, "%s \"%s\"\n", HARDLINK, found_obj->objname);
+                PRINTSTREAM(rawoutstream, "%s \"%s\"\n", HARDLINK, found_obj->objname);
                 indentation(dump_indent);
                 end_obj(h5tools_dump_header_format->datasetend, h5tools_dump_header_format->datasetblockend);
             } 
@@ -1614,9 +1607,9 @@ handle_groups(hid_t fid, const char *group, void UNUSED *data, int pe, const cha
 
     if((gid = H5Gopen2(fid, group, H5P_DEFAULT)) < 0) {
         if (pe) {
-            HDfprintf(rawoutstream, "\n");
+            PRINTVALSTREAM(rawoutstream, "\n");
             begin_obj(h5tools_dump_header_format->groupbegin, real_name, h5tools_dump_header_format->groupblockbegin);
-            HDfprintf(rawoutstream, "\n");
+            PRINTVALSTREAM(rawoutstream, "\n");
             indentation(COL);
             error_msg("unable to open group \"%s\"\n", real_name);
             end_obj(h5tools_dump_header_format->groupend, h5tools_dump_header_format->groupblockend);
@@ -1671,15 +1664,15 @@ handle_links(hid_t fid, const char *links, void UNUSED * data, int UNUSED pe, co
     } 
     else {
         char *buf = (char *)HDmalloc(linfo.u.val_size);
-        HDfprintf(rawoutstream, "\n");
+        PRINTVALSTREAM(rawoutstream, "\n");
 
         switch(linfo.type) {
         case H5L_TYPE_SOFT:    /* Soft link */
             begin_obj(h5tools_dump_header_format->softlinkbegin, links, h5tools_dump_header_format->softlinkblockbegin);
-            HDfprintf(rawoutstream, "\n");
+            PRINTVALSTREAM(rawoutstream, "\n");
             indentation(COL);
             if(H5Lget_val(fid, links, buf, linfo.u.val_size, H5P_DEFAULT) >= 0)
-                HDfprintf(rawoutstream, "LINKTARGET \"%s\"\n", buf);
+                PRINTSTREAM(rawoutstream, "LINKTARGET \"%s\"\n", buf);
             else {
                 error_msg("h5dump error: unable to get link value for \"%s\"\n", links);
                 h5tools_setstatus(EXIT_FAILURE);
@@ -1689,21 +1682,21 @@ handle_links(hid_t fid, const char *links, void UNUSED * data, int UNUSED pe, co
 
         case H5L_TYPE_EXTERNAL:
             begin_obj(h5tools_dump_header_format->udlinkbegin, links, h5tools_dump_header_format->udlinkblockbegin);
-            HDfprintf(rawoutstream, "\n");
+            PRINTVALSTREAM(rawoutstream, "\n");
             indentation(COL);
             begin_obj(h5tools_dump_header_format->extlinkbegin, links, h5tools_dump_header_format->extlinkblockbegin);
-            HDfprintf(rawoutstream, "\n");
+            PRINTVALSTREAM(rawoutstream, "\n");
             if(H5Lget_val(fid, links, buf, linfo.u.val_size, H5P_DEFAULT) >= 0) {
                 const char *elink_file;
                 const char *elink_path;
 
                 if(H5Lunpack_elink_val(buf, linfo.u.val_size, NULL, &elink_file, &elink_path)>=0) {
                     indentation(COL);
-                    HDfprintf(rawoutstream, "LINKCLASS %d\n", linfo.type);
+                    PRINTSTREAM(rawoutstream, "LINKCLASS %d\n", linfo.type);
                     indentation(COL);
-                    HDfprintf(rawoutstream, "TARGETFILE \"%s\"\n", elink_file);
+                    PRINTSTREAM(rawoutstream, "TARGETFILE \"%s\"\n", elink_file);
                     indentation(COL);
-                    HDfprintf(rawoutstream, "TARGETPATH \"%s\"\n", elink_path);
+                    PRINTSTREAM(rawoutstream, "TARGETPATH \"%s\"\n", elink_path);
                 } 
                 else {
                     error_msg("h5dump error: unable to unpack external link value for \"%s\"\n", links);
@@ -1719,12 +1712,12 @@ handle_links(hid_t fid, const char *links, void UNUSED * data, int UNUSED pe, co
 
         default:
             begin_obj(h5tools_dump_header_format->udlinkbegin, links, h5tools_dump_header_format->udlinkblockbegin);
-            HDfprintf(rawoutstream, "\n");
+            PRINTVALSTREAM(rawoutstream, "\n");
             indentation(COL);
             begin_obj(h5tools_dump_header_format->udlinkbegin, links, h5tools_dump_header_format->udlinkblockbegin);
-            HDfprintf(rawoutstream, "\n");
+            PRINTVALSTREAM(rawoutstream, "\n");
             indentation(COL);
-            HDfprintf(rawoutstream, "LINKCLASS %d\n", linfo.type);
+            PRINTSTREAM(rawoutstream, "LINKCLASS %d\n", linfo.type);
             end_obj(h5tools_dump_header_format->udlinkend, h5tools_dump_header_format->udlinkblockend);
             break;
         } /* end switch */
@@ -1778,9 +1771,9 @@ handle_datatypes(hid_t fid, const char *type, void UNUSED * data, int pe, const
         if(idx == type_table->nobjs) {
             if (pe) {
                 /* unknown type */
-                HDfprintf(rawoutstream, "\n");
+                PRINTVALSTREAM(rawoutstream, "\n");
                 begin_obj(h5tools_dump_header_format->datatypebegin, real_name, h5tools_dump_header_format->datatypeblockbegin);
-                HDfprintf(rawoutstream, "\n");
+                PRINTVALSTREAM(rawoutstream, "\n");
                 indentation(COL);
                 error_msg("unable to open datatype \"%s\"\n", real_name);
                 end_obj(h5tools_dump_header_format->datatypeend, h5tools_dump_header_format->datatypeblockend);
