@@ -732,6 +732,7 @@ int do_copy_objects(hid_t fidin,
     void     *hslab_buf=NULL;   /* hyperslab buffer for raw data */
     int      has_filter;        /* current object has a filter */
     int      req_filter;        /* there was a request for a filter */
+    int      req_obj_layout=0;  /* request layout to current object */
     unsigned crt_order_flags;   /* group creation order flag */
     unsigned i;
     unsigned u;
@@ -863,6 +864,22 @@ int do_copy_objects(hid_t fidin,
                 }
             }
 
+            /* check if layout change requested individual object */
+            if (options->layout_g != H5D_LAYOUT_ERROR)
+            {
+	            pack_info_t *pckinfo;
+	            /* any dataset is specified */
+	            if (options->op_tbl->nelems > 0)
+	            {
+	                /* check if object exist */
+	                pckinfo = options_get_object (travt->objs[i].name, options->op_tbl);
+	                if (pckinfo)
+	                {
+	                    req_obj_layout = 1;
+	                }
+	            }
+            }
+
             /* early detection of references */
             if((dset_in = H5Dopen2(fidin, travt->objs[i].name, H5P_DEFAULT)) < 0)
                 goto error;
@@ -959,16 +976,6 @@ int do_copy_objects(hid_t fidin,
                         /* get the storage size of the input dataset */
                         dsize_in=H5Dget_storage_size(dset_in);
 
-                        /* check for small size datasets (less than 1k) except 
-                         * changing to COMPACT. For the reference, COMPACT is limited
-                         * by size 64K by library.
-                         */
-                        if (options->layout_g != H5D_COMPACT)
-                        {
-                            if ( size_dset < options->min_comp )
-                                apply_s=0;
-                        }
-
                         /* apply the filter */
                         if (apply_s)
                         {
@@ -982,6 +989,9 @@ int do_copy_objects(hid_t fidin,
                                 goto error;
                         }
 
+                    /* only if layout change requested for entire file or 
+                     * individual obj */
+                    if (options->all_layout > 0 || req_obj_layout == 1)
                         /*------------------------------------------------- 
                          * Unset the unlimited max dims if convert to other
                          * than chunk layouts, because unlimited max dims
@@ -1500,7 +1510,7 @@ static void print_dataset_info(hid_t dcpl_id,
         printf(FORMAT_OBJ,"dset",objname );
     else
     {
-        char str[255], temp[20];
+        char str[255], temp[28];
         HDstrcpy(str,"dset     ");
         HDstrcat(str,strfilter);
         sprintf(temp,"  (%.3f:1)",ratio);
