@@ -30,7 +30,7 @@
 #define DATASET_NAME	"DATASET_NAME"
 #define GROUP_NAME	"GROUP"
 #define ATTR_NAME	"ATTR"
-#define NUM_GRPS       	35000
+#define NUM_GRPS 	35000
 #define NUM_ATTRS	100
 
 /*
@@ -40,11 +40,17 @@
  */
 static void gen_file(void)
 {
-    int     	ret, i;
-    hid_t	fapl, gid;
-    hid_t   	file, type_id, space_id, attr_id, dset_id;
-    char	name[30];
-    char	attrname[30];
+    hid_t	fapl; 	/* File access property */
+    hid_t   file;	/* File id */
+    hid_t	gid;	/* Group id */
+    hid_t	type_id;	/* Datatype id */
+    hid_t	space_id; 	/* Dataspace id */
+    hid_t	attr_id; 	/* Attribute id */
+    hid_t	dset_id;	/* Dataset id */
+    char	name[30];	/* Group name */
+    char	attrname[30];	/* Attribute name */
+    int     ret;	/* Return value */
+    int 	i;	/* Local index variable */
 
     fapl = H5Pcreate(H5P_FILE_ACCESS);
     ret = H5Pset_libver_bounds(fapl, H5F_LIBVER_LATEST, H5F_LIBVER_LATEST);
