@@ -21,23 +21,6 @@
 #include "h5diff.h"
 #include "ph5diff.h"
 
-/*
- * Debug printf macros. The prefix allows output filtering by test scripts.
- */
-#ifdef H5DIFF_DEBUG
-#define h5diffdebug(x) HDfprintf(stderr, "h5diff debug: " x)
-#define h5diffdebug2(x1, x2) HDfprintf(stderr, "h5diff debug: " x1, x2)
-#define h5diffdebug3(x1, x2, x3) HDfprintf(stderr, "h5diff debug: " x1, x2, x3)
-#define h5diffdebug4(x1, x2, x3, x4) HDfprintf(stderr, "h5diff debug: " x1, x2, x3, x4)
-#define h5diffdebug5(x1, x2, x3, x4, x5) HDfprintf(stderr, "h5diff debug: " x1, x2, x3, x4, x5)
-#else
-#define h5diffdebug(x)
-#define h5diffdebug2(x1, x2)
-#define h5diffdebug3(x1, x2, x3)
-#define h5diffdebug4(x1, x2, x3, x4)
-#define h5diffdebug5(x1, x2, x3, x4, x5)
-#endif
-
 
 /*-------------------------------------------------------------------------
  * Function: print_objname
@@ -258,7 +241,6 @@ static int is_exclude_path (char * path, h5trav_type_t type, diff_opt_t *options
     struct exclude_path_list * exclude_path_ptr;
     int ret_cmp;
     int ret = 0;
-    int len_grp;
 
     /* check if exclude path option is given */
     if (!options->exclude_path)
@@ -277,6 +259,8 @@ static int is_exclude_path (char * path, h5trav_type_t type, diff_opt_t *options
                                 HDstrlen(exclude_path_ptr->obj_path));
             if (ret_cmp == 0)  /* found matching members */
             {
+                size_t len_grp;
+
                 /* check if given path belong to an excluding group, if so 
                  * exclude it as well.
                  * This verifies if “/grp1/dset1” is only under “/grp1”, but
@@ -355,7 +339,6 @@ static void free_exclude_path_list(diff_opt_t *options)
  *------------------------------------------------------------------------*/
 static void build_match_list (const char *objname1, trav_info_t *info1, const char *objname2, trav_info_t *info2, trav_table_t ** table_out, diff_opt_t *options)
 {
-    unsigned i;
     size_t curr1 = 0;
     size_t curr2 = 0;
     unsigned infile[2];
@@ -363,8 +346,8 @@ static void build_match_list (const char *objname1, trav_info_t *info1, const ch
     char * path2_lp;
     h5trav_type_t type1_l;
     h5trav_type_t type2_l;
-    int path1_offset = 0;
-    int path2_offset = 0;
+    size_t path1_offset = 0;
+    size_t path2_offset = 0;
     int cmp;
     trav_table_t *table;
     size_t  idx;
@@ -378,6 +361,7 @@ static void build_match_list (const char *objname1, trav_info_t *info1, const ch
      * All the objects belong to given groups are the cadidates.
      * So prepare to compare paths without the group names.
      */
+
     /* if obj1 is not root */
     if (HDstrcmp (objname1,"/") != 0)
         path1_offset = HDstrlen(objname1);
@@ -390,7 +374,6 @@ static void build_match_list (const char *objname1, trav_info_t *info1, const ch
     */
     while(curr1 < info1->nused && curr2 < info2->nused)
     {
-        
         path1_lp = (info1->paths[curr1].path) + path1_offset;
         path2_lp = (info2->paths[curr2].path) + path2_offset;
         type1_l = info1->paths[curr1].type;
@@ -399,7 +382,8 @@ static void build_match_list (const char *objname1, trav_info_t *info1, const ch
         /* criteria is string compare */
         cmp = HDstrcmp(path1_lp, path2_lp);
 
-        if(cmp == 0) {
+        if(cmp == 0)
+        {
             if(!is_exclude_path(path1_lp, type1_l, options))
             {
                 infile[0] = 1;
@@ -470,27 +454,6 @@ static void build_match_list (const char *objname1, trav_info_t *info1, const ch
     } /* end while */
 
     free_exclude_path_list (options);
-   /*------------------------------------------------------
-    * print the list
-    */
-    if(options->m_verbose)
-    {
-        parallel_print("\n");
-        /* if given objects is group under root */
-        if (HDstrcmp (objname1,"/") || HDstrcmp (objname2,"/"))
-            parallel_print("group1   group2\n");
-        else
-            parallel_print("file1     file2\n");
-        parallel_print("---------------------------------------\n");
-        for(i = 0; i < table->nobjs; i++) 
-        {
-            char c1, c2;
-            c1 = (table->objs[i].flags[0]) ? 'x' : ' ';
-            c2 = (table->objs[i].flags[1]) ? 'x' : ' ';
-            parallel_print("%5c %6c    %-15s\n", c1, c2, table->objs[i].name);
-        } /* end for */
-        parallel_print ("\n");
-    } /* end if */
 
     *table_out = table;
 }
@@ -651,8 +614,9 @@ hsize_t h5diff(const char *fname1,
     int i;
     int l_ret1 = -1;
     int l_ret2 = -1;
-    const char * obj1fullname = NULL;
-    const char * obj2fullname = NULL;
+    char * obj1fullname = NULL;
+    char * obj2fullname = NULL;
+    int both_objs_grp = 0;
     /* init to group type */
     h5trav_type_t obj1type = H5TRAV_TYPE_GROUP;
     h5trav_type_t obj2type = H5TRAV_TYPE_GROUP;
@@ -733,25 +697,25 @@ hsize_t h5diff(const char *fname1,
         /* make the given object1 fullpath, start with "/"  */
         if (HDstrncmp(objname1, "/", 1))
         {
-            HDstrcpy((char *)obj1fullname, "/");
-            HDstrcat((char *)obj1fullname, objname1);
+            HDstrcpy(obj1fullname, "/");
+            HDstrcat(obj1fullname, objname1);
         }
         else
-            HDstrcpy((char *)obj1fullname, objname1);
+            HDstrcpy(obj1fullname, objname1);
 
         /* make the given object2 fullpath, start with "/" */
         if (HDstrncmp(objname2, "/", 1))
         {
-            HDstrcpy((char *)obj2fullname, "/");
-            HDstrcat((char *)obj2fullname, objname2);
+            HDstrcpy(obj2fullname, "/");
+            HDstrcat(obj2fullname, objname2);
         }
         else
-            HDstrcpy((char *)obj2fullname, objname2);
+            HDstrcpy(obj2fullname, objname2);
 
         /*----------------------------------------------------------
          * check if obj1 is root, group, single object or symlink
          */
-        if(!HDstrcmp((char *)obj1fullname, "/"))
+        if(!HDstrcmp(obj1fullname, "/"))
         {
             obj1type = H5TRAV_TYPE_GROUP;
         }
@@ -778,6 +742,7 @@ hsize_t h5diff(const char *fname1,
              */
             if(src_linfo1.type == H5L_TYPE_HARD)
             {
+                int idx = 0;
                 /* optional data pass */
                 info1_obj->opts = (diff_opt_t*)options;
 
@@ -789,6 +754,9 @@ hsize_t h5diff(const char *fname1,
                 }
                 obj1type = oinfo1.type;
                 trav_info_add(info1_obj, obj1fullname, obj1type);
+                idx = info1_obj->nused - 1;
+                info1_obj->paths[idx].objno = oinfo1.addr;
+                info1_obj->paths[idx].fileno = oinfo1.fileno;
             }
             else if (src_linfo1.type == H5L_TYPE_SOFT)
             {
@@ -832,6 +800,7 @@ hsize_t h5diff(const char *fname1,
              */
             if(src_linfo2.type == H5L_TYPE_HARD)
             {
+                int idx = 0;
                 /* optional data pass */
                 info2_obj->opts = (diff_opt_t*)options;
 
@@ -843,6 +812,9 @@ hsize_t h5diff(const char *fname1,
                 }
                 obj2type = oinfo2.type;
                 trav_info_add(info2_obj, obj2fullname, obj2type);
+                idx = info2_obj->nused - 1;
+                info2_obj->paths[idx].objno = oinfo2.addr;
+                info2_obj->paths[idx].fileno = oinfo2.fileno;
             }
             else if (src_linfo2.type == H5L_TYPE_SOFT)
             {
@@ -861,15 +833,17 @@ hsize_t h5diff(const char *fname1,
     {
         /* set root group */
         obj1fullname = (char*)HDcalloc(2, sizeof(char));
-        HDstrcat((char *)obj1fullname, "/");
+        HDstrcat(obj1fullname, "/");
+        obj1type = H5TRAV_TYPE_GROUP;
         obj2fullname = (char*)HDcalloc(2, sizeof(char));
-        HDstrcat((char *)obj2fullname, "/");
+        HDstrcat(obj2fullname, "/");
+        obj2type = H5TRAV_TYPE_GROUP;
     }
 
 
     /* get any symbolic links info */
-    l_ret1 = H5tools_get_symlink_info(file1_id, obj1fullname, &trg_linfo1, TRUE);
-    l_ret2 = H5tools_get_symlink_info(file2_id, obj2fullname, &trg_linfo2, TRUE);
+    l_ret1 = H5tools_get_symlink_info(file1_id, obj1fullname, &trg_linfo1, options->follow_links);
+    l_ret2 = H5tools_get_symlink_info(file2_id, obj2fullname, &trg_linfo2, options->follow_links);
 
     /*---------------------------------------------
      * check for following symlinks 
@@ -913,7 +887,15 @@ hsize_t h5diff(const char *fname1,
             goto out;
         }
         else if(l_ret1 != 2) /* symbolic link */
+        {
             obj1type = trg_linfo1.trg_type;
+            if (info1_lp != NULL) {
+                int idx = info1_lp->nused - 1;
+                info1_lp->paths[idx].type = trg_linfo1.trg_type;
+                info1_lp->paths[idx].objno = trg_linfo1.objno;
+                info1_lp->paths[idx].fileno = trg_linfo1.fileno;
+            }
+        }
 
         /*-------------------------------
          * check symbolic link (object2)
@@ -949,11 +931,19 @@ hsize_t h5diff(const char *fname1,
             goto out;
         }
         else if(l_ret2 != 2)  /* symbolic link */
+        {
             obj2type = trg_linfo2.trg_type;
+            if (info2_lp != NULL) {
+                int idx = info2_lp->nused - 1;
+                info2_lp->paths[idx].type = trg_linfo2.trg_type;
+                info2_lp->paths[idx].objno = trg_linfo2.objno;
+                info2_lp->paths[idx].fileno = trg_linfo2.fileno;
+            }
+        }
     } /* end of if follow symlinks */
 
    /* 
-    * If verbose options is not used, don't need to traverse thorugh the list 
+    * If verbose options is not used, don't need to traverse through the list
     * of objects in the group to display objects information,
     * So use h5tools_is_obj_same() to improve performance by skipping 
     * comparing details of same objects. 
@@ -963,24 +953,22 @@ hsize_t h5diff(const char *fname1,
     {
         /* if no danglink links */
         if ( l_ret1 > 0 && l_ret2 > 0 )
-            if (h5tools_is_obj_same(file1_id,obj1fullname,file2_id,obj2fullname)!=0)
+            if (h5tools_is_obj_same(file1_id, obj1fullname, file2_id, obj2fullname)!=0)
                 goto out;
     }
 
-
-    /* if both obj1 and obj2 are group */
-    if (obj1type == H5TRAV_TYPE_GROUP && obj2type == H5TRAV_TYPE_GROUP)
+    both_objs_grp = (obj1type == H5TRAV_TYPE_GROUP && obj2type == H5TRAV_TYPE_GROUP);
+    if (both_objs_grp)
     {
-
-        /* 
-         * traverse group1 
+        /*
+         * traverse group1
          */
         trav_info_init(fname1, file1_id, &info1_grp);
         /* optional data pass */
         info1_grp->opts = (diff_opt_t*)options;
 
-        if(h5trav_visit(file1_id,obj1fullname,TRUE,TRUE,
-                        trav_grp_objs,trav_grp_symlinks, info1_grp) < 0)
+        if(h5trav_visit(file1_id, obj1fullname, TRUE, TRUE,
+                        trav_grp_objs, trav_grp_symlinks, info1_grp) < 0)
         {
             parallel_print("Error: Could not get file contents\n");
             options->err_stat = 1;
@@ -988,59 +976,71 @@ hsize_t h5diff(const char *fname1,
         }
         info1_lp = info1_grp;
 
-        /* 
-         * traverse group2 
+        /*
+         * traverse group2
          */
         trav_info_init(fname2, file2_id, &info2_grp);
         /* optional data pass */
         info2_grp->opts = (diff_opt_t*)options;
 
-        if(h5trav_visit(file2_id,obj2fullname,TRUE,TRUE,
-                        trav_grp_objs,trav_grp_symlinks, info2_grp) < 0)
+        if(h5trav_visit(file2_id, obj2fullname, TRUE, TRUE,
+                        trav_grp_objs, trav_grp_symlinks, info2_grp) < 0)
         {
             parallel_print("Error: Could not get file contents\n");
             options->err_stat = 1;
             goto out;
         } /* end if */
         info2_lp = info2_grp;
-
+    }
 
 #ifdef H5_HAVE_PARALLEL
-        if(g_Parallel)
-        {
-            if((HDstrlen(fname1) > MAX_FILENAME) || 
-               (HDstrlen(fname2) > MAX_FILENAME))
-            {
-                HDfprintf(stderr, "The parallel diff only supports path names up to %d characters\n", MAX_FILENAME);
-                MPI_Abort(MPI_COMM_WORLD, 0);
-            } /* end if */
-
-            HDstrcpy(filenames[0], fname1);
-            HDstrcpy(filenames[1], fname2);
-
-            /* Alert the worker tasks that there's going to be work. */
-            for(i = 1; i < g_nTasks; i++)
-                MPI_Send(filenames, (MAX_FILENAME * 2), MPI_CHAR, i, MPI_TAG_PARALLEL, MPI_COMM_WORLD);
-        } /* end if */
-#endif
-        build_match_list (obj1fullname, info1_lp, obj2fullname, info2_lp, 
-                         &match_list, options);
-        nfound = diff_match(file1_id, obj1fullname, info1_lp, 
-                            file2_id, obj2fullname, info2_lp, 
-                            match_list, options); 
-    }
-    else
+    if(g_Parallel)
     {
-#ifdef H5_HAVE_PARALLEL
-        if(g_Parallel)
-            /* Only single object diff, parallel workers won't be needed */
-            phdiff_dismiss_workers();
+        if((HDstrlen(fname1) > MAX_FILENAME) || (HDstrlen(fname2) > MAX_FILENAME))
+        {
+            HDfprintf(stderr, "The parallel diff only supports path names up to %d characters\n", MAX_FILENAME);
+            MPI_Abort(MPI_COMM_WORLD, 0);
+        } /* end if */
+
+        HDstrcpy(filenames[0], fname1);
+        HDstrcpy(filenames[1], fname2);
+
+        /* Alert the worker tasks that there's going to be work. */
+        for(i = 1; i < g_nTasks; i++)
+            MPI_Send(filenames, (MAX_FILENAME * 2), MPI_CHAR, i, MPI_TAG_PARALLEL, MPI_COMM_WORLD);
+    } /* end if */
 #endif
 
-        nfound = diff_compare(file1_id, fname1, obj1fullname, info1_lp,
-                              file2_id, fname2, obj2fullname, info2_lp,
-                              options);
+    /* process the objects */
+    build_match_list (obj1fullname, info1_lp, obj2fullname, info2_lp,
+                     &match_list, options);
+    if (both_objs_grp)
+    {
+        /*------------------------------------------------------
+         * print the list
+         */
+         if(options->m_verbose)
+         {
+             parallel_print("\n");
+             /* if given objects is group under root */
+             if (HDstrcmp (obj1fullname,"/") || HDstrcmp (obj2fullname,"/"))
+                 parallel_print("group1   group2\n");
+             else
+                 parallel_print("file1     file2\n");
+             parallel_print("---------------------------------------\n");
+             for(i = 0; i < match_list->nobjs; i++)
+             {
+                 char c1, c2;
+                 c1 = (match_list->objs[i].flags[0]) ? 'x' : ' ';
+                 c2 = (match_list->objs[i].flags[1]) ? 'x' : ' ';
+                 parallel_print("%5c %6c    %-15s\n", c1, c2, match_list->objs[i].name);
+             } /* end for */
+             parallel_print ("\n");
+         } /* end if */
     }
+    nfound = diff_match(file1_id, obj1fullname, info1_lp,
+                        file2_id, obj2fullname, info2_lp,
+                        match_list, options);
 
 out:
 #ifdef H5_HAVE_PARALLEL
@@ -1061,9 +1061,9 @@ out:
 
     /* free buffers */
     if (obj1fullname)
-        HDfree((char *)obj1fullname);
+        HDfree(obj1fullname);
     if (obj2fullname)
-        HDfree((char *)obj2fullname);
+        HDfree(obj2fullname);
 
     /* free link info buffer */
     if (trg_linfo1.trg_path)
@@ -1142,7 +1142,7 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
     *-------------------------------------------------------------------------
     */     
        
-    /* not valid compare nused when --exclude-path option is used */
+    /* not valid compare used when --exclude-path option is used */
     if (!options->exclude_path)
     {
         /* number of different objects */
@@ -1222,7 +1222,6 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
             {
                 int workerFound = 0;
 
-                h5diffdebug("beginning of big else block\n");
                 /* We're in parallel mode */
                 /* Since the data type of diff value is hsize_t which can
                 * be arbitary large such that there is no MPI type that
@@ -1247,7 +1246,6 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
                 args.argdata.type[1] = info2->paths[idx2].type;
                 args.argdata.is_same_trgobj = table->objs[i].is_same_trgobj;
 
-                h5diffdebug2("busyTasks=%d\n", busyTasks);
                 /* if there are any outstanding print requests, let's handle one. */
                 if(busyTasks > 0)
                 {
@@ -1319,7 +1317,6 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
                     } /* end if */
                 } /* end for */
 
-                h5diffdebug2("workerfound is %d \n", workerFound);
                 if(!workerFound)
                 {
                     /* if they were all busy, we've got to wait for one free up
@@ -1395,7 +1392,6 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
                 HDfree (obj2_fullpath);
         } /* end if */
     } /* end for */
-    h5diffdebug("done with for loop\n");
 
 #ifdef H5_HAVE_PARALLEL
     if(g_Parallel)
@@ -1411,14 +1407,6 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
                 options->not_cmp = options->not_cmp | nFoundbyWorker.not_cmp;
                 busyTasks--;
             } /* end if */
-            else if(Status.MPI_TAG == MPI_TAG_TOK_RETURN)
-            {
-                MPI_Recv(&nFoundbyWorker, sizeof(nFoundbyWorker), MPI_BYTE, Status.MPI_SOURCE, MPI_TAG_DONE, MPI_COMM_WORLD, &Status);
-                nfound += nFoundbyWorker.nfound;
-                options->not_cmp = options->not_cmp | nFoundbyWorker.not_cmp;
-                busyTasks--;
-                havePrintToken = 1;
-            } /* end else-if */
             else if(Status.MPI_TAG == MPI_TAG_TOK_REQUEST)
             {
                 MPI_Recv(NULL, 0, MPI_BYTE, Status.MPI_SOURCE, MPI_TAG_TOK_REQUEST, MPI_COMM_WORLD, &Status);
@@ -1490,7 +1478,6 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
         /* Print any final data waiting in our queue */
         print_incoming_data();
     } /* end if */
-    h5diffdebug("done with if block\n");
 
     HDfree(workerTasks);
     }
@@ -1504,130 +1491,6 @@ hsize_t diff_match(hid_t file1_id, const char *grp1, trav_info_t *info1,
 }
 
 
-/*-------------------------------------------------------------------------
- * Function: diff_compare
- *
- * Purpose: get objects from list, and check for the same type
- *
- * Return: Number of differences found
- *
- * Programmer: Pedro Vicente, pvn@ncsa.uiuc.edu
- * Date: May 9, 2003
- *
- * Programmer: Jonathan Kim
- *  - add following links feature (Feb 11,2010)
- *-------------------------------------------------------------------------
- */
-
-hsize_t diff_compare(hid_t file1_id,
-                     const char *file1_name,
-                     const char *obj1_name,
-                     trav_info_t *info1,
-                     hid_t file2_id,
-                     const char *file2_name,
-                     const char *obj2_name,
-                     trav_info_t *info2,
-                     diff_opt_t *options)
-{
-    int     f1 = 0;
-    int     f2 = 0;
-    hsize_t nfound = 0;
-    ssize_t i,j;
-    int l_ret;
-    int is_dangle_link1 = 0;
-    int is_dangle_link2 = 0;
-    const char *obj1name = obj1_name;
-    const char *obj2name = obj2_name;
-    diff_args_t argdata;
-
-    /* local variables for diff() */
-    h5trav_type_t obj1type, obj2type;
-
-    /* to get link info */
-    h5tool_link_info_t linkinfo1;
-    h5tool_link_info_t linkinfo2;
-
-    /* init link info struct */
-    HDmemset(&linkinfo1, 0, sizeof(h5tool_link_info_t));
-    HDmemset(&linkinfo2, 0, sizeof(h5tool_link_info_t));
-
-    i = h5trav_getindex (info1, obj1name);
-    j = h5trav_getindex (info2, obj2name);
-
-    if (i == -1)
-    {
-        parallel_print ("Object <%s> could not be found in <%s>\n", obj1name,
-            file1_name);
-        f1 = 1;
-    }
-    if (j == -1)
-    {
-        parallel_print ("Object <%s> could not be found in <%s>\n", obj2name,
-            file2_name);
-        f2 = 1;
-    }
-    if (f1 || f2)
-    {
-        options->err_stat = 1;
-        return 0;
-    }
-    /* use the name with "/" first, as obtained by iterator function */
-    obj1name = info1->paths[i].path;
-    obj2name = info2->paths[j].path;
-
-    obj1type = info1->paths[i].type;
-    obj2type = info2->paths[j].type;
-
-    /* Set argdata to pass other args into diff() */
-    argdata.type[0] = obj1type;
-    argdata.type[1] = obj2type;
-    argdata.is_same_trgobj = 0;
-
-    nfound = diff(file1_id, obj1name,
-                  file2_id, obj2name,
-                  options, &argdata);
-
-out:
-    /*-------------------------------
-     * handle dangling link(s) */
-    /* both obj1 and obj2 are dangling links */
-    if(is_dangle_link1 && is_dangle_link2)
-    {
-        if(print_objname(options, nfound))
-        {
-            do_print_objname("dangling link", obj1name, obj2name, options);
-            print_found(nfound);
-        }
-    }
-    /* obj1 is dangling link */
-    else if (is_dangle_link1)
-    {
-        if(options->m_verbose)
-           parallel_print("obj1 <%s> is a dangling link.\n", obj1name);
-        nfound++;
-        if(print_objname(options, nfound))
-            print_found(nfound);
-    }
-    /* obj2 is dangling link */
-    else if (is_dangle_link2)
-    {
-        if(options->m_verbose)
-            parallel_print("obj2 <%s> is a dangling link.\n", obj2name);
-        nfound++;
-        if(print_objname(options, nfound))
-            print_found(nfound);
-    }
-
-    /* free link info buffer */
-    if (linkinfo1.trg_path)
-        HDfree((char *)linkinfo1.trg_path);
-    if (linkinfo2.trg_path)
-        HDfree((char *)linkinfo2.trg_path);
-
-    return nfound;
-}
-
-
 /*-------------------------------------------------------------------------
  * Function: diff
  *
@@ -1661,6 +1524,8 @@ hsize_t diff(hid_t file1_id,
               diff_opt_t * options,
               diff_args_t *argdata)
 {
+    hid_t   dset1_id = (-1);
+    hid_t   dset2_id = (-1);
     hid_t   type1_id = (-1);
     hid_t   type2_id = (-1);
     hid_t   grp1_id = (-1);
@@ -1697,7 +1562,7 @@ hsize_t diff(hid_t file1_id,
          */
 
         /* target object1 - get type and name */
-        ret = H5tools_get_symlink_info(file1_id, path1, &linkinfo1, TRUE);
+        ret = H5tools_get_symlink_info(file1_id, path1, &linkinfo1, options->follow_links);
         /* dangling link */
         if (ret == 0)
         {
@@ -1715,7 +1580,7 @@ hsize_t diff(hid_t file1_id,
             goto out;
 
         /* target object2 - get type and name */
-        ret = H5tools_get_symlink_info(file2_id, path2, &linkinfo2, TRUE);
+        ret = H5tools_get_symlink_info(file2_id, path2, &linkinfo2, options->follow_links );
         /* dangling link */
         if (ret == 0)
         {
@@ -1826,6 +1691,10 @@ hsize_t diff(hid_t file1_id,
         *----------------------------------------------------------------------
         */
         case H5TRAV_TYPE_DATASET:
+            if((dset1_id = H5Dopen2(file1_id, path1, H5P_DEFAULT)) < 0)
+                goto out;
+            if((dset2_id = H5Dopen2(file2_id, path2, H5P_DEFAULT)) < 0)
+                goto out;
       /* verbose (-v) and report (-r) mode */
             if(options->m_verbose || options->m_report)
             {
@@ -1849,6 +1718,22 @@ hsize_t diff(hid_t file1_id,
                     print_found(nfound);  
                 }
             }
+
+
+            /*---------------------------------------------------------
+             * compare attributes
+             * if condition refers to cases when the dataset is a 
+             * referenced object
+             *---------------------------------------------------------
+             */
+            if(path1)
+                nfound += diff_attr(dset1_id, dset2_id, path1, path2, options);
+
+
+            if(H5Dclose(dset1_id) < 0)
+                goto out;
+            if(H5Dclose(dset2_id) < 0)
+                goto out;
             break;
 
        /*----------------------------------------------------------------------
