@@ -108,17 +108,17 @@ static void table_attrs_free( table_attrs_t *table )
  *------------------------------------------------------------------------*/
 static void table_attr_mark_exist(unsigned *exist, char *name, table_attrs_t *table)
 {
-    unsigned int new;
+    size_t new_val;
 
     if(table->nattrs == table->size) {
         table->size = MAX(1, table->size * 2);
         table->attrs = (match_attr_t *)HDrealloc(table->attrs, table->size * sizeof(match_attr_t));
     } /* end if */
 
-    new = table->nattrs++;
-    table->attrs[new].exist[0] = exist[0];
-    table->attrs[new].exist[1] = exist[1];
-    table->attrs[new].name = (char *)HDstrdup(name);
+    new_val = table->nattrs++;
+    table->attrs[new_val].exist[0] = exist[0];
+    table->attrs[new_val].exist[1] = exist[1];
+    table->attrs[new_val].name = (char *)HDstrdup(name);
 }
 
 /*-------------------------------------------------------------------------
@@ -207,6 +207,12 @@ static herr_t build_match_list_attrs(hid_t loc1_id, hid_t loc2_id, table_attrs_t
             table_lp->nattrs_only2++;
             curr2++;
         }
+
+        /* close for next turn */
+        H5Aclose(attr1_id);
+        attr1_id = -1;
+        H5Aclose(attr2_id);
+        attr2_id = -1;
     } /* end while */
 
     /* list1 did not end */
@@ -225,6 +231,10 @@ static herr_t build_match_list_attrs(hid_t loc1_id, hid_t loc2_id, table_attrs_t
         table_attr_mark_exist(infile, name1, table_lp);
         table_lp->nattrs_only1++;
         curr1++;
+
+        /* close for next turn */
+        H5Aclose(attr1_id);
+        attr1_id = -1;
     }
 
     /* list2 did not end */
@@ -243,6 +253,9 @@ static herr_t build_match_list_attrs(hid_t loc1_id, hid_t loc2_id, table_attrs_t
         table_attr_mark_exist(infile, name2, table_lp);
         table_lp->nattrs_only2++;
         curr2++;
+
+        /* close for next turn */
+        H5Aclose(attr2_id);
     }
 
     /*------------------------------------------------------
@@ -272,6 +285,11 @@ static herr_t build_match_list_attrs(hid_t loc1_id, hid_t loc2_id, table_attrs_t
     return 0;
 
 error:
+    if (0 < attr1_id)
+        H5Aclose(attr1_id);
+    if (0 < attr2_id)
+        H5Aclose(attr2_id);
+
     return -1;
 }
 
@@ -332,6 +350,13 @@ hsize_t diff_attr(hid_t loc1_id,
     if( build_match_list_attrs(loc1_id, loc2_id, &match_list_attrs, options) < 0)
         goto error;
 
+    /* if detect any unique extra attr */
+    if(match_list_attrs->nattrs_only1 || match_list_attrs->nattrs_only2)
+    {
+        /* exit will be 1 */
+        options->contents = 0;
+    }
+
     for(u = 0; u < (unsigned)match_list_attrs->nattrs; u++)
     {
         if( (match_list_attrs->attrs[u].exist[0]) && (match_list_attrs->attrs[u].exist[1]) )
@@ -405,6 +430,14 @@ hsize_t diff_attr(hid_t loc1_id,
             continue;
         }
 
+       /*-----------------------------------------------------------------
+        * "upgrade" the smaller memory size
+        *------------------------------------------------------------------
+        */
+        if (FAIL == match_up_memsize (ftype1_id, ftype2_id,
+                                      &mtype1_id, &mtype2_id, 
+                                      &msize1, &msize2))
+            goto error;
 
         /*---------------------------------------------------------------------
         * read
@@ -426,8 +459,8 @@ hsize_t diff_attr(hid_t loc1_id,
             goto error;
 
         /* format output string */
-        sprintf(np1,"%s of <%s>",name1,path1);
-        sprintf(np2,"%s of <%s>",name2,path2);
+        HDsnprintf(np1, sizeof(np1), "%s of <%s>", name1, path1);
+        HDsnprintf(np2, sizeof(np1), "%s of <%s>", name2, path2);
 
         /*---------------------------------------------------------------------
         * array compare
