@@ -36,6 +36,12 @@
 
 #define H5TOOLS_DUMP_MAX_RANK     H5S_MAX_RANK
 
+/* Stream macros */
+#define FLUSHSTREAM(S)           if(S != NULL) HDfflush(S)
+#define PRINTSTREAM(S, F, ...)   if(S != NULL) HDfprintf(S, F, __VA_ARGS__)
+#define PRINTVALSTREAM(S, V)   if(S != NULL) HDfprintf(S, V)
+#define PUTSTREAM(X,S)          if(S != NULL) HDfputs(X, S);
+
 /*
  * Strings for output - these were duplicated from the h5dump.h
  * file in order to support region reference data display
@@ -435,7 +441,7 @@ typedef struct h5tool_format_t {
      * indentlevel: a string that shows how far to indent if extra spacing
      *              is needed. dumper uses it.
      */
-    int         line_ncols;             /*columns of output             */
+    unsigned    line_ncols;             /*columns of output             */
     size_t      line_per_line;          /*max elements per line         */
     const char  *line_pre;              /*prefix at front of each line  */
     const char  *line_1st;              /*alternate pre. on first line  */
@@ -524,6 +530,7 @@ H5TOOLS_DLLVAR int     packed_bits_num;     /* number of packed bits to display
 H5TOOLS_DLLVAR int     packed_data_offset;  /* offset of packed bits to display */
 H5TOOLS_DLLVAR int     packed_data_length; /* lengtht of packed bits to display */
 H5TOOLS_DLLVAR unsigned long long packed_data_mask;  /* mask in which packed bits to display */
+H5TOOLS_DLLVAR FILE   *rawattrstream;       /* output stream for raw attribute data */
 H5TOOLS_DLLVAR FILE   *rawdatastream;       /* output stream for raw data */
 H5TOOLS_DLLVAR FILE   *rawoutstream;        /* output stream for raw output */
 H5TOOLS_DLLVAR FILE   *rawerrorstream;      /* output stream for raw error */
@@ -560,8 +567,7 @@ H5TOOLS_DLL void    h5tools_simple_prefix(FILE *stream, const h5tool_format_t *i
 H5TOOLS_DLL void    h5tools_region_simple_prefix(FILE *stream, const h5tool_format_t *info,
                             h5tools_context_t *ctx, hsize_t elmtno, hsize_t *ptdata, int secnum);
 
-H5TOOLS_DLL int     do_bin_output(FILE *stream, FILE *err_stream, hid_t container, hsize_t nelmts, hid_t tid, void *_mem);
-H5TOOLS_DLL int     render_bin_output(FILE *stream, hid_t container, hid_t tid, void *_mem);
+H5TOOLS_DLL int     render_bin_output(FILE *stream, hid_t container, hid_t tid, void *_mem, hsize_t nelmts);
 H5TOOLS_DLL int     render_bin_output_region_data_blocks(hid_t region_id, FILE *stream,
                             hid_t container, int ndims, hid_t type_id, hssize_t nblocks, hsize_t *ptdata);
 H5TOOLS_DLL hbool_t render_bin_output_region_blocks(hid_t region_space, hid_t region_id,
