@@ -48,6 +48,9 @@ typedef struct {
     hid_t fid;                      /* File ID being traversed */
 } trav_print_udata_t;
 
+/* format for hsize_t */
+#define HSIZE_T_FORMAT   "%"H5_PRINTF_LL_WIDTH"u"
+
 /*-------------------------------------------------------------------------
  * local functions
  *-------------------------------------------------------------------------
@@ -60,6 +63,46 @@ static void trav_table_addlink(trav_table_t *table,
                         haddr_t objno,
                         const char *path);
 
+/*-------------------------------------------------------------------------
+ * local variables
+ *-------------------------------------------------------------------------
+ */
+static H5_index_t trav_index_by = H5_INDEX_NAME;
+static H5_iter_order_t trav_index_order = H5_ITER_INC;
+
+static int trav_verbosity = 0;
+
+/*-------------------------------------------------------------------------
+ * Function: h5trav_set_index
+ *
+ * Purpose: Set indexing properties for the objects & links in the file
+ *
+ * Return: none
+ *
+ *-------------------------------------------------------------------------
+ */
+void
+h5trav_set_index(H5_index_t print_index_by, H5_iter_order_t print_index_order)
+{
+    trav_index_by = print_index_by;
+    trav_index_order = print_index_order;
+}
+
+/*-------------------------------------------------------------------------
+ * Function: h5trav_set_verbose
+ *
+ * Purpose: Set verbosity of file contents 1=>attributes
+ *
+ * Return: none
+ *
+ *-------------------------------------------------------------------------
+ */
+void
+h5trav_set_verbose(int print_verbose)
+{
+    trav_verbosity = print_verbose;
+}
+
 /*-------------------------------------------------------------------------
  * "h5trav info" public functions. used in h5diff
  *-------------------------------------------------------------------------
@@ -255,12 +298,12 @@ traverse(hid_t file_id, const char *grp_name, hbool_t visit_start,
         /* Check for iteration of links vs. visiting all links recursively */
         if(recurse) {
             /* Visit all links in group, recursively */
-            if(H5Lvisit_by_name(file_id, grp_name, H5_INDEX_NAME, H5_ITER_INC, traverse_cb, &udata, H5P_DEFAULT) < 0)
+            if(H5Lvisit_by_name(file_id, grp_name, trav_index_by, trav_index_order, traverse_cb, &udata, H5P_DEFAULT) < 0)
                 return -1;
         } /* end if */
         else {
             /* Iterate over links in group */
-            if(H5Literate_by_name(file_id, grp_name, H5_INDEX_NAME, H5_ITER_INC, NULL, traverse_cb, &udata, H5P_DEFAULT) < 0)
+            if(H5Literate_by_name(file_id, grp_name, trav_index_by, trav_index_order, NULL, traverse_cb, &udata, H5P_DEFAULT) < 0)
                 return -1;
         } /* end else */
 
@@ -311,6 +354,31 @@ trav_info_add(trav_info_t *info, const char *path, h5trav_type_t obj_type)
     info->paths[idx].objno = HADDR_UNDEF;
 } /* end trav_info_add() */
 
+
+/*-------------------------------------------------------------------------
+ * Function: trav_fileinfo_add
+ *
+ * Purpose: Add a file addr & fileno to info struct
+ *
+ * Return: void
+ *
+ *-------------------------------------------------------------------------
+ */
+void
+trav_fileinfo_add(trav_info_t *info, hid_t loc_id)
+{
+    H5O_info_t oinfo;
+    size_t idx = info->nused - 1;
+
+    if ( info->paths[idx].path && HDstrcmp(info->paths[idx].path, "."))
+      H5Oget_info_by_name(loc_id, info->paths[idx].path, &oinfo, H5P_DEFAULT);
+    else
+      H5Oget_info(loc_id, &oinfo);
+
+    info->paths[idx].objno = oinfo.addr;
+    info->paths[idx].fileno = oinfo.fileno;
+} /* end trav_fileinfo_add() */
+
 
 /*-------------------------------------------------------------------------
  * Function: trav_info_visit_obj
@@ -821,6 +889,72 @@ void trav_table_free( trav_table_t *table )
     HDfree(table);
 }
 
+static herr_t
+trav_attr(hid_t obj, const char *attr_name, const H5A_info_t UNUSED *ainfo, void *op_data)
+{
+    char               *buf;
+
+    buf = (char*)op_data;
+    if((strlen(buf)==1) && (*buf=='/'))
+        printf(" %-10s %s%s", "attribute", buf, attr_name);
+    else
+        printf(" %-10s %s/%s", "attribute", buf, attr_name);
+
+#ifdef H5TRAV_PRINT_SPACE
+    if(trav_verbosity < 2) {
+#endif
+        printf("\n");
+#ifdef H5TRAV_PRINT_SPACE
+    }
+    else {
+        hid_t               attr = -1;
+        hid_t               space = -1;
+        hsize_t             size[H5S_MAX_RANK];
+        int                 ndims;
+        int                 i;
+        H5S_class_t         space_type;
+
+        if((attr = H5Aopen(obj, attr_name, H5P_DEFAULT))) {
+            space = H5Aget_space(attr);
+
+            /* Data space */
+            ndims = H5Sget_simple_extent_dims(space, size, NULL);
+            space_type = H5Sget_simple_extent_type(space);
+            switch(space_type) {
+                case H5S_SCALAR:
+                    /* scalar dataspace */
+                    printf(" scalar\n");
+                    break;
+
+                case H5S_SIMPLE:
+                    /* simple dataspace */
+                    printf(" {");
+                    for (i=0; i<ndims; i++) {
+                        printf("%s" HSIZE_T_FORMAT, i?", ":"", size[i]);
+                    }
+                    printf("}\n");
+                    break;
+
+                case H5S_NULL:
+                    /* null dataspace */
+                    printf(" null\n");
+                    break;
+
+                default:
+                    /* Unknown dataspace type */
+                    printf(" unknown\n");
+                    break;
+            } /* end switch */
+
+            H5Sclose(space);
+            H5Aclose(attr);
+        }
+    }
+#endif
+
+    return(0);
+}
+
 
 /*-------------------------------------------------------------------------
  * Function: trav_print_visit_obj
@@ -837,8 +971,9 @@ void trav_table_free( trav_table_t *table )
  */
 static int
 trav_print_visit_obj(const char *path, const H5O_info_t *oinfo,
-    const char *already_visited, void UNUSED *udata)
+    const char *already_visited, void *udata)
 {
+    trav_print_udata_t *print_udata = (trav_print_udata_t *)udata;
     /* Print the name of the object */
     /* (no new-line, so that objects that we've encountered before can print
      *  the name of the original object)
@@ -862,9 +997,12 @@ trav_print_visit_obj(const char *path, const H5O_info_t *oinfo,
     } /* end switch */
 
     /* Check if we've already seen this object */
-    if(NULL == already_visited)
+    if(NULL == already_visited) {
         /* Finish printing line about object */
         printf("\n");
+        if(trav_verbosity > 0)
+            H5Aiterate_by_name(print_udata->fid, path, trav_index_by, trav_index_order, NULL, trav_attr, path, H5P_DEFAULT);
+    }
     else
         /* Print the link's original name */
         printf(" -> %s\n", already_visited);
