@@ -46,6 +46,7 @@ typedef struct {
     size_t ngroups;             /* Number of groups to create */
     char **groups;              /* Pointer to array of group names */
 } param_t;
+param_t params;             /* Command line parameter settings */
 
 
 /*-------------------------------------------------------------------------
@@ -62,8 +63,17 @@ typedef struct {
 static void
 leave(int ret)
 {
+    int curr_group;
+
+    if (params.fname)
+        HDfree (params.fname);
+    if (params.ngroups) {
+        for(curr_group = 0; curr_group < params.ngroups; curr_group++)
+            HDfree (params.groups[curr_group]);
+        HDfree (params.groups);
+    }
     h5tools_close();
-    exit(ret);
+    HDexit(ret);
 } /* end leave() */
 
 
@@ -81,7 +91,7 @@ leave(int ret)
 static void
 usage(void)
 {
-    fprintf(stdout, "\
+    HDfprintf(stdout, "\
 usage: h5mkgrp [OPTIONS] FILE GROUP...\n\
    OPTIONS\n\
       -h, --help         Print a usage message and exit\n\
@@ -97,8 +107,8 @@ usage: h5mkgrp [OPTIONS] FILE GROUP...\n\
  *
  * Purpose: Parses command line and sets up global variable to control output
  *
- * Return:	Success: 0
- *		Failure: -1
+ * Return:  Success: 0
+ *    Failure: -1
  *
  * Programmer: Quincey Koziol, 2/13/2007
  *
@@ -206,7 +216,6 @@ for(curr_group = 0; curr_group < params->ngroups; curr_group++)
 int
 main(int argc, const char *argv[])
 {
-    param_t params;             /* Command line parameter settings */
     hid_t fid;                  /* HDF5 file ID */
     hid_t fapl_id;              /* File access property list ID */
     hid_t lcpl_id;              /* Link creation property list ID */
@@ -322,6 +331,6 @@ main(int argc, const char *argv[])
     /* Shut down h5tools lib */
     h5tools_close();
 
-    return EXIT_SUCCESS;
+    leave(EXIT_SUCCESS);
 } /* end main() */
 
